@@ -1,8 +1,8 @@
 /*============================================================================*/
-/* ѹ                                                                   */
+/* 変更履歴                                                                   */
 /*----------------------------------------------------------------------------*/
-/* 1.0 : APIб(2003/06)                                             */
-/* 1.1 : -S10ʸޤǻǽˤ                                         */
+/* 1.0 : 新しいAPIに対応(2003/06)                                             */
+/* 1.1 : -Sを10文字まで指定可能にする                                         */
 /*============================================================================*/
   
 #include <musashi.h>
@@ -20,29 +20,29 @@
 
 #include <xml2xtHelp.h>
 struct mssComHelp comHelp={
-  "xml2xt",       /* ޥ̾       */
-  "1.1",          /* С       */
-  HELPT,          /* ޥɥȥ */                                    
-  HELPS,          /*              */
-  HELPE,          /*            */
-  HELPR,          /* ȥޥ     */
-  HELPA,          /* Ծ         */
-  HELPB,          /* ХݡȾ */
-  HELPH           /* ۡڡ     */
+  "xml2xt",       /* コマンド名       */
+  "1.1",          /* バージョン       */
+  HELPT,          /* コマンドタイトル */                                    
+  HELPS,          /* 要約             */
+  HELPE,          /* 利用例           */
+  HELPR,          /* 参照コマンド     */
+  HELPA,          /* 作者情報         */
+  HELPB,          /* バグレポート情報 */
+  HELPH           /* ホームページ     */
 };
 
 #define UNDEF 0
 #define MAX_NEST 32
 #define LOCAL_BUF 256
-#define EncMax MssFieldMaxLen  /*iconvǻȤʸĹ*/
+#define EncMax MssFieldMaxLen  /*iconvで使う出力用文字列長*/
 
 /*----------------------------------------------------------------------------*/
-/* ¤                                                                     */
+/* 構造体                                                                     */
 /*----------------------------------------------------------------------------*/
 
-/* -f ̾¤                                      */
+/* -f 項目名構造体                                      */
 /* ex) -f rec@id:recID                                  */
-/*        ǥѥ@°̾%ץ:̾           */
+/*        要素パス@属性名%オプション:新項目名           */
 /* data/rec@id%f:recID,/a/b@id%n:keyID                  */
 /*   eleNam[0][0]="data",[0][1]="rec",[0][2]=NULL       */
 /*   attNam[0]="id"                                     */
@@ -55,131 +55,131 @@ struct mssComHelp comHelp={
 /*   newNam[1]="keyID"                                  */
 
 struct XmlFld {
-  int   cnt;                       /*ܿ         */
-  char *element[MssFieldMaxCnt];   /*̾UTF8     */
-  char *attribute[MssFieldMaxCnt]; /*°̾UTF8     */
-  char  option[MssFieldMaxCnt];    /*ץ t:ƥ,f:ե饰,n:̾ */
-  char *field[MssFieldMaxCnt];     /*̾UTF8   */
+  int   cnt;                       /*項目数         */
+  char *element[MssFieldMaxCnt];   /*要素名UTF8     */
+  char *attribute[MssFieldMaxCnt]; /*属性名UTF8     */
+  char  option[MssFieldMaxCnt];    /*オプション t:テキスト,f:フラグ,n:名前 */
+  char *field[MssFieldMaxCnt];     /*新項目名UTF8   */
  };
 
 
 struct XmlKey {
-  char    **path;  /*-kǻꤵ줿ޤǶڤ줿ʸ*/
-  regex_t  *regex; /*ʸɽ˥ѥ뤷*/
-  int       cnt;   /*Ǥο*/
+  char    **path;  /*-kで指定されたカンマで区切られた文字列*/
+  regex_t  *regex; /*上の文字列を正規表現にコンパイルしたもの*/
+  int       cnt;   /*キー要素の数*/
 };
 
 typedef struct _XmlState {
-  int level;            /* ߽NodeΥ٥(rootNode=0) */
+  int level;            /* 現在処理中の要素Nodeのレベル(rootNode=0) */
 }XmlState;
 
 /*----------------------------------------------------------------------------*/
-/* Хѿ                                                             */
+/* グローバル変数                                                             */
 /*----------------------------------------------------------------------------*/
 extern xmlParserCtxtPtr ctxt;
 extern struct mssGlobalVariables mssGV;
 
-static struct mssFPW    *fpw; /*ϥե빽¤*/
-static struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
-static iconv_t *icid;   /*iconv Ѵϥɥ*/
-static char *inEnc=NULL; /*󥳡ǥ*/
-static char *inVer=NULL; /*С*/
-static char currentPath[4096]; /*߽Υѥ (/a/b/c/)*/
-static char *inKeyStartPath=NULL; /*-kǻꤷѥθ߽Хѥ*/
-static int inKey;/*߽Ǥ-kǻꤷ줫ΥѥäƤ뤫*/
-static int inFldNo[MssFieldMaxCnt];/*߽-fֹ*/
-static char   fldDat[MssFieldMaxCnt][MssFieldMaxLen];/*-fǻꤵ줿ƹܤμºݤ*/
+static struct mssFPW    *fpw; /*出力ファイル構造体*/
+static struct mssHeader *hdo; /*出力ファイル用<head>タグ格納構造体*/
+static iconv_t *icid;   /*iconv用 変換ハンドラ*/
+static char *inEnc=NULL; /*エンコーディング*/
+static char *inVer=NULL; /*バージョン*/
+static char currentPath[4096]; /*現在処理中のパス (/a/b/c/)*/
+static char *inKeyStartPath=NULL; /*-kで指定したパスからの現在処理中の相対パス*/
+static int inKey;/*現在処理中の要素が-kで指定したいずれかのパスに入ってるか*/
+static int inFldNo[MssFieldMaxCnt];/*現在処理中の-fの番号*/
+static char   fldDat[MssFieldMaxCnt][MssFieldMaxLen];/*-fで指定された各項目の実際の値*/
 static struct XmlKey *key;
 static struct XmlFld *fld;
 
 
 /*============================================================================*/
-/* ץ                                                       */
+/* オプション宣言＆定義                                                       */
 /*============================================================================*/
 /*----------------------------------------------------------------------------*/
-/* Ԥñ̤ȤʤXMLΥѥ̾                                            */
+/* 一行の単位となるXMLタグのパス名                                            */
 /*----------------------------------------------------------------------------*/
   MssOptSTR optKEY={
-    OSTR,   /* ץ󥿥                                             */
-    "k",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    NULL,   /* ǥե                                                   */
-    1,      /* ʸκǾĹ                                               */
-    256,    /* ʸκĹ                                               */
-    KEYT,   /* ΥץΥȥ(Helpɽ)                         */
-    KEYC    /* ΥץΥ(Helpɽ)                         */
+    OSTR,   /* オプションタイプ                                             */
+    "k",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    NULL,   /* デフォルト                                                   */
+    1,      /* 文字列の最小長                                               */
+    256,    /* 文字列の最大長                                               */
+    KEYT,   /* このオプションのタイトル(Helpで表示)                         */
+    KEYC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϤܤΥ̾                                                       */
+/* 出力する項目のタグ名                                                       */
 /*----------------------------------------------------------------------------*/
   MssOptSTR optFLD={
-    OSTR,   /* ץ󥿥                                             */
-    "f",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    NULL  , /* ǥե                                                   */
-    1,      /* ʸκǾĹ                                               */
-    1024,   /* ʸκĹ                                               */
-    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
-    FLDC    /* ΥץΥ(Helpɽ)                         */
+    OSTR,   /* オプションタイプ                                             */
+    "f",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    NULL  , /* デフォルト                                                   */
+    1,      /* 文字列の最小長                                               */
+    1024,   /* 文字列の最大長                                               */
+    FLDT,   /* このオプションのタイトル(Helpで表示)                         */
+    FLDC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* space򲿤Ѵ뤫                                                      */
+/* spaceを何に変換するか                                                      */
 /*----------------------------------------------------------------------------*/
   MssOptSTR optSPC={
-    OSTR,   /* ץ󥿥                                             */
-    "S",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    "_",    /* ǥե                                                   */
-    0,      /* ʸκǾĹ                                               */
-    10,     /* ʸκĹ                                               */
-    SPCT,   /* ΥץΥȥ(Helpɽ)                         */
-    SPCC    /* ΥץΥ(Helpɽ)                         */
+    OSTR,   /* オプションタイプ                                             */
+    "S",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    "_",    /* デフォルト                                                   */
+    0,      /* 文字列の最小長                                               */
+    10,     /* 文字列の最大長                                               */
+    SPCT,   /* このオプションのタイトル(Helpで表示)                         */
+    SPCC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 入力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptINF optINF={
-    OINF,   /* ץ󥿥                                             */
-    "i",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    1,      /* ǽκե                                     */
-    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
-    INFT,   /* ΥץΥȥ(Helpɽ)                         */
-    INFC    /* ΥץΥ(Helpɽ)                         */
+    OINF,   /* オプションタイプ                                             */
+    "i",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    1,      /* 指定可能の最大ファイル数                                     */
+    0,      /*1:file not foundのエラーで終了しない 0:する                   */
+    INFT,   /* このオプションのタイトル(Helpで表示)                         */
+    INFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 出力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptOTF optOTF={
-    OOTF,   /* ץ󥿥                                             */
-    "o",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
-    OTFC    /* ΥץΥ(Helpɽ)                         */
+    OOTF,   /* オプションタイプ                                             */
+    "o",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    OTFT,   /* このオプションのタイトル(Helpで表示)                         */
+    OTFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ̽                                                                   */
+/* 圧縮出力                                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optZIP={
-    OFLG,   /* ץ󥿥                                             */
-    "z",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
-    ZIPC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "z",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    ZIPT,   /* このオプションのタイトル(Helpで表示)                         */
+    ZIPC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ץޤȤ                                                       */
+/* オプションをまとめる                                                       */
 /*----------------------------------------------------------------------------*/
 void *opt[]={&optKEY,&optFLD,&optSPC,&optINF,&optOTF,&optZIP,NULL};
     
 /*----------------------------------------------------------------------------*/
-/* -k Υȡʬ+encoding                                                 */
+/* -k のトークン分割+encoding                                                 */
 /*----------------------------------------------------------------------------*/
 static void setXmlKey(void){
   int i;
@@ -189,7 +189,7 @@ static void setXmlKey(void){
   key=mssCalloc(sizeof(struct XmlKey),"setXmlKey");
   if(optKEY.set){
 
-    /* ޤˤȡʬ */
+    /* カンマによるトークン分割 */
     i=0;
     pos = strtok(optKEY.str,",");
     while(pos!=NULL){
@@ -198,7 +198,7 @@ static void setXmlKey(void){
     }
     key->cnt=i;
 
-    /* encoding path˥å */
+    /* encoding してpathにセット */
     key->path=mssCalloc(sizeof(char *),"xml2xt");
     for(i=0; i<key->cnt; i++){
       *(key->path+i)=mssEncoding(keyPos[i],icid);
@@ -230,22 +230,22 @@ static void freeXmlKey(struct XmlKey *key){
 }
 
 /*----------------------------------------------------------------------------*/
-/* -f Υȡʬ+encoding                                                 */
+/* -f のトークン分割+encoding                                                 */
 /* data/rec@id%f:recID,/a/b@id%n:keyID                                        */
 /*----------------------------------------------------------------------------*/
 static struct XmlFld *setXmlFld(){
   int i,j;
   char *pos;
   struct XmlFld *fld=NULL;
-  char *element[MssFieldMaxCnt];    /*encode̾     */
-  char *attribute[MssFieldMaxCnt];  /*encode°̾     */
-  char  option[MssFieldMaxCnt];     /*encodeΥץ */
-  char *field[MssFieldMaxCnt];      /*encodeο̾   */
+  char *element[MssFieldMaxCnt];    /*encode前の要素名     */
+  char *attribute[MssFieldMaxCnt];  /*encode前の属性名     */
+  char  option[MssFieldMaxCnt];     /*encode前のオプション */
+  char *field[MssFieldMaxCnt];      /*encode前の新項目名   */
   char tmp[4096];
 
   fld=mssCalloc(sizeof(struct XmlFld),"setXmlFld");
 
-  /*ޤΥȡʬ(̾Ƭɥ쥹򥻥å)*/
+  /*カンマのトークン分割(要素名の先頭アドレスをセット)*/
   /* data/rec@id%f:recID|/a/b@id%n:keyID              */
   fld->cnt=0;
   pos = strtok(optFLD.str,",");
@@ -260,7 +260,7 @@ static struct XmlFld *setXmlFld(){
     pos=strtok(NULL,",");
   }
 
-  /*ǥȡʬ(̾Υå:strdup)*/
+  /*コロンでトークン分割(新項目名のセット:strdup)*/
   /* data/rec@id%f|recID|/a/b@id%n|keyID  */
   for(i=0; i<fld->cnt; i++){
     pos=strchr(element[i],':');
@@ -272,7 +272,7 @@ static struct XmlFld *setXmlFld(){
     }
   }
 
-  /*%ǥȡʬ(ץΥå)  */
+  /*%でトークン分割(オプションのセット)  */
   /* data/rec@id|f|recID|/a/b@id|n|keyID  */
   for(i=0; i<fld->cnt; i++){
     j=0;
@@ -285,15 +285,15 @@ static struct XmlFld *setXmlFld(){
     }
   }
 
-  /*ʳǿ̾ꤵƤʤС
-    ̾+°̾򿷹̾ȤϿ*/
+  /*この段階で新項目名が指定されていなければ、
+    要素名+属性名を新項目名として登録する*/
   for(i=0; i<fld->cnt; i++){
     if(field[i]==NULL){
       field[i]=mssStrdup(element[i]);
     }
   }
 
-  /*@ǥȡʬ(°̾Υå)*/
+  /*@でトークン分割(属性名のセット)*/
   /* data/rec|id|f|recID|/a/b|id|n|keyID  */
   for(i=0; i<fld->cnt; i++){
     pos=strchr(element[i],'@');
@@ -306,12 +306,12 @@ static struct XmlFld *setXmlFld(){
   }
 
   /*-----------------------------------*/
-  /*UTF8ؤencoding + ¤ΤؤΥå*/
+  /*UTF8へのencoding + 構造体へのセット*/
   /*-----------------------------------*/
   for(i=0; i<fld->cnt; i++){
 
-    /**/
-    /* ǤκǸ"/"ä */
+    /*要素*/
+    /* 要素の最後に"/"を加える */
     if(*(element[i]+strlen(element[i])-1)!='/'){
       strcpy(tmp,element[i]);
       strcat(tmp,"/");
@@ -320,13 +320,13 @@ static struct XmlFld *setXmlFld(){
     }
     fld->element[i]=mssEncoding(tmp,icid);
 
-    /*°*/
+    /*属性*/
     fld->attribute[i]=mssEncoding(attribute[i],icid);
 
-    /*ѥ᡼*/
+    /*パラメータ*/
     fld->option[i]=option[i];
 
-    /*̾*/
+    /*新項目名*/
     fld->field[i]=mssEncoding(field[i],icid);
   }
 
@@ -360,14 +360,14 @@ static void writeEncStr(char *str){
   }
 }
 
-/*ǥߥʸ(\t,\n)ʸѴ*/
+/*デリミタ文字(\t,\n)を指定の文字列に変換する*/
 static char *chgSpc(char *str){
   int repStrLen;
   int cnt;
   char *pos;
   char *last;
-  char *newStr; /*DelimiterʸѴ¸ʸΰ*/
-  char *retStr; /*Ѥʸ*/
+  char *newStr; /*Delimiter文字を変換して保存する文字列領域*/
+  char *retStr; /*返値用の文字列*/
 
   if(str==NULL) return(NULL);
 
@@ -376,13 +376,13 @@ static char *chgSpc(char *str){
 
   repStrLen=strlen(optSPC.str);
 
-  /*Delimiterʸ򥹥å*/
+  /*左のDelimiter文字をスキップ*/
   while(*str!='\0'){
     if(*str!=MssFieldDelim && *str!='\n') break;
     str++;
   }
 
-  /*Delimiterʸʤ*/
+  /*右のDelimiter文字を省く*/
   last=str+strlen(str)-1;
   if(str==last+1) return(newStr);
   while(*last==MssFieldDelim || *last=='\n'){
@@ -393,7 +393,7 @@ static char *chgSpc(char *str){
   pos=newStr;
   while(*str!='\0'){
     if(*str==MssFieldDelim || *str=='\n'){
-      /*ܺĹĶ餽Ǥڤ*/
+      /*項目最大長を超えたらそこで打ち切り*/
       if(cnt+repStrLen>=MssFieldMaxLen-1){
         break;
       }
@@ -413,7 +413,7 @@ static char *chgSpc(char *str){
   return(retStr);
 }
  
-/*fldDat*/
+/*fldDatを出力*/
 static void printDat(XmlState *state){
   int fn;
   char *str;
@@ -431,12 +431,12 @@ static void printDat(XmlState *state){
   mssGV.outCnt++;
 }
 
-/*fldDat򥯥ꥢ*/
+/*fldDatをクリア*/
 static void clearFldDat(XmlState *state){
   int i;
 
   for(i=0; i<fld->cnt; i++){
-    /*Хѥ()ιܤϥꥢʤ*/
+    /*絶対パス指定(キー要素)の項目はクリアしない*/
     if(*fld->element[i]!='/') fldDat[i][0]='\0';
   }
 }
@@ -470,7 +470,7 @@ void Strncat(char *to, char *from, int len){
 }
 
 /*----------------------------------------------------------------------------*/
-/* SAX ϥɥ顼                                                             */
+/* SAX ハンドラー                                                             */
 /*----------------------------------------------------------------------------*/
 /*############## start_doc */
 void start_doc(XmlState *state){
@@ -480,39 +480,39 @@ void start_doc(XmlState *state){
   inVer=mssStrdup((char *)ctxt->version);
   if(inEnc==NULL) inEnc=mssStrdup("UTF-8");
 
-  /*ѥ᡼Ѥiconvץ                                   */
-  /*xmlޥɤΥѥ᡼ϥǡϥǡencoding     */
-  /*ơϥǡΥ󥳡ǥ󥰤ȤʤȤ˺롣*/
+  /*パラメータ用のiconvオープン                                   */
+  /*xmlコマンドのパラメータ、入力データ、出力データのencoding     */
+  /*は全て、入力データのエンコーディングとおなじことを前提に作る。*/
   icid=iconv_open("UTF-8",inEnc);
   if((int)icid==-1) {
     mssShowErrMsg("encoding type error in iconv_open");
     mssEnd(mssErrorNoDefault);
   }
 
-  /* -k,-f ѥ᡼Υå+UTF-8Ѵ */
+  /* -k,-f パラメータのセット+漢字をUTF-8に変換 */
   setXmlKey();
   fld=setXmlFld(key);
 
-  /*ѥ᡼Ѥiconv*/
+  /*パラメータ用のiconvクローズ*/
   if(icid!=NULL) iconv_close(icid);
 
-  /*Ϥiconvץ*/
+  /*出力のiconvオープン*/
   icid=iconv_open(inEnc,"UTF-8");
   if((int)icid==-1) {
     mssShowErrMsg("encoding type error in iconv_open");
     mssEnd(mssErrorNoDefault);
   }
 
-  /*ϥإåκȽ   */
+  /*出力ヘッダーの作成と出力   */
   hdo=mssInitHeader(NULL,NULL);
   for(i=0; i<fld->cnt; i++){
     mssAddFieldsByStr( hdo->flds, mssEncoding(fld->field[i],icid) );
   }
 
-  /*xmlTableإåν񤭽Ф*/
+  /*xmlTableヘッダーの書き出し*/
   mssWriteHeader(hdo, fpw);
 
-  /* currentPathν */
+  /* currentPathの初期化 */
   currentPath[0]='/';
   currentPath[1]='\0';
 
@@ -523,36 +523,36 @@ void start_doc(XmlState *state){
 
 /*############## end_doc */
 void end_doc(XmlState *state){
-  /*Ѥiconv*/
+  /*出力用のiconvクローズ*/
   if(icid!=NULL) iconv_close(icid);
 }
 
-/*-kΥäʤ1֤¾0*/
+/*-kのキーに入ったならば1を返す。その他は0。*/
 static int isInKey(void){
   int i;
   for(i=0; i<key->cnt; i++){
-    /*0ǥޥå*/
+    /*0でマッチ*/
     if(0==regexec(key->regex+i,currentPath,0,NULL,0)) return(1);
   }
   return(0);
 }
 
 /*----------------------------------------------*/
-/*-fǤäʤСǤֹ֤*/
-/* inFldNo[]ƤϤޤֹ򥻥åȤ    */
-/* inFldCntˤιܿ򥻥åȤ롣           */
+/*-fの要素に入ったならば、その要素の番号を返す。*/
+/* inFldNo[]に当てはまる項目番号をセットし、    */
+/* inFldCntにその項目数をセットする。           */
 /*----------------------------------------------*/
 static void setInFld(){
   int i;
 
   for(i=0; i<fld->cnt; i++){
-    if(*fld->element[i]=='/'){ /* ----- Хѥξ ( -f /a/b ) */
+    if(*fld->element[i]=='/'){ /* ----- 絶対パスの場合 ( -f /a/b ) */
       if(currentPath!=NULL){
         if(0==strcmp(currentPath,fld->element[i])){
           inFldNo[i]=1;
         }
       }
-    }else{                     /* ----- Хѥξ ( -f a/b ) */
+    }else{                     /* ----- 相対パスの場合 ( -f a/b ) */
       if(inKeyStartPath!=NULL){
         if(0==strcmp(inKeyStartPath,fld->element[i])){
           inFldNo[i]=1;
@@ -566,13 +566,13 @@ static void unsetInFld(){
   int i;
 
   for(i=0; i<fld->cnt; i++){
-    if(*fld->element[i]=='/'){ /* ----- Хѥξ ( -f /a/b ) */
+    if(*fld->element[i]=='/'){ /* ----- 絶対パスの場合 ( -f /a/b ) */
       if(currentPath!=NULL){
         if(0==strcmp(currentPath,fld->element[i])){
           inFldNo[i]=0;
         }
       }
-    }else{                     /* ----- Хѥξ ( -f a/b ) */
+    }else{                     /* ----- 相対パスの場合 ( -f a/b ) */
       if(inKeyStartPath!=NULL){
         if(0==strcmp(inKeyStartPath,fld->element[i])){
           inFldNo[i]=0;
@@ -606,60 +606,60 @@ void start_element(XmlState *state, char *fullname, char **atts){
 
   mssGV.inCnt++;
 
-  /*ߤΥΡɥѥ򹹿*/
+  /*現在のノードパスを更新*/
   strcat(currentPath,fullname);
   strcat(currentPath,"/");
 
-  /*-kΥäɤ*/
+  /*-kのキーに入ったかどうか*/
   inKey=isInKey();
 //printf("curPath=%s(%d)\n",currentPath,inKey);
 
-  /*ƥä γʸ֤򥻥å*/
+  /*初めてキーに入った場合 キー内の開始文字位置をセット*/
   if(prvInKey==0 && inKey==1){
     inKeyStartPath=currentPath+strlen(currentPath);
   }
 
-  /*-fǻꤷɤǤäƤ뤫*/
+  /*-fで指定したどの要素に入っているか*/
   setInFld();
 
   for(i=0; i<fld->cnt; i++){
     if(inFldNo[i]){
-      /*°ܤξ(<a id="aaa">)*/
+      /*属性指定項目の場合(<a id="aaa">)*/
       if(fld->attribute[i]!=NULL){
         attVal=getAttVal(fld->attribute[i],atts);
         if( attVal!=NULL ){
           switch(fld->option[i]){
-          case 'f': /*ե饰*/
+          case 'f': /*フラグ*/
             fldDat[i][0]='1';
             fldDat[i][1]='\0';
             break;
-          case 'n': /*̾(̾+°̾)*/
+          case 'n': /*名前(要素名+属性名)*/
             Strncpy(fldDat[i],currentPath,strlen(currentPath));
-            fldDat[i][strlen(currentPath)-1]='\0'; /*Ǹ"/"ä*/
+            fldDat[i][strlen(currentPath)-1]='\0'; /*最後の"/"を消す*/
             Strncat(fldDat[i],"@",1);
             Strncat(fldDat[i],fld->attribute[i],strlen(fld->attribute[i]));
             break;
-          default: /*ƥ(ǥե)*/
+          default: /*テキスト(デフォルト)*/
             Strncpy(fldDat[i],attVal,strlen(attVal));
             break;
           }
         }
 
-      /*ǻܤξ(<a>)*/
+      /*要素指定項目の場合(<a>)*/
       }else{
         switch(fld->option[i]){
-        case 'f': /*ե饰*/
+        case 'f': /*フラグ*/
           fldDat[i][0]='1';
           fldDat[i][1]='\0';
           break;
-        case 'n': /*̾(̾+°̾)*/
+        case 'n': /*名前(要素名+属性名)*/
           Strncpy(fldDat[i],currentPath,strlen(currentPath));
-          fldDat[i][strlen(currentPath)-1]='\0'; /*Ǹ"/"ä*/
+          fldDat[i][strlen(currentPath)-1]='\0'; /*最後の"/"を消す*/
           break;
-        default: /*ƥ(ǥե)*/
-          /*ƥȻξ(<a>text</a>)characerˤƥåȤ*/
-          /*ƱǤФ褿ȤΤˡΥǡ򥯥ꥢ*/
-          fldDat[i][0]='\0'; /*Ǹ"/"ä*/
+        default: /*テキスト(デフォルト)*/
+          /*要素内テキスト指定の場合(<a>text</a>)はcharacerにてセットする*/
+          /*同じ要素が出て来たときのために、前のデータをクリアする*/
+          fldDat[i][0]='\0'; /*最後の"/"を消す*/
           break;
         }
       }
@@ -677,23 +677,23 @@ void end_element(XmlState *state, char *fullname, char **atts){
 
   state->level--;
 
-  /*ߤΥΡɥѥ򹹿*/
+  /*現在のノードパスを更新*/
   pos=currentPath+strlen(currentPath)-2;
   while(*pos!='/') pos--;
   *(++pos)='\0';
 
-  /*end_elementǥФʤ*/
+  /*今回のend_elementでキーを出たならば*/
   inKey=isInKey();
   if(prvInKey==1 && inKey==0){
-    /*Ф γʸ֤NULL˥å*/
+    /*キーから出る場合 キー内の開始文字位置をNULLにセット*/
     inKeyStartPath=NULL;
-    /*ǡ*/
+    /*データ出力*/
     printDat(state);
     clearFldDat(state);
   }
 
-  /*-fǻꤷɤǤäƤ뤫*/
-  /*end_elementǤϡƥȻܤλΤߡĴ*/
+  /*-fで指定したどの要素に入っているか*/
+  /*end_elementでは、テキスト指定項目の時のみ、調査する*/
 
 }
 
@@ -703,11 +703,11 @@ void start_characters(XmlState *state, xmlChar *chars, int len){
 
   for(i=0; i<fld->cnt; i++){
     if(inFldNo[i]){
-      /*°ǤʤǤξ*/
+      /*属性でなく、要素の場合*/
       if(fld->attribute[i]==NULL){
-        /*%n,%fǤʤ*/
+        /*%n,%fでない場合*/
         if(fld->option[i]==0){
-          /* fldDat[i][0]='\0'; start_elementǥꥢѹ*/
+          /* fldDat[i][0]='\0'; start_elementでクリアに変更*/
           Strncat(fldDat[i],chars,len);
         }
       }
@@ -774,11 +774,11 @@ int main(int argc, char *argv[]){
   char *fname;
 
 /*----------------------------------------------------------------------------*/
-/*                                                                      */
+/* 前処理                                                                     */
 /*----------------------------------------------------------------------------*/
-  mssInit(argc,argv,&comHelp); /* ʥʤɤν     */
-  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                       */
-  mssSetOption(opt,argc,argv);    /* ޥɥץ     */
+  mssInit(argc,argv,&comHelp); /* シグナル処理などの初期化     */
+  mssHelpDoc(opt,&comHelp,argc,argv);/* ヘルプ                       */
+  mssSetOption(opt,argc,argv);    /* コマンドオプションの設定     */
 
 /*prnOption(opt);*/
 
@@ -790,10 +790,10 @@ int main(int argc, char *argv[]){
     }
   }
 
-  fpw=mssOpenFPW(optOTF.str,optZIP.set,0); /*ɸϥץ*/
+  fpw=mssOpenFPW(optOTF.str,optZIP.set,0); /*標準出力オープン*/
 
 /*----------------------------------------------------------------------------*/
-/*ᥤ롼                                                              */
+/*メインルーチン                                                              */
 /*----------------------------------------------------------------------------*/
   state=mssCalloc(sizeof(XmlState),"xml2xt");
   state->level = 0;
@@ -819,13 +819,13 @@ int main(int argc, char *argv[]){
   mssFree(state);
 
 /*----------------------------------------------------------------------------*/
-/*եå&λ                                                       */
+/*フッター出力&終了処理                                                       */
 /*----------------------------------------------------------------------------*/
-  mssWriteFooter(fpw);    /*եåν*/
-  mssCloseFPW(fpw);       /*ϥեΥ*/
-  mssFreeHeader(hdo);     /*ϥإåΰ賫*/
-  mssFreeOption(opt);     /*ץΰ賫*/
-  mssShowEndMsg();        /*λå*/
-  mssEnd(mssExitSuccess); /*λ*/
+  mssWriteFooter(fpw);    /*フッターの出力*/
+  mssCloseFPW(fpw);       /*出力ファイルのクローズ*/
+  mssFreeHeader(hdo);     /*出力ヘッダ領域開放*/
+  mssFreeOption(opt);     /*オプション領域開放*/
+  mssShowEndMsg();        /*完了メッセージ*/
+  mssEnd(mssExitSuccess); /*終了*/
   return(0); /* to avoid warning message*/
 }
