@@ -1,10 +1,10 @@
 
 /*============================================================================*/
-/* ѹ                                                                   */
+/* 変更履歴                                                                   */
 /*----------------------------------------------------------------------------*/
-/* 1.0 : APIб 2003/06/20                                           */
-/* 1.1 : ХåȤοϰϤϲǽˤ 2004/08/09                        */
-/* 1.2 : ꡼ 2004/10/31                                          */
+/* 1.0 : 新しいAPIに対応 2003/06/20                                           */
+/* 1.1 : バケットの数値範囲を出力可能にする 2004/08/09                        */
+/* 1.2 : メモリリーク修正 2004/10/31                                          */
 /*============================================================================*/
 #include <musashi.h>
 #include <stdlib.h>
@@ -13,15 +13,15 @@
 
 #include <xtbucketHelp.h>
 struct mssComHelp comHelp={
-  "xtbucket",     /* ޥ̾       */
-  "1.2",          /* С       */
-  HELPT,          /* ޥɥȥ */
-  HELPS,          /*              */
-  HELPE,          /*            */
-  HELPR,          /* ȥޥ     */
-  HELPA,          /* Ծ         */
-  HELPB,          /* ХݡȾ */
-  HELPH           /* ۡڡ     */
+  "xtbucket",     /* コマンド名       */
+  "1.2",          /* バージョン       */
+  HELPT,          /* コマンドタイトル */
+  HELPS,          /* 要約             */
+  HELPE,          /* 利用例           */
+  HELPR,          /* 参照コマンド     */
+  HELPA,          /* 作者情報         */
+  HELPB,          /* バグレポート情報 */
+  HELPH           /* ホームページ     */
 };
 
 extern struct mssGlobalVariables mssGV;
@@ -45,24 +45,24 @@ struct rTbl { /*range table*/
   double to;
 };
 
-static struct ctbl *cTable;       /*ͤȤηä*/
-static long         cTableCnt;    /*cTableϿƤ*/
-static long         cTableMaxCnt; /*cTableϿǽ(malloc)*/
+static struct ctbl *cTable;       /*値とその件数の入った配列*/
+static long         cTableCnt;    /*各cTable配列に登録されている件数*/
+static long         cTableMaxCnt; /*各cTable配列に登録可能最大件数(malloc)*/
 
 static struct kTbl   *kTable;
 static struct rTbl   *rTable;
 static unsigned long *sTable;
 static struct rTbl   **rTables;
 
-int cutCnt; /*ºݤʬ*/
+int cutCnt; /*実際の分割数*/
 
 void insertValue(
-  double value,	/**/
-  int    start	/*륹Ȱ*/
+  double value,	/*挿入する値*/
+  int    start	/*挿入するスタート位置*/
                  ){
   int i;
 
-  /*ꥪСΥꥢMALLOC_CNTñ̤ */
+  /*メモリオーバー時のリアロケーション（MALLOC_CNT行単位で増える） */
   if( cTableCnt >= cTableMaxCnt) {
     cTableMaxCnt+=MALLOC_CNT;
     cTable = (struct ctbl *)mssRealloc(cTable,
@@ -79,8 +79,8 @@ void insertValue(
 }
 
 void setCntTable(char *str){
-  /*Хʥꥵõ륹Ȱ֤ȥɰ֤Ȥ*/
-  double value; /*ơ֥˥åȤ*/
+  /*バイナリサーチで探索するスタート位置とエンド位置とその中間値*/
+  double value; /*テーブルにセットする値*/
   int start;
   int end;
   int try=0;
@@ -88,8 +88,8 @@ void setCntTable(char *str){
   if(MssIsNull(str))return;
 
   value=atof(str);
-  /*õƱͤơ֥˸ĤХȥå*/
-  /*Ĥʤstartΰ֤ˤͤ*/
+  /*探索中に同じ値がテーブルに見つかればカウントアップ*/
+  /*見つからなければstartの位置にその値を挿入する*/
   start=0;
   end=cTableCnt-1;
   while(start<=end){
@@ -103,20 +103,20 @@ void setCntTable(char *str){
       return;
     }
   }
-  /*õǸĤʤФͤơ֥˿Ͽ*/
+  /*探索で見つからなければその値をテーブルに新規登録*/
   insertValue(value, start);
   return;
 }
 
 
 /*----------------------------------------------------------------------------*/
-/*ǡΥؤΥå
-cTable[i]˥åȤ if=ǻꤷֹ򣰤֤˳꿶äֹ
-                        ex)f=2,5ξ cTable[0]2,cTable[1]5
-cTable[i]mallocǳݤ줿ΰƬɥ쥹åȤ롣
-ΰϼι¤ΤΥǡ¤
-double Val;        
-unsigned long Cnt; ͤνи
+/*データのメモリへのセット
+cTable[i]にセットされる iはf=で指定した項目番号を０から順番に割り振った番号
+                        ex)f=2,5の場合 cTable[0]が項目2,cTable[1]が項目5
+cTable[i]にmallocで確保された領域の先頭アドレスがセットされる。
+領域は次の構造体のデータ構造を持つ
+double Val;        値
+unsigned long Cnt; その値の出現件数
 */
 /*----------------------------------------------------------------------------*/
 struct ctbl *setcTable(struct mssFldRecKey *frk,int fldNo){
@@ -128,11 +128,11 @@ struct ctbl *setcTable(struct mssFldRecKey *frk,int fldNo){
 
   mssSeekTopFRK(frk);
   while( EOF != mssReadFldRecFRK(frk) ){
-    /*ܤͤ򥻥åȤ*/
+    /*項目の値をセットする*/
     setCntTable(*(frk->pnt+fldNo));
   }
 
-/* ǥХåꥹ*/
+/* デバッグリスト*/
 /*
   for(i=0; i<cTableCnt; i++){
     printf("field[%d] %g - %ld\n",i,(cTable+i)->Val,(cTable+i)->Cnt);
@@ -141,8 +141,8 @@ struct ctbl *setcTable(struct mssFldRecKey *frk,int fldNo){
   return(cTable);
 }
 
-/*cTableˤơstartendޤǤη¤*/
-/*ʬǾϷºǾΤ*/
+/*cTableにおいて、startからendまでの件数二乗和を求める*/
+/*分散最小化は件数の二乗和最小化に等しいので*/
 double calVariance( int start, int end){
   double result=0;
   int i;
@@ -153,14 +153,14 @@ double calVariance( int start, int end){
 }
 
 /*----------------------------------------------------------------------------*/
-/* ŬåȥݥȤ                                                 */
+/* 最適カットポイントを求める                                                 */
 /*----------------------------------------------------------------------------*/
 /*
 Algorithm by N.Katoh
-kTableȤϡʬǾ뤿Υơ֥ǰʲΤ褦ʹ¤Ȥ
-kTablerTable롣
+kTableとは、分散最小化を求めるためのワークテーブルで以下のような構造をとる
+kTableからrTableが作られる。
 
-ʬ 1    2    3    ... k
+分割数 値1    値2    値3    ... 値k
      1 a(1,1) a(1,2) a(1,3) ... a(1,k)
      2 a(2,1) a(2,2) a(2,3) ... a(2,k)
      3 a(3,1) a(3,2) a(3,3) ... a(3,k)
@@ -168,17 +168,17 @@ kTablerTable롣
      .   .      .      .    ...   .
      j a(j,1) a(j,2) a(j,3) ... a(j,k)
 
-a(j,k)ˤϼι¤Τ
+a(j,k)には次の構造体を持つ
            double minVar;
   unsigned long prvNo;
   unsigned long from;
   unsigned long to;
-minVarϡkĤͤˤĤjʬ䤷ȤκǾʬ
-ʬͤѤɬפϤʤñ˷Σͤؤ뤳ȤǤ
-prvNoϡjʬξˡǾʬͤĤ褦j-1ʬk
-from,toϡjʬξˡǾʬͤĤ褦jܤʬϰϡ
+minVarは、k個の値についてj分割したときの最小分散値
+ただし、分散値は用いる必要はなく、単に件数の２乗値で代替することができる
+prvNoは、j分割の場合に、最小分散値を持つようなj-1分割時のk。
+from,toは、j分割の場合に、最小分散値を持つようなj番目の分割範囲。
 
-ʬιԤϡºݤˤcTableηΣ¤äƤ
+分割数１の行は、実際にはcTableの件数の２乗和が入っている
 */
 /*----------------------------------------------------------------------------*/
 void calOptCutPoint(int cutNum){
@@ -192,7 +192,7 @@ void calOptCutPoint(int cutNum){
   struct kTbl *tmpKtbl;
   int j,k,l;
 
-  /* cTableCnt==0 ȤȤϡͤNULL */
+  /* cTableCnt==0 ということは、値が全てNULL */
   if(cTableCnt==0){
     kTable=NULL;
     sTable=NULL;
@@ -201,24 +201,24 @@ void calOptCutPoint(int cutNum){
     return;
   }
 
-  maxCnt=cTableCnt; /* ͤμ */
-  /*kTableꥢ*/
+  maxCnt=cTableCnt; /* 値の種類数 */
+  /*kTableメモリアロケーション*/
   kTable = (struct kTbl *)mssCalloc(
                           maxCnt*cutNum*sizeof(struct kTbl),"calOptCutP");
-  /*sTableꥢ*/
+  /*sTableメモリアロケーション*/
   sTable = (unsigned long *)mssCalloc(
                           maxCnt*sizeof(unsigned long),"calOptCutP");
-  /*rTableꥢ*/
+  /*rTableメモリアロケーション*/
   rTable = (struct rTbl *)mssCalloc(
                           cutNum*sizeof(struct rTbl),"calOptCutP");
 
-  /*ͤäƤ*/
+  /*累積値を持っておく*/
   *sTable = cTable->Cnt;
   for(j=1; j<cTableCnt; j++){
     *(sTable+j) = *(sTable+j-1) + (cTable+j)->Cnt;
   }
 
-  /*k=1ξη׻*/
+  /*k=1の場合の計算*/
   for(j=0; j<cTableCnt; j++){
     (kTable+j)->minVar = calVariance(0,j);
     (kTable+j)->prvNo  = 0;
@@ -226,19 +226,19 @@ void calOptCutPoint(int cutNum){
     (kTable+j)->to     = j;
   }
 
-  /*ͤμ⥫åȿ(k=)礭cutCntĴ*/
+  /*値の種類数よりもカット数(k=の値)が大きければcutCntを調整*/
   cutCnt=cutNum;
   if(cutNum>cTableCnt)cutCnt=cTableCnt;
 
-  /*k=2ʾξη׻*/
-  for(j=1; j<cutCnt; j++){ /*j=1ǻϤޤΤkʬ10б*/
+  /*k=2以上の場合の計算*/
+  for(j=1; j<cutCnt; j++){ /*j=1で始まるのはk分割の1は配列の0に対応*/
     for(k=j; k<cTableCnt; k++){
       minMinVar=DBL_MAX;
       for(l=j-1; l<k; l++){
         tmpVar = (kTable+cTableCnt*(j-1)+l)->minVar +
                  (double)(sTable[k]-sTable[l])*(double)(sTable[k]-sTable[l]);
-        /*>ˤСƱξ˸¿*/
-        /*>=ˤСƱξ¿*/
+        /*ここの不等式を>にすれば、同じ件数の場合に後を多くする*/
+        /*ここの不等式を>=にすれば、同じ件数の場合に前を多くする*/
         if( minMinVar > tmpVar ){
           minMinVar =tmpVar;
           minPrvNo  =l;
@@ -261,7 +261,7 @@ void calOptCutPoint(int cutNum){
     (rTable+j)->to  =(cTable+(tmpKtbl->to  ))->Val;
     tmpKtbl=kTable+(j-1)*cTableCnt+(tmpKtbl->prvNo);
   }
-  /*fromtoȤ*/
+  /*fromとtoの中点をとる*/
   if(cutCnt>1) (rTable+0)->to=((rTable+0)->to+(rTable+1)->from)/2;
   for(j=1; j<cutCnt-1; j++){
     (rTable+j)->from=(rTable+j-1)->to;
@@ -269,7 +269,7 @@ void calOptCutPoint(int cutNum){
   }
   (rTable+j)->from=(rTable+j-1)->to;
 
-/* ǥХåꥹ*/
+/* デバッグリスト*/
 /*
   printf("---- kTable : cnt-----\n");
   for(j=0; j<cutCnt; j++){
@@ -313,191 +313,191 @@ Main Function
 */
 int main(int argc, char *argv[]){
 /*============================================================================*/
-/* ץ                                                       */
+/* オプション宣言＆定義                                                       */
 /*============================================================================*/
 /*----------------------------------------------------------------------------*/
-/*                                                                    */
+/* キー項目                                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptKEY optKEY={
-    OKEY,   /* ץ󥿥                                             */
-    "k",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    MssFieldMaxCnt, /* ǽʺܿ                                 */
-    "i",    /* оݤȤϥǡΥ(GUI)                  */
-    2,      /* ǥե(Υץ󤬻ꤵʤäȤư) */
-            /* 1:ƤιԤۤ륭ͤȤư                             */
-            /* 2:ƤιԤƱͤȤư)                            */
-    KEYT,   /* ΥץΥȥ(Helpɽ)                         */
-    KEYC    /* ΥץΥ(Helpɽ)                         */
+    OKEY,   /* オプションタイプ                                             */
+    "k",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    MssFieldMaxCnt, /* 指定可能な最大項目数                                 */
+    "i",    /* 対象とする入力データのキーワード(GUIで利用)                  */
+    2,      /* デフォルト(このオプションが指定されなかったときの動作を指定) */
+            /* 1:全ての行を異るキー値として扱う                             */
+            /* 2:全ての行を同じキー値として扱う)                            */
+    KEYT,   /* このオプションのタイトル(Helpで表示)                         */
+    KEYC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* оݹ                                                                   */
+/* 対象項目                                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptFLD optFLD={
-    OFLD,   /* ץ󥿥                                             */
-    "f",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    MssFieldMaxCnt, /* ǽʺܿ                                 */
-    "i",    /* оݤȤϥǡΥ(GUI)                  */
-    1,      /* ɽĤ뤫ɤ(0:Բ,1:)                      */
-    1,      /* ̾Ǥ뤫ɤ(0:Բ,1:)                    */
-    NULL,   /* ܥץ(%ʲ)ǻǽʸ                        */
-            /* ex) ԲĤξNULL, "nr": "-f ̾%rn"λǽ     */
-    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
-    FLDC,   /* ΥץΥ(Helpɽ)                         */
-    FLDF    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
+    OFLD,   /* オプションタイプ                                             */
+    "f",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    MssFieldMaxCnt, /* 指定可能な最大項目数                                 */
+    "i",    /* 対象とする入力データのキーワード(GUIで利用)                  */
+    1,      /* 正規表現を許可するかどうか(0:不可,1:可)                      */
+    1,      /* 新項目名を指定できるかどうか(0:不可,1:可)                    */
+    NULL,   /* 項目オプション(%以下)で指定可能な文字                        */
+            /* ex) 指定不可の場合はNULL, "nr": "-f 項目名%rn"の指定可能     */
+    FLDT,   /* このオプションのタイトル(Helpで表示)                         */
+    FLDC,   /* このオプションのコメント(Helpで表示)                         */
+    FLDF    /* フラグについての説明(Helpで表示)複数の場合はカンマで区切る   */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ʬ                                                                     */
+/* 分割数                                                                     */
 /*----------------------------------------------------------------------------*/
   MssOptINT optNUM={
-    OINT,   /* ץ󥿥                                             */
-    "n",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    0,      /* ǥե(ͤȤƻ)                                   */
-    2,      /* Ǿ                                                       */
-    255,    /*                                                        */
-    NUMT,   /* ΥץΥȥ(Helpɽ)                         */
-    NUMC    /* ΥץΥ(Helpɽ)                         */
+    OINT,   /* オプションタイプ                                             */
+    "n",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    0,      /* デフォルト(数値として指定)                                   */
+    2,      /* 最小値                                                       */
+    255,    /* 最大値                                                       */
+    NUMT,   /* このオプションのタイトル(Helpで表示)                         */
+    NUMC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* Ͻ                                                                   */
+/* 出力書式                                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptSEL optFMT={
-    OSEL,    /* ץ󥿥                                             */
-    "F",     /* (ʣʸԲ)                                   */
-    0,       /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    "0",     /* ǥե(ʸˤ)                                       */
+    OSEL,    /* オプションタイプ                                             */
+    "F",     /* キーワード(複数文字は不可)                                   */
+    0,       /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    "0",     /* デフォルト(文字列にて)                                       */
     "0,1,2",
-            /* ǽͥꥹ                                           */
-    FMTT,   /* ΥץΥȥ(Helpɽ)                         */
-    FMTC,   /* ΥץΥ(Helpɽ)                         */
-    FMTS    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
+            /* 指定可能な値リスト                                           */
+    FMTT,   /* このオプションのタイトル(Helpで表示)                         */
+    FMTC,   /* このオプションのコメント(Helpで表示)                         */
+    FMTS    /* フラグについての説明(Helpで表示)複数の場合はカンマで区切る   */
   };
 
 /*----------------------------------------------------------------------------*/
-/* Хåȷ׻ˡ                                                           */
+/* バケット計算方法                                                           */
 /*----------------------------------------------------------------------------*/
   MssOptSEL optTyp={
-    OSEL,    /* ץ󥿥                                             */
-    "c",     /* (ʣʸԲ)                                   */
-    0,       /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    "cnt",   /* ǥե(ʸˤ)                                       */
+    OSEL,    /* オプションタイプ                                             */
+    "c",     /* キーワード(複数文字は不可)                                   */
+    0,       /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    "cnt",   /* デフォルト(文字列にて)                                       */
     "cnt,rng",
-            /* ǽͥꥹ                                           */
-    TYPT,   /* ΥץΥȥ(Helpɽ)                         */
-    TYPC,   /* ΥץΥ(Helpɽ)                         */
-    TYPS    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
+            /* 指定可能な値リスト                                           */
+    TYPT,   /* このオプションのタイトル(Helpで表示)                         */
+    TYPC,   /* このオプションのコメント(Helpで表示)                         */
+    TYPS    /* フラグについての説明(Helpで表示)複数の場合はカンマで区切る   */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ֹսե饰                                                             */
+/* 番号逆順フラグ                                                             */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optREV={
-    OFLG,   /* ץ󥿥                                             */
-    "r",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    REVT,   /* ΥץΥȥ(Helpɽ)                         */
-    REVC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "r",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    REVT,   /* このオプションのタイトル(Helpで表示)                         */
+    REVC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 入力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptINF optINF={
-    OINF,   /* ץ󥿥                                             */
-    "i",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    1,      /* ǽκե                                     */
-    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
-    INFT,   /* ΥץΥȥ(Helpɽ)                         */
-    INFC    /* ΥץΥ(Helpɽ)                         */
+    OINF,   /* オプションタイプ                                             */
+    "i",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    1,      /* 指定可能の最大ファイル数                                     */
+    0,      /*1:file not foundのエラーで終了しない 0:する                   */
+    INFT,   /* このオプションのタイトル(Helpで表示)                         */
+    INFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ХåϰϽϥե                                                   */
+/* バケット範囲出力ファイル                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptOTF optRNG={
-    OOTF,   /* ץ󥿥                                             */
-    "O",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    RNGT,   /* ΥץΥȥ(Helpɽ)                         */
-    RNGC    /* ΥץΥ(Helpɽ)                         */
+    OOTF,   /* オプションタイプ                                             */
+    "O",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    RNGT,   /* このオプションのタイトル(Helpで表示)                         */
+    RNGC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 出力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptOTF optOTF={
-    OOTF,   /* ץ󥿥                                             */
-    "o",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
-    OTFC    /* ΥץΥ(Helpɽ)                         */
+    OOTF,   /* オプションタイプ                                             */
+    "o",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    OTFT,   /* このオプションのタイトル(Helpで表示)                         */
+    OTFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ̽                                                                   */
+/* 圧縮出力                                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optZIP={
-    OFLG,   /* ץ󥿥                                             */
-    "z",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
-    ZIPC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "z",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    ZIPT,   /* このオプションのタイトル(Helpで表示)                         */
+    ZIPC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
 /* plain text                                                                 */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optTXT={
-    OFLG,   /* ץ󥿥                                             */
-    "t",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    TXTT,   /* ΥץΥȥ(Helpɽ)                         */
-    TXTC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "t",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    TXTT,   /* このオプションのタイトル(Helpで表示)                         */
+    TXTC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* եѥǥ쥯ȥ̾                                             */
+/* ワークファイル用ディレクトリ名                                             */
 /*----------------------------------------------------------------------------*/
   MssOptSTR optTMP={
-    OSTR,   /* ץ󥿥                                             */
-    "T",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    MssTempDir, /* ǥե                                               */
-    1,      /* ʸκǾĹ                                               */
-    MssFileNameMaxLen,  /* ʸκĹ                                   */
-    TMPT,   /* ΥץΥȥ(Helpɽ)                         */
-    TMPC    /* ΥץΥ(Helpɽ)                         */
+    OSTR,   /* オプションタイプ                                             */
+    "T",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    MssTempDir, /* デフォルト                                               */
+    1,      /* 文字列の最小長                                               */
+    MssFileNameMaxLen,  /* 文字列の最大長                                   */
+    TMPT,   /* このオプションのタイトル(Helpで表示)                         */
+    TMPC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ץޤȤ                                                       */
+/* オプションをまとめる                                                       */
 /*----------------------------------------------------------------------------*/
   void *opt[]={&optKEY,&optFLD,&optNUM,&optFMT,&optTyp,&optREV,
                &optINF,&optRNG,&optOTF,&optZIP,&optTXT,&optTMP,NULL};
 
 /*============================================================================*/
-/* ѿ                                                             */
+/* 変数宣言＆定義                                                             */
 /*============================================================================*/
-  struct mssHeader    *hdi;     /* ϥե<head>Ǽ¤*/
-  struct mssHeader    *hdo;     /* ϥե<head>Ǽ¤*/
-  struct mssHeader    *hdo2;    /* ϥե<head>Ǽ¤*/
-  struct mssFPR       *fpr;     /* ϥե빽¤                */
-  struct mssFPW       *fpw;     /* ϥե빽¤                */
-  struct mssFPW       *fpw2;    /* ϰϽϥե빽¤            */
-  struct mssFldRecKey *frk=NULL;/* Хåե¤                */
-  struct mssFields    *sf;      /* ȹܹ¤                  */
-  int sorted;                   /*Ⱥѥå                 */
+  struct mssHeader    *hdi;     /* 入力ファイル用<head>タグ格納構造体*/
+  struct mssHeader    *hdo;     /* 出力ファイル用<head>タグ格納構造体*/
+  struct mssHeader    *hdo2;    /* 出力ファイル用<head>タグ格納構造体*/
+  struct mssFPR       *fpr;     /* 入力ファイル構造体                */
+  struct mssFPW       *fpw;     /* 出力ファイル構造体                */
+  struct mssFPW       *fpw2;    /* 範囲出力ファイル構造体            */
+  struct mssFldRecKey *frk=NULL;/* キーバッファ構造体                */
+  struct mssFields    *sf;      /* ソート項目構造体                  */
+  int sorted;                   /*ソート済チェック用                 */
 
   char *vstr;
   double val;
-  int num;      /*ϤХåֹ*/
-  int *cutCnts; /*μºݤΥХåȿ*/
+  int num;      /*出力するバケット番号*/
+  int *cutCnts; /*項目毎の実際のバケット数*/
   char  *bufStr;
   double bufNum;
   double *max;
@@ -506,50 +506,50 @@ int main(int argc, char *argv[]){
   int i,j,k,l;
 
 /*----------------------------------------------------------------------------*/
-/*                                                                      */
+/* 前処理                                                                     */
 /*----------------------------------------------------------------------------*/
-  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
-  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
-  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
-  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
-  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
-  mssSetOptKey(&optKEY, hdi);        /* -k ܤإåܤ˴ϢŤ     */
-  mssSetOptFld(&optFLD, hdi);        /* -f ܤإåܤ˴ϢŤ     */
+  mssInit(argc,argv,&comHelp);       /* シグナル処理などの初期化              */
+  mssHelpDoc(opt,&comHelp,argc,argv);/* ヘルプ                                */
+  mssSetOption(opt,argc,argv);       /* コマンドオプションの設定              */
+  fpr=mssOpenFPR(optINF.str,4);      /* 入力ファイルオープン                  */
+  hdi=mssReadHeader(fpr);            /* ヘッダの読み込み                      */
+  mssSetOptKey(&optKEY, hdi);        /* -k 項目をヘッダー項目に関連づける     */
+  mssSetOptFld(&optFLD, hdi);        /* -f 項目をヘッダー項目に関連づける     */
   
-  /*ȹܤκ*/
+  /*ソート項目の作成*/
   sf=mssInitFields();
-  mssAddFieldsByFields(sf,optKEY.flds); /* -k ܤ򥽡ȹܤȤƥå    */
-  mssSetFieldsSortPriority(sf);         /* ֹͥϿˤդ   */
-  sorted=mssChkSorted(sf,hdi);          /* ȺѤå                 */
+  mssAddFieldsByFields(sf,optKEY.flds); /* -k 項目をソート項目としてセット    */
+  mssSetFieldsSortPriority(sf);         /* ソート優先順位番号を登録順にふる   */
+  sorted=mssChkSorted(sf,hdi);          /* ソート済かチェック                 */
 
 /*mssShowFields(sf);*/
 /*mssShowOption(opt);*/
 /*mssShowHeader(hdi);*/
 
 /*----------------------------------------------------------------------------*/
-/*ϥإåκȽ                                                    */
+/*出力ヘッダーの作成と出力                                                    */
 /*----------------------------------------------------------------------------*/
-  /*ϥإåν(ȥΥԡ)*/                              
+  /*出力ヘッダーの初期化(タイトル等のコピー)*/                              
   hdo=mssInitCpyHeader(hdi);
 
-  /*ϥإåܤɲ*/
+  /*入力ヘッダの全項目を追加*/
   mssAddFieldsByFields(hdo->flds,hdi->flds);
 
-  /*̾ɲä*/
+  /*新項目名を追加する*/
   mssAddFieldsByStrList(hdo->flds,optFLD.newNam,optFLD.cnt);                  
     
-  /*ȤɬפʤsfΥȾȿ*/
+  /*ソートする必要があるならばsfのソート情報を反映*/
   if(!sorted){
     mssSetFieldsSort(hdo->flds,sf);
   } 
     
-  /*ɸϥץ+إåν*/
+  /*標準出力オープン+ヘッダーの出力*/
   fpw=mssOpenFPW(optOTF.str,optZIP.set,0);                                    
   mssWriteHeader(hdo, fpw);
 
-  /*ϰϽϥե륪ץ+إåν*/
+  /*範囲出力ファイルオープン+ヘッダーの出力*/
 
-  /*ϥإåν(ȥΥԡ)*/
+  /*出力ヘッダーの初期化(タイトル等のコピー)*/
   if(optRNG.set){
     hdo2=mssInitCpyHeader(hdi);
 
@@ -569,9 +569,9 @@ int main(int argc, char *argv[]){
   }
   
 /*----------------------------------------------------------------------------*/
-/*ᥤ롼                                                              */
+/*メインルーチン                                                              */
 /*----------------------------------------------------------------------------*/
-  /*ȤɬѤʤХȤƥȺѤߥեȤƥץ*/            
+  /*ソートが必用ならばソートしてソート済みファイルとしてオープン*/            
   if(!sorted){
     fpr=mssReopenFPRsort(fpr,4,sf,hdi->flds->cnt,optTMP.str);
   }
@@ -579,14 +579,14 @@ int main(int argc, char *argv[]){
   rTables=mssMalloc(optFLD.flds->cnt*sizeof(struct rTbl *),"xtbucket");
   cutCnts=mssMalloc(optFLD.flds->cnt*sizeof(int),"xtbucket");
 
-  /*FRK¤Τν*/
+  /*FRK構造体の初期化*/
   frk=mssInitFRK(hdi->flds->cnt, &optKEY,optTMP.str);
 
   while(1){ /*loop by key*/
-    /*ǡɤ߹*/
+    /*データ読み込み*/
     if(EOF==mssReadFRK(fpr,frk)) break;
 
-    /*ϰ϶ʬ(rng)*/
+    /*範囲均等化分割(rng)*/
     if( strcmp("rng",optTyp.str)==0 ){
       max=mssMalloc(optFLD.flds->cnt*sizeof(double),"rng1");
       min=mssMalloc(optFLD.flds->cnt*sizeof(double),"rng2");
@@ -597,7 +597,7 @@ int main(int argc, char *argv[]){
 
       mssSeekTopFRK(frk);
       while( EOF != mssReadFldRecFRK(frk) ){
-        /*͡Ǿͤ򥻥åȤ*/
+        /*最大値、最小値をセットする*/
         for(i=0; i<optFLD.flds->cnt; i++){
           bufStr=*(frk->pnt+MssFlds2num(optFLD.flds,i));
           if(MssIsNull(bufStr)) continue;
@@ -607,17 +607,17 @@ int main(int argc, char *argv[]){
         }
       }
 
-      /*rTableꥢ*/
+      /*rTableメモリアロケーション*/
       for(i=0; i<optFLD.flds->cnt; i++){
         if( *(max+i)==DBL_MAX || *(min+i)==-DBL_MAX ){
           *(rTables+i)=NULL;
-          *(cutCnts+i)=0; /*åȿΥå*/
+          *(cutCnts+i)=0; /*カット数のセット*/
         }else if( *(max+i) == *(min+i) ){
           *(rTables+i) = (struct rTbl *)mssMalloc(
                           1*sizeof(struct rTbl),"calOptCutP");
           ((*(rTables+i))+0)->from=*(min+i);
           ((*(rTables+i))+0)->to  =*(max+i);
-          *(cutCnts+i)=1; /*åȿΥå*/
+          *(cutCnts+i)=1; /*カット数のセット*/
         }else{
           *(rTables+i) = (struct rTbl *)mssMalloc(
                           optNUM.val*sizeof(struct rTbl),"calOptCutP");
@@ -627,37 +627,37 @@ int main(int argc, char *argv[]){
             if(j==optNUM.val-1)  (*(rTables+i)+j)->to  =*(max+i);
             else                 (*(rTables+i)+j)->to  =*(min+i)+rng*(j+1);
           }
-          *(cutCnts+i)=optNUM.val; /*åȿΥå*/
+          *(cutCnts+i)=optNUM.val; /*カット数のセット*/
         }
       }
       mssFree(max);
       mssFree(min);
 
-    /*ʬ(cnt)*/
+    /*件数均等化分割(cnt)*/
     }else{
       for(i=0; i<optFLD.flds->cnt; i++){
-        /*ǡcTable˥å*/
+        /*データをcTableにセット*/
         cTableCnt=0;
         cTableMaxCnt=0;
         cTable=setcTable(frk,MssFlds2num(optFLD.flds,i));
 
-        /*ŬåȥݥȤ*/
+        /*最適カットポイントを求める*/
         calOptCutPoint(optNUM.val);
 
-        /*åȿΥå*/
+        /*カット数のセット*/
         *(cutCnts+i)=cutCnt;
 
-        /*rTable¸*/
+        /*rTableの保存*/
         *(rTables+i)=rTable;
 
-        /*ΰ賫*/
+        /*領域開放*/
         mssFree(cTable);
         mssFree(kTable);
         mssFree(sTable);
       }
     }
 
-    /*ϰϥե*/
+    /*範囲ファイル出力*/
     if(optRNG.set){
       for(i=0; i<optFLD.flds->cnt; i++){
         for(k=0; k<*(cutCnts+i); k++){
@@ -683,7 +683,7 @@ int main(int argc, char *argv[]){
       }
     }
 
-    /**/
+    /*出力*/
     mssSeekTopFRK(frk);
     while( EOF != mssReadFldRecFRK(frk) ){
       mssGV.inCnt++;
@@ -727,26 +727,26 @@ int main(int argc, char *argv[]){
     }
   }
 
-  /*ΰ賫*/
+  /*領域開放*/
   mssFree(rTables);
   mssFree(cutCnts);
   mssFreeFRK(frk);
 
 /*----------------------------------------------------------------------------*/
-/*եå&λ                                                       */
+/*フッター出力&終了処理                                                       */
 /*----------------------------------------------------------------------------*/
 /*printf("allocCnt=%d\n",getAllocCnt());*/
-  mssWriteFooter(fpw);    /* եåν             */
-  mssWriteFooter(fpw2);   /* եåν             */
-  mssCloseFPR(fpr);       /* ϥեΥ     */
-  mssCloseFPW(fpw);       /* ϥեΥ     */
-  mssCloseFPW(fpw2);      /* ϥեΥ     */
-  mssFreeFields(sf);      /* ȹܹ¤Τΰ賫 */
-  mssFreeHeader(hdi);     /* ϥإåΰ賫         */
-  mssFreeHeader(hdo);     /* ϥإåΰ賫         */
-  mssFreeHeader(hdo2);    /* ϥإåΰ賫         */
-  mssFreeOption(opt);     /* ץΰ賫         */
-  mssShowEndMsg();        /* λå             */
-  mssEnd(mssExitSuccess); /* λ                       */
+  mssWriteFooter(fpw);    /* フッターの出力             */
+  mssWriteFooter(fpw2);   /* フッターの出力             */
+  mssCloseFPR(fpr);       /* 入力ファイルのクローズ     */
+  mssCloseFPW(fpw);       /* 出力ファイルのクローズ     */
+  mssCloseFPW(fpw2);      /* 出力ファイルのクローズ     */
+  mssFreeFields(sf);      /* ソート項目構造体の領域開放 */
+  mssFreeHeader(hdi);     /* 入力ヘッダ領域開放         */
+  mssFreeHeader(hdo);     /* 出力ヘッダ領域開放         */
+  mssFreeHeader(hdo2);    /* 出力ヘッダ領域開放         */
+  mssFreeOption(opt);     /* オプション領域開放         */
+  mssShowEndMsg();        /* 完了メッセージ             */
+  mssEnd(mssExitSuccess); /* 終了                       */
   return(0);              /* to avoid warning message   */
 }
