@@ -1,7 +1,8 @@
 /*============================================================================*/
-/* ѹ                                                                   */
+/* 変更履歴                                                                   */
 /*----------------------------------------------------------------------------*/
-/* 1.0 : APIб 2003/06/20                                           */
+/* 1.0 : 新しいAPIに対応 2003/06/20                                           */
+/* 1.2 : wild cardを持たないファイルの指定時、なければエラー終了 2004/07/30   */
 /*============================================================================*/
 #include <musashi.h>
 #include <stdlib.h>
@@ -9,15 +10,15 @@
 
 #include <xtcatHelp.h>
 struct mssComHelp comHelp={
-  "xtcat",        /* ޥ̾       */                                    
-  "1.1",          /* С       */
-  HELPT,          /* ޥɥȥ */
-  HELPS,          /*              */
-  HELPE,          /*            */
-  HELPR,          /* ȥޥ     */
-  HELPA,          /* Ծ         */
-  HELPB,          /* ХݡȾ */                                      
-  HELPH           /* ۡڡ     */
+  "xtcat",        /* コマンド名       */                                    
+  "1.2",          /* バージョン       */
+  HELPT,          /* コマンドタイトル */
+  HELPS,          /* 要約             */
+  HELPE,          /* 利用例           */
+  HELPR,          /* 参照コマンド     */
+  HELPA,          /* 作者情報         */
+  HELPB,          /* バグレポート情報 */                                      
+  HELPH           /* ホームページ     */
 };
 
 extern struct mssGlobalVariables mssGV;
@@ -25,10 +26,10 @@ extern struct mssGlobalVariables mssGV;
 int diffHeaderName(struct mssHeader *hdi,struct mssHeader *hdn){
   int i;
 
-  /*ܿۤʤ*/
+  /*項目数が異なれば*/
   if(hdi->flds->cnt != hdn->flds->cnt) return(1);
 
-  /*̾ۤʤ*/
+  /*項目名が異なれば*/
   for(i=0; i<hdi->flds->cnt; i++){
     if( 0!=strcmp(MssFlds2name(hdi->flds,i),MssFlds2name(hdn->flds,i)) ){
       return(1);
@@ -41,7 +42,7 @@ void setFldConv(int conv[MssFieldMaxCnt],struct mssHeader *hdi,struct mssHeader
   int i,j;
   int ino,jno;
 
-  /*-1бܤʤȤ̣*/
+  /*初期化：-1は対応する項目がないという意味*/
   for(i=0; i<hdi->flds->cnt; i++)conv[i]=-1;
 
   for(i=0; i<hdi->flds->cnt; i++){
@@ -57,77 +58,77 @@ void setFldConv(int conv[MssFieldMaxCnt],struct mssHeader *hdi,struct mssHeader
 
 int main(int argc, char *argv[]){
 /*============================================================================*/
-/* ץ                                                       */
+/* オプション宣言＆定義                                                       */
 /*============================================================================*/
 /*----------------------------------------------------------------------------*/
-/* ܿΤߥåե饰                                               */
+/* 項目数のみチェックするフラグ                                               */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optCNT={
-    OFLG,   /* ץ󥿥                                             */
-    "c",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    CNTT,   /* ΥץΥȥ(Helpɽ)                         */
-    CNTC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "c",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    CNTT,   /* このオプションのタイトル(Helpで表示)                         */
+    CNTC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* Ʊ̾Τcatե饰                                                */
+/* 同一項目名のみcatするフラグ                                                */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optNAM={
-    OFLG,   /* ץ󥿥                                             */
-    "n",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    NAMT,   /* ΥץΥȥ(Helpɽ)                         */
-    NAMC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "n",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    NAMT,   /* このオプションのタイトル(Helpで表示)                         */
+    NAMC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 入力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptINF optINF={
-    OINF,   /* ץ󥿥                                             */
-    "i",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ                                         */
-    256,    /* ǽκե                                     */
-    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
-    INFT,   /* ΥץΥȥ(Helpɽ)                         */
-    INFC    /* ΥץΥ(Helpɽ)                         */
+    OINF,   /* オプションタイプ                                             */
+    "i",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須                                         */
+    256,    /* 指定可能の最大ファイル数                                     */
+    0,      /*1:file not foundのエラーで終了しない 0:する                   */
+    INFT,   /* このオプションのタイトル(Helpで表示)                         */
+    INFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 出力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptOTF optOTF={
-    OOTF,   /* ץ󥿥                                             */
-    "o",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
-    OTFC    /* ΥץΥ(Helpɽ)                         */
+    OOTF,   /* オプションタイプ                                             */
+    "o",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    OTFT,   /* このオプションのタイトル(Helpで表示)                         */
+    OTFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ̽                                                                   */
+/* 圧縮出力                                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optZIP={
-    OFLG,   /* ץ󥿥                                             */
-    "z",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
-    ZIPC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "z",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    ZIPT,   /* このオプションのタイトル(Helpで表示)                         */
+    ZIPC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 
 /*----------------------------------------------------------------------------*/
-/* ץޤȤ                                                       */
+/* オプションをまとめる                                                       */
 /*----------------------------------------------------------------------------*/
   void *opt[]={&optCNT,&optNAM,&optINF,&optOTF,&optZIP,NULL};
 
 /*============================================================================*/
-/* ѿ                                                             */
+/* 変数宣言＆定義                                                             */
 /*============================================================================*/
-  struct mssHeader *hdi; /*Ĥϥե<head>Ǽ¤*/
-  struct mssHeader *hdn; /*Ĥʹߤϥե<head>Ǽ¤*/
-  struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
+  struct mssHeader *hdi; /*一つめの入力ファイル用<head>タグ格納構造体*/
+  struct mssHeader *hdn; /*二つめ以降の入力ファイル用<head>タグ格納構造体*/
+  struct mssHeader *hdo; /*出力ファイル用<head>タグ格納構造体*/
   struct mssFPR    *fpi;
   struct mssFPR    *fpn;
   struct mssFPW    *fpw;
@@ -138,11 +139,11 @@ int main(int argc, char *argv[]){
   int conv[MssFieldMaxCnt];
 
 /*----------------------------------------------------------------------------*/
-/*                                                                      */
+/* 前処理                                                                     */
 /*----------------------------------------------------------------------------*/
-  mssInit(argc,argv,&comHelp);      /* ʥʤɤν     */
-  mssHelpDoc(opt,&comHelp,argc,argv);    /* إ                       */
-  mssSetOption(opt,argc,argv);      /* ޥɥץ     */
+  mssInit(argc,argv,&comHelp);      /* シグナル処理などの初期化     */
+  mssHelpDoc(opt,&comHelp,argc,argv);    /* ヘルプ                       */
+  mssSetOption(opt,argc,argv);      /* コマンドオプションの設定     */
 /*prnOption(opt);*/
 
   if( (optCNT.set+optNAM.set) >1 ){
@@ -150,28 +151,28 @@ int main(int argc, char *argv[]){
     mssEnd(mssErrorNoDefault);
   }
 
-  fpi=mssOpenFPR(*(optINF.strList+0),4); /*ĤΥե륪ץ*/
-  hdi=mssReadHeader(fpi);                /*̾ɤ߹*/
+  fpi=mssOpenFPR(*(optINF.strList+0),4); /*一つめのファイルオープン*/
+  hdi=mssReadHeader(fpi);                /*項目名情報の読み込み*/
 /*prnHeader(hdi);*/
 
 /*----------------------------------------------------------------------------*/
-/*ϥإåκȽ                                                    */
+/*出力ヘッダーの作成と出力                                                    */
 /*----------------------------------------------------------------------------*/
-  /*ϥإåϥإå˥ԡ*/
+  /*入力ヘッダーを出力ヘッダーにコピー*/
   hdo=mssInitCpyHeader(hdi);
 
-  /*ϥإåܤɲ*/
+  /*入力ヘッダの全項目を追加*/
   mssAddFieldsByFields(hdo->flds,hdi->flds);
 
-  /*Ƚ뤿ᡢȾ򥯥ꥢ*/
+  /*ソート順序は崩れるため、ソート情報をクリア*/
   mssClearFieldsSort(hdo->flds);
 
-  /*ɸϥץ+إåν*/
+  /*標準出力オープン+ヘッダーの出力*/
   fpw=mssOpenFPW(optOTF.str,optZIP.set,0);
   mssWriteHeader(hdo, fpw);
 
 /*----------------------------------------------------------------------------*/
-/*ᥤ롼                                                              */
+/*メインルーチン                                                              */
 /*----------------------------------------------------------------------------*/
 
   fri =mssInitFldRec(hdi->flds->cnt);
@@ -181,13 +182,13 @@ int main(int argc, char *argv[]){
     mssGV.outCnt++;
   }
   mssFreeFldRec(fri);
-  mssCloseFPR(fpi);/*ϥեΥ*/
+  mssCloseFPR(fpi);/*入力ファイルのクローズ*/
 
   for(i=1; i<optINF.cnt; i++){
-    fpn=mssOpenFPR(*(optINF.strList+i),4); /*ե륪ץ*/
-    hdn=mssReadHeader(fpn);                /*̾ɤ߹*/
+    fpn=mssOpenFPR(*(optINF.strList+i),4); /*ファイルオープン*/
+    hdn=mssReadHeader(fpn);                /*項目名情報の読み込み*/
 
-    /*ܿåξ*/
+    /*項目数チェックの場合*/
     if(optCNT.set){
       if(hdi->flds->cnt!=hdn->flds->cnt){
         mssShowErrMsg("different number of fields on header : %s",
@@ -201,7 +202,7 @@ int main(int argc, char *argv[]){
         mssGV.outCnt++;
       }
 
-    /*̾åξ*/
+    /*項目名チェックの場合*/
     }else if(optNAM.set){
       setFldConv(conv,hdi,hdn);
       frn =mssInitFldRec(hdn->flds->cnt);
@@ -218,7 +219,7 @@ int main(int argc, char *argv[]){
         mssGV.outCnt++;
       }
 
-    /*ǥե*/
+    /*デフォルト*/
     }else{
       if(diffHeaderName(hdi,hdn)){
         mssShowErrMsg("different type of header detected : %s",
@@ -233,21 +234,21 @@ int main(int argc, char *argv[]){
       }
     }
 
-    mssCloseFPR(fpn);/*ϥեΥ*/
+    mssCloseFPR(fpn);/*入力ファイルのクローズ*/
     mssFreeFldRec(frn);
     mssFreeHeader(hdn);
   }
 
 /*----------------------------------------------------------------------------*/
-/*եå&λ                                                       */
+/*フッター出力&終了処理                                                       */
 /*----------------------------------------------------------------------------*/
 /*printf("allocCnt=%d\n",getAllocCnt());*/
-  mssWriteFooter(fpw);    /*եåν           */
-  mssCloseFPW(fpw);       /*ϥեΥ   */
-  mssFreeHeader(hdi);     /*ϥإåΰ賫       */
-  mssFreeHeader(hdo);     /*ϥإåΰ賫       */
-  mssFreeOption(opt);     /*ץΰ賫       */
-  mssShowEndMsg();        /*λå           */
-  mssEnd(mssExitSuccess); /*λ                     */
+  mssWriteFooter(fpw);    /*フッターの出力           */
+  mssCloseFPW(fpw);       /*出力ファイルのクローズ   */
+  mssFreeHeader(hdi);     /*入力ヘッダ領域開放       */
+  mssFreeHeader(hdo);     /*出力ヘッダ領域開放       */
+  mssFreeOption(opt);     /*オプション領域開放       */
+  mssShowEndMsg();        /*完了メッセージ           */
+  mssEnd(mssExitSuccess); /*終了                     */
   return(0);              /* to avoid warning message*/
 }
