@@ -1,8 +1,8 @@
 
 /*============================================================================*/
-/* ѹ                                                                   */
+/* 変更履歴                                                                   */
 /*----------------------------------------------------------------------------*/
-/* 1.0 : APIб 2003/08/21                                           */
+/* 1.0 : 新しいAPIに対応 2003/08/21                                           */
 /*============================================================================*/
 
 #include <musashi.h>
@@ -11,26 +11,26 @@
 
 #include <xtasruleHelp.h>
 struct mssComHelp comHelp={
-  "xtasrule",     /* ޥ̾       */
-  "1.0",          /* С       */
-  HELPT,          /* ޥɥȥ */
-  HELPS,          /*              */
-  HELPE,          /*            */
-  HELPR,          /* ȥޥ     */
-  HELPA,          /* Ծ         */
-  HELPB,          /* ХݡȾ */
-  HELPH           /* ۡڡ     */
+  "xtasrule",     /* コマンド名       */
+  "1.0",          /* バージョン       */
+  HELPT,          /* コマンドタイトル */
+  HELPS,          /* 要約             */
+  HELPE,          /* 利用例           */
+  HELPR,          /* 参照コマンド     */
+  HELPA,          /* 作者情報         */
+  HELPB,          /* バグレポート情報 */
+  HELPH           /* ホームページ     */
 };
 
 extern struct mssGlobalVariables mssGV;
 
-int TotalCnt=0;        /*ȥ󥶥*/
-int MinSupportCnt=0;   /*ݡȤη(TotalCnt*optSPP*100)*/
-int DepthMax;          /*õƱƥκ(optMAX)*/
-int PMML;              /*PMMLǽϤե饰*/
+int TotalCnt=0;        /*全トランザクション件数*/
+int MinSupportCnt=0;   /*サポートの件数(TotalCnt*optSPP*100)*/
+int DepthMax;          /*探索する同時購入アイテム数の最大値(optMAX)*/
+int PMML;              /*PMMLで出力するフラグ*/
 
 /**
- * νУƥॻåȤǼ빽¤
+ * 瀕出１アイテムセットを格納する構造体
  */
 struct OneItemList {
   struct mssHash *hash;
@@ -39,10 +39,10 @@ struct OneItemList {
 };
 
 /**
- * OneItemList¤ΤѤ줿ƥоݤˡȥ󥶥󤫤
- * ʲΤ褦ʿDepthMaxΥĥ꡼롣
- * "Sn"Status¤ΤǤ롣
- * statusˤϡ(support)׻롣
+ * OneItemList構造体に蓄積されたアイテムを対象に、トランザクションから
+ * 以下のような深さDepthMaxのツリーを作成する。
+ * "Sn"がStatus構造体である。
+ * 各statusには、件数(support)が計算される。
  *
  *    a      b
  * S0-+---S1-+---S4
@@ -57,19 +57,19 @@ struct OneItemList {
  *    +---S3
  * |0   |  1   |  2  | -> status->depth
  *
- * ȥ󥶥{abc,bc}ʤС
+ * トランザクション{abc,bc}ならば、
  * S1->cnt=1, S2->cnt=2, S3->cnt=1
  * S4->cnt=1, S5->cnt=1, S6->cnt=2
- * Ȥʤ롣
+ * となる。
  */
 struct Status {
   struct mssHashNode *val;
-  int depth;               /*statusο*/
-  int support;             /*ݡȷ*/
-  struct Hash *next;       /*statusؤΥϥåɽ*/
+  int depth;               /*そのstatusの深さ*/
+  int support;             /*サポート件数*/
+  struct Hash *next;       /*次のstatusへのハッシュ表*/
 };
 
-/*StatusStatusĤʤϥåɽ*/
+/*StatusとStatusをつなぐハッシュ表*/
 struct HashNode {
   int str;
   struct Status *status;
@@ -78,20 +78,20 @@ struct HashNode {
 
 struct Hash {
   int hashVal;
-  int cnt;                 /*줿ͤο*/
-  struct HashNode **node;  /*줿ͤؤΥݥ*/
+  int cnt;                 /*挿入された値の数*/
+  struct HashNode **node;  /*挿入された値へのポインタ*/
 };
 
 /**
- * 嵭Υĥ꡼˥ȥ󥶥"ab"򥻥åȤ뤳Ȥͤ롣
- * ޤtarget{S0}˥åȤ롣
- * S0"a"arc򤿤ɤꡢS1support򥫥ȥåפ롣
- * targetˡS1target={S0,S1}Ȥʤ롣
- * "b"ˤƤϡtargetˤS0,S1ξ"b"arc򤿤ɤꡢ
- * S2S4support򥫥ȥåפ롣
- * λɤĤS4οMaxDepthĶΤǡtargetˤɲäʤ
- * target={S0,S1,S2}Ȥʤ롣
- * ʾΤ褦ʼ򷫤֤Ƥ
+ * 上記のツリーにトランザクション"ab"をセットすることを考える。
+ * まず、初期のtargetは{S0}にセットされる。
+ * そこでS0から"a"のarcをたどり、S1のsupportをカウントアップする。
+ * そしてtargetに、そのS1を挿入し、target={S0,S1}となる。
+ * 次に"b"の挿入においては、targetにあるS0,S1の両方から"b"のarcをたどり、
+ * S2およびS4のsupportをカウントアップする。
+ * この時たどりついた、S4の深さはMaxDepthを超えるので、targetには追加しない。
+ * そこでtarget={S0,S1,S2}となる。
+ * 以上のような手順を繰り返していく。
  */
 struct Target {
   int cnt;
@@ -101,12 +101,12 @@ struct Target {
 
 /**
  *------------------------------------------------------------------------------
- * status֤ΤĤʤΤHashɽϢδؿ
+ * status間のつなぎのためのHash表関連の関数
  *------------------------------------------------------------------------------
  */
 
 /**
- * Hashɽν
+ * Hash表の初期化
  */
 struct Hash *initHash(int size){
   struct Hash *hash;
@@ -119,7 +119,7 @@ struct Hash *initHash(int size){
 }
 
 /**
- * Hashɽγ
+ * Hash表の開放
  */
 void freeHash(struct Hash *hash)
 {
@@ -143,17 +143,17 @@ void freeHash(struct Hash *hash)
 
 
 /**
- * Hashͤη׻
- * strϡƥʸǼmssHashɽΥɥ쥹Ǥ롣
- * Υɥ쥹̵intѴѤƤ롣
+ * Hash値の計算
+ * strは、アイテム文字列を格納したmssHash表のアドレスである。
+ * そのアドレスを無理矢理int型に変換して利用している。
  */
 static int getHashVal(int str,int hv){
   return(str % hv);
 }
 
 /**
- * Status->nextHashɽ˼status *valHashNodeɥ쥹֤
- * Ǥ¸ߤϡHashNodeɥ쥹֤
+ * Status->nextのHash表に次のstatus *valを挿入し、そのHashNodeアドレスを返す。
+ * すでに存在する時は、そのHashNodeアドレスを返す。
  */
 struct HashNode *hashInsertAdd(struct Hash *hash, int str, struct Status *val)
 {
@@ -189,8 +189,8 @@ struct HashNode *hashInsertAdd(struct Hash *hash, int str, struct Status *val)
 }
 
 /**
- * Status->nextHashɽ˼status뤫ΤᡢФHashNode֤
- * ʤNULL֤
+ * Status->nextのHash表に次のstatusがあるかを確かめ、あればそのHashNodeを返し、
+ * なければNULLを返す。
  */
 struct HashNode *hashMemberAdd(struct Hash *hash, int str)
 {
@@ -211,12 +211,12 @@ struct HashNode *hashMemberAdd(struct Hash *hash, int str)
 
 /**
  *------------------------------------------------------------------------------
- * Status¤&ĥ꡼Ϣ
+ * Status構造体&ツリー関連
  *------------------------------------------------------------------------------
  */
 
 /**
- * Status¤Τν
+ * Status構造体の初期化
  */
 struct Status *initStatus(int depth){
   struct Status *status;
@@ -227,7 +227,7 @@ struct Status *initStatus(int depth){
 }
 
 /**
- * Status¤Τγ
+ * Status構造体の開放
  */
 void freeStatus(struct Status *status){
   freeHash(status->next);
@@ -235,7 +235,7 @@ void freeStatus(struct Status *status){
 }
 
 /**
- * Target¤Τˡstatusɲä롣
+ * Target構造体に、指定のstatusを追加する。
  */
 void addTarget(struct Target *target, struct Status *status){
 
@@ -246,8 +246,8 @@ void addTarget(struct Target *target, struct Status *status){
 }
 
 /**
- * statuschrArc򤿤ɤästatus֤
- * ⤷statusޤϿƤʤСɲä롣
+ * 指定のstatusからchrのArcをたどった先のstatusを返す。
+ * もし、そのstatusがまだ登録されていなければ、追加される。
  */
 struct Status *nextStatus(struct Status *status, struct mssHashNode *chr){
   struct HashNode *node;
@@ -263,11 +263,11 @@ struct Status *nextStatus(struct Status *status, struct mssHashNode *chr){
 }
 
 /**
- * targetϿ줿status饢ƥchr򤿤ɤꡢStatussupport
- * 򥫥ȥåפ롣
- * ơΤɤ夤statusMaxDepthĶƤʤСstatus
- * targetɲϿ롣
- * ⤷statusޤϿƤʤСɲä롣
+ * targetに登録された全statusからアイテムchrをたどり、そのStatusのsupport
+ * をカウントアップする。
+ * そして、そのたどり着いたstatusのMaxDepthを超えていなければ、そのstatus
+ * をtargetに追加登録する。
+ * もし、そのstatusがまだ登録されていなければ、追加される。
  */
 void setStatus(struct Target *target, struct mssHashNode *chr){
   int i;
@@ -285,7 +285,7 @@ void setStatus(struct Target *target, struct mssHashNode *chr){
 }
 
 /**
- * ƥꥹstrˤäƥĥ꡼γstatussupport򥫥ȥåפ
+ * アイテムリストstrによってツリーの各statusのsupportをカウントアップする
  */
 void addTree(struct Status *top, struct mssHashNode **str, int strLen){
   struct Target target;
@@ -302,7 +302,7 @@ void addTree(struct Status *top, struct mssHashNode **str, int strLen){
 }
 
 /**
- * ĥ꡼ɽ(ǥХå)
+ * ツリーの表示(デバッグ用)
  */
 void showTree(struct Status *status){
   int i;
@@ -313,7 +313,7 @@ void showTree(struct Status *status){
     printf("  ");
   }
 
-  /*ȥåץΡȽ*/
+  /*トップノード判定*/
   if(status->val!=NULL){
     printf("status=%s [%d]\n",status->val->str,status->support);
   }else{
@@ -335,7 +335,7 @@ void showTree(struct Status *status){
 }
 
 /**
- * ĥ꡼ΰ賫
+ * ツリーの領域開放
  */
 void freeTree(struct Status *status){
   int i;
@@ -358,7 +358,7 @@ void freeTree(struct Status *status){
 
 /**
  *------------------------------------------------------------------------------
- * ɽϢ
+ * 結果表示関連
  *------------------------------------------------------------------------------
  */
 struct OutItem {
@@ -368,7 +368,7 @@ struct OutItem {
 };
 
 /**
- * OutItem¤ΤˡItem(mssHashNode)ɲä롣
+ * OutItem構造体に、指定のItem(mssHashNode)を追加する。
  */
 void addOutItem(struct OutItem *outItem, struct Status *item){
 
@@ -379,7 +379,7 @@ void addOutItem(struct OutItem *outItem, struct Status *item){
 }
 
 /**
- * OutItem¤ΤǸItem(mssHashNode)롣
+ * OutItem構造体から最後のItem(mssHashNode)を削除する。
  */
 void delOutItem(struct OutItem *outItem){
 
@@ -394,8 +394,8 @@ void delOutItem(struct OutItem *outItem){
 }
 
 /**
- * OutItem->listiܤItemʤItemSetη֤
- * outItem˰ΤItemʤ顢Τη֤
+ * OutItem->listからi番目のItemを省いたItemSetの件数を返す。
+ * outItemに一件のみItemがあるなら、全体の件数を返す。
  */
 int  getItemCnt(struct OutItem *outItem, int omit){
   struct Status *status;
@@ -421,8 +421,8 @@ int  getItemCnt(struct OutItem *outItem, int omit){
 }
 
 /**
- * OutItem->listiܤItemʤItemSetη֤
- * outItem˰ΤItemʤ顢Τη֤
+ * OutItem->listからi番目のItemを省いたItemSetの件数を返す。
+ * outItemに一件のみItemがあるなら、全体の件数を返す。
  */
 int  getOneItemCnt(struct OutItem *outItem, struct Status *status){
   struct HashNode *hn;
@@ -433,16 +433,16 @@ int  getOneItemCnt(struct OutItem *outItem, struct Status *status){
 
 void writeRulePMML(
   struct OutItem *outItem,
-  int conNo,   /*outItem->listˤֹ*/
-  int conCnt,  /**/
-  int antCnt,  /**/
+  int conNo,   /*outItem->listにおける後件番号*/
+  int conCnt,  /*後件部件数*/
+  int antCnt,  /*前件部件数*/
   struct mssFPW *fpw){
   int i;
   int firstWrite;
   int conTotalCnt;
   double conf,supp,lift;
 
-  /**/
+  /*前件部出力*/
   if(outItem->cnt==1){
     mssWriteNull(fpw);
     mssWriteDlm(fpw);
@@ -464,27 +464,27 @@ void writeRulePMML(
   supp=(double)conCnt/(double)TotalCnt;
   lift=conf/((double)conTotalCnt/(double)TotalCnt);
 
-  /**/
+  /*後件部出力*/
   mssWriteStr( (*(outItem->list+conNo))->val->str, fpw);
   mssWriteDlm(fpw);
 
-  /*Item(itemSize)*/
+  /*前件部Item数(itemSize)*/
   mssWriteInt(outItem->cnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(antecedentCnt)*/
+  /*前件部件数(antecedentCnt)*/
   mssWriteInt(antCnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(consequenctCnt)*/
+  /*後件部件数(consequenctCnt)*/
   mssWriteInt(conCnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(consequenctTotal)*/
+  /*後件部全件数(consequenctTotal)*/
   mssWriteInt(conTotalCnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(totalCnt)*/
+  /*全件数(totalCnt)*/
   mssWriteInt(TotalCnt,fpw);
   mssWriteDlm(fpw);
 
@@ -503,16 +503,16 @@ void writeRulePMML(
 
 void writeRuleTEXT(
   struct OutItem *outItem,
-  int conNo,   /*outItem->listˤֹ*/
-  int conCnt,  /**/
-  int antCnt,  /**/
+  int conNo,   /*outItem->listにおける後件番号*/
+  int conCnt,  /*後件部件数*/
+  int antCnt,  /*前件部件数*/
   struct mssFPW *fpw){
   int i;
   int firstWrite;
   int conTotalCnt;
   double conf,supp,lift;
 
-  /**/
+  /*前件部出力*/
   if(outItem->cnt==1){
     mssWriteNull(fpw);
     mssWriteDlm(fpw);
@@ -534,27 +534,27 @@ void writeRuleTEXT(
   supp=(double)conCnt/(double)TotalCnt;
   lift=conf/((double)conTotalCnt/(double)TotalCnt);
 
-  /**/
+  /*後件部出力*/
   mssWriteStr( (*(outItem->list+conNo))->val->str, fpw);
   mssWriteDlm(fpw);
 
-  /*Item(itemSize)*/
+  /*前件部Item数(itemSize)*/
   mssWriteInt(outItem->cnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(antecedentCnt)*/
+  /*前件部件数(antecedentCnt)*/
   mssWriteInt(antCnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(consequenctCnt)*/
+  /*後件部件数(consequenctCnt)*/
   mssWriteInt(conCnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(consequenctTotal)*/
+  /*後件部全件数(consequenctTotal)*/
   mssWriteInt(conTotalCnt,fpw);
   mssWriteDlm(fpw);
 
-  /*(totalCnt)*/
+  /*全件数(totalCnt)*/
   mssWriteInt(TotalCnt,fpw);
   mssWriteDlm(fpw);
 
@@ -573,17 +573,17 @@ void writeRuleTEXT(
 }
 
 /**
- * OutItem->list˥åȤ줿ItemConfʾΥ롼񤭽Ф
+ * OutItem->listにセットされたItemからConf以上のルールを書き出す
  */
 void calConf(struct OutItem *outItem, int support, double minConf, struct mssFPW *fpw){
   int i;
-  int antCnt; /**/
-  int conCnt; /**/
+  int antCnt; /*前件部件数*/
+  int conCnt; /*後件部件数*/
   double conf;
 
   conCnt=(*(outItem->list+outItem->cnt-1))->support;
   for(i=0; i<outItem->cnt; i++){
-    /*iǾʤƥ*/
+    /*iは前件部で省くアイテム*/
     antCnt=getItemCnt(outItem,i);
     conf = (double)conCnt/(double)antCnt;
     if(conf>=minConf){
@@ -600,7 +600,7 @@ void writeRslSub(struct OutItem *outItem, struct Status *status,int minSupp, dou
   int i;
   struct HashNode *node;
 
-  /*ȥåץΡɤλϤȤФ*/
+  /*トップノードの時はとばす*/
   if(status->val!=NULL){
 
     if(status->support < minSupp){
@@ -643,12 +643,12 @@ void writeRsl(struct Status *top, int minSupp, double minConf, struct mssFPW *fp
 
 /**
  *------------------------------------------------------------------------------
- * νУƥॻåȴϢ
+ * 瀕出１アイテムセット関連
  *------------------------------------------------------------------------------
  */
 
 /**
- * supportʾνУƥॻåȤϥåɽϿ
+ * 指定のsupport以上の瀕出１アイテムセットをハッシュ表に登録する
  */
 struct OneItemList *setFrequent1ItemList(MssOptKEY *optKEY,int itemFldNo, double supp, struct mssFldRecDbl *frd,struct mssFPR *fpr){
   struct OneItemList *itemTable;
@@ -668,10 +668,10 @@ struct OneItemList *setFrequent1ItemList(MssOptKEY *optKEY,int itemFldNo, double
   TotalCnt=1;
   while( EOF!=mssReadFRD(fpr,frd) ){
 
-    /*֥쥤ν*/
+    /*キーブレイク時の処理*/
     if(mssKeyBreak(frd, optKEY)){
       if(frd->eof) break;
-      TotalCnt++; /*ѿȥ󥶥*/
+      TotalCnt++; /*この変数に全トランザクション件数を入れる*/
     }
 
     node=mssHashInsertAdd(hash,*(frd->pnt[frd->new]+itemFldNo),v);
@@ -679,7 +679,7 @@ struct OneItemList *setFrequent1ItemList(MssOptKEY *optKEY,int itemFldNo, double
   }
   MinSupportCnt=(int)ceil(TotalCnt*supp);
 
-  /*ݡȷ꾯ʤΡɤ*/
+  /*サポート件数より少ないノードを削除*/
   itemCnt=0;
   for(i=0; i<hash->hashVal; i++){
     if( NULL != (node=*(hash->node+i)) ){
@@ -702,16 +702,16 @@ struct OneItemList *setFrequent1ItemList(MssOptKEY *optKEY,int itemFldNo, double
 }
 
 /**
- * ȥ󥶥ʣƥseqơ֥Ͽ
- * λνУƥॻåȤϿƤʤƥϾʤ
+ * 一トランザクションの複数アイテムをseqテーブルに登録する
+ * この時、瀕出１アイテムセットに登録されていないアイテムは省かれる
  */
 struct mssHashNode **setSeqDat(
-  struct mssHashNode **seq, /*󥹤*/
-  struct mssHash *hash,     /*νУƥॻå(hashɽ)*/
-  int *seqCnt,                /*ȥ󥶥ǲܤitem*/
-  char *str){               /*ϿʸȤƤitem*/
+  struct mssHashNode **seq, /*シーケンスが入る配列*/
+  struct mssHash *hash,     /*瀕出１アイテムセット(hash表)*/
+  int *seqCnt,                /*トランザクション内で何番目のitemか*/
+  char *str){               /*登録する文字列としてのitem*/
 
-  struct mssHashNode *hn;  /*Ͽ줿hashNodeؤΥݥ*/
+  struct mssHashNode *hn;  /*登録されたhashNodeへのポインタ*/
 
   if( NULL != (hn=mssHashMember(hash,str)) ){
     seq=mssRealloc(seq,sizeof(struct mssHashNode *)*(*seqCnt+1),"seq1");
@@ -722,9 +722,9 @@ struct mssHashNode **setSeqDat(
 }
 
 void showSeqDat(
-  struct mssHashNode **seq, /*󥹤*/
-  struct mssHash *hash,     /*νУƥॻå(hashɽ)*/
-  int seqCnt){              /*ȥ󥶥ǲܤitem*/
+  struct mssHashNode **seq, /*シーケンスが入る配列*/
+  struct mssHash *hash,     /*瀕出１アイテムセット(hash表)*/
+  int seqCnt){              /*トランザクション内で何番目のitemか*/
   int i;
   for(i=0; i<seqCnt; i++){
     printf("%s-",(*(seq+i))->str );
@@ -734,202 +734,202 @@ void showSeqDat(
 
 int main(int argc, char *argv[]){
 /*============================================================================*/
-/* ץ                                                       */
+/* オプション宣言＆定義                                                       */
 /*============================================================================*/
 /*----------------------------------------------------------------------------*/
-/* (ȥ󥶥̹)                                         */
+/* キー項目(トランザクション識別項目)                                         */
 /*----------------------------------------------------------------------------*/
   MssOptKEY optKEY={
-    OKEY,   /* ץ󥿥                                             */
-    "k",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    MssFieldMaxCnt, /* ǽʺܿ                                 */
-    "i",    /* оݤȤϥǡΥ(GUI)                  */
-    1,      /* ǥե(Υץ󤬻ꤵʤäȤư) */
-            /* 1:ƤιԤۤ륭ͤȤư                             */
-            /* 2:ƤιԤƱͤȤư)                            */
-    KEYT,   /* ΥץΥȥ(Helpɽ)                         */
-    KEYC    /* ΥץΥ(Helpɽ)                         */
+    OKEY,   /* オプションタイプ                                             */
+    "k",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    MssFieldMaxCnt, /* 指定可能な最大項目数                                 */
+    "i",    /* 対象とする入力データのキーワード(GUIで利用)                  */
+    1,      /* デフォルト(このオプションが指定されなかったときの動作を指定) */
+            /* 1:全ての行を異るキー値として扱う                             */
+            /* 2:全ての行を同じキー値として扱う)                            */
+    KEYT,   /* このオプションのタイトル(Helpで表示)                         */
+    KEYC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ƥ                                                               */
+/* アイテム項目                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptFLD optFLD={
-    OFLD,   /* ץ󥿥                                             */
-    "f",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    MssFieldMaxCnt, /* ǽʺܿ                                 */
-    "i",    /* оݤȤϥǡΥ(GUI)                  */
-    1,      /* ɽĤ뤫ɤ(0:Բ,1:)                      */
-    1,      /* ̾Ǥ뤫ɤ(0:Բ,1:)                    */
-    NULL,   /* ܥץ(%ʲ)ǻǽʸ                        */
-            /* ex) ԲĤξNULL, "nr": "-f ̾%rn"λǽ     */
-    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
-    FLDC,   /* ΥץΥ(Helpɽ)                         */
-    FLDF    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
+    OFLD,   /* オプションタイプ                                             */
+    "f",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    MssFieldMaxCnt, /* 指定可能な最大項目数                                 */
+    "i",    /* 対象とする入力データのキーワード(GUIで利用)                  */
+    1,      /* 正規表現を許可するかどうか(0:不可,1:可)                      */
+    1,      /* 新項目名を指定できるかどうか(0:不可,1:可)                    */
+    NULL,   /* 項目オプション(%以下)で指定可能な文字                        */
+            /* ex) 指定不可の場合はNULL, "nr": "-f 項目名%rn"の指定可能     */
+    FLDT,   /* このオプションのタイトル(Helpで表示)                         */
+    FLDC,   /* このオプションのコメント(Helpで表示)                         */
+    FLDF    /* フラグについての説明(Helpで表示)複数の場合はカンマで区切る   */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ݡȷ()                                                         */
+/* サポート件数(割合)                                                         */
 /*----------------------------------------------------------------------------*/
   MssOptDBL optSPP={
-    ODBL,   /* ץ󥿥                                             */
-    "S",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    0.2,    /* ǥե(ͤȤƻ)                                   */
-    0,      /* Ǿ                                                       */
-    1,      /*                                                        */
-    SPPT,   /* ΥץΥȥ(Helpɽ)                         */
-    SPPC    /* ΥץΥ(Helpɽ)                         */
+    ODBL,   /* オプションタイプ                                             */
+    "S",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    0.2,    /* デフォルト(数値として指定)                                   */
+    0,      /* 最小値                                                       */
+    1,      /* 最大値                                                       */
+    SPPT,   /* このオプションのタイトル(Helpで表示)                         */
+    SPPC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
 /* confidence                                                                 */
 /*----------------------------------------------------------------------------*/
   MssOptDBL optCNF={
-    ODBL,   /* ץ󥿥                                             */
-    "C",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    0.2,    /* ǥե(ͤȤƻ)                                   */
-    0,      /* Ǿ                                                       */
-    1,      /*                                                        */
-    CNFT,   /* ΥץΥȥ(Helpɽ)                         */
-    CNFC    /* ΥץΥ(Helpɽ)                         */
+    ODBL,   /* オプションタイプ                                             */
+    "C",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    0.2,    /* デフォルト(数値として指定)                                   */
+    0,      /* 最小値                                                       */
+    1,      /* 最大値                                                       */
+    CNFT,   /* このオプションのタイトル(Helpで表示)                         */
+    CNFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* õƱƥ                                               */
+/* 探索する同時購入アイテム件数                                               */
 /*----------------------------------------------------------------------------*/
   MssOptINT optMAX={
-    OINT,   /* ץ󥿥                                             */
-    "M",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    4,      /* ǥե(ͤȤƻ)                                   */
-    1,      /* Ǿ                                                       */
-    10,     /*                                                        */
-    MAXT,   /* ΥץΥȥ(Helpɽ)                         */
-    MAXC    /* ΥץΥ(Helpɽ)                         */
+    OINT,   /* オプションタイプ                                             */
+    "M",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    4,      /* デフォルト(数値として指定)                                   */
+    1,      /* 最小値                                                       */
+    10,     /* 最大値                                                       */
+    MAXT,   /* このオプションのタイトル(Helpで表示)                         */
+    MAXC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ̾                                                                   */
+/* 新項目名                                                                   */
 /*----------------------------------------------------------------------------*/
   MssOptSLS optFNM={
-    OSLS,   /* ץ󥿥                                             */
-    "a",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
-    "antecedent,consequent,itemSize,antecedentCnt,consequentCnt,consequentTotal,totalCnt,support,confidence,lift", /* ǥե(ʸ)                   */
-    10,     /* ޤǶڤǿκ                             */
-    1,      /* ǤʸĹκǾ                                     */
-    MssFieldNameMaxLen,/* ǤʸĹκ                          */
-    0,      /* 1:Ǥ˥Ǥ,0:Բ  ex) aaaa:xxxxx            */
-    FNMT,   /* ΥץΥȥ(Helpɽ)                         */
-    FNMC    /* ΥץΥ(Helpɽ)                         */
+    OSLS,   /* オプションタイプ                                             */
+    "a",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須, 2:XMLtableでのみ必須(txtでは無視)      */
+    "antecedent,consequent,itemSize,antecedentCnt,consequentCnt,consequentTotal,totalCnt,support,confidence,lift", /* デフォルト(文字列)                   */
+    10,     /* カンマで区切られる要素数の最大値                             */
+    1,      /* 各要素の文字列長の最小値                                     */
+    MssFieldNameMaxLen,/* 各要素の文字列長の最大値                          */
+    0,      /* 1:要素にコロンを指定できる,0:不可  ex) aaaa:xxxxx            */
+    FNMT,   /* このオプションのタイトル(Helpで表示)                         */
+    FNMC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 入力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptINF optINF={
-    OINF,   /* ץ󥿥                                             */
-    "i",    /* (ʣʸԲ)                                   */
-    1,      /* 0:ץ, 1:ɬ                                         */
-    1,      /* ǽκե                                     */
-    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
-    INFT,   /* ΥץΥȥ(Helpɽ)                         */
-    INFC    /* ΥץΥ(Helpɽ)                         */
+    OINF,   /* オプションタイプ                                             */
+    "i",    /* キーワード(複数文字は不可)                                   */
+    1,      /* 0:オプション, 1:必須                                         */
+    1,      /* 指定可能の最大ファイル数                                     */
+    0,      /*1:file not foundのエラーで終了しない 0:する                   */
+    INFT,   /* このオプションのタイトル(Helpで表示)                         */
+    INFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ϥե                                                               */
+/* 出力ファイル                                                               */
 /*----------------------------------------------------------------------------*/
   MssOptOTF optOTF={
-    OOTF,   /* ץ󥿥                                             */
-    "o",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
-    OTFC    /* ΥץΥ(Helpɽ)                         */
+    OOTF,   /* オプションタイプ                                             */
+    "o",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    OTFT,   /* このオプションのタイトル(Helpで表示)                         */
+    OTFC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
 /* PMML                                                                       */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optPML={
-    OFLG,   /* ץ󥿥                                             */
-    "p",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    PMLT,   /* ΥץΥȥ(Helpɽ)                         */
-    PMLC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "p",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    PMLT,   /* このオプションのタイトル(Helpで表示)                         */
+    PMLC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
 /* plain text                                                                 */
 /*----------------------------------------------------------------------------*/
   MssOptFLG optTXT={
-    OFLG,   /* ץ󥿥                                             */
-    "t",    /* (ʣʸԲ)                                   */
-    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
-    TXTT,   /* ΥץΥȥ(Helpɽ)                         */
-    TXTC    /* ΥץΥ(Helpɽ)                         */
+    OFLG,   /* オプションタイプ                                             */
+    "t",    /* キーワード(複数文字は不可)                                   */
+    0,      /* デフォルト(基本的には0) 常にonにしたいときは1にする          */
+    TXTT,   /* このオプションのタイトル(Helpで表示)                         */
+    TXTC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* եѥǥ쥯ȥ̾                                             */
+/* ワークファイル用ディレクトリ名                                             */
 /*----------------------------------------------------------------------------*/
   MssOptSTR optTMP={
-    OSTR,   /* ץ󥿥                                             */
-    "T",    /* (ʣʸԲ)                                   */
-    0,      /* 0:ץ, 1:ɬ                                         */
-    MssTempDir, /* ǥե                                               */
-    1,      /* ʸκǾĹ                                               */
-    MssFileNameMaxLen,  /* ʸκĹ                                  */
-    TMPT,   /* ΥץΥȥ(Helpɽ)                         */
-    TMPC    /* ΥץΥ(Helpɽ)                         */
+    OSTR,   /* オプションタイプ                                             */
+    "T",    /* キーワード(複数文字は不可)                                   */
+    0,      /* 0:オプション, 1:必須                                         */
+    MssTempDir, /* デフォルト                                               */
+    1,      /* 文字列の最小長                                               */
+    MssFileNameMaxLen,  /* 文字列の最大長                                  */
+    TMPT,   /* このオプションのタイトル(Helpで表示)                         */
+    TMPC    /* このオプションのコメント(Helpで表示)                         */
   };
 
 /*----------------------------------------------------------------------------*/
-/* ץޤȤ                                                       */
+/* オプションをまとめる                                                       */
 /*----------------------------------------------------------------------------*/
   void *opt[]={&optKEY,&optFLD,&optSPP,&optCNF,&optMAX,&optPML,&optFNM,
                &optINF,&optOTF,&optTXT,&optTMP,NULL};
 
 /*============================================================================*/
-/* ѿ                                                             */
+/* 変数宣言＆定義                                                             */
 /*============================================================================*/
-  struct mssHeader    *hdi;      /*ϥե<head>Ǽ¤*/
-  struct mssHeader    *hdo;      /*ϥե<head>Ǽ¤*/
-  struct mssFPR       *fpr;      /*ϥե빽¤                */
-  struct mssFPW       *fpw;      /*ϥե빽¤                */
-  struct mssFldRecDbl *frd=NULL; /*-Хåե¤           */
-  struct mssFields     *sf;      /*ȹܹ¤                  */
-  int sorted;                    /*Ⱥѥå                */
+  struct mssHeader    *hdi;      /*入力ファイル用<head>タグ格納構造体*/
+  struct mssHeader    *hdo;      /*出力ファイル用<head>タグ格納構造体*/
+  struct mssFPR       *fpr;      /*入力ファイル構造体                */
+  struct mssFPW       *fpw;      /*出力ファイル構造体                */
+  struct mssFldRecDbl *frd=NULL; /*項目-キーバッファ構造体           */
+  struct mssFields     *sf;      /*ソート項目構造体                  */
+  int sorted;                    /*ソート済チェック用                */
 
-  struct OneItemList *oneItemList; /*νУƥꥹ*/
-  int itemFldNo;                 /*-fܤΥǡǤΰ*/
-  struct mssHashNode **seq;      /*itemΥ󥹤*/
-  int seqCnt;                     /*󥹤ǤΥitemֹ*/
+  struct OneItemList *oneItemList; /*瀕出１アイテムリスト*/
+  int itemFldNo;                 /*-f項目のデータ上での位置*/
+  struct mssHashNode **seq;      /*itemのシーケンスが入る配列*/
+  int seqCnt;                     /*シーケンスでのカレントitem番号*/
 
   struct Status *topStatus;
 
 /*----------------------------------------------------------------------------*/
-/*                                                                      */
+/* 前処理                                                                     */
 /*----------------------------------------------------------------------------*/
-  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
-  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
-  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
-  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
-  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
-  mssSetOptKey(&optKEY, hdi);        /* -k ܤإåܤ˴ϢŤ     */
-  mssSetOptFld(&optFLD, hdi);        /* -f ܤإåܤ˴ϢŤ     */
+  mssInit(argc,argv,&comHelp);       /* シグナル処理などの初期化              */
+  mssHelpDoc(opt,&comHelp,argc,argv);/* ヘルプ                                */
+  mssSetOption(opt,argc,argv);       /* コマンドオプションの設定              */
+  fpr=mssOpenFPR(optINF.str,4);      /* 入力ファイルオープン                  */
+  hdi=mssReadHeader(fpr);            /* ヘッダの読み込み                      */
+  mssSetOptKey(&optKEY, hdi);        /* -k 項目をヘッダー項目に関連づける     */
+  mssSetOptFld(&optFLD, hdi);        /* -f 項目をヘッダー項目に関連づける     */
 
-  /*-pϸߥݡȤƤʤ*/
+  /*-pは現在サポートされていない*/
   if(optPML.set){
     mssShowErrMsg("PMML is not supported in the current version");
     mssEnd(mssErrorNoDefault);
   }
 
-  /*-aꤹĿ10ǤʤФʤʤ*/
+  /*-aを指定する時、個数は10でなければならない*/
   if(optFNM.set && optFNM.cnt!=10){
     mssShowErrMsg("must specify 10 field names on -a");
     mssEnd(mssErrorNoDefault);
@@ -938,12 +938,12 @@ int main(int argc, char *argv[]){
   DepthMax=optMAX.val;
   PMML=optPML.set;
 
-  /*ȹܤκ*/
+  /*ソート項目の作成*/
   sf=mssInitFields();
-  mssAddFieldsByFields(sf,optKEY.flds); /* -k ܤ򥽡ȹܤȤƥå    */
-  mssAddFieldsByFields(sf,optFLD.flds); /* -k ܤ򥽡ȹܤȤƥå    */
-  mssSetFieldsSortPriority(sf);         /* ֹͥϿˤդ   */
-  sorted=mssChkSorted(sf,hdi);          /* ȺѤå                 */
+  mssAddFieldsByFields(sf,optKEY.flds); /* -k 項目をソート項目としてセット    */
+  mssAddFieldsByFields(sf,optFLD.flds); /* -k 項目をソート項目としてセット    */
+  mssSetFieldsSortPriority(sf);         /* ソート優先順位番号を登録順にふる   */
+  sorted=mssChkSorted(sf,hdi);          /* ソート済かチェック                 */
 
 /*mssShowFields(sf);*/
 /*mssShowOption(opt);*/
@@ -951,20 +951,20 @@ int main(int argc, char *argv[]){
 
 
 /*----------------------------------------------------------------------------*/
-/*ᥤ롼                                                              */
+/*メインルーチン                                                              */
 /*----------------------------------------------------------------------------*/
-  /*ȤɬѤʤХȤƥȺѤߥեȤƥץ*/
+  /*ソートが必用ならばソートしてソート済みファイルとしてオープン*/
   if(!sorted){
     fpr=mssReopenFPRsort(fpr,4,sf,hdi->flds->cnt,optTMP.str);
   }
 
 
   /*------------------------------------------------*/
-  /*ݡȷʾΣƥνХꥹȤ*/
+  /*サポート件数以上の１アイテム瀕出リストを作成する*/
   /*------------------------------------------------*/
   mssShowMsg("scanning frequent one item list");
-  itemFldNo=MssFlds2num(optFLD.flds,0); /*itemܤΥǡǤΰ*/
-  frd=mssInitFRD(hdi->flds->cnt);       /*쥳-ܹ¤*/
+  itemFldNo=MssFlds2num(optFLD.flds,0); /*item項目のデータ上での位置*/
+  frd=mssInitFRD(hdi->flds->cnt);       /*レコード-項目構造体*/
   oneItemList = setFrequent1ItemList(&optKEY,
                               MssFlds2num(optFLD.flds,0),
                               optSPP.val,
@@ -976,16 +976,16 @@ int main(int argc, char *argv[]){
   mssFreeFRD(frd);
 
   /*------------------------------------------------*/
-  /* ĥ꡼κ                                   */
+  /* ツリーの作成                                   */
   /*------------------------------------------------*/
   mssShowMsg("creating tree");
-  topStatus=initStatus(0); /*ΥȥåץΡstatusκ*/
-  seq=NULL;                /*ƥȥ󥶥󤴤ȤΥƥꥹ*/
-  seqCnt=0;                /*󥹤ǤΥitemֹ*/
+  topStatus=initStatus(0); /*深さ０のトップノードstatusの作成*/
+  seq=NULL;                /*各トランザクションごとのアイテムリスト*/
+  seqCnt=0;                /*シーケンスでのカレントitem番号*/
   mssSeekTopFPR(fpr);
   frd=mssInitFRD(hdi->flds->cnt);
   while( EOF!=mssReadFRD(fpr,frd) ){
-    /*֥쥤ν*/
+    /*キーブレイク時の処理*/
     if(mssKeyBreak(frd, &optKEY)){
       if(seqCnt>0){
         addTree(topStatus,seq,seqCnt);
@@ -998,55 +998,55 @@ int main(int argc, char *argv[]){
     }
    
     mssGV.inCnt++;
-    /*̾Ԥν(ƥꥹȤκ)*/
+    /*通常行の処理(アイテムリストの作成)*/
     seq=setSeqDat(seq,oneItemList->hash, &seqCnt,
                   *(frd->pnt[frd->new]+itemFldNo));
   }
   /*showTree(topStatus);*/
 
   /*------------------------------------------------*/
-  /* ̤ν                                     */
+  /* 結果の出力                                     */
   /*------------------------------------------------*/
   mssShowMsg("outputing result");
 
   fpw=mssOpenFPW(optOTF.str,0,0);
 
-  /*ϥإåν(ȥΥԡ)*/
+  /*出力ヘッダーの初期化(タイトル等のコピー)*/
   hdo=mssInitCpyHeader(hdi);
 
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+0)); /*unit̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+1)); /*no̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+2)); /*len̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+3)); /*cnt̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+4)); /*totalCnt̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+5)); /*totalCnt̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+6)); /*totalCnt̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+7)); /*totalCnt̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+8)); /*totalCnt̾ɲ*/
-  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+9)); /*totalCnt̾ɲ*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+0)); /*unit項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+1)); /*no項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+2)); /*len項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+3)); /*cnt項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+4)); /*totalCnt項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+5)); /*totalCnt項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+6)); /*totalCnt項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+7)); /*totalCnt項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+8)); /*totalCnt項目名の追加*/
+  mssAddFieldsByStr(hdo->flds,*(optFNM.strList+9)); /*totalCnt項目名の追加*/
 
   if(!PMML) mssWriteHeader(hdo, fpw);
 
   writeRsl(topStatus,MinSupportCnt,optCNF.val,fpw);
 
   /*------------------------------------------------*/
-  /* Ƽΰ賫                                   */
+  /* 各種領域開放                                   */
   /*------------------------------------------------*/
   freeTree(topStatus);
   mssFreeHash(oneItemList->hash);
   mssFreeFRD(frd);
 
 /*----------------------------------------------------------------------------*/
-/*եå&λ                                                       */
+/*フッター出力&終了処理                                                       */
 /*----------------------------------------------------------------------------*/
-  if(!PMML) mssWriteFooter(fpw);    /* եåν             */
-  mssCloseFPR(fpr);       /* ϥեΥ     */
-  mssCloseFPW(fpw);       /* ϥեΥ     */
-  mssFreeFields(sf);      /* ȹܹ¤Τΰ賫 */
-  mssFreeHeader(hdi);     /* ϥإåΰ賫         */
-  mssFreeHeader(hdo);     /* ϥإåΰ賫         */
-  mssFreeOption(opt);     /* ץΰ賫         */
-  mssShowEndMsg();        /* λå             */
-  mssEnd(mssExitSuccess); /* λ                       */
+  if(!PMML) mssWriteFooter(fpw);    /* フッターの出力             */
+  mssCloseFPR(fpr);       /* 入力ファイルのクローズ     */
+  mssCloseFPW(fpw);       /* 出力ファイルのクローズ     */
+  mssFreeFields(sf);      /* ソート項目構造体の領域開放 */
+  mssFreeHeader(hdi);     /* 入力ヘッダ領域開放         */
+  mssFreeHeader(hdo);     /* 出力ヘッダ領域開放         */
+  mssFreeOption(opt);     /* オプション領域開放         */
+  mssShowEndMsg();        /* 完了メッセージ             */
+  mssEnd(mssExitSuccess); /* 終了                       */
   return(0);              /* to avoid warning message   */
 }
