@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * BONSAIϢδؿ
+ * BONSAI関連の関数
  * ============================================================================
  */
 
@@ -12,41 +12,41 @@
 #include <condition.h>
 #include <priorityQueue.h>
 
-/* ############ Хѿ ##############*/
-/*ѥ顼᡼*/
+/* ############ グローバル変数 ##############*/
+/*パラーメータ*/
 extern MssOptFLG optSEQ;
 extern MssOptINT optEND;
 extern MssOptINT optBGN;
 extern MssOptINT optSED;
 extern MssOptINT optCAN;
 
-extern int ClassSize; /*饹Υ*/
+extern int ClassSize; /*クラスのサイズ*/
 
-int usedRandSeed; /*Ѥ줿μ(ɽѤȤtree.cǻ)*/
+int usedRandSeed; /*利用された乱数の種(表示用としてtree.cで参照)*/
 
 /*
  * # STRUCT #
- * ѥǼץ饤ƥ塼¤
+ * 正規パターン候補を格納するプライオリティキュー構造体
  */
 struct RegBest{
-  struct PQnode *pqNode; /*ץ饤ƥ塼*/
-  int    cnt;            /*ϿƤ*/
-  int    maxCnt;         /*ѥ(optCAN)*/
-  double maxVal;         /*ץ饤ƥ塼ϿƤǺǤ*/
-                         /*GiniIndex*/
+  struct PQnode *pqNode; /*プライオリティキュー本体*/
+  int    cnt;            /*現在登録されている候補数*/
+  int    maxCnt;         /*正規パターン最大候補数(optCAN)*/
+  double maxVal;         /*プライオリティキューに登録されている中で最も*/
+                         /*悪いGiniIndexの値*/
 };
 
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ե٥åȡݥǥåϢδؿ
+ * アルファベット−インデックス関連の関数
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * 륵ΥǥåȤŬڤǤ1else 0֤
- * ǤŬڤȤϡǥåΥʬμѤƤ륤ǥå
+ * ローカルサーチ初期のインデックスとして適切であれば1、else 0を返す
+ * ここでの適切とは、インデックスのサイズ分の種類を全て用いてるインデックス
  */
 static int goodInitIdx( usint *idx, int cnt){
   int len;
@@ -67,8 +67,8 @@ static int goodInitIdx( usint *idx, int cnt){
 
 /**
  * # FUNCTION #
- * ǥåȤŬڤǤ1else 0֤
- * ǤΡŬڡפȤϡƤƱǤʤǥå
+ * インデックスとして適切であれば1、else 0を返す
+ * ここでの「適切」とは、全てが同じでないインデックス
  */
 static int goodIdx(usint *idx){
   int i;
@@ -83,8 +83,8 @@ static int goodIdx(usint *idx){
 
 /**
  * # FUNCTION #
- * ǥå򥢥ե٥åȤƱѰդ
- * ǥåʤ(-s 0)ξѤ
+ * インデックスをアルファベットと同じ種類用意する
+ * インデックス化なし(-s 0)の場合に用いる
  */
 struct Idxs *initIdxs0(struct Data *dat){
   int i,j,k;
@@ -92,7 +92,7 @@ struct Idxs *initIdxs0(struct Data *dat){
   struct Idxs *idxs;
   usint *str;
 
-  usedRandSeed=mssInitRand(optSED.val); /**/
+  usedRandSeed=mssInitRand(optSED.val); /*乱数初期化*/
 
   idxs=mssMalloc(sizeof(struct Idxs),"initIdxs01");
   idxs->idx=mssMalloc(sizeof(usint **)*1,"initIdxs02");
@@ -118,7 +118,7 @@ struct Idxs *initIdxs0(struct Data *dat){
 
 /**
  * # FUNCTION #
- * ǥå˷ꤹ
+ * インデックスをランダムに決定する
  */
 struct Idxs *initIdxs(struct Data *dat){
   int i,j,k;
@@ -130,7 +130,7 @@ struct Idxs *initIdxs(struct Data *dat){
   int numCnt;
   int digits;
 
-  usedRandSeed=mssInitRand(optSED.val); /**/
+  usedRandSeed=mssInitRand(optSED.val); /*乱数初期化*/
 
   idxs=mssMalloc(sizeof(struct Idxs),"initIdxs1");
   idxs->idx=mssMalloc(sizeof(usint **)*1,"initIdxs2");
@@ -147,7 +147,7 @@ struct Idxs *initIdxs(struct Data *dat){
     *(*(idxs->idx+0)+j)=mssCalloc(sizeof(usint)*(size+1),"initIdxs4");
     str=*(*(idxs->idx+0)+j);
 
-    /*ͥѥξ*/
+    /*数値パターンの場合*/
     if((dat->pat+j)->numPat){
       numCnt=0;
       while(numCnt<(dat->pat+j)->map->idxSiz-1){
@@ -162,7 +162,7 @@ struct Idxs *initIdxs(struct Data *dat){
         *(str+i)=num;
       }
 
-    /*ʸѥξ*/
+    /*文字パターンの場合*/
     }else{
       while(1){
         for(k=0; k<size; k++){
@@ -178,7 +178,7 @@ struct Idxs *initIdxs(struct Data *dat){
 
 /**
  * # FUNCTION #
- * ǥåꥹȤγ(ѥܿʬ)
+ * インデックスリストの開放(パターン項目数分)
  */
 static void freeIdxsSub(usint **add, int cnt){
   int i;
@@ -190,7 +190,7 @@ static void freeIdxsSub(usint **add, int cnt){
 
 /**
  * # FUNCTION #
- * ǥåꥹȤγ()
+ * インデックスリストの開放(全て)
  */
 void freeIdxs(struct Idxs *idxs){
   int i;
@@ -204,16 +204,16 @@ void freeIdxs(struct Idxs *idxs){
 
 /**
  * # FUNCTION #
- * ǥåΰγ
+ * インデックス領域の確保
  */
 static struct Idxs *malNextIdxs(struct Idxs *idxs, struct Data *dat){
   int i;
 
-  /*ΰ*/
+  /*領域確保*/
   idxs->idx=mssRealloc(idxs->idx,sizeof(usint **)*(idxs->cnt+1),"malIdxs1");
   *(idxs->idx+idxs->cnt)=mssCalloc(sizeof(usint *)*dat->patCnt,"malIdxs2");
 
-  /*öȤalpha-index򥳥ԡ*/
+  /*一旦もとのalpha-indexをコピーする*/
   for(i=0; i<dat->patCnt; i++){
     *(*(idxs->idx+idxs->cnt)+i)
       =mssCalloc(sizeof(usint)*((dat->pat+i)->map->alpSiz+1),"malIdxs3");
@@ -224,7 +224,7 @@ static struct Idxs *malNextIdxs(struct Idxs *idxs, struct Data *dat){
 
 /**
  * # FUNCTION #
- * ߤΥǥåŤѹǥåΥꥹȤ
+ * 現在のインデックスから一桁づつ変更したインデックスのリストを作成
  */
 struct Idxs *setNextIdxs(struct Data *dat){
   int i,j,k;
@@ -238,19 +238,19 @@ struct Idxs *setNextIdxs(struct Data *dat){
   idxs->cnt=0;
   idxs->patCnt=dat->patCnt;
 
-  /*ǥåѹܤǲ*/
+  /*インデックスを変更する項目で回す*/
   for(i=0; i<dat->patCnt; i++){
-    numPat=(dat->pat+i)->numPat; /*ͥѥ󤫤ɤ*/
-    for(j=0; j<(dat->pat+i)->map->alpSiz; j++){ /*alphaĹ*/
-      chr=*((dat->pat+i)->map->idx+j); /*оݤʸ*/
+    numPat=(dat->pat+i)->numPat; /*数値パターンかどうか*/
+    for(j=0; j<(dat->pat+i)->map->alpSiz; j++){ /*alphaの長さ回す*/
+      chr=*((dat->pat+i)->map->idx+j); /*対象の文字*/
       if(!numPat){
-        for(k=1; k<=(dat->pat+i)->map->idxSiz; k++){ /*indexμ*/
+        for(k=1; k<=(dat->pat+i)->map->idxSiz; k++){ /*indexの種類回す*/
           if(k==chr) continue;
           idxs=malNextIdxs(idxs,dat);
           *(*(*(idxs->idx+idxs->cnt)+i)+j)=k;
           if( !goodIdx( *(*(idxs->idx+idxs->cnt)+i) ) ){
             freeIdxsSub( *(idxs->idx+idxs->cnt),dat->patCnt );
-            continue; /*idxs->cnt򥫥ȥåפʤΤϿʤƱ*/
+            continue; /*idxs->cntをカウントアップしないので登録しないと同じ*/
           }
           idxs->cnt++;
         }
@@ -264,7 +264,7 @@ struct Idxs *setNextIdxs(struct Data *dat){
           *(*(*(idxs->idx+idxs->cnt)+i)+j)=prv;
           if( !goodIdx( *(*(idxs->idx+idxs->cnt)+i) ) ){
             freeIdxsSub( *(idxs->idx+idxs->cnt),dat->patCnt );
-            continue; /*idxs->cnt򥫥ȥåפʤΤϿʤƱ*/
+            continue; /*idxs->cntをカウントアップしないので登録しないと同じ*/
           }
           idxs->cnt++;
         }
@@ -273,7 +273,7 @@ struct Idxs *setNextIdxs(struct Data *dat){
           *(*(*(idxs->idx+idxs->cnt)+i)+j)=nxt;
           if( !goodIdx( *(*(idxs->idx+idxs->cnt)+i) ) ){
             freeIdxsSub( *(idxs->idx+idxs->cnt),dat->patCnt );
-            continue; /*idxs->cnt򥫥ȥåפʤΤϿʤƱ*/
+            continue; /*idxs->cntをカウントアップしないので登録しないと同じ*/
           }
           idxs->cnt++;
         }
@@ -285,7 +285,7 @@ struct Idxs *setNextIdxs(struct Data *dat){
 
 /**
  * # FUNCTION #
- * ʣǥådat¤ΤؤΥԡ
+ * 複数インデックスのdat構造体へのコピー
  */
 void cpyIdx(struct Data *dat, usint **idx){
   int j;
@@ -297,7 +297,7 @@ void cpyIdx(struct Data *dat, usint **idx){
 
 /**
  * # FUNCTION #
- * Ϳ줿alphabetбindex֤
+ * 与えられたalphabetに対応するindexを返す
  */
 char alp2idx(struct Map *map, usint alpha){
   int i;
@@ -311,7 +311,7 @@ char alp2idx(struct Map *map, usint alpha){
 
 /**
  * # FUNCTION #
- * Ϳ줿alphabetʸбindexʸ򥻥åȤ
+ * 与えられたalphabet文字列に対応するindex文字列をセットする
  */
 void alpStr2idxStr(usint index[],usint *alpha, struct Map *map){
   int i=0;
@@ -325,39 +325,39 @@ void alpStr2idxStr(usint index[],usint *alpha, struct Map *map){
 
 /**
  * # FUNCTION #
- * dat¤ΤΥǡ򥤥ǥå
+ * dat構造体のデータをインデックス化する
  */
 void datIndexing( struct Data *dat ){
 
-  usint          alpha;            /*ե٥åʸ*/
-  usint          index[MaxPatLen]; /*ǥå줿ʸ*/
-  usint         *str;              /*ѥȤΰŪݥ*/
+  usint          alpha;            /*アルファベット文字*/
+  usint          index[MaxPatLen]; /*インデックス化された文字列を入れる*/
+  usint         *str;              /*パターンを操作するときの一時的ポインタ*/
   int i,j,k;
 
-  for(i=0; i<dat->patCnt; i++){ /*ѥܿ*/
+  for(i=0; i<dat->patCnt; i++){ /*パターン項目数*/
     freeStrListUSI((dat->pat+i)->patIdx);
-    /*index줿ǡѿ*/
+    /*index化されたデータを入れる変数初期化*/
     (dat->pat+i)->patIdx=initStrListUSI();
   }
 
-  for(i=0; i<dat->patCnt; i++){ /*ѥܿ*/
-    for(j=0; j<dat->cnt; j++){  /*ǡ*/
-      k=0;                      /*ǥåθʸ*/
-      /*iܹܤjܥǡʸ*/
+  for(i=0; i<dat->patCnt; i++){ /*パターン項目数*/
+    for(j=0; j<dat->cnt; j++){  /*データ件数*/
+      k=0;                      /*インデックスの現在文字数*/
+      /*i番目項目のj行目データの文字列*/
       str=getStrListUSI((dat->pat+i)->patAlp,j);
-      while(*str!='\0'){ /*NULLͤξϤʤ֥졼*/
+      while(*str!='\0'){ /*NULL値の場合はいきなりブレーク*/
         alpha=*(str++);
         index[k++]=alp2idx((dat->pat+i)->map,alpha);
       }
-      index[k]=0; /*ߥ͡*/
-      putStrListUSI( (dat->pat+i)->patIdx, index); /*ѥγǼ*/
+      index[k]=0; /*ターミネータ*/
+      putStrListUSI( (dat->pat+i)->patIdx, index); /*パターンの格納*/
     }
   }
 }
 
 /**
  * # FUNCTION #
- * ѥ°Ȥơ֥
+ * 正規パターンを属性とするテーブルを作成
  */
 void mkAtt( struct Data *dat ){
 
@@ -365,7 +365,7 @@ void mkAtt( struct Data *dat ){
 
   freeAtt(dat);
 
-  /*ѥ°ΰγ*/
+  /*パターン属性領域の確保*/
   for(i=0; i<dat->patCnt; i++){
     (dat->pat+i)->attCnt = (dat->pat+i)->regTbl->cnt;
 
@@ -374,10 +374,10 @@ void mkAtt( struct Data *dat ){
     }
   }
 
-  /*ɽ°*/
-  for(i=0; i<dat->patCnt; i++){ /*ѥܿ*/
-    for(j=0; j<dat->cnt; j++){ /*ץǡ*/
-      for(k=0; k<(dat->pat+i)->attCnt; k++){ /*ɽ*/
+  /*正規表現属性*/
+  for(i=0; i<dat->patCnt; i++){ /*パターン項目数*/
+    for(j=0; j<dat->cnt; j++){ /*サンプルデータ件数*/
+      for(k=0; k<(dat->pat+i)->attCnt; k++){ /*正規表現数*/
       *((dat->pat+i)->att[k]+j) =
          (char)regCmp( getStrListUSI((dat->pat+i)->patIdx,j),
                      (dat->pat+i)->regTbl->reg+k );
@@ -388,7 +388,7 @@ void mkAtt( struct Data *dat ){
 
 /**
  * # FUNCTION #
- * ѥ°Ȥơ֥ΰ賫
+ * 正規パターンを属性とするテーブルの領域開放
  */
 void freeAtt( struct Data *dat ){
   int i,j;
@@ -403,13 +403,13 @@ void freeAtt( struct Data *dat ){
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ѥϢ
+ * 正規パターン関連
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * Regexp¤ΤΥԡ
+ * Regexp構造体のコピー
  */
 void cpReg(struct Regexp *to, struct Regexp *from){
 
@@ -422,14 +422,14 @@ void cpReg(struct Regexp *to, struct Regexp *from){
 
 /**
  * # FUNCTION #
- * ʸstrκǸnʸǽʸreg뤫ɤ
+ * 文字列strの最後のn文字内で終る文字列regがあるかどうか
  */
 static int atEndRng(usint *str,usint *reg,int n){
-  int l=strlenUSI(str); /*strĹ*/
-  int s=strlenUSI(reg); /*regĹ*/
+  int l=strlenUSI(str); /*strの長さ*/
+  int s=strlenUSI(reg); /*regの長さ*/
   int i;
-  int start; /*strθϰ*/
-  int end;   /*strθλ*/
+  int start; /*strの検索開始位置*/
+  int end;   /*strの検索終了位置*/
 
   start=l-n-s+1;
   if(start<0){start=0;end=start+l-s+1;}
@@ -442,41 +442,41 @@ static int atEndRng(usint *str,usint *reg,int n){
 
 /**
  * # FUNCTION #
- * substringΥޥå(1:ޥå,0:ޥå)
+ * substringのマッチング(1:マッチ,0:アンマッチ)
  */
 int regCmpStr(usint *str,struct Regexp *reg){
-  usint *bgnPos; /*ǽθǤΰװ*/
+  usint *bgnPos; /*最初の検索での一致位置*/
 
-  /*substringmatch֤򸡺*/
+  /*substringのmatch位置を検索*/
   if( NULL == (bgnPos=strstrUSI(str,reg->str)) ) return(0);
 
-  /*Ƭפλ꤬*/
+  /*先頭一致の指定がある場合*/
   if(reg->bgnRng!=0){
     if(bgnPos-str >= reg->bgnRng) return(0);
   }
 
-  /*פλ꤬*/
+  /*末尾一致の指定がある場合*/
   if(reg->endRng!=0){
     if(0==atEndRng(str,reg->str,reg->endRng)) return(0);
   }
 
-  /*嵭ξ˰äʤаפȤ*/
+  /*上記の条件に引っかからなければ一致ということ*/
   return(1);
 }
 
 /**
  * # FUNCTION #
- * subsequenceΥޥå(1:ޥå,0:ޥå)
+ * subsequenceのマッチング(1:マッチ,0:アンマッチ)
  */
 int regCmpSeq(usint *str,struct Regexp *reg){
   usint *strPnt=str;
   usint *regPnt=reg->str;
-  usint *strEnd; /*strend*/
-  usint *regEnd; /*reg->strend*/
+  usint *strEnd; /*strのend位置*/
+  usint *regEnd; /*reg->strのend位置*/
   int   flg;
   int   i;
 
-  /*subsequenceȤưפ뤫Ĵ٤*/
+  /*subsequenceとして一致するか調べる*/
   while(*regPnt!=0 && *strPnt!=0){
     if(NULL==(strPnt=strchrUSI(strPnt,*regPnt))){
       return(0);
@@ -485,10 +485,10 @@ int regCmpSeq(usint *str,struct Regexp *reg){
     regPnt++;
   }
 
-  /*ѥʸɤڤäƤʤ*/
+  /*正規パターンの文字を読み切っていなければ*/
   if(*regPnt!=0) return(0);
 
-  /*Ƭפλ꤬,ѥκǽʸbgnRngˤ뤫Ĵ٤*/
+  /*先頭一致の指定があれば,正規パターンの最初の文字がbgnRng内にあるか調べる*/
   if(reg->bgnRng!=0){
     flg=0;
     for(i=0; i<reg->bgnRng; i++){
@@ -497,7 +497,7 @@ int regCmpSeq(usint *str,struct Regexp *reg){
     if(!flg) return(0);
   }
 
-  /*פλ꤬,ѥκǽʸendRngˤ뤫Ĵ٤*/
+  /*末尾一致の指定があれば,正規パターンの最初の文字がendRng内にあるか調べる*/
   if(reg->endRng!=0){
     flg=0;
     strEnd=     str+strlenUSI(     str)-1;
@@ -508,14 +508,14 @@ int regCmpSeq(usint *str,struct Regexp *reg){
     if(!flg) return(0);
   }
 
-  /*嵭ξ˰äʤаפȤ*/
+  /*上記の条件に引っかからなければ一致ということ*/
   return(1);
 }
 
 /**
  * # FUNCTION #
- * ѥͿ줿ʸ˥ޥå뤫ɤ(1:ޥå,0:ޥå)
- * substring or subsequence , end,start θ
+ * 正規パターンが与えられた文字列にマッチするかどうか(1:マッチ,0:アンマッチ)
+ * substring or subsequence , end位置,start位置 を考慮
  */
 int regCmp(usint *str, struct Regexp *reg){
 
@@ -533,7 +533,7 @@ int regCmp(usint *str, struct Regexp *reg){
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ѥݤι®르ꥺ
+ * 正規パターン候補を求める際の高速アルゴリズム
  *  algorithm by
  *    M. Hirao, H.Hoshino, A.Shinohara, M.Takeda, and S.Arikawa,
  *    "A Practical Algorithm to Find the Best Subsequence Patterns"
@@ -542,8 +542,8 @@ int regCmp(usint *str, struct Regexp *reg){
 
 /**
  * # FUNCTION #
- * 饹̥ޥåޥåɽ顢upperBound 
- * upperBound : оݤȤʤѥĥɤsv
+ * クラス別マッチ、アンマッチ件数表から、upperBound を求める
+ * upperBound : 対象となる正規パターンを拡張して得られる最良のsv
  */
 static double calUpperBound( struct CndCnt *cnt){
 
@@ -591,43 +591,43 @@ static double calUpperBound( struct CndCnt *cnt){
 
 /**
  * # FUNCTION #
- * ѥΥǡФGINIupperBound
- * ѥ󤬰ޥåʤ1,Ǥʤ0֤
+ * 正規パターンのデータに対するGINIおよびupperBoundを求める
+ * 正規パターンが一件もマッチしなければ1,そうでなければ0を返す
  */
 static int regCnt(
-  struct PQkey   *pqKey,     /*ѥ*/
-  struct StrListUSI  *patIdx,/*index줿training dataΥѥܥǡ*/
-  struct Class   *cls,       /*饹ܥǡ*/
-  struct Cost    *cost){     /*ȥǡ*/
+  struct PQkey   *pqKey,     /*正規パターン*/
+  struct StrListUSI  *patIdx,/*index化されたtraining dataのパターン項目データ*/
+  struct Class   *cls,       /*クラス項目データ*/
+  struct Cost    *cost){     /*コストデータ*/
 
-  struct CndCnt  cnt; /*饹̥ޥåޥåɽ*/
+  struct CndCnt  cnt; /*クラス別マッチ、アンマッチ件数表*/
 
   int i;
 
-  /*cntν*/
+  /*cntの初期化*/
   iniCndCnt(&cnt,cost);
 
-  /*ǡƤѥƤϤᡢCndCnt¤Τ˷򥻥åȤ*/
+  /*データ行全てを正規パターンに当てはめ、CndCnt構造体に件数をセットする*/
   for(i=0; i<patIdx->lineCnt; i++){
 
-    /*ιԤޥåƤ*/
+    /*その行がマッチしていれば*/
     if(regCmp(getStrListUSI(patIdx,i),&pqKey->reg)){
       cnt.mCnt[(int)*(cls->chr+i)]+=1;
 
-    /*ιԤޥåʤ*/
+    /*その行がアンマッチならば*/
     }else{
       cnt.uCnt[(int)*(cls->chr+i)]+=1;
     }
   }
 
-  /**/
+  /*件数集計*/
   calCndCnt(&cnt);
 
-  /*Giniη׻*/
+  /*Giniの計算*/
   calCndCntSplit(&cnt);
   pqKey->reg.objVal = cnt.splitAfter;
 
-  /*upperBoundη׻*/
+  /*upperBoundの計算*/
   pqKey->upperBound = calUpperBound(&cnt);
 
   if(cnt.mtCnt==0) return(1);
@@ -636,25 +636,25 @@ static int regCnt(
 
 /**
  * # FUNCTION #
- * ѥ٥ȥ塼Ͽ
+ * 正規パターンをベストキューに登録
  */
 static void setRegBest(struct PQkey *pqKey, struct RegBest *regBest){
   struct PQnode *worst;
 
   worst=PQworstMember(regBest->pqNode->left);
 
-  /* ޤϿƤʤ⤷ϺãƤʤ */
-  /* ñϿ */
+  /* まだ一件も登録されていない、もしくは最大数に達していない場合 */
+  /* 単純に登録するだけ */
   if( worst == NULL || regBest->cnt <regBest->maxCnt){
     PQinsert(pqKey, regBest->pqNode->left);
     regBest->cnt++;
 
-  /* worstsvɤСworstƿϿ */
+  /* worstのsvより良ければ、worstを削除して新たに登録 */
   } else if ( pqKey->reg.objVal < regBest->maxVal ) {
     PQdeleteNode(worst);
     PQinsert(pqKey, regBest->pqNode->left);
 
-    /*regBest->maxValι(upperboundȤӤʤɤ)*/
+    /*regBest->maxValの更新(upperboundとの比較などで利用)*/
     worst=PQworstMember(regBest->pqNode->left);
     regBest->maxVal=worst->key.reg.objVal;
   }
@@ -664,38 +664,38 @@ static int RegPQ2Tbl_Cnt;
 
 /**
  * # FUNCTION #
- * 塼regBestƵŪõơ֥Ͽ
+ * キューregBestを再帰的に探りテーブルに登録
  */
 static void regPQ2TblSub(
   struct PQnode *pqNode,
   struct RegTbl *regTbl){
 
-  /*꡼հʳΥΡɤϺƵŪ˸ƤӽФ*/
+  /*リーフ以外のノードは再帰的に呼び出される*/
   if(!PQisExternalNode(pqNode)){
 
-    /*(left)귫*/
+    /*小さい方(left)から手繰る*/
     regPQ2TblSub(pqNode->left,regTbl);
 
-    /*塼ΥΡɤtable˥ԡ*/
+    /*キューのノードをtableにコピーする*/
     cpReg(regTbl->reg+RegPQ2Tbl_Cnt,&pqNode->key.reg);
 
-    /*tableηȥå*/
+    /*tableの件数カウントアップ*/
     RegPQ2Tbl_Cnt++;
 
-    /*礭(right)귫*/
+    /*大きい方(right)を手繰る*/
     regPQ2TblSub(pqNode->right,regTbl);
   }
 }
 
 /**
  * # FUNCTION #
- * 塼regBestϿ줿ѥơ֥Ѵ
+ * キューregBestに登録された正規パターン候補をテーブルに変換する
  */
 static struct RegTbl *regPQ2Tbl( struct RegBest *regBest ){
 
   struct RegTbl *regTbl;
 
-  /*ΰ*/
+  /*領域確保*/
   regTbl=mssMalloc(sizeof(struct RegTbl), "regPQ2Tbl");
   regTbl->reg=mssCalloc(sizeof(struct Regexp) * regBest->maxCnt, "regPQ2Tbl");
 
@@ -708,20 +708,20 @@ static struct RegTbl *regPQ2Tbl( struct RegBest *regBest ){
 
 /**
  * # FUNCTION #
- *ػߥꥹȤϿƤ뤫ɤΤ
- *  reg->regStr="abcd"ΤȤ
- *                "bcd","cd","d"  ػߥꥹȤˤ뤫Ĵ٤
+ *禁止リストに登録されているかどうかを確かめる
+ *  reg->regStr="abcd"のとき
+ *                "bcd","cd","d"  が禁止リストにあるか調べる
  */
 static int isForbid(struct Regexp *reg,struct cell **forbidden){
   int i;
   usint *pos;
 
-  /*ƬפפξȽǤʤ(ػߥꥹȤˤʤΤȤߤʤ)*/
+  /*先頭一致と末尾一致の場合は判断しない(禁止リストにないものとみなす)*/
   if(reg->bgnRng!=0 || reg->bgnRng!=0) return(0);
 
   pos=reg->str;
   for(i=1; i<strlenUSI(reg->str); i++){
-    pos++;  /* ʸ */
+    pos++;  /* 次の文字へ */
 
     if(EHmember(pos,forbidden)) return(1);
   }
@@ -730,54 +730,54 @@ static int isForbid(struct Regexp *reg,struct cell **forbidden){
 
 /**
  * # FUNCTION #
- * ߤΤʤѥforbidden listϿ
- * ϿʸɽѴʸ(Regexp->regStr)
+ * 見込みのない正規パターンをforbidden listに登録
+ * 登録する文字列は正規表現に変換した文字列(Regexp->regStr)
  */
 static void putForbid(struct Regexp *reg,struct cell **forbidden){
 
-  /*Ƭפפξ϶ػߥꥹȤʤ*/
+  /*先頭一致と末尾一致の場合は禁止リストに入れない*/
   if(reg->bgnRng!=0 || reg->bgnRng!=0) return;
-  /*ϥåꥹȤϿ*/
+  /*外部ハッシュリストに登録*/
   EHinsert(reg->str,forbidden);
 }
 
 /**
  * # FUNCTION #
- * оݤȤʤѥ(pqKey)ˤĤưʲΥƥȾ夫˹Ԥ
- * pqTop,regBest,ForbiddenListϿ
- * 1. ʬѥForbiddenListˤ               -> ⤷ʤ  &return
- * 2. ѥ󤬰ޥåʤ                -> ForbidenList&return
- * 3. ѥregBestޤ                 -> regBest&pqTop&return
- * 4. ѥUpperBoundregBestޤǤʤ -> ForbidenList&return
- * 5. ѥĹĹã              -> ⤷ʤ&return
- * 6. 嵭ƤϤޤʤ                        -> pqTop&return
+ * 対象となる正規パターン(pqKey)について以下のテスト上から順に行い
+ * pqTop,regBest,ForbiddenListに登録する
+ * 1. 部分パターンがForbiddenListにある               -> 何もしない  &return
+ * 2. 正規パターンが一件もマッチしない                -> ForbidenList&return
+ * 3. 正規パターンがregBestに入賞した                 -> regBest&pqTop&return
+ * 4. 正規パターンのUpperBoundがregBestに入賞できない -> ForbidenList&return
+ * 5. 正規パターンの長さが最大長に達した              -> 何もしない&return
+ * 6. 上記条件に当てはまらない                        -> pqTop&return
  */
 static void putPFB(
-  struct PQkey *pqKey,       /*оݤȤʤѥ*/
-  struct cell  *forbidden[], /*õػߥꥹ*/
+  struct PQkey *pqKey,       /*対象となる正規パターン*/
+  struct cell  *forbidden[], /*探索禁止リスト*/
   struct Data *dat,
   struct Cost *cost,
   struct Pattern *pat,
-  struct PQnode *pqTop,      /*õоݥꥹ*/
-  struct RegBest *regBest){  /*٥nꥹ*/
-  int noMatch; /*ѥ󤬰ޥåʤե饰*/
-  double upperBound; /*fobidden list뤫ɤη׻*/
+  struct PQnode *pqTop,      /*探索対象リスト*/
+  struct RegBest *regBest){  /*ベストnリスト*/
+  int noMatch; /*正規パターンが一件もマッチしないフラグ*/
+  double upperBound; /*fobidden listに入れるかどうかの計算用*/
 
-  /*(1) ѥʬѥforbiddenꥹȤˤreturn*/
+  /*(1) 正規パターンの部分パターンがforbiddenリストにあればreturn*/
   if(isForbid(&pqKey->reg,forbidden)){
     return;
   }
 
-  /*split rule,upperbound׻*/
+  /*split rule,upperboundを計算*/
   noMatch=regCnt(pqKey,pat->patIdx,dat->cls,cost);
 
-  /*(2) ޥåʤforbidenꥹȤϿ&return*/
+  /*(2) 一件もマッチしなければforbidenリストに登録&return*/
   if(noMatch){
     putForbid(&pqKey->reg,forbidden);
     return;
   }
 
-  /*(3) ߤBest nʤregBest˥å*/
+  /*(3) 現在のBest nに入るならばregBestにセット*/
   if(pqKey->reg.objVal < regBest->maxVal){
     setRegBest(pqKey, regBest);
     if(strlenUSI(pqKey->reg.str)<MaxRegLen){
@@ -786,31 +786,31 @@ static void putPFB(
     return;
   }
 
-  /*upperBoundη׻classSize2λΤͭʤΤ            */
-  /*classSize2礭upperBoundη׻Ωʤ  */
-  /*ΤǡǤɤsvupperBoundȤƤ                */
-  /*ʤupperBoundˤforbidenϿΥ르ꥺȤʤ*/
+  /*upperBoundの計算はclassSizeが2の時のみ有効なので            */
+  /*classSizeが2より大きい場合はupperBoundの計算が成り立たない  */
+  /*ので、最も良いsvをupperBoundとして入れておく                */
+  /*すなわちupperBoundによるforbiden登録のアルゴリズムを使わない*/
   if(ClassSize==2) upperBound=pqKey->upperBound;
   else             upperBound=0;
 
-  /*(4) ѥUpperBoundregBestޤǤʤ*/
+  /*(4) 正規パターンのUpperBoundがregBestに入賞できない*/
   if(upperBound > regBest->maxVal){
     putForbid(&pqKey->reg,forbidden);
     return;
   }
 
-  /*(5) ѥĹĹã*/
+  /*(5) 正規パターンの長さが最大長に達した*/
   if(strlenUSI(pqKey->reg.str)>=MaxRegLen){
     return;
   }
 
-  /*(6)嵭ƤϤޤʤ->塼ơ*/
+  /*(6)上記条件に当てはまらない->キューに入れて、次回に備える*/
   PQinsert(pqKey,pqTop->left);
 }
 
 /**
  * # FUNCTION #
- *ʸ(str)˰ʸ(chr)ɲ
+ *文字列(str)に一文字(chr)追加
  */
 static void addStrChr(usint *str,usint chr){
   int len;
@@ -822,7 +822,7 @@ static void addStrChr(usint *str,usint chr){
 
 /**
  * # FUNCTION #
- * ѥ (dat->pat+patNo)->regTbl ˥åȤ
+ * 正規パターン候補を生成し (dat->pat+patNo)->regTbl にセットする
  */
 void setRegTbl(struct Data *dat, struct Cost *cost){
 
@@ -840,11 +840,11 @@ void setRegTbl(struct Data *dat, struct Cost *cost){
   for(patNo=0; patNo<dat->patCnt; patNo++){
     pat=dat->pat+patNo;
 
-    /*hash bucket*/
+    /*hash のbucketを初期化*/
     for(j=0; j<EHbucket; j++) forbidden[j]=NULL;
 
-    /*Best nĤɽ빽¤Τν*/
-    /*ǥѤѥ䤬Ǽ*/
+    /*Best n個の正規表現が入る構造体の初期化*/
+    /*モデル生成に利用する正規パターン候補が格納される*/
     regBest.pqNode               = PQmakeNode();
     regBest.pqNode->parent       = regBest.pqNode;
     regBest.pqNode->right        = NULL;
@@ -855,9 +855,9 @@ void setRegTbl(struct Data *dat, struct Cost *cost){
     regBest.maxVal               = 9999;
     regBest.maxCnt               = optCAN.val;
 
-    /*priority queueν*/
-    /*ͭ˾ѥŪ˳Ǽ*/
-    /*Υ塼ˤʤޤѥõ³*/
+    /*priority queueの初期化*/
+    /*有望な正規パターンを一時的に格納する*/
+    /*このキューが空になるまで正規パターン候補を探し続ける*/
     pqTop               = PQmakeNode();
     pqTop->parent       = pqTop;
     pqTop->right        = NULL;
@@ -866,15 +866,15 @@ void setRegTbl(struct Data *dat, struct Cost *cost){
     pqTop->left->parent = pqTop;
 
     /*-------------------------------------------------------------*/
-    /* ᥤ롼                                              */
-    /* pqTop   : ȤʤɽƤpriority queue      */
-    /* regBest : ȤʤnĤpatternsv㤤ߤ  */
-    /* fobidden: θߤΤʤpatternߤƤϥå */
+    /* メインルーチン                                              */
+    /* pqTop   : 候補となる正規表現を入れておくpriority queue      */
+    /* regBest : 候補となるn個の正規patternを、svの低い順に蓄える  */
+    /* fobidden: 改善の見込みのない正規patternを蓄えておくハッシュ */
     /*-------------------------------------------------------------*/
 
-    /*ޤʸѥͤȤpqTop˳Ǽ*/
+    /*まず一文字だけの正規パターンを初期値としてpqTopに格納する*/
     for(i=0; i<pat->map->idxSiz; i++){
-      /*̾ѥ*/
+      /*通常の正規パターン*/
       pqKey.reg.str[0]=i+1;
       pqKey.reg.str[1]=0;
       pqKey.reg.bgnRng=0;
@@ -882,22 +882,22 @@ void setRegTbl(struct Data *dat, struct Cost *cost){
       pqKey.reg.type  =optSEQ.set;
       putPFB(&pqKey,forbidden,dat,cost,pat,pqTop,&regBest);
 
-      /*Ƭ*/
+      /*先頭一致*/
       for(j=1; j<=optBGN.val; j++){
         pqKey.reg.bgnRng=j;
         putPFB(&pqKey,forbidden,dat,cost,pat,pqTop,&regBest);
       }
       pqKey.reg.bgnRng=0;
 
-      /**/
+      /*末尾一致*/
       for(j=1; j<=optEND.val; j++){
         pqKey.reg.endRng=j;
         putPFB(&pqKey,forbidden,dat,cost,pat,pqTop,&regBest);
       }
       pqKey.reg.endRng=0;
 
-      /*Ƭξ*/
-      /*ϼ
+      /*先頭、末尾両一致*/
+      /*今回は実装を見送る
       for(j=1; j<=optBGN.val; j++){
         for(k=1; k<=optEND.val; k++){
           pqKey.reg.bgnRng=j;
@@ -910,15 +910,15 @@ void setRegTbl(struct Data *dat, struct Cost *cost){
     pqKey.reg.bgnRng=0;
     pqKey.reg.endRng=0;
 
-    /* priority queue(pqTop)ˤʤޤǥ롼פ */
+    /* priority queue(pqTop)が空になるまでループする */
     while(PQisEmpty(pqTop->left) != 1){
-      /*priority queueͥѥФ*/
-      /*regupperBound򥻥å*/
+      /*priority queueより最優先の正規パターンを取り出し*/
+      /*regとupperBoundをセット*/
       PQpop(&reg,&upperBound,pqTop->left);
-      /*popUB٥nʲΤȤõ*/
+      /*popしたUBがベストn以下のときだけ探索*/
       if(upperBound <= regBest.maxVal){
 
-        /*Фɽ˰ʸɲ*/
+        /*取り出した正規表現に一文字追加*/
         for(i=0; i<pat->map->idxSiz; i++){
           cpReg(&pqKey.reg,&reg);
           addStrChr(pqKey.reg.str,i+1);
@@ -927,10 +927,10 @@ void setRegTbl(struct Data *dat, struct Cost *cost){
       }
     }
   
-    /*ץ饤ƥ塼ơ֥Ѵ*/
+    /*プライオリティキューをテーブルに変換*/
     (dat->pat+patNo)->regTbl=regPQ2Tbl(&regBest);
 
-    /*ΰ賫*/
+    /*領域開放*/
     PQfree(pqTop);
     PQfree(regBest.pqNode);
     EHfree(forbidden);
@@ -940,7 +940,7 @@ void setRegTbl(struct Data *dat, struct Cost *cost){
 
 /**
  * # FUNCTION #
- * ѥΰ賫
+ * 正規パターン候補の領域開放
  */
 void freeRegTbl(struct Data *dat){
   int i;
@@ -954,13 +954,13 @@ void freeRegTbl(struct Data *dat){
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * Ϸ
+ * 出力系
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ѥɽ
+ * 正規パターンの表示
  */
 void prnRegexp(struct Regexp *reg, struct mssFPW *fpw){
   usint *str;
@@ -970,7 +970,7 @@ void prnRegexp(struct Regexp *reg, struct mssFPW *fpw){
 
   mssWriteStr("\"",fpw);
 
-  /*Ƭ*/
+  /*先頭一致*/
   if(reg->bgnRng!=0){
     mssWriteStr("^[",fpw);
     mssWriteInt(reg->bgnRng,fpw);
@@ -984,7 +984,7 @@ void prnRegexp(struct Regexp *reg, struct mssFPW *fpw){
     str++;
   }
 
-  /**/
+  /*末尾一致*/
   if(reg->endRng!=0){
     mssWriteStr("$[",fpw);
     mssWriteInt(reg->endRng,fpw);
