@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * xtclassifyѤǡɤ߹ߴϢδؿ
+ * xtclassifyで用いられるデータ読み込み関連の関数
  * ============================================================================
  */
 
@@ -12,28 +12,28 @@
 #include <iconv.h>
 #include <libxml/xmlerror.h>
 
-/* ############ Хѿ ##############*/
-/*ѥ顼᡼*/
+/* ############ グローバル変数 ##############*/
+/*パラーメータ*/
 extern MssOptFLD optPAT;
 extern MssOptFLD optCAT;
 extern MssOptSTR optDLM;
 extern MssOptINT optSIZ;
 
-extern struct mssFields *fpat; /*ѥ*/
-extern struct mssFields *fnum; /*͹*/
-extern struct mssFields *fcat; /*ƥ*/
-extern struct mssFields *fcls; /*饹*/
+extern struct mssFields *fpat; /*パターン項目*/
+extern struct mssFields *fnum; /*数値項目*/
+extern struct mssFields *fcat; /*カテゴリ項目*/
+extern struct mssFields *fcls; /*クラス項目*/
 
-extern int ClassSize;          /*饹Υ*/
+extern int ClassSize;          /*クラスのサイズ*/
 //extern iconv_t *icid;          /*Encoding*/
-extern char mssXmlDomErrMsg[]; /*ɤ߹߻Υ顼å*/
+extern char mssXmlDomErrMsg[]; /*コスト読み込み時のエラーメッセージ*/
 
 /**
  * # FUNCTION #
- * ǡ򥫥Ȥؿ
+ * データ件数をカウントする関数
  */
 int countDat(struct mssFPR *fpr){
-  struct mssRec *rec=NULL; /*ԥХåե¤*/
+  struct mssRec *rec=NULL; /*行バッファ構造体*/
   int i=0;
 
   rec=mssInitRec();
@@ -46,7 +46,7 @@ int countDat(struct mssFPR *fpr){
 
 /**
  * # FUNCTION #
- * 饹ʸ(str)顢ֹ֤ؿ
+ * クラスの文字(str)から、その配列番号を返す関数
  */
 static char getClassNum(struct Class *cls, char *str){
   int i;
@@ -59,13 +59,13 @@ static char getClassNum(struct Class *cls, char *str){
 
 /**
  * # FUNCTION #
- * ǡǻȤƤ륯饹ͤ򥻥åȤ
- * Ǥϡȥ졼˥󥰤ȥƥȤξꤦ륯饹ͤ
+ * データ上で使われているクラスの値をセットする
+ * ここでは、トレーニングとテストを両方走査し、ありうるクラスの値を得る
  */
 struct Class *setClass(struct mssFPR *trn, struct mssFPR *tst, struct mssHeader *hd){
 
-  struct Class *cls;     /*饹ʸ-ֹ湽¤*/
-  struct mssFldRec *fr;  /*бΥ쥳ɥХåե*/
+  struct Class *cls;     /*クラス文字列-番号構造体*/
+  struct mssFldRec *fr;  /*項目対応のレコードバッファ*/
   char *str;
   int flg;
   int i;
@@ -75,13 +75,13 @@ struct Class *setClass(struct mssFPR *trn, struct mssFPR *tst, struct mssHeader
   cls->cnt=0;
   cls->chr=NULL;
 
-  /*ȥ졼˥󥰤Υ饹*/
+  /*トレーニングのクラスを走査*/
   fr=mssInitFldRec(hd->flds->cnt);
   mssSeekTopFPR(trn);
   recCnt=0;
   while( EOF != mssReadFldRec(trn,fr) ){
 
-    /*饹ܤͤ򥻥å*/
+    /*クラス項目の値をセット*/
     str=*(fr->pnt+MssFlds2num(fcls,0));
 
     if( MssIsNull(str) ){
@@ -89,13 +89,13 @@ struct Class *setClass(struct mssFPR *trn, struct mssFPR *tst, struct mssHeader
       mssEnd(mssErrorNoDefault);
     }
 
-    /*ϿƤ륯饹ܤʸ򸡺ʤflg=1*/
+    /*登録されているクラス項目の文字列を検索。なければflg=1*/
     flg=1;
     for(i=0; i<cls->cnt; i++){
       if(0==strcmp(cls->str[i],str)){ flg=0; break; }
     }
 
-    /*Ͽ*/
+    /*登録*/
     if(flg){
       cls->str[cls->cnt]=mssMalloc(sizeof(char)*(strlen(str)+1),"setClass");
       strcpy(cls->str[cls->cnt],str);
@@ -104,22 +104,22 @@ struct Class *setClass(struct mssFPR *trn, struct mssFPR *tst, struct mssHeader
   }
   mssFreeFldRec(fr);
 
-  /*ƥȤΥ饹*/
+  /*テストのクラスを走査*/
   fr=mssInitFldRec(hd->flds->cnt);
   mssSeekTopFPR(tst);
   recCnt=0;
   while( EOF != mssReadFldRec(tst,fr) ){
 
-    /*饹ܤͤ򥻥å*/
+    /*クラス項目の値をセット*/
     str=*(fr->pnt+MssFlds2num(fcls,0));
 
-    /*ϿƤ륯饹ܤʸ򸡺ʤflg=1*/
+    /*登録されているクラス項目の文字列を検索。なければflg=1*/
     flg=1;
     for(i=0; i<cls->cnt; i++){
       if(0==strcmp(cls->str[i],str)){ flg=0; break; }
     }
 
-    /*Ͽ*/
+    /*登録*/
     if(flg){
       cls->str[cls->cnt]=mssMalloc(sizeof(char)*(strlen(str)+1),"setClass");
       strcpy(cls->str[cls->cnt],str);
@@ -128,7 +128,7 @@ struct Class *setClass(struct mssFPR *trn, struct mssFPR *tst, struct mssHeader
   }
   mssFreeFldRec(fr);
 
-  /* 饹ɽ(for debug) */
+  /* クラスの表示(for debug) */
   /*
   for(i=0; i<cls->cnt; i++){
     printf("cls%d = %s\n",i,cls->str[i]);
@@ -139,7 +139,7 @@ struct Class *setClass(struct mssFPR *trn, struct mssFPR *tst, struct mssHeader
 
 /**
  * # FUNCTION #
- * Class¤ΰγ
+ * Class構造体領域の開放
  */
 void freeClass(struct Class *cls){
   int i;
@@ -151,20 +151,20 @@ void freeClass(struct Class *cls){
 
 /**
  * # FUNCTION #
- * ȥեɤ߹
+ * コストファイルの読み込み
  *
  * <?xml version="1.0" encoding="euc-jp"?>
  * <missClassificationCost>
- *   <cost class="ͥ" predict="ͥ" value="9"/>
- *   <cost class="ͥ" predict="ͥ" value="2.1"/>
+ *   <cost class="優良" predict="非優良" value="9"/>
+ *   <cost class="非優良" predict="優良" value="2.1"/>
  * </missClassificationCost>
  *
- * ͥɤΥͥɤͽ¬줿ȤΥȤ9
- * ͥɤΥͥɤͽ¬줿ȤΥȤ2.1
+ * 優良のケースが非優良と予測されたときのコストは9。
+ * 非優良のケースが優良と予測されたときのコストは2.1。
  *
- * ǥեȤΥ
- * ƱͤƱͤͽ¬ȤΥȤ0
- * ͤ㤦ͤͽ¬ȤΥȤ1
+ * デフォルトのコスト
+ * 同じ値を同じ値と予測したときのコストは0。
+ * ある値を違う値と予測したときのコストは1。
  */
 struct Cost *readCost(char *fname,struct Class *cls){
         xmlDocPtr doc;
@@ -178,7 +178,7 @@ struct Cost *readCost(char *fname,struct Class *cls){
 
   int i,j;
 
-  /*ȤǥեͤǺ*/
+  /*コストをデフォルト値で作成*/
   cost=mssCalloc(sizeof(struct Cost),"readCost");
   for(i=0; i<ClassSize; i++){
     for(j=0; j<ClassSize; j++){
@@ -187,20 +187,20 @@ struct Cost *readCost(char *fname,struct Class *cls){
     }
     cost->actTtl[i] = ClassSize-1;
   }
-  /*Class򥻥å*/
+  /*Classをセット*/
   cost->cls=cls;
 
-  /*ե̾ꤵƤʤХǥեȥȤ֤*/
+  /*ファイル名が指定されていなければデフォルトコストを返す*/
   if(fname==NULL) return(cost);
 
-  /*顼ؿ*/
+  /*エラー関数の設定*/
   mssXmlDomErrMsg[0]='\0';
   xmlSetGenericErrorFunc(NULL,mssXmlDomErrHandler);
 
-  /*ȥեparse*/
+  /*コストファイルのparse*/
   doc = xmlParseFile(fname);
 
-  /*encoding*/
+  /*encodingの設定*/
   icid=iconv_open(doc->encoding,"UTF-8");
 
   if (doc == NULL ) {
@@ -208,17 +208,17 @@ struct Cost *readCost(char *fname,struct Class *cls){
     exit(mssErrorNoDefault);
   }
 
-  /*ȥåץΡɤΥå*/
+  /*トップノードのセット*/
   cur = xmlDocGetRootElement(doc);
 
-  /*ɥȥå*/
+  /*空ドキュメントチェック*/
   if (cur == NULL) {
     xmlFreeDoc(doc);
     mssShowErrMsg("empty document");
     exit(mssErrorNoDefault);
   }
 
-  /*롼ȥ̾(missClassificationCost)å*/
+  /*ルートタグ名(missClassificationCost)チェック*/
   if (xmlStrcmp(cur->name, (const xmlChar *) "missClassificationCost")) {
     xmlFreeDoc(doc);
     mssShowErrMsg("cost file: root tag must be '<missClassificationCost>'");
@@ -226,7 +226,7 @@ struct Cost *readCost(char *fname,struct Class *cls){
   }
 
 
-  /*<cost>Ǥɤ߹*/
+  /*<cost>要素を全て読み込む*/
   cur = cur->xmlChildrenNode;
   while (cur != NULL) {
     if((0==xmlStrcmp(cur->name, (const xmlChar *)"cost"))){
@@ -249,7 +249,7 @@ struct Cost *readCost(char *fname,struct Class *cls){
   }
   xmlFreeDoc(doc);
 
-  /*actClassΥȡ륳Ȥ׻*/
+  /*actClassのトータルコストを計算*/
   for(i=0; i<ClassSize; i++){
     for(j=0; j<ClassSize; j++){
       cost->actTtl[i]+=cost->tbl[i][j];
@@ -262,7 +262,7 @@ struct Cost *readCost(char *fname,struct Class *cls){
 
 /**
  * # FUNCTION #
- * ȥǡɽ
+ * コストデータの表示
  */
 void showCost(struct Cost *cost, struct mssFPW *fpw){
   int i,j;
@@ -288,7 +288,7 @@ void showCost(struct Cost *cost, struct mssFPW *fpw){
 
 /**
  * # FUNCTION #
- * ͥѥξ硢ե٥åȤ򸵤οͤˤä¤ٴ
+ * 数値パターンの場合、アルファベットを元の数値によって並べ換える
  */
 static void sortAlp(struct Map *map){
   struct mssHashNode *node;
@@ -316,8 +316,8 @@ static void sortAlp(struct Map *map){
 
 /**
  * # FUNCTION #
- * alphabetֹ梪alphabetѴΰ٤Ͽ
- * alpOrgϥåɽΤϿ줿ʸؤΥݥ
+ * alphabet内部番号→alphabetの変換の為の配列を登録。
+ * alpOrgハッシュ表のに登録された文字列へのポインタ配列。
  */
 static char **setNumAlp( struct Map *map ){
   struct mssHashNode *node;
@@ -339,8 +339,8 @@ static char **setNumAlp( struct Map *map ){
 
 /**
  * # FUNCTION #
- * ѥܤǥߥ(dlm)ǥȡʬ䤷ʸ֤
- * ǥߥ'\0'ξϡХȤalphabetȤƥåȤ롣
+ * パターン項目をデリミタ(dlm)でトークン分割し、その文字列配列を返す。
+ * デリミタが'\0'の場合は、一バイトを一alphabetとしてセットする。
  */
 static char **tokByChr(char *str,char dlm,int *cnt){
   char **list;
@@ -366,17 +366,17 @@ static char **tokByChr(char *str,char dlm,int *cnt){
 
 /**
  * # FUNCTION #
- * ǡǻȤƤѥͤĴMap¤Τ˥åȤ
- * Ǥϡȥ졼˥󥰤ȥƥȤξꤦalphabet
- * NULLͤФ
+ * データ上で使われているパターンの値を調べMap構造体にセットする
+ * ここでは、トレーニングとテストを両方走査し、ありうるalphabetを得る
+ * NULL値は飛ばす
  */
 struct Map **setMapAlp(
   struct mssFPR *trn,
   struct mssFPR *tst,
   struct mssHeader *hd){
 
-  struct mssFldRec *fr;  /*бΥ쥳ɥХåե*/
-  char         *str; /*ѥȤΰŪݥ*/
+  struct mssFldRec *fr;  /*項目対応のレコードバッファ*/
+  char         *str; /*パターンを操作するときの一時的ポインタ*/
   int i,j;
   struct Map **map;
   struct Map *mapi;
@@ -401,7 +401,7 @@ struct Map **setMapAlp(
     (alpNum+i)->v.usi=1;
   }
 
-  /*ȥ졼˥󥰤Υե٥åȤ*/
+  /*トレーニングのアルファベットを走査*/
   fr=mssInitFldRec(hd->flds->cnt);
   mssSeekTopFPR(trn);
   while( EOF != mssReadFldRec(trn,fr) ){
@@ -424,7 +424,7 @@ struct Map **setMapAlp(
   }
   mssFreeFldRec(fr);
 
-  /*ƥȤΥե٥åȤ*/
+  /*テストのアルファベットを走査*/
   fr=mssInitFldRec(hd->flds->cnt);
   mssSeekTopFPR(tst);
   while( EOF != mssReadFldRec(tst,fr) ){
@@ -448,25 +448,25 @@ struct Map **setMapAlp(
   mssFreeFldRec(fr);
 
   for(i=0; i<fpat->cnt; i++){
-    /*ǥåΰ*/
+    /*インデックスの領域確保*/
     (*(map+i))->idx=mssCalloc(sizeof(usint)*((*(map+i))->alpSiz+1), "setMapAlp");
 
-    /*ե٥åȤ˥ߥ͡ɲ*/
+    /*アルファベットの末尾にターミネータ追加*/
     (*(map+i))->alp=
       mssRealloc((*(map+i))->alp,
         sizeof(usint)*((*(map+i))->alpSiz+1),"setMapAlp");
     *((*(map+i))->alp+(*(map+i))->alpSiz)=0;
 
-    /*hashϿ줿alphabet(ʸ->Ϳ)ͤǤȤ
-      Ͽ*/
+    /*hashに登録されたalphabet(文字列->内部数値数値)を、内部数値を要素とした
+      配列に登録する*/
     (*(map+i))->numAlp=setNumAlp( *(map+i) );
 
-    /*ͥѥξ硢ե٥åȤͽ¤ٴ*/
+    /*数値パターンの場合、アルファベットを数値順に並べ換える*/
     if(mssIsFldOptOn(&optPAT,0,'n')){
       sortAlp(*(map+i));
     }
 
-    /*ǥåĴ*/
+    /*インデックスサイズの調整*/
     if(optSIZ.val>(*(map+i))->alpSiz) (*(map+i))->idxSiz=(*(map+i))->alpSiz;
     else                              (*(map+i))->idxSiz=optSIZ.val;
   }
@@ -478,7 +478,7 @@ struct Map **setMapAlp(
 
 /**
  * # FUNCTION #
- * Map¤Τΰ賫
+ * Map構造体の領域開放
  */
 void freeMap(struct Map **map){
   int i;
@@ -495,9 +495,9 @@ void freeMap(struct Map **map){
 
 /**
  * # FUNCTION #
- * ǡǻȤƤ륫ƥ꡼°ͤĴhashɽ˥åȤ
- * Ǥϡȥ졼˥󥰤ȥƥȤξꤦͤ򥻥åȤ
- * NULLͤФ
+ * データ上で使われているカテゴリー属性の値を調べhash表にセットする
+ * ここでは、トレーニングとテストを両方走査し、ありうる値をセットする
+ * NULL値は飛ばす
  */
 struct Category *setCatHash(
   struct mssFPR *trn,
@@ -506,25 +506,25 @@ struct Category *setCatHash(
 
   struct Category *cat;
   struct Category *cat_i;
-  struct mssFldRec *fr;  /*бΥ쥳ɥХåե*/
+  struct mssFldRec *fr;  /*項目対応のレコードバッファ*/
   int i;
   char *fldStr;
   MssValue val;
 
   mssVinit(&val,INT);
 
-  /*ƥ°λ̵꤬NULL֤*/
+  /*カテゴリ属性の指定が無ければNULLを返す*/
   if(!optCAT.set) return(NULL);
 
   cat = mssMalloc(sizeof(struct Category)*fcat->cnt,"setCatHash");
   for(i=0; i<fcat->cnt; i++){
-   (cat+i)->val     = NULL; /*ǤvalϥåȤsetDatǥå*/
+   (cat+i)->val     = NULL; /*ここではvalはセットせず、setDatでセット*/
    (cat+i)->name    = mssInitHash(101);
    (cat+i)->cnt     = 0;
    (cat+i)->valName = NULL;
   }
 
-  /*ȥ졼˥󥰤category°*/
+  /*トレーニングのcategory属性を走査*/
   fr=mssInitFldRec(hd->flds->cnt);
   mssSeekTopFPR(trn);
   while( EOF != mssReadFldRec(trn,fr) ){
@@ -532,10 +532,10 @@ struct Category *setCatHash(
       cat_i=cat+i;
       fldStr=*(fr->pnt+MssFlds2num(fcat,i));
 
-      /*ͤhashơ֥˥å*/
+      /*値をhashテーブルにセット*/
       mssVclear(&val);
       val.v.i=cat_i->cnt;
-      /*hashơ֥줿ʤ,-(հ)ɽϿ&cnt++*/
+      /*新たにhashテーブルに挿入されたなら,内部数値-値(逆引)表を登録&cnt++*/
       if(NULL != mssHashInsert(cat_i->name,fldStr,val) ){
         cat_i->valName=mssRealloc(cat_i->valName,
           sizeof(char *)*(cat_i->cnt+1),"setCatHash2");
@@ -546,7 +546,7 @@ struct Category *setCatHash(
   }
   mssFreeFldRec(fr);
 
-  /*ƥȤcategory°*/
+  /*テストのcategory属性を走査*/
   fr=mssInitFldRec(hd->flds->cnt);
   mssSeekTopFPR(tst);
   while( EOF != mssReadFldRec(tst,fr) ){
@@ -554,10 +554,10 @@ struct Category *setCatHash(
       cat_i=cat+i;
       fldStr=*(fr->pnt+MssFlds2num(fcat,i));
 
-      /*ͤhashơ֥˥å*/
+      /*値をhashテーブルにセット*/
       mssVclear(&val);
       val.v.i=cat_i->cnt;
-      /*hashơ֥줿ʤ,-(հ)ɽϿ&cnt++*/
+      /*新たにhashテーブルに挿入されたなら,内部数値-値(逆引)表を登録&cnt++*/
       if(NULL != mssHashInsert(cat_i->name,fldStr,val) ){
         cat_i->valName=mssRealloc(cat_i->valName,
           sizeof(char *)*(cat_i->cnt+1),"setCatHash2");
@@ -574,17 +574,17 @@ struct Category *setCatHash(
 
 /**
  * # FUNCTION #
- * ǡ򥻥åȤ
+ * データをセットする
  */
 struct Data *setDat(
   struct mssFPR *fpr,
   struct mssHeader *hd,
-  struct Class  *cls,   /*饹ʸ-Τ*/
-  int            cnt,   /*ǡ*/
-  struct Map   **map,   /*ƥѥ°Υޥå*/
+  struct Class  *cls,   /*クラスの文字列-数字のみ*/
+  int            cnt,   /*データ件数*/
+  struct Map   **map,   /*各パターン属性のマップ*/
   struct Category *cat){
 
-  struct mssFldRec *fr;  /*бΥ쥳ɥХåե*/
+  struct mssFldRec *fr;  /*項目対応のレコードバッファ*/
   int i,j,k;
   struct Data *dat;
   char *fldStr;
@@ -597,13 +597,13 @@ struct Data *setDat(
   mssVinit(&val,INT);
   dat=mssCalloc(sizeof(struct Data),"setDat");
 
-  /*饹ΰγݤȡ饹ʸ-Υԡ*/
+  /*クラス領域の確保と、クラスの文字列-数字のコピー*/
   dat->cls=mssCalloc(sizeof(struct Class),"setDat");
   for(i=0; i<cls->cnt; i++) dat->cls->str[i]=cls->str[i];
   dat->cls->cnt=cls->cnt;
   dat->cls->chr=mssCalloc(sizeof(char)*cnt,"setDat1");
 
-  /*°ΰγ*/
+  /*数値属性領域の確保*/
   dat->numCnt=fnum->cnt;
   dat->num    =mssCalloc(sizeof(double *)*dat->numCnt,"setDat2");
   dat->numNull=mssCalloc(sizeof(char   *)*dat->numCnt,"setDat2");
@@ -612,7 +612,7 @@ struct Data *setDat(
     *(dat->numNull+i) = mssCalloc(sizeof(char  )*cnt,"setDat3" );
   }
 
-  /*ƥ꡼°ǡΰγ*/
+  /*カテゴリー属性データ領域の確保*/
   dat->catCnt=fcat->cnt;
   dat->cat    =mssCalloc(sizeof(struct Category)*dat->catCnt,"setDat5" );
   dat->catNull=mssCalloc(sizeof(char          *)*dat->catCnt,"setDat5");
@@ -624,19 +624,19 @@ struct Data *setDat(
    *(dat->catNull+i)  = mssCalloc(sizeof(char  )*cnt,"setDat5" );
   }
 
-  /*ѥ°ΰγݤmapΥԡ*/
+  /*パターン属性領域の確保とmapのコピー*/
   dat->patCnt=fpat->cnt;
   dat->pat    =mssCalloc(sizeof(struct Pattern)*dat->patCnt ,"setDat6" );
   dat->patNull=mssCalloc(sizeof(char         *)*dat->patCnt ,"setDat6" );
   for(i=0; i<dat->patCnt; i++){
-    /*mapΥå*/
+    /*mapのセット*/
     (dat->pat+i)->map=*(map+i);
-    /*ͥѥǤ뤫ɤΥå*/
+    /*数値パターンであるかどうかのセット*/
     (dat->pat+i)->numPat=mssIsFldOptOn(&optPAT,0,'n');
-    /*¥ǡΰν*/
+    /*実データ領域の初期化*/
     (dat->pat+i)->patAlp=initStrListUSI();
     (dat->pat+i)->patIdx=initStrListUSI();
-    /*ǥåη*/
+    /*インデックスサイズの決定*/
     if(optSIZ.val > (*(map+i))->alpSiz || optSIZ.val==0 )
       (dat->pat+i)->map->idxSiz=(*(map+i))->alpSiz;
     else
@@ -645,20 +645,20 @@ struct Data *setDat(
 
   }    
 
-  /*¥ǡ˳Ǽ*/
+  /*実データをメモリに格納*/
   i=0;
   fr=mssInitFldRec(hd->flds->cnt);
   mssSeekTopFPR(fpr);
   while( EOF != mssReadFldRec(fpr,fr) ){
 
-    /*饹ܤͤ򥻥å*/
-    /*饹ܤNULLǤ뤳ȤϤʤ(setClassǥå)*/
+    /*クラス項目の値をセット*/
+    /*クラス項目がNULLであることはない(setClassでチェック済)*/
     *(dat->cls->chr+i)=getClassNum(cls,*(fr->pnt+MssFlds2num(fcls,0)));
 
-    /*°γǼ*/
+    /*数値属性の格納*/
     for(j=0; j<fnum->cnt; j++){
 
-      /*ܤ(ʸ)Υɥ쥹򥻥å*/
+      /*項目の値(文字列)のアドレスをセット*/
       fldStr = *(fr->pnt+MssFlds2num(fnum,j));
 
       if( MssIsNull(fldStr) ){
@@ -669,10 +669,10 @@ struct Data *setDat(
       }
     }
 
-    /*ƥ꡼°γǼ*/
+    /*カテゴリー属性の格納*/
     for(j=0; j<dat->catCnt; j++){
 
-      /*ܤ(ʸ)Υɥ쥹򥻥å*/
+      /*項目の値(文字列)のアドレスをセット*/
       fldStr = *(fr->pnt+MssFlds2num(fcat,j));
 
       if( MssIsNull(fldStr) ){
@@ -680,7 +680,7 @@ struct Data *setDat(
       }else{
         *(*(dat->catNull+j)+i)=0;
 
-        /*쥳ɤΥǡͤȤϿ*/
+        /*レコードのデータを内部数値として登録*/
         mssVclear(&val);
         val=mssHashMemberVal( (dat->cat+j)->name, fldStr );
         if(val.nul) *((dat->cat+j)->val + i) = 0;
@@ -688,9 +688,9 @@ struct Data *setDat(
       }
     }
 
-    /*ѥγǼ*/
+    /*パターンの格納*/
     for(j=0; j<fpat->cnt; j++){
-      /*ܤ(ʸ)Υɥ쥹򥻥å*/
+      /*項目の値(文字列)のアドレスをセット*/
       fldStr=*(fr->pnt+MssFlds2num(fpat,j));
 
       if( MssIsNull(fldStr) ){
@@ -701,7 +701,7 @@ struct Data *setDat(
         *(*(dat->patNull+j)+i)=0;
  
         list=tokByChr(fldStr,*optDLM.str,&listCnt);
-        /*k(ex.1024)ۤ饨顼ˤ*/
+        /*kがある値(ex.1024)を越えたらエラーにする*/
         for(k=0;k<listCnt;k++){
           node=(struct mssHashNode *)mssHashMember((*(map+j))->alpOrg,*(list+k));
           if( NULL == node ){
@@ -712,20 +712,20 @@ struct Data *setDat(
           }
         }
         mssFree(*list); mssFree(list);
-        alpha[k]=0; /*ߥ͡*/
+        alpha[k]=0; /*ターミネータ*/
         putStrListUSI((dat->pat+j)->patAlp,alpha);
       }
     }
 
-    /*ȥå*/
+    /*件数カウントアップ*/
     i++;
   }
   mssFreeFldRec(fr);
 
-  /*եݥ󥿤Υԡ*/
+  /*ファイルポインタのコピー*/
   dat->fpr=fpr;
 
-  /*ǡΥå*/
+  /*データ件数のセット*/
   dat->cnt=cnt;
 
   return(dat);
@@ -733,8 +733,8 @@ struct Data *setDat(
 
 /**
  * # FUNCTION #
- * ǡɽ(debug)
- * Map¤Τΰ賫
+ * データの表示(debug用)
+ * Map構造体の領域開放
  */
 void showDat( struct Data *dat){
 
@@ -767,7 +767,7 @@ void showDat( struct Data *dat){
   }
   printf("-----------------------------------------\n");
   for(i=0; i<dat->cnt; i++){
-    /*ѥ*/
+    /*パターン項目*/
     for(j=0; j<dat->patCnt; j++){
       if(*(*(dat->patNull+j)+i)==1){
         printf("NULL ");
@@ -782,7 +782,7 @@ void showDat( struct Data *dat){
         }
       }
     }
-    /*͹*/
+    /*数値項目*/
     for(j=0; j<dat->numCnt; j++){
       if(*(*(dat->numNull+j)+i)==1){
         printf("NULL ");
@@ -790,7 +790,7 @@ void showDat( struct Data *dat){
         printf("%g ",*(*(dat->num+j)+i) );
       }
     }
-    /*ƥ꡼*/
+    /*カテゴリー項目*/
     for(j=0; j<dat->catCnt; j++){
       if(*(*(dat->catNull+j)+i)==1){
         printf("NULL ");
@@ -799,11 +799,11 @@ void showDat( struct Data *dat){
                          *((dat->cat+j)->val+i) );
       }
     }
-    /*饹*/
+    /*クラス項目*/
     printf("cls=%d\n",(int)*(dat->cls->chr+i) );
   }
   
-  /*ѥν*/
+  /*正規パターン候補の出力*/
   if(dat->pat->regTbl!=NULL){
     printf("-----------------------------------------\n");
     for(i=0; i<dat->patCnt; i++){
@@ -817,13 +817,13 @@ void showDat( struct Data *dat){
   }
 
   
-  /*ѥ°Ȥǡν*/
+  /*正規パターン候補を属性とした全データの出力*/
   if(dat->pat->attCnt!=0){
     printf("-----------------------------------------\n");
-    for(i=0; i<dat->patCnt; i++){ /*ѥܿ*/
+    for(i=0; i<dat->patCnt; i++){ /*パターン項目数*/
       printf("----- pat #%d\n",i);
-      for(j=0; j<dat->cnt; j++){ /*ץǡ*/
-        for(k=0; k<(dat->pat+i)->attCnt; k++){ /*ɽ*/
+      for(j=0; j<dat->cnt; j++){ /*サンプルデータ件数*/
+        for(k=0; k<(dat->pat+i)->attCnt; k++){ /*正規表現数*/
           if(*((dat->pat+i)->att[k]+j) ) printf("1");
           else                           printf("0");
         }
@@ -836,7 +836,7 @@ void showDat( struct Data *dat){
 
 /**
  * # FUNCTION #
- * ǡΰ
+ * データ領域を開放する
  */
 void freeDat(struct Data *dat){
   int i;
