@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * xtclassifyѤڴϢؿ
+ * xtclassifyで用いられる決定木関連関数
  * ============================================================================
  */
 
@@ -36,29 +36,29 @@ extern int   usedRandSeed;
 extern struct mssGlobalVariables mssGV;
 extern struct mssPMMLvariables mssPV;
 
-/*ĥ꡼ˡData򻲾Ȥ뤿Υݥ*/
+/*ツリー生成時に、Dataを参照するためのポインタ*/
 struct Pointer {
-  int  recCnt;        /*ǡ*/
-  int *recNo;         /*ƬιԿ*/
-  double *weight;     /*NULLͤθrecNoб륱νŤ*/
+  int  recCnt;        /*データ数*/
+  int *recNo;         /*先頭からの行数*/
+  double *weight;     /*NULL値を考慮したrecNoに対応するケースの重み*/
 };
 
 /**
  * # FUNCTION #
- *٥ΥåȴϢ
- *  1. ٥Υå
- *  2. ǿ٥Υå
- *  3. ꡼տΥ
+ *レベルのセット関連
+ *  1. レベルのセット
+ *  2. 最深レベルのセット
+ *  3. リーフ数のカウント
  */
 static void setLevel(struct Node *node,struct Tree *tree, int level){
 
-  /*٥Υå*/
+  /*レベルのセット*/
   node->level=level;
 
-  /*ǿ٥ι*/
+  /*最深レベルの更新*/
   if(level>tree->deepest) tree->deepest=level;
 
-  /*꡼դʤХ꥿*/
+  /*リーフならばリターン*/
   if( 0==node->nodeType || node->pruned){
     tree->leafCnt++;
     return;
@@ -70,7 +70,7 @@ static void setLevel(struct Node *node,struct Tree *tree, int level){
 
 /**
  * # FUNCTION #
- * ĥ꡼ΥΡɤ򼡡˲Ƶؿ
+ * ツリーのノードを次々に解放する再帰関数
  */
 static struct Node **freeTreeTbl(
   struct Node  *node,
@@ -78,10 +78,10 @@ static struct Node **freeTreeTbl(
   int          *nodeCnt){
 
   int cnt;
-  if(node->attType==2){ /*ƥΥꥹȤ*/
+  if(node->attType==2){ /*カテゴリのリストを解放*/
     mssFree( node->catList );
   } 
-  if(node->nodeType==0){ /*leafʤ*/
+  if(node->nodeType==0){ /*leafなら*/
     return(nodeTbl);
   }else{
     cnt=(*nodeCnt);
@@ -98,7 +98,7 @@ static struct Node **freeTreeTbl(
 
 /**
  * # FUNCTION #
- * ץ빽¤ΤΥԡ(toγƼΰݤޤ)
+ * サンプル構造体のコピー(to内の各種領域確保を含む)
  */
 static struct Data *cpyDatMapReg(struct Data *from){
 
@@ -108,7 +108,7 @@ static struct Data *cpyDatMapReg(struct Data *from){
   to         = mssCalloc(sizeof(struct Data),"cpySmp");
 
   /*==============================================*/
-  /*ڤˤäѤѿϥݥ󥿤Ȥƥԡ*/
+  /*決定木によって不変の変数はポインタとしてコピー*/
   /*==============================================*/
   to->numCnt = from->numCnt;
   to->num    = from->num;
@@ -121,7 +121,7 @@ static struct Data *cpyDatMapReg(struct Data *from){
 
 
   /*====================================================*/
-  /*ѥܤϷڤˤäѤΤǡΤ򥳥ԡ*/
+  /*パターン項目は決定木によって変わるので、実体をコピー*/
   /*====================================================*/
   to->patCnt = from->patCnt;
   if(to->patCnt>0){
@@ -132,7 +132,7 @@ static struct Data *cpyDatMapReg(struct Data *from){
 
       (to->pat+i)->numPat=(from->pat+i)->numPat;
 
-      /*MapΥԡ*/
+      /*Mapのコピー*/
       (to->pat+i)->map=mssCalloc(sizeof(struct Map), "cpySmp");
       (to->pat+i)->map->alpOrg = (from->pat+i)->map->alpOrg;
       (to->pat+i)->map->numAlp = (from->pat+i)->map->numAlp;
@@ -145,7 +145,7 @@ static struct Data *cpyDatMapReg(struct Data *from){
       strcpyUSI((to->pat+i)->map->alp,(from->pat+i)->map->alp);
       strcpyUSI((to->pat+i)->map->idx,(from->pat+i)->map->idx);
 
-      /*regTblΥԡ*/
+      /*regTblのコピー*/
       (to->pat+i)->regTbl=mssMalloc(sizeof(struct RegTbl),"spySmp");
       (to->pat+i)->regTbl->reg =
         mssCalloc(sizeof(struct Regexp)*(from->pat+i)->regTbl->cnt,"scr");
@@ -161,7 +161,7 @@ static struct Data *cpyDatMapReg(struct Data *from){
 
 /**
  * # FUNCTION #
- * cpyDatMapRegǥԡ줿ΰβ
+ * cpyDatMapRegでコピーされた領域の解放
  */
 static void freeDatMapReg(struct Data *dat){
 
@@ -170,12 +170,12 @@ static void freeDatMapReg(struct Data *dat){
   if(dat->patCnt==0) return;
 
   for(i=0; i<dat->patCnt; i++){
-    /*Mapfree*/
+    /*Mapのfree*/
     mssFree( (dat->pat+i)->map->alp );
     mssFree( (dat->pat+i)->map->idx );
     mssFree( (dat->pat+i)->map );
 
-    /*regTblfree*/
+    /*regTblのfree*/
     mssFree( (dat->pat+i)->regTbl->reg );
     mssFree( (dat->pat+i)->regTbl );
   }
@@ -185,7 +185,7 @@ static void freeDatMapReg(struct Data *dat){
 
 /**
  * # FUNCTION #
- * ΥǡڤΥΡɤƤϤᡢͽ¬饹Ƶؿ
+ * 一件のデータを決定木のノードに当てはめ、予測クラスを求める再帰関数
  */
 static void predictTreeSub(
   double clsWeight[],
@@ -201,14 +201,14 @@ static void predictTreeSub(
   int isNull=0;
   int match=0;
 
-  /*꡼դãСweightclsWeightơ֥˥åȤ롣*/
+  /*リーフに到達すれば、weightをclsWeightテーブルにセットする。*/
   if( 0==this->nodeType || this->pruned ){
     clsWeight[this->cls]+=weight;
     return;
   }
 
-  /*ߥΡɤξܤǡNULLξ
-    ˤweight򤫤ƺƵ*/
+  /*現在ノードの条件項目がデータ上でNULLの場合は
+    件数によるweightをかけて再帰処理*/
   switch(this->attType){
   case 0:
     isNull=*(*(dat->patNull+this->attFldNo)+recNo);
@@ -227,13 +227,13 @@ static void predictTreeSub(
     predictTreeSub(clsWeight, this->uNode,dat,recNo,uWeight,tree);
   } else {
 
-    /*ˤmatch⤷unmatchΡɤ򤿤ɤ*/
+    /*条件によりmatchもしくはunmatchノードをたどる*/
     switch(this->attType){
     case 0:
-      /*ѥ°ϡalphabet-indexΥǡɬפʤ
-        ꥸʥΥե٥åȥѥ󤫤饤ǥå줿ǡ
-        θmatch,unmatchꤹ(ȥ졼˥󥰤ʤʤƥ
-        ǡͽ¬ݤɬפȤʤ롣*/
+      /*パターン属性だけは、alphabet-index等のデータが必要なため
+        オリジナルのアルファベットパターンからインデックス化されたデータを作成し
+        その後にmatch,unmatchを決定する(トレーニングだけなら問題ないが、テスト
+        データを予測する際に必要となる。*/
       alpStr2idxStr(index,
                     getStrListUSI((dat->pat+this->attFldNo)->patAlp,recNo),
                     (tree->dat->pat+this->attFldNo)->map);
@@ -259,7 +259,7 @@ static void predictTreeSub(
 
 /**
  * # FUNCTION #
- * ǡ(dat)Τ쥳(rec)(tree)ͽ¬륯饹֤ͤؿ
+ * データ(dat)のあるレコード(rec)が決定木(tree)で予測されるクラス値を返す関数
  */
 static int predictTree( struct Tree *tree, struct Data *dat, int recNo){
   double clsWeight[MaxClsLen];
@@ -282,8 +282,8 @@ static int predictTree( struct Tree *tree, struct Data *dat, int recNo){
 
 /**
  * # FUNCTION #
- * ǡ鷺ɤ߹ߡClassificationTable˷򥻥åȤ
- * åȤ줿ơ֥֤
+ * データを一件ずつ読み込み、ClassificationTableに件数をセットする
+ * セットされたテーブルを返す。
  */
 struct ClsTbl *setClsTbl( struct Data *dat, struct Tree *tree){
   struct ClsTbl *ct;
@@ -305,13 +305,13 @@ struct ClsTbl *setClsTbl( struct Data *dat, struct Tree *tree){
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ڤĹϢ
+ * 決定木を成長させる関連
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ѥ̥饹̷
+ * 正規パターン条件別クラス別件数
  */
 static void setCndCntPat(
   struct CndCnt  *cnt,
@@ -344,17 +344,17 @@ static void setCndCntPat(
 
 /**
  * # STRUCT #
- * °ͽ˥Ȥ뤿ι¤
+ * 数値属性を数値順にソートするための構造体
  */
 struct NumCls {
   double num;
   char   cls;
-  double weight; /*NULL򴪰ƤŤ*/
+  double weight; /*NULLを勘案した重み*/
 };
 
 /**
  * # FUNCTION #
- * °ͽ˥Ȥ
+ * 数値属性を数値順にソートする
  */
 static int qscmp3(const void **a, const void **b){
   double x,y;
@@ -367,7 +367,7 @@ static int qscmp3(const void **a, const void **b){
 
 /**
  * # FUNCTION #
- * °ξ̥饹̷
+ * 数値属性の条件別クラス別件数
  */
 static double setCndCntNum(
   struct CndCnt  *cnt,
@@ -384,11 +384,11 @@ static double setCndCntNum(
   double bestSv;
   int i,j;
 
-  /* NumCls¤Τΰ*/
+  /* NumCls構造体の領域確保*/
   tbl=mssMalloc(pnt->recCnt * sizeof(struct NumCls),"setCndCntNum");
 
-  /*°͡饹ͤNumCls¤Τ˥å*/
-  /*ƱtmpCnt¤Τ*/
+  /*数値属性の値、クラス値をNumCls構造体にセット*/
+  /*同時にtmpCnt構造体を初期化*/
   iniCndCnt(&tmpCnt,cost);
   j=0;
   for(i=0; i<pnt->recCnt; i++){
@@ -409,7 +409,7 @@ static double setCndCntNum(
     }
   }
 
-  /*ͽ¤Ѥ*/
+  /*数値順に並べ変える*/
 /*
   qsort(tbl,j,sizeof(struct NumCls),
                        (int (*)(const void *, const void *))qscmp3);
@@ -428,17 +428,17 @@ static double setCndCntNum(
     tmpCnt.mCount++;
     tmpCnt.uCount--;
 
-    if( i!=j-1 ){ /*ǽ쥳ɤǤʤʤ*/
-      if(th == (tbl+i+1)->num){ /*Υ쥳ɤͤƱʤcontinue*/
+    if( i!=j-1 ){ /*最終レコードでないならば*/
+      if(th == (tbl+i+1)->num){ /*次のレコードの値も同じならばcontinue*/
         continue;
       }
     }
 
-    /*̥饹֥ȥԡη׻*/
+    /*条件別クラス間エントロピーの計算*/
     calCndCnt(&tmpCnt);
     calCndCntSplit(&tmpCnt);
 
-    /* °ι */ 
+    /* 最良属性の更新 */ 
     if( tmpCnt.splitAfter < bestSv){
       cpyCndCnt(cnt,&tmpCnt);
       bestSv=tmpCnt.splitAfter;
@@ -455,8 +455,8 @@ static double setCndCntNum(
 
 /**
  * # FUNCTION #
- * ƥ꡼°ξ̥饹̷
- * ƥ꡼Match,Unmatchɽ֤
+ * カテゴリー属性の条件別クラス別件数
+ * カテゴリー値別Match,Unmatch表を返す
  *   ex) MMUUUMUM
  */
 static char *setCndCntCat(
@@ -477,8 +477,8 @@ static char *setCndCntCat(
   int i,j,k;
 
   double *valClsCnt;
-  int *valRecCnt;    /*쥳ɷ*/
-  int nulRec; /*nullΥ쥳ɷ*/
+  int *valRecCnt;    /*レコード件数を入れる*/
+  int nulRec; /*nullのレコード件数*/
   int catVal,clsVal;
   double nulCnt[MaxClsLen];
 
@@ -490,8 +490,8 @@ static char *setCndCntCat(
     nulCnt[i]=0;
   }
 
-  /* ƥ꡼classɽκ */
-  /* valClsCnt[val][class] ΰ*/
+  /* カテゴリーの値別class集計表の作成 */
+  /* valClsCnt[val][class] 領域確保*/
   valClsCnt=mssCalloc(cat->cnt*cls->cnt*sizeof(double),"setCndCntCat1");
   valRecCnt=mssCalloc(cat->cnt*sizeof(int),"setCndCntCat1");
   nulRec=0;
@@ -507,7 +507,7 @@ static char *setCndCntCat(
     }
   }
 
-  /*  ɽɽ */
+  /*  集計表の表示 */
   /*
   for(i=0; i<cat->cnt; i++){
     printf(" val=%d : ",i);
@@ -518,12 +518,12 @@ static char *setCndCntCat(
   }
   */
 
-  /*tmpCnt¤Τ*/
+  /*tmpCnt構造体を初期化*/
   iniCndCnt(&tmpCnt,cost);
 
   /*=======================================================================*/
-  /*ƥ꡼°ͤμʲʤСMatch,Unmatchȹ礻*/
-  /*׻Ŭʬ롣                                 */
+  /*カテゴリー属性の値の種類数が１０種類以下ならば、Match,Unmatchの全組合せ*/
+  /*を計算し、そこから最適な分割を求める。                                 */
   /* catCombi[i][val]={M,U};                                               */
   /* i 0 1 2 .... */
   /* 0 M M M .... */
@@ -534,12 +534,12 @@ static char *setCndCntCat(
   /* 5 U M U .... */
   /* 6 M U U .... */
   /* 7 U U U .... */
-  /*   ºݤĴ٤Τi=1to72ӡʤ1,3,5Ĵ٤ */
-  /*   2ӤˤΤϡ07,16,25,34Ʊ̣ʤΤ*/ 
+  /*   実際に調べるのはi=1to7で2飛び、すなわち、1,3,5を調べる */
+  /*   2飛びにするのは、0と7,1と6,2と5,3と4は同じ意味なので*/ 
   if(cat->cnt <= 10){
     for(i=0; i<end[cat->cnt-1]-1; i=i+2){
       iniCndCnt(&tmpCnt,cost);
-      /*NULLȿǤ*/
+      /*NULL件数を反映させる*/
       for(j=0; j<ClassSize; j++){
         tmpCnt.nCnt[j]=nulCnt[j];
       }
@@ -549,8 +549,8 @@ static char *setCndCntCat(
 
       tmpCnt.mCount=nulRec;
       tmpCnt.uCount=nulRec;
-      for(j=0; j<cat->cnt; j++){ /*ƥμ*/
-        total=0; /*ƥ꡼(j)ȡ벿狼򥫥Ȥ*/
+      for(j=0; j<cat->cnt; j++){ /*カテゴリの種類数*/
+        total=0; /*カテゴリーの値(j)がトータル何件かをカウントする*/
 
         if(catCombi[i][j]=='M'){
           tmpCnt.mCount += *(valRecCnt+j);
@@ -558,7 +558,7 @@ static char *setCndCntCat(
           tmpCnt.uCount += *(valRecCnt+j);
         }
  
-        for(k=0; k<cls->cnt; k++){ /*饹*/
+        for(k=0; k<cls->cnt; k++){ /*クラス数*/
           if(catCombi[i][j]=='M'){
             tmpCnt.mCnt[k]+=ValClsCnt(j,k);
           }else{
@@ -567,18 +567,18 @@ static char *setCndCntCat(
           total+=ValClsCnt(j,k);
         }
 
-        /*ƥ(j)ʤХե饰ΩƤƤ(ɽʤ)*/
+        /*カテゴリの値(j)が一件もなければフラグを立てておく(表示しないため)*/
         if(total==0){
           combiNull[j]='N';
         }
       }
 
-      /*̥饹֥ȥԡη׻*/
+      /*条件別クラス間エントロピーの計算*/
       calCndCnt(&tmpCnt);
       calCndCntSplit(&tmpCnt);
       /*prnCndCnt(&tmpCnt);*/
 
-      /* °ι */ 
+      /* 最良属性の更新 */ 
       if( tmpCnt.splitAfter < bestSv){
         cpyCndCnt(cnt,&tmpCnt);
         bestSv=tmpCnt.splitAfter;
@@ -599,12 +599,12 @@ static char *setCndCntCat(
     mssFree(bestCombiNull);
 
   /*=======================================================================*/
-  /*ƥ꡼°ͤμۤʤСgreedy           */
-  /*ɤʬ                                                       */
+  /*カテゴリー属性の値の種類数が１０種類を越えるならば、greedyに           */
+  /*良い分割を求める                                                       */
   }else{
-    /*ͤȤơMatchȤư*/
+    /*初期値として、全てMatchとして扱う*/
     catList=mssCalloc(sizeof(char)*cat->cnt,"setCndCntCat3");
-    /*NULLȿǤ*/
+    /*NULL件数を反映させる*/
     for(j=0; j<ClassSize; j++){
       tmpCnt.nCnt[j]=nulCnt[j];
     }
@@ -621,14 +621,14 @@ static char *setCndCntCat(
     cpyCndCnt(cnt,&tmpCnt);
     bestSv=tmpCnt.splitAfter;
 
-    /*¤ꡢMatchUnmatch˥ƥ꡼ͤưƤ*/
+    /*改善がある限り、MatchからUnmatchにカテゴリー値を移動していく*/
     improve=1;
     while(improve) {
       improve=0;
-      /*MatchĤİưɤʤ뤫ǧ*/
+      /*Matchから一つずつ移動して良くなるか確認*/
       for(j=0; j<cat->cnt; j++){
         if(*(catList+j)=='M'){
-          /*MatchUnmatch˰ư*/
+          /*MatchからUnmatchに移動*/
           for(k=0; k<cls->cnt; k++){
             tmpCnt.mCnt[k]-=ValClsCnt(j,k);
             tmpCnt.uCnt[k]+=ValClsCnt(j,k);
@@ -642,7 +642,7 @@ static char *setCndCntCat(
             moveCat=j;
             improve=1;
           }
-          /*MatchUnmatch˰ưΤ򸵤᤹*/
+          /*MatchからUnmatchに移動したのを元に戻す*/
           for(k=0; k<cls->cnt; k++){
             tmpCnt.mCnt[k]+=ValClsCnt(j,k);
             tmpCnt.uCnt[k]-=ValClsCnt(j,k);
@@ -652,7 +652,7 @@ static char *setCndCntCat(
         } /*if*/
       }
 
-      /*СmoveCatUnmatch˰ư*/
+      /*改善があれば、moveCatをUnmatchに正式に移動する*/
       if(improve){
         *(catList+moveCat)='U';
         for(k=0; k<cls->cnt; k++){
@@ -676,7 +676,7 @@ static char *setCndCntCat(
 
 /**
  * # FUNCTION #
- * TreeΥΡɺƵؿ
+ * Treeのノード作成再帰関数
  */
 static struct Node *makeTree(
   struct Data     *dat,
@@ -697,18 +697,18 @@ static struct Node *makeTree(
   int isNull=0;
   int i,j,jm,ju,jn;
 
-  /*ȥΡΰγݤȽ*/
+  /*カレントノード領域の確保と初期化*/
   this = mssCalloc(sizeof(struct Node), "Node");
   this->parent = parent;
 
-  /* this->xxxCntν */
+  /* this->xxxCntの初期化 */
   iniCndCnt(&this->trnCnt,cost);
 
-  /*splitting ruleͤν*/
+  /*splitting ruleの値の初期化*/
   this->trnCnt.splitAfter=DBL_MAX;
 
   /*----------------------------------------------*/
-  /*ѥܤˤǾȤ°դ*/
+  /*パターン項目における最小コストの属性を見付ける*/
   /*----------------------------------------------*/
   for(i=0; i<dat->patCnt; i++){
     for(j=0; j<(dat->pat+i)->attCnt; j++){
@@ -718,7 +718,7 @@ static struct Node *makeTree(
       calCndCntSplit(&cnt);
       /*prnCndCnt(&cnt);*/
 
-      /* ǾȤ°򹹿*/
+      /* 最小コストの属性を更新*/
       if(this->trnCnt.splitAfter > cnt.splitAfter){
         cpyCndCnt(&this->trnCnt,&cnt);
         this->attType =0;
@@ -729,7 +729,7 @@ static struct Node *makeTree(
   }
 
   /*----------------------------------------------*/
-  /*͹ܤˤǾȤ°դ    */
+  /*数値項目における最小コストの属性を見付ける    */
   /*----------------------------------------------*/
   for(i=0; i<dat->numCnt; i++){
     iniCndCnt(&cnt,cost);
@@ -747,7 +747,7 @@ static struct Node *makeTree(
   }
 
   /*------------------------------------------------*/
-  /*ƥ꡼ܤˤǾȤ°դ*/
+  /*カテゴリー項目における最小コストの属性を見付ける*/
   /*------------------------------------------------*/
   for(i=0; i<dat->catCnt; i++){
     iniCndCnt(&cnt,cost);
@@ -766,11 +766,11 @@ static struct Node *makeTree(
     }
   }
 
-  /*ΡɤΥ饹(꡼հʳǤ⥯饹ꤹΤϻ޴Τ)*/
+  /*ノードのクラスを決定(リーフ以外でもクラスを決定するのは枝苅のため)*/
   this->cls=dominantClass(&this->trnCnt);
 
 
-  /*match, unmatchΥΡɤǤ줫NULLǡξLeaf&return*/
+  /*match, unmatchのノードでいずれかが、全てNULLデータの場合はLeaf処理&return*/
   if(this->trnCnt.mCount==this->trnCnt.nCount ||
      this->trnCnt.uCount==this->trnCnt.nCount ){
     this->nodeType=0;
@@ -778,25 +778,25 @@ static struct Node *makeTree(
   }
 
 
-  /*ʤLeaf&return*/
+  /*改善がなければLeaf処理&return*/
   if(this->trnCnt.splitAfter >= this->trnCnt.splitBefor){
     this->nodeType=0;
     return(this);
   }
 
-  /*줫0ξ,Leaf&return*/
+  /*右左いずれかが0件の場合,Leaf処理&return*/
   if(this->trnCnt.utCnt == 0 || this->trnCnt.mtCnt == 0){
     this->nodeType=0;
     return(this);
   }
 
-  /*ξƤϤޤʤȤȤϥΡɤǤ*/
+  /*上の条件に当てはまらないということはノードである*/
   this->nodeType = 1;
   /*prnCndCnt(&this->trnCnt);*/
 
 
   /*------------------------------------------------------*/
-  /* ǡ(pointer)matchǡunmatchǡʬ*/
+  /* 元データ(pointer)をmatchデータとunmatchデータに分ける*/
   /*------------------------------------------------------*/
   uPnt.recCnt = this->trnCnt.uCount;
   mPnt.recCnt = this->trnCnt.mCount;
@@ -853,12 +853,12 @@ static struct Node *makeTree(
   }
 
   /*----------------------------*/
-  /*Ρɤ򿭤Ф(ƵƤӽФ)*/
+  /*ノードを伸ばす(再帰呼び出し)*/
   /*----------------------------*/
   this->mNode = makeTree(dat,cost,&mPnt,this);
   this->uNode = makeTree(dat,cost,&uPnt,this);
 
-  /*ݥΰγ*/
+  /*ポインタ領域の開放*/
   mssFree(uPnt.recNo);
   mssFree(uPnt.weight);
   mssFree(mPnt.recNo);
@@ -870,7 +870,7 @@ static struct Node *makeTree(
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ޴ (Error-Based Pruning)
+ * 枝苅り (Error-Based Pruning)
  * ----------------------------------------------------------------------------
  */
 
@@ -881,7 +881,7 @@ double Dev[] = {100.0,3.09,  2.58,  2.33, 1.65, 1.28, 0.84, 0.25, 0.00};
 
 /**
  * # FUNCTION #
- * ޴ ͽ¬ʬ׻(refered from C4.5)
+ * 枝苅り 予測分類誤差計算(refered from C4.5)
  */
 static double calEBPerr(double NN, double e){
 
@@ -909,13 +909,13 @@ static double calEBPerr(double NN, double e){
 
 /**
  * # FUNCTION #
- * Ρɤˤͽ¬ʬ(C4.5)׻ƥåȤ
+ * 全ノードにおける予測分類誤差(C4.5)を計算してセットする
  */
 static void setEBPNodeErr(struct Node *node){
   double errCnt;
   int i;
 
-  /*errorΥ*/
+  /*error件数のカウント*/
   errCnt=0;
   for(i=0; i<ClassSize; i++){
     if(i!=node->cls) errCnt += (double)node->trnCnt.total 
@@ -923,7 +923,7 @@ static void setEBPNodeErr(struct Node *node){
   }
   node->estErrNode = calEBPerr((double)node->trnCnt.total,errCnt)+errCnt;
 
-  /*꡼դʤХ꥿*/
+  /*リーフならばリターン*/
   if( 0==node->nodeType ) return;
 
   setEBPNodeErr(node->uNode);
@@ -932,7 +932,7 @@ static void setEBPNodeErr(struct Node *node){
 
 /**
  * # FUNCTION #
- * Ϳ줿Ρɰʲ꡼դˤͽ¬ʬ(C4.5)׻֤
+ * 与えられたノード以下の全リーフにおける予測分類誤差(C4.5)を計算して返す
  */
 static double setEBPLeafErr(struct Node *node){
 
@@ -944,7 +944,7 @@ static double setEBPLeafErr(struct Node *node){
 
 /**
  * # FUNCTION #
- * ޴¹
+ * 枝苅り実行
  */
 static void pruneEBP(struct Node *node){
 
@@ -963,7 +963,7 @@ static void pruneEBP(struct Node *node){
 
 /**
  * # FUNCTION #
- * ޴ Ʊ饹ͽ¬դĥΡɤϻ޴()
+ * 枝苅り 同じクラスを予測する二の葉を持つノードは枝苅り(共通)
  */
 static void pruneSameClass(struct Node *node){
 
@@ -974,7 +974,7 @@ static void pruneSameClass(struct Node *node){
   if( 1==node->mNode->nodeType && !node->mNode->pruned )
     pruneSameClass(node->mNode);
 
-  /*ҤξȤ꡼դ⤷PrunedNodeξ硢ξȤƱ饹ʤ޴*/
+  /*子が両方ともリーフもしくはPrunedNodeの場合、両方とも同じクラスなら枝苅り*/
   if( (0==node->uNode->nodeType || node->uNode->pruned) &&
       (0==node->mNode->nodeType || node->mNode->pruned) &&
       (node->uNode->cls == node->mNode->cls)            ){
@@ -985,7 +985,7 @@ static void pruneSameClass(struct Node *node){
 
 /**
  * # FUNCTION #
- * ΡǾ(optMIN.val)ʤΡɤϻ޴
+ * ノード内最小ケース数(optMIN.val)に満たないノードは枝刈り
  */
 static void pruneMinCaseSize(struct Node *node){
 
@@ -996,7 +996,7 @@ static void pruneMinCaseSize(struct Node *node){
   if( 1==node->mNode->nodeType && !node->mNode->pruned )
     pruneMinCaseSize(node->mNode);
 
-  /*ҤξȤ꡼դ⤷PrunedNodeξ硢ξȤƱ饹ʤ޴*/
+  /*子が両方ともリーフもしくはPrunedNodeの場合、両方とも同じクラスなら枝苅り*/
   if( node->trnCnt.total < optMIN.val){
     node->pruned=1;
   }
@@ -1004,11 +1004,11 @@ static void pruneMinCaseSize(struct Node *node){
 
 /**
  * # FUNCTION #
- * ޴ᥤ
+ * 枝苅りメイン
  */
 static void pruneTree(struct Tree *tree,struct Cost *cost){
 
-  /*ΡǾ(optMIN.val)ˤ޴*/
+  /*ノード内最小ケース数(optMIN.val)による枝刈り*/
   if(optMIN.set){
     pruneMinCaseSize(tree->topNode);
   }
@@ -1019,20 +1019,20 @@ static void pruneTree(struct Tree *tree,struct Cost *cost){
   setEBPLeafErr(tree->topNode);
   pruneEBP(tree->topNode);
 
-  /*Ʊ饹Υ꡼դĥΡɤ޴*/
+  /*同じクラスの二のリーフを持つノードを枝苅り*/
   pruneSameClass(tree->topNode);
 }
 
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ɽϴؿ
+ * 表示系関数
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ڤΥΡɤɽƵؿ
+ * 決定木のノードを表示する再帰関数
  */
 static void showNode(
   struct Tree *tree,
@@ -1062,7 +1062,7 @@ static void showNode(
     break;
   }
 
-  /*LeafʤХ饹̷ɽ & */
+  /*Leafならばクラス別件数の表示 & 改行*/
   if(node->nodeType==0 || node->pruned==1){
     clsNam = MssFlds2name(fcls,0);
     clsVal = tree->dat->cls->str[node->cls];
@@ -1080,7 +1080,7 @@ static void showNode(
     return;
   }
 
-  /*Ρɤʤ*/
+  /*ノードならば*/
   if(node->nodeType==1){
     switch(node->attType){
     case 0: /*pat*/
@@ -1122,7 +1122,7 @@ static void showNode(
 
 /**
  * # FUNCTION #
- * ѥʸȤ֤
+ * 正規パターンを文字列として返す
  */
 char *getRegStr(struct Regexp *reg){
   char buf[4096];
@@ -1131,7 +1131,7 @@ char *getRegStr(struct Regexp *reg){
 
   buf[0]='\0';
 
-  /*Ƭ*/
+  /*先頭一致*/
   if(reg->bgnRng!=0){
     strcat(buf,"^[");
     sprintf(tmp,"%d",reg->bgnRng);
@@ -1146,7 +1146,7 @@ char *getRegStr(struct Regexp *reg){
     if(*str!=0) strcat(buf," ");
   }
 
-  /**/
+  /*末尾一致*/
   if(reg->endRng!=0){
     strcat(buf,"$[");
     sprintf(tmp,"%d",reg->endRng);
@@ -1158,7 +1158,7 @@ char *getRegStr(struct Regexp *reg){
 
 /**
  * # FUNCTION #
- * ѥ°ΥΡɽ񤭽Ф
+ * パターン属性のノード書き出し
  */
 void writePatPMML(
   struct Tree *tree,
@@ -1204,7 +1204,7 @@ void writePatPMML(
 
 /**
  * # FUNCTION #
- * °ΥΡɽ񤭽Ф
+ * 数値属性のノード書き出し
  */
 void writeNumPMML(
   struct Tree *tree,
@@ -1225,7 +1225,7 @@ void writeNumPMML(
 
 /**
  * # FUNCTION #
- * ƥ°ΥΡɽ񤭽Ф
+ * カテゴリ属性のノード書き出し
  */
 void writeCatPMML(
   struct Tree *tree,
@@ -1267,7 +1267,7 @@ void writeCatPMML(
 
 /**
  * # FUNCTION #
- * ڤΥΡɤɽƵؿ(PMML)
+ * 決定木のノードを表示する再帰関数(PMML)
  */
 static void showNodePMML(
   struct Tree *tree,
@@ -1308,7 +1308,7 @@ static void showNodePMML(
 
 /**
  * # FUNCTION #
- * PMMLեޥåȤǷڤ
+ * PMMLフォーマットで決定木を出力
  */
 void showTreePMML(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
 
@@ -1319,7 +1319,7 @@ void showTreePMML(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
   int ival;
   int i,j,k;
 
-  /* PMMLϽ*/
+  /* PMML出力初期化*/
   mssPMMLinit();
 
   /* <?xml version="1.0" encoding="EUC-JP"?> */
@@ -1346,21 +1346,21 @@ void showTreePMML(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
   ival=optPAT.cnt+optNUM.cnt+optCAT.cnt+optCLS.cnt;
   mssPMMLdataDictionaryStart(&ival,fpw);
 
-  /*     <DataField name="" optype="continuous">*/
+  /*     <DataField name="温度" optype="continuous">*/
   for(i=0; i<fnum->cnt; i++){
     mssPMMLdataFieldStart(MssFlds2name(fnum,i),NULL,"continuous",NULL,NULL,0,fpw);
     mssPMMLvalueStart(MssNullStr,NULL,"missing",1,fpw);
     mssPMMLdataFieldEnd(fpw);
   }
 
-  /*     <DataField name="ŷ" optype="categorical">*/
+  /*     <DataField name="天気" optype="categorical">*/
   for(i=0; i<fcat->cnt; i++){
     mssPMMLdataFieldStart(MssFlds2name(fcat,i),NULL,"categorical",NULL,NULL,0,fpw);
     mssPMMLvalueStart(MssNullStr,NULL,"missing",1,fpw);
     mssPMMLdataFieldEnd(fpw);
   }
 
-  /*     <DataField name="ѥ" optype="categorical">*/
+  /*     <DataField name="パターン" optype="categorical">*/
   for(i=0; i<fpat->cnt; i++){
     mssPMMLdataFieldStart(MssFlds2name(fpat,i),NULL,"categorical",NULL,NULL,0,fpw);
     mssPMMLextensionStart("MUSASHI","optype","pattern",1,fpw);
@@ -1368,7 +1368,7 @@ void showTreePMML(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
     mssPMMLdataFieldEnd(fpw);
   }
 
-  /*     <DataField name="" optype="categorical">*/
+  /*     <DataField name="ゴルフ" optype="categorical">*/
   for(i=0; i<fcls->cnt; i++){
     mssPMMLdataFieldStart(MssFlds2name(fcls,i),NULL,"categorical",NULL,NULL,1,fpw);
   }
@@ -1398,12 +1398,12 @@ void showTreePMML(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
       mssWriteRet(fpw); mssPV.outRetCnt++;
 
       /*<Array n="3" type="string">aa bb cc</Array>*/
-      /*ĤΥǥå˴ޤޤ륢ե٥åȤη򥫥*/
+      /*一つのインデックスに含まれるアルファベットの件数をカウント*/
       cnt=0;
       for(k=0; k<map->alpSiz; k++){
         if(*(map->idx+k) == (usint)(j+1) ) cnt++;
       }
-      /*ĤΥǥå˴ޤޤ륢ե٥åȤΥɥ쥹Ͽ*/
+      /*一つのインデックスに含まれるアルファベットのアドレスを登録*/
       str=mssMalloc(sizeof(char *)*cnt,"showTreePMML");
       cnt=0;
       for(k=0; k<map->alpSiz; k++){
@@ -1438,7 +1438,7 @@ void showTreePMML(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
 
 /**
  * # FUNCTION #
- * ƥȤǷڤ
+ * テキストで決定木を出力
  *  1.Command Line
  *  2.Cost Matrix
  *  3.Alphabet-Index
@@ -1528,7 +1528,7 @@ void showTree(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * API
+ * 決定木生成API
  *   1.decisionTree
  *   2.updateTree
  *   3.freeTree
@@ -1537,20 +1537,20 @@ void showTree(struct Tree *tree,struct Cost *cost, struct mssFPW *fpw){
 
 /**
  * # FUNCTION #
- * ᥤ롼
+ * 決定木生成メインルーチン
  */
 struct Tree *decisionTree(
-  struct Data *trn,   /*ȥ졼˥󥰥ǡ*/
-  struct Data *tst,   /*ƥȥǡ*/
-  struct Cost *cost){ /*ɽ*/
+  struct Data *trn,   /*トレーニングデータ*/
+  struct Data *tst,   /*テストデータ*/
+  struct Cost *cost){ /*コスト表*/
 
   struct Tree   *tree;
-  struct Pointer pointer; /*ĥ꡼ѤattTblΥǥå*/
+  struct Pointer pointer; /*ツリー生成時に利用するattTblのインデックス*/
   int i;
 
   tree = mssCalloc(sizeof(struct Tree),"tree");
 
-  /*pointerĤ*/
+  /*pointerをつける*/
   pointer.recCnt=trn->cnt;
   pointer.recNo =mssCalloc(trn->cnt * sizeof(int),"decTreePointer");
   pointer.weight=mssCalloc(trn->cnt * sizeof(double),"decTreePointer");
@@ -1562,29 +1562,29 @@ struct Tree *decisionTree(
   mssFree(pointer.recNo);
   mssFree(pointer.weight);
 
-  /*ץǡ¤ΤΥԡ(ºݤmapHash,mapTbl,cat->catListΤߥԡ)*/
+  /*サンプルデータ構造体のコピー(実際はmapHash,mapTbl,cat->catListのみコピー)*/
   tree->dat=cpyDatMapReg(trn);
 
-  /*޴*/
+  /*枝苅り*/
   pruneTree(tree,cost);
 
-  /*ĥ꡼¤ΤγƼѿΥå*/
+  /*ツリー構造体の各種変数のセット*/
   setLevel(tree->topNode,tree,0);
 
-  /*ɽκ(ȥ졼˥)*/
+  /*結果表の作成(トレーニング)*/
   tree->trnRsl=setClsTbl( trn, tree);
-  calClsTbl(tree->trnRsl,cost); /*Ƽ͡ɸ׻*/
+  calClsTbl(tree->trnRsl,cost); /*各種合計値、指標を計算*/
 
-  /*ɽκ(ƥ)*/
+  /*結果表の作成(テスト)*/
   tree->tstRsl=setClsTbl( tst, tree);
-  calClsTbl(tree->tstRsl,cost); /*Ƽ͡ɸ׻*/
+  calClsTbl(tree->tstRsl,cost); /*各種合計値、指標を計算*/
 
   return(tree);
 }
 
 /**
  * # FUNCTION #
- * ĥ꡼¤Τΰ
+ * ツリー構造体の領域解放
  */
 void freeTree(struct Tree *tree){
   struct Node **nodeTbl=NULL;
@@ -1607,19 +1607,19 @@ void freeTree(struct Tree *tree){
 
 /**
  * # FUNCTION #
- * 褤ĥ꡼ι
+ * よいツリーの更新
  */
 struct Tree *updateTree(
   struct Tree *tree,
   struct Tree *betterTree){
 
-  /*NULLȽ*/
+  /*一方がNULLの判定*/
   if(tree==NULL){
     return(betterTree);
   }else if(betterTree==NULL){
     return(tree);
 
-  /*Ȥ*/
+  /*コストの比較*/
   }else if(tree->trnRsl->tCst < betterTree->trnRsl->tCst){
     freeTree(betterTree);
     return(tree);
@@ -1627,7 +1627,7 @@ struct Tree *updateTree(
     freeTree(tree);
     return(betterTree);
 
-  /*ȤƱϥ*/
+  /*コストが同じ時はサイズが小さい方が勝ち*/
   }else{
     if(tree->leafCnt < betterTree->leafCnt){
       freeTree(betterTree);
@@ -1642,7 +1642,7 @@ struct Tree *updateTree(
 
 /**
  * # FUNCTION #
- * вɽ
+ * 途中経過表示
  */
 void showProgressTree(struct Data *dat, struct Tree *tree){
   int i;
