@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * unsigned intˤʸ򰷤إå
+ * unsigned intによる文字列を扱うヘッダー
  * ============================================================================
  */
 
@@ -15,22 +15,22 @@ typedef unsigned short int usint;
 
 /**
  * # STRUCT #
- * ꥹȤȤϿ빽¤
- * Ͽ줿nܤʸؤΥݥ󥿤ˤ륢ǽ
- * (line)(element):0ϥߥ͡
+ * 数値列をリストとして登録する構造体
+ * 登録されたn番目の文字列へのポインタによるアクセスが可能
+ * 行(line)、要素(element):0はターミネータ
  * 1,2,3,0
  * 3,5,0
  * 6,1,2,3,0
- * top=ƬԤƬǤΥɥ쥹
+ * top=先頭行の先頭要素のアドレス
  * pointer={0,4,7}
  * lineCnt=3
  * size=9
  */
 struct StrListUSI {
-  usint *top;     /*intꥹȤƬ*/
-  int   *pointer; /*intŪ(Ƭǿ)*/
-  int    lineCnt; /*Ͽ줿int*/
-  int    size;    /*Ͽ줿intǤ*/
+  usint *top;     /*intリストの先頭*/
+  int   *pointer; /*int列の相対的位置(先頭からの要素数)が入る*/
+  int    lineCnt; /*登録されたint列数*/
+  int    size;    /*登録されたint要素の総数*/
 }; 
 
 /**
