@@ -33,17 +33,17 @@
 
 /*-t*/
 #define C_TXTT "plain text"
-#define C_TXTC "o̓f[^̍\\ƂāAXMLtablef[^\\łȂplain textgB"
+#define C_TXTC "o̓f[^̍\ƂāAXMLtablef[^\łȂplain textgB"
 
 /*-T*/
 #define C_TMPT "ƃfBNg"
-#define C_TMPC "\\[gȂǂňꎞIɗpt@Ci[fBNgB"
+#define C_TMPC "\[gȂǂňꎞIɗpt@Ci[fBNgB"
 
 /*author*/
-#define C_HELPA "Yukinobu Hamuro,Naoki Katoh,Katsutoshi Yada"
+#define C_HELPA "Yukinobu Hamuro,Naoki Katoh"
 
 /*bugreport*/
-#define C_HELPB "musashi@adm.osaka-sandai.ac.jp"
+#define C_HELPB "musashi-users@lists.sourceforge.jp"
 
 /*homepage*/
-#define C_HELPH "http://musashi.adm.osaka-sandai.ac.jp"
+#define C_HELPH "http://musashi.sourceforge.jp"
