@@ -7,7 +7,7 @@
 /* コマンドのタイトル                                                         */
 /* コマンドヘルプの最初の行に表示                                             */
 /*----------------------------------------------------------------------------*/
-#define HELPT "レコードの集計"
+#define HELPT "複数のXMLtableファイルの併合"
 
 /*----------------------------------------------------------------------------*/
 /* パラメータ                                                                 */
@@ -15,11 +15,11 @@
 /* flagのオプションはコマンドヘルプのOPTIONS)として表示 ex)-z : 標準出力の圧縮*/
 /*----------------------------------------------------------------------------*/
 /*-c*/
-#define CNTT "項目数チェック"
+#define CNTT "項目数のみチェックして連結"
 #define CNTC "項目の数だけチェックして連結する(項目名のチェックはしない)"
 
 /*-n*/
-#define NAMT ""
+#define NAMT "同じ項目名のみ連結"
 #define NAMC "項目名が同じ項目のみを連結する(同じ項目がなければnullとする)。項目数が異なっていてもOK。"
 
 /*-i*/
