@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIɬפƤΥإåinclue뤿Υإåե
+ * MUSASHIで必要な全てのヘッダーをinclueするためのヘッダーファイル
  * ============================================================================
  */
 
@@ -23,6 +23,7 @@
 #include <musashi/mssXml.h>
 #include <musashi/mssValue.h>
 #include <musashi/mssPMML.h>
+#include <musashi/mssMisc.h>
 #include <musashi/qs5.h>
 #include <musashi/random.h>
 
