@@ -8,9 +8,9 @@
 
 /**
  * # DEFINE #
- * (mssCal.ccal_datefmtؿ
+ * 曜日(mssCal.cのcal_datefmt関数で利用
  */
-#define MssEMdow {"","","","","","",""}
+#define MssEMdow {"日","月","火","水","木","金","土"}
 
 #endif /* _MSSENCMSG_H */
 
