@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤʹϢΥإåե
+ * MUSASHIで用いられる値関連のヘッダーファイル
  * ============================================================================
  */
 
@@ -15,13 +15,13 @@
 
 /**
  * # MACRO #
- * ͤNULLꤹޥ
+ * 値をNULLに設定するマクロ
  */
 #define MssVnull(v) ((v).nul=1)
 
 /**
  * # ENUM #
- * ڥ졼
+ * オペレータ列挙体
  */
 enum OpeType {
   OPE_EQ, /* ==   */
@@ -34,7 +34,7 @@ enum OpeType {
 
 /**
  * # UNION #
- * ºݤͤ¸붦
+ * 実際に値を保存する共用体
  */
 union V {
   int     i;
@@ -46,7 +46,7 @@ union V {
 
 /**
  * # ENUM #
- * ͤμ
+ * 値の種類の列挙体
  */
 enum vType {
   INT, /* int     */
@@ -58,12 +58,12 @@ enum vType {
 
 /**
  * # STRUCT #
- * Ƥͤ빽¤
+ * 全ての値を収める構造体
  */
 struct MssValueStruct {
   enum  vType vType;
   union V     v;
-  int   nul; /*nullͤξ:1*/
+  int   nul; /*null値の場合:1*/
 };
 
 /**
@@ -103,7 +103,8 @@ MssValue 	mssVcntUp(MssValue v);
 MssValue 	mssVcntDown(MssValue v);
 MssValue 	mssVmin(MssValue v1, MssValue v2);
 MssValue 	mssVmax(MssValue v1, MssValue v2);
-int 		mssVcmp(MssValue a, enum OpeType ope, MssValue b);
+int 		mssVcmpOpe(MssValue a, enum OpeType ope, MssValue b);
+int 		mssVcmp(MssValue a, MssValue b);
 void 		mssVwrite(MssValue v, struct mssFPW *fp);
 void 		mssVwriteInt(MssValue v, struct mssFPW *fp);
 void 		mssVwriteDbl(MssValue v, struct mssFPW *fp);
