@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤ뽸״Ϣδؿ
+ * MUSASHIで用いられる集計関連の関数
  * ============================================================================
  */
 #include <musashi/mssBase.h>
@@ -20,25 +20,25 @@
 static MssValue *getAggValMem(enum MssAggType aggType, int fc);
 
 /**
- * Хѿ
+ * グローバル変数
  */
 extern struct mssGlobalVariables mssGV;
 
-static MssOptKEY *OptKey;           /*-kѥ᡼*/
-static MssOptFLD *OptFld;           /*-fѥ᡼*/
-static int  FldCnt;              /*פܿ*/
-static enum MssAggType AGGType;  /*ˡ("sum","avg",...)*/
-static char fname[MssFileNameMaxLen]; /*ե̾*/
-static char readEnd[2]={0xff,0}; /*ʼ*/
+static MssOptKEY *OptKey;           /*-kパラメータ*/
+static MssOptFLD *OptFld;           /*-fパラメータ*/
+static int  FldCnt;              /*集計する項目数*/
+static enum MssAggType AGGType;  /*集計方法("sum","avg",...)*/
+static char fname[MssFileNameMaxLen]; /*一時ファイル名*/
+static char readEnd[2]={0xff,0}; /*番兵*/
 
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ֹ(Red Black Tree)
+ * 赤黒木(Red Black Tree)
  * ----------------------------------------------------------------------------
- * ʸ: إǡ¤ȥ르ꥺٶΩ,2000,64.
- * p.224 9ܤϸ!!
- * ) if (v == NULL ) return(1) -> ) if (v == NULL ) return(0)
+ * 参考文献: 渡部敏正『データ構造とアルゴリズム』共立出版,2000,6章4節.
+ * p.224 下から9行目は誤り!!
+ * 誤) if (v == NULL ) return(1) -> 正) if (v == NULL ) return(0)
  */
 
 /**
@@ -190,7 +190,7 @@ static int keyCmp(struct mssFldRec *fr, struct RBAGnode *v)
       return(cmp);
     }
   }
-  return(0); /*Ʊ!!*/
+  return(0); /*同じキー!!*/
 }
 
 /**
@@ -411,7 +411,7 @@ static void RBAGptree(struct RBAGnode *p,int h)
 
 /**
  * # FUNCTION #
- * RBAGcpKeyδؿǳݤ줿̤η׻
+ * RBAGcpKeyの関数で確保されたメモリ量の計算
  */
 static int RBAGcpKeyMemCnt(struct mssFldRec *fr)
 {
@@ -419,24 +419,24 @@ static int RBAGcpKeyMemCnt(struct mssFldRec *fr)
   int memCnt=0;
 
   if(fr->eof==1){ /*EOF*/
-    /*ʸȤʼƤ*/
+    /*文字列として番兵を入れておく*/
     memCnt+=2*sizeof(char);
 
-    /*ܤΥɥ쥹ʼꤹ*/
+    /*キー項目のアドレスを全て番兵に設定する*/
     memCnt+=FldCnt*sizeof(char *);
 
-    /*sortAGǤϰʲbktѿѤƤʤmergeRBAGѡ*/
+    /*sortAGでは以下のbkt変数は利用していない。mergeRBAGで利用。*/
     memCnt+=(sizeof(int)*PWayA);
 
-    /*ߡǺäƤ(freeΤ)*/
+    /*ダミーで作っておく(freeのため)*/
     memCnt+=(sizeof(MssValue));
 
   }else{
 
-    /*frܤޤ뤴ȥԡ*/
+    /*frの全項目をまるごとコピー*/
     memCnt+=fr->chrCnt*sizeof(char);
 
-    /*ܤΥɥ쥹׻ˤꥻå*/
+    /*キー項目のアドレスを計算によりセット*/
     memCnt+=FldCnt*sizeof(char *);
 
     switch(AGGType){
@@ -458,7 +458,7 @@ static int RBAGcpKeyMemCnt(struct mssFldRec *fr)
       break;
     }
 
-    /*sortAGǤϰʲbktѿѤƤʤmergeRBAGѡ*/
+    /*sortAGでは以下のbkt変数は利用していない。mergeRBAGで利用。*/
     memCnt+=(sizeof(int)*PWayA);
   }
   return(memCnt);
@@ -473,44 +473,44 @@ static void RBAGcpKey(struct RBAGnode *v, struct mssFldRec *fr, int bkt, MssValu
   int i;
 
   if(fr->eof==1){ /*EOF*/
-    /*ʸȤʼƤ*/
+    /*文字列として番兵を入れておく*/
     v->key->str = mssMalloc(2*sizeof(char),"RBAGAGtree1");
     memcpy(v->key->str, readEnd, 2);
 
-    /*ܤΥɥ쥹ʼꤹ*/
+    /*キー項目のアドレスを全て番兵に設定する*/
     v->key->fld = mssMalloc(FldCnt*sizeof(char *),"RBAGAGtree2");
     for(i=0; i<FldCnt; i++){
       *(v->key->fld+i) = v->key->str;
     }
 
-    /*sortAGǤϰʲbktѿѤƤʤmergeRBAGѡ*/
+    /*sortAGでは以下のbkt変数は利用していない。mergeRBAGで利用。*/
     v->key->bkt    = mssCalloc(sizeof(int)*PWayA, "RBAGtree");
     *(v->key->bkt+bkt) = 1;
     /**v->key->bkt    = bkt;*/
     /*v->key->bktCnt = 1;*/
 
-    /*ߡǺäƤ(freeΤ)*/
+    /*ダミーで作っておく(freeのため)*/
     v->key->val = mssMalloc(sizeof(MssValue),"RBAGAGtree3");
 
   }else{
 
-    /*frܤޤ뤴ȥԡ*/
+    /*frの全項目をまるごとコピー*/
     v->key->str = mssMalloc(fr->chrCnt*sizeof(char),"RBAGAGtree4");
     memcpy(v->key->str, *fr->pnt, fr->chrCnt); 
 
-    /*ܤΥɥ쥹׻ˤꥻå*/
+    /*キー項目のアドレスを計算によりセット*/
     v->key->fld = mssMalloc(FldCnt*sizeof(char *),"RBAGAGtree5");
     for(i=0; i<FldCnt; i++){
       *(v->key->fld+i) = v->key->str + (*(fr->pnt+i) - *fr->pnt);
     }
 
-    /*ΰγ*/
+    /*集計値領域の確保*/
     v->key->val=getAggValMem(AGGType, OptFld->flds->cnt);
 
-    /*ͤη׻*/
+    /*集計値の計算*/
     mssCalAggVal(v->key->val, AGGType, val);
 
-    /*sortAGǤϰʲbktѿѤƤʤmergeRBAGѡ*/
+    /*sortAGでは以下のbkt変数は利用していない。mergeRBAGで利用。*/
     v->key->bkt    = mssCalloc(sizeof(int)*PWayA, "RBAGtree");
     *(v->key->bkt+bkt) = 1;
   }
@@ -518,23 +518,23 @@ static void RBAGcpKey(struct RBAGnode *v, struct mssFldRec *fr, int bkt, MssValu
 
 /**
  * # FUNCTION #
- * ΥΡɤFldRec¤ΤΥǡǹ
+ * 指定のノードをFldRec構造体のデータで更新
  */
 static void RBAGupdate(struct RBAGnode *v, struct mssFldRec *fr, int bkt, MssValue *val)
 {
-  /*ХåֹХåȥե饰˹*/
+  /*更新したバケット番号をバケットフラグに更新する*/
   *(v->key->bkt+bkt) = 1;
 
   if(fr->eof!=1){ /*not EOF*/
-    /*ͤη׻*/
+    /*集計値の計算*/
     mssCalAggVal(v->key->val, AGGType, val);
   }
 }
 
 /**
  * # FUNCTION #
- * RBtreeFldRec¤ΤΥǡɲ
- * ˥¸ߤRBAGupdateͤ򹹿
+ * RBtreeにFldRec構造体のデータを追加
+ * 既にキーが存在すればRBAGupdateで値を更新
  */
 static int RBAGinsert(struct RBAGnode *v, struct mssFldRec *fr, int bkt, MssValue *val)
 {
@@ -542,7 +542,7 @@ static int RBAGinsert(struct RBAGnode *v, struct mssFldRec *fr, int bkt, MssValu
 
   v = RBAGmember(fr, v);
 
-  /*¸ߤʤɲ*/
+  /*キーが存在しなければ追加*/
   if(RBAGisExternalNode(v)){
     RBAGcpKey(v, fr, bkt, val);
     memCnt=RBAGcpKeyMemCnt(fr);
@@ -552,7 +552,7 @@ static int RBAGinsert(struct RBAGnode *v, struct mssFldRec *fr, int bkt, MssValu
     memCnt+=sizeof(struct RBAGnode)*2;
     memCnt+=sizeof(struct RBAGkey )*2;
 
-  /*¸ߤй*/
+  /*キーが存在すれば更新*/
   }else{
     RBAGupdate(v, fr, bkt,val);
   }
@@ -563,7 +563,7 @@ static int RBAGinsert(struct RBAGnode *v, struct mssFldRec *fr, int bkt, MssValu
 
 /**
  * # FUNCTION #
- * ΥΡɤ
+ * 指定のノードを削除
  */
 static void RBAGdeleteNode(struct RBAGnode *v)
 {
@@ -622,8 +622,8 @@ static void RBAGdeleteNode(struct RBAGnode *v)
 
 /**
  * # FUNCTION #
- * RBtreeͥԤΥΡɥɥ쥹֤
- * νǥΡɤϤʤƤӽФ¦RBAGdeleteNode(node)¹
+ * RBtreeから優先行のノードアドレスを返す
+ * この処理でノードを削除はしない。呼び出す本体側でRBAGdeleteNode(node)を実行
  */
 static struct RBAGnode *RBAGpop(struct RBAGnode *v)
 {
@@ -634,7 +634,7 @@ static struct RBAGnode *RBAGpop(struct RBAGnode *v)
   }else{
     vv=v;
     while(!RBAGisExternalNode(vv)){
-      vv=vv->left; /*rightéк硢leftϺǾ*/
+      vv=vv->left; /*rightを辿れば最大、leftは最小*/
     }
     return(vv->parent);
   }
@@ -642,7 +642,7 @@ static struct RBAGnode *RBAGpop(struct RBAGnode *v)
 
 /**
  * # FUNCTION #
- * RBtreeĥ꡼Ȥƽ񤭽Ф(ǥХå)
+ * RBtreeをツリーとして書き出す(デバッグ用)
  */
 void RBAGprintTree(char *s,struct RBAGnode *pp)
 {
@@ -652,13 +652,13 @@ void RBAGprintTree(char *s,struct RBAGnode *pp)
 
 /**
  * # FUNCTION #
- * ΥΡɤԤȤƽ񤭽Ф
+ * 指定のノードを行として書き出す
  */
 static void RBAGwriteNode(struct RBAGnode *p, int valCnt, struct mssFPW *fpw, FILE *valFile)
 {
   int i;
 
-  /*ǡƥȤν*/
+  /*データテキストの出力*/
   for(i=0; i<FldCnt-1; i++){
     mssWriteStr(*(p->key->fld+i),fpw); mssWriteDlm(fpw);
   }
@@ -669,7 +669,7 @@ static void RBAGwriteNode(struct RBAGnode *p, int valCnt, struct mssFPW *fpw, FI
 
 /**
  * # FUNCTION #
- * RBtreeƹԤȤƽ񤭽Ф
+ * RBtreeを全て行として書き出す
  */
 static void RBAGwriteAllNode(struct RBAGnode *p, int valCnt, struct mssFPW *fpw, FILE *valFile)
 {
@@ -683,7 +683,7 @@ static void RBAGwriteAllNode(struct RBAGnode *p, int valCnt, struct mssFPW *fpw,
 
 /**
  * # FUNCTION #
- * RBtreeΥΰ
+ * RBtreeのメモリ領域解放
  */
 static void RBAGfree(struct RBAGnode *v)
 {
@@ -695,11 +695,11 @@ static void RBAGfree(struct RBAGnode *v)
 
 /**
  * # FUNCTION #
- * RBnodeν(Ρɺ)
+ * RBnodeの初期化(ノード作成)
  */
 static struct RBAGnode *RBAGinit(struct RBAGnode *rb)
 {
-  /*ֹڤν*/
+  /*赤黒木の初期化*/
   rb               = RBAGmakeNode();
   rb->parent       = rb;
   rb->right        = NULL;
@@ -712,13 +712,13 @@ static struct RBAGnode *RBAGinit(struct RBAGnode *rb)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ץ̤α黻
+ * 集計タイプ別の演算
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ׽
+ * 合計集計
  */
 static void aggSum(MssValue *val, MssValue *val2)
 {
@@ -730,7 +730,7 @@ static void aggSum(MssValue *val, MssValue *val2)
 
 /**
  * # FUNCTION #
- * 
+ * 件数集計
  */
 static void aggCnt(MssValue *val, MssValue *val2)
 {
@@ -745,7 +745,7 @@ static void aggCnt(MssValue *val, MssValue *val2)
 
 /**
  * # FUNCTION #
- * ʿѽ
+ * 平均集計
  */
 static void aggAvg(MssValue *val, MssValue *val2)
 {
@@ -760,7 +760,7 @@ static void aggAvg(MssValue *val, MssValue *val2)
 
 /**
  * # FUNCTION #
- * ʿѽף
+ * 平均集計２
  */
 static void aggAvg2(MssValue *val, MssValue *val2)
 {
@@ -773,7 +773,7 @@ static void aggAvg2(MssValue *val, MssValue *val2)
 
 /**
  * # FUNCTION #
- * Ǿͽ
+ * 最小値集計
  */
 static void aggMin(MssValue *val, MssValue *val2)
 {
@@ -785,7 +785,7 @@ static void aggMin(MssValue *val, MssValue *val2)
 
 /**
  * # FUNCTION #
- * ͽ
+ * 最大値集計
  */
 static void aggMax(MssValue *val, MssValue *val2)
 {
@@ -797,7 +797,7 @@ static void aggMax(MssValue *val, MssValue *val2)
 
 /**
  * # FUNCTION #
- * ʬ
+ * 分散集計
  */
 static void aggVar(MssValue *val, MssValue *x)
 {
@@ -810,10 +810,10 @@ static void aggVar(MssValue *val, MssValue *x)
   mssVinit(&const1,DBL);
   const1.v.d=1;
 
-  /*x   :ʿѤȤκ(x)*/
-  /*n :Ŀ(n)*/
-  /*s1:ʿ(s1)*/
-  /*s2:ʿ(s2)*/
+  /*x   :仮平均との差(x)*/
+  /*n :個数(n)*/
+  /*s1:平均(s1)*/
+  /*s2:平方和(s2)*/
   n =val;
   s1=val+OptFld->flds->cnt;
   s2=val+OptFld->flds->cnt*2;
@@ -838,8 +838,8 @@ static void aggVar(MssValue *val, MssValue *x)
 
 /**
  * # FUNCTION #
- * ʻˤϽˡѤΤ
- *˶뤳
+ * 併合時には集計方法が変わるものがある
+ *ここに具体例を説明すること
  */
 static enum MssAggType chgAggType(enum MssAggType aggType)
 {
@@ -860,14 +860,14 @@ static enum MssAggType chgAggType(enum MssAggType aggType)
     return(aggAVG2);
     break;
   case aggSTD:
-  case aggSTDP:     /*ꤨʤٹ򤱤뤿*/
+  case aggSTDP:     /*ありえないが警告を避けるため*/
     return(aggSTD);
     break;
   case aggVAR:
-  case aggVARP:     /*ꤨʤٹ򤱤뤿*/
+  case aggVARP:     /*ありえないが警告を避けるため*/
     return(aggVAR);
     break;
-  case aggAVG2:     /*ѥٹɤ*/
+  case aggAVG2:     /*コンパイル警告を防ぐために*/
     return(aggAVG2);
     break;
   }
@@ -878,24 +878,24 @@ static enum MssAggType chgAggType(enum MssAggType aggType)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ״Ϣؿ
+ * 集計関連関数
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ե̾μ
+ * 一時ファイル名の取得
  */
 static char *getFname(char *prefix, int number)
 {
-  /*fnameϥХѿ*/
+  /*fnameはグローバル変数*/
   sprintf(fname,"%s%d",prefix,number);
   return(fname);
 }
 
 /**
  * # FUNCTION #
- * mssFldRec¤Τ˰ɤ߹(ʼ)
+ * mssFldRec構造体に一行読み込む(番兵処理)
  */
 static void readRBAGkey( struct mssFPR *fp, struct mssFldRec *fr)
 {
@@ -903,27 +903,27 @@ static void readRBAGkey( struct mssFPR *fp, struct mssFldRec *fr)
 
   if(EOF==mssReadFldRec(fp,fr)){
     for(i=0; i<fr->fldCnt; i++)
-      *(fr->pnt+i)=readEnd; /*EOFλʼ*/
+      *(fr->pnt+i)=readEnd; /*EOFの時は番兵を入れる*/
   }
 }
 
 /**
  * # FUNCTION #
- * ƥХåȤκǽιԤRB塼ɤ߹
- * mergeRB,preSortƤӽФ
- * iFromiToޤǤΥեƬԤRB塼
- * ad   : iFile,rb򥻥åȤ
- * iFrom: ϥեֹ
- * iTo  : λեֹ
+ * 各バケットの最初の行をRBキューに読み込み
+ * mergeRB,preSortから呼び出される
+ * iFromからiToまでのファイルの先頭行をRBキューに入れる
+ * ad   : iFile,rbをセットする
+ * iFrom: 開始ファイル番号
+ * iTo  : 終了ファイル番号
  */
 static void setFirstLineRBAG(struct mssAggDat *ad, int iFrom, int iTo)
 {
-  int bkt;                /*߽ΥХåֹ(0Ϥޤ)*/
+  int bkt;                /*現在処理中のバケット番号(0から始まる)*/
   int i;
 
-  /*ad->bktCnt=iTo-iFrom+1; Хåȿ*/
+  /*ad->bktCnt=iTo-iFrom+1; バケット数の設定*/
 
-  /*ץ饤ƥ塼ν*/
+  /*プライオリティキューの初期化*/
   ad->rb=RBAGinit(ad->rb);
   bkt=0;
   for(i=iFrom; i<=iTo; i++){
@@ -932,11 +932,11 @@ static void setFirstLineRBAG(struct mssAggDat *ad, int iFrom, int iTo)
     ad->iFile[bkt]=mssOpenFPR(getFname(ad->prefixTxt,i),4);
     ad->vFile[bkt]=fopen(getFname(ad->prefixVal,i),"rb");
 
-    /*(Ƭ)ɤ߹*/
+    /*一行(先頭行)読み込み*/
     readRBAGkey(ad->iFile[bkt],ad->fr[bkt]);
     fread(ad->val, sizeof(MssValue), ad->valCnt, ad->vFile[bkt]);
 
-    /*ֹڤ(ʪŪ˥ԡ)*/
+    /*赤黒木に挿入(物理的にコピー)*/
     RBAGinsert(ad->rb->left,ad->fr[bkt],bkt, ad->val);
     bkt++;
   }
@@ -944,120 +944,120 @@ static void setFirstLineRBAG(struct mssAggDat *ad, int iFrom, int iTo)
 
 /**
  * # FUNCTION #
- *RB塼ѤPWayޡ
- * ¤ѤäƤХå(iCnt)ʻ礷Ƥ
- * ǸΰĤˤʤޤʻϤʤ
- * PWayAĤ꾯ʤʤäȤʻߤ
+ *RBキューを用いたPWayマージ
+ * 既に並べ変わっているバケット(iCnt個)を併合していく
+ * 最後の一つになるまで併合はしない
+ * PWayA個より少なくなったときに併合を止める
  */
 static void mergeRBAG(struct mssAggDat *ad)
 {
-  int    bkt[PWayA];       /*PwayʻRBtreepopǡΥХåNo*/
-  int    bktCnt;           /*ΥХåȿ*/
-  struct RBAGnode *node;   /*popˤƼΡɤǼ*/
+  int    bkt[PWayA];       /*Pway併合時にRBtreeからpopしたデータのバケットNo*/
+  int    bktCnt;           /*そのバケット数*/
+  struct RBAGnode *node;   /*popにて取りだしたノードを格納*/
 
-  struct mssFPW *oFile;       /*ϥեݥ*/
-  FILE       *vFile;       /*ϥեݥ*/
+  struct mssFPW *oFile;       /*出力ワークファイルポインタ*/
+  FILE       *vFile;       /*出力ワークファイルポインタ*/
 
-  int    iStart;           /*ϥեγֹ(ե̾ΰ)*/
-  int    iEnd;             /*ϥեνλֹ(ե̾ΰ)*/
-  int    oStart;           /*ϥեγֹ(ե̾ΰ)*/
-  int    oEnd;             /*ϥեνλֹ(ե̾ΰ)*/
-  int    iFrom,iTo;        /*ʻ礹Υեֹ*/
+  int    iStart;           /*入力ワークファイルの開始番号(ファイル名の一部)*/
+  int    iEnd;             /*入力ワークファイルの終了番号(ファイル名の一部)*/
+  int    oStart;           /*出力ワークファイルの開始番号(ファイル名の一部)*/
+  int    oEnd;             /*出力ワークファイルの終了番号(ファイル名の一部)*/
+  int    iFrom,iTo;        /*併合する時のファイル番号*/
   int    k;
   int    i;
 
-  /*Υ롼פin,outswapΤǡǤϵդ*/
+  /*次のループでin,outをswapするので、ここでは逆に定義*/
   iStart=ad->iEnd+1;
   iEnd  =ad->iEnd+1;
   oStart=ad->iStart;
   oEnd  =ad->iEnd;
 
-  /*եʻ礹롼 iCntPWayAĤ礭ޤ³*/
+  /*ファイルを併合するループ iCntがPWayA個より大きい場合まわり続ける*/
   while(1){
     mssSwapInt(&iStart,&oStart);
     mssSwapInt(&iEnd  ,&oEnd  );
     oEnd=oStart;
 
-    /*ϥեPWayAʲʤнλ*/
+    /*入力ファイル数がPWayA以下ならば終了*/
     if(iEnd-iStart+1 <= PWayA){
       ad->iStart = iStart;
       ad->iEnd   = iEnd;
       break;
     }
 
-    /*PwayĤiFileĤoFile˽񤭽Ф"򷫤֤롼*/
+    /*Pway個のiFileを一つのoFileに書き出す"を繰り返すループ*/
     k=0;
     while(1){
-      /*ƥХåȤκǽԤ򥭥塼*/
-      iFrom= k   *PWayA+iStart;    /*PWayA=3ǰե뤬0,1,2,3,4,5,6λ*/
+      /*各バケットの最初行をキューに入れる*/
+      iFrom= k   *PWayA+iStart;    /*PWayA=3で一時ファイルが0,1,2,3,4,5,6の時*/
       iTo  =(k+1)*PWayA+iStart-1;  /* iFrom: 0 3 6*/
       if(iTo>iEnd) iTo=iEnd;       /* iTo  : 2 5 6*/
       setFirstLineRBAG(ad, iFrom,iTo);
 
-      /*ϥե륪ץ*/
+      /*出力ファイルオープン*/
       oFile=mssOpenFPW(getFname(ad->prefixTxt,oEnd),0,0);
       vFile=fopen(getFname(ad->prefixVal,oEnd),"wb");
 
-      /*ƥХåȤԤŤɤ߹߽񤭽Ф롼*/
+      /*各バケットから一行づつ読み込み書き出すループ*/
       while(1) {
-        node=RBAGpop(ad->rb->left);          /*塼ԼФ*/
-        if(strcmp(node->key->str,readEnd)==0)/*readEnd(ʼ)Ф齪λ*/
+        node=RBAGpop(ad->rb->left);          /*キューから一行取り出し*/
+        if(strcmp(node->key->str,readEnd)==0)/*readEnd(番兵)を取り出したら終了*/
           break;
-        RBAGwriteNode(node,ad->valCnt,oFile,vFile);  /*Խ񤭽Ф*/
-        bktCnt=0;                   /*popǼФkeyͤΥХåȿ*/
+        RBAGwriteNode(node,ad->valCnt,oFile,vFile);  /*一行書き出し*/
+        bktCnt=0;                   /*popで取り出したkey値のバケット数*/
         for(i=0; i<PWayA; i++){
           if(*(node->key->bkt+i) == 1)
-          bkt[bktCnt++]=i;          /*Хåֹ򥻥å*/
+          bkt[bktCnt++]=i;          /*バケット番号をセット*/
         } 
-        RBAGdeleteNode(node);              /*ФΡɤκ*/
+        RBAGdeleteNode(node);              /*取り出したノードの削除*/
 
-        /*popХåȤ鿷ɤߤRBtree*/
+        /*popしたバケットから新に読みこんでRBtreeに挿入する*/
         for(i=0; i<bktCnt; i++){
           readRBAGkey(ad->iFile[bkt[i]],ad->fr[bkt[i]]);
           fread(ad->val,sizeof(MssValue),ad->valCnt,ad->vFile[bkt[i]]);
           RBAGinsert(ad->rb->left,ad->fr[bkt[i]],bkt[i],ad->val);
         }
       }
-      RBAGfree(ad->rb);                    /*塼γ*/
-      for(i=0; i<=iTo-iFrom; i++){         /*ϥեΥ*/
+      RBAGfree(ad->rb);                    /*キューの開放*/
+      for(i=0; i<=iTo-iFrom; i++){         /*入力ファイルのクローズ*/
         mssCloseFPR(ad->iFile[i]);
         fclose(ad->vFile[i]);
         mssFreeFldRec(ad->fr[i]);
       }
-      mssCloseFPW(oFile);                  /*ϥեΥ*/
-      fclose(vFile);                       /*ϥեΥ*/
-      if(iTo==iEnd)break;                  /*ǸΥХåȤޤǤнλ*/
-      oEnd++;                              /*ϥեֹ楫ȥå*/
-      k++;                                 /*ʻȥå*/
+      mssCloseFPW(oFile);                  /*出力ファイルのクローズ*/
+      fclose(vFile);                       /*出力ファイルのクローズ*/
+      if(iTo==iEnd)break;                  /*最後のバケットまでいけば終了*/
+      oEnd++;                              /*出力ファイル番号カウントアップ*/
+      k++;                                 /*併合回数カウントアップ*/
     }
     for(i=iStart; i<=iEnd; i++){
-      unlink(getFname(ad->prefixTxt,i));      /*ϥեκ*/
-      unlink(getFname(ad->prefixVal,i));      /*ϥեκ*/
+      unlink(getFname(ad->prefixTxt,i));      /*入力ワークファイルの削除*/
+      unlink(getFname(ad->prefixVal,i));      /*入力ワークファイルの削除*/
     }
   }
 }
 
 /**
  * # FUNCTION #
- *פʤsortؿ(uniq,sum,avg,max,min,cnt,stdev,var...)
- *פʤֹڤ
- * MAXۤե˽񤭽Ф
+ *集計しながらsortする関数(uniq,sum,avg,max,min,cnt,stdev,var...)
+ *集計しながら赤黒木を作成
+ * メモリ消費がMAXを越えたら一時ファイルに書き出し
  */
 static void sortAG(struct mssAggDat *ad, struct mssFPR *fpr)
 {
-  struct mssFldRec *fr;    /*ϥե򥭡¤ٴ뤿ΥХåե*/
-  int    pid;              /*ץID(ե̾ΰ)*/
-  int    oNum;             /*եֹΥȥåѿ*/
-  int    memCnt;           /**/
+  struct mssFldRec *fr;    /*入力ファイルをキー順に並べ換えるためのバッファ*/
+  int    pid;              /*プロセスID(ファイル名の一部)*/
+  int    oNum;             /*ワークファイル番号のカウントアップ変数*/
+  int    memCnt;           /*メモリ消費量*/
 
-  struct RBAGnode *rb=NULL; /*ֹ*/
-  struct mssFPW *outFile;      /*ϰե*/
-  FILE       *valFile;      /*ϰե*/
+  struct RBAGnode *rb=NULL; /*赤黒木*/
+  struct mssFPW *outFile;      /*出力一時ファイル*/
+  FILE       *valFile;      /*出力一時ファイル*/
 
-  fr=mssInitFldRec(FldCnt);/*FldRecν*/
-  rb=RBAGinit(rb);          /*RBAGtreeν*/
+  fr=mssInitFldRec(FldCnt);/*FldRecの初期化*/
+  rb=RBAGinit(rb);          /*RBAGtreeの初期化*/
 
-  /*ե̾Υץեå*/
+  /*ファイル名のプレフィックスの設定*/
   pid=getpid();
   if(strlen(ad->tmpDir) > MssFileNameMaxLen - 50 ) {
     mssShowErrMsg("length of path name must be less than %d",MssFileNameMaxLen-50);
@@ -1066,36 +1066,36 @@ static void sortAG(struct mssAggDat *ad, struct mssFPR *fpr)
   sprintf(ad->prefixTxt,"%s/xt##%d-PreAggTxt-",ad->tmpDir,pid);
   sprintf(ad->prefixVal,"%s/xt##%d-PreAggVal-",ad->tmpDir,pid);
 
-  memCnt=0; /*ꥫ󥿤Υꥢ*/
-  oNum=0;   /*ϥեֹ*/
+  memCnt=0; /*消費メモリカウンタのクリア*/
+  oNum=0;   /*出力ファイル番号*/
   while(1){
-    /*ǡɤ߹*/
+    /*データの読み込み*/
     mssReadFldRec(fpr,fr);
     (*ad->inCnt)++;
 
-    /*ֹڤΥMaxۤ ⤷ ǽԤ򸡽Ф*/
-    /*եؽ񤭽Ф*/
+    /*赤黒木のサイズがMaxを越えたら もしくは 最終行を検出したら*/
+    /*ワークファイルへ書き出す*/
     if( memCnt >= MaxMemA || fr->eof==1){
-      outFile=mssOpenFPW(getFname(ad->prefixTxt,oNum),0,0);/*ϥե륪ץ*/
-      valFile=fopen(getFname(ad->prefixVal,oNum),"wb"); /*ϥե륪ץ*/
-      RBAGwriteAllNode(rb->left,ad->valCnt, outFile,valFile);/*RBtreeƽ*/
-      mssCloseFPW(outFile);                          /*ϥեΥ*/
-      fclose(valFile);                            /*ϥեΥ*/
-      oNum++;                                     /*ϥեcountUp*/
-      RBAGfree(rb);   /*RBAGtreeΰ*/
-      if(fr->eof==1){ /*ǽԤǽλ*/
+      outFile=mssOpenFPW(getFname(ad->prefixTxt,oNum),0,0);/*出力ファイルオープン*/
+      valFile=fopen(getFname(ad->prefixVal,oNum),"wb"); /*出力ファイルオープン*/
+      RBAGwriteAllNode(rb->left,ad->valCnt, outFile,valFile);/*RBtree全て出力*/
+      mssCloseFPW(outFile);                          /*出力ファイルのクローズ*/
+      fclose(valFile);                            /*出力ファイルのクローズ*/
+      oNum++;                                     /*出力ファイル数countUp*/
+      RBAGfree(rb);   /*RBAGtreeの領域解放*/
+      if(fr->eof==1){ /*最終行で終了*/
         (*ad->inCnt)--;
         break;
       }
-      rb=RBAGinit(rb);    /*RBAGtreeν*/
-      memCnt=0;           /*ꥫ󥿤Υꥢ*/
+      rb=RBAGinit(rb);    /*RBAGtreeの初期化*/
+      memCnt=0;           /*消費メモリカウンタのクリア*/
     }
 
-    /*ֹڤ(ʪŪ˥ԡ)򥫥ȥå*/
+    /*赤黒木に挿入して(物理的にコピー)、メモリ消費をカウントアップ*/
     mssSetAggVal(ad->val, fr->pnt);
     memCnt += RBAGinsert(rb->left,fr,1,ad->val);
   }
-  mssFreeFldRec(fr);/*FldRecν*/
+  mssFreeFldRec(fr);/*FldRecの初期化*/
 
   ad->iStart = 0;
   ad->iEnd   = oNum-1;
@@ -1103,7 +1103,7 @@ static void sortAG(struct mssAggDat *ad, struct mssFPR *fpr)
 
 /**
  * # FUNCTION #
- * ʸȤƤνˡ("sum","avg","min"..)enumAGtypeǤѴ
+ * 文字列としての集計方法("sum","avg","min"..)をenumAGtypeの要素に変換
  */
 static enum MssAggType setAggType(char *str)
 {
@@ -1130,12 +1130,12 @@ static enum MssAggType setAggType(char *str)
   mssShowErrMsg("Invalid aggregation method:'%s'",str);
   exit(mssErrorNoDefault);
 
-  return(-1); /*ѥwarningå򤱤뤿*/
+  return(-1); /*コンパイラwarningメッセージを避けるため*/
 }
 
 /**
  * # FUNCTION #
- * ܿ(fc)Ƚץפ˱ƽΰǳݤMssValueο֤
+ * 項目数(fc)と集計タイプに応じて集計値領域で確保するMssValueの数を返す。
  */
 static int getAggValCnt(enum MssAggType aggType, int fc)
 {
@@ -1162,7 +1162,7 @@ static int getAggValCnt(enum MssAggType aggType, int fc)
 
 /**
  * # FUNCTION #
- * ܿ(fc)Ƚץפ˱ƽΰݤ롣
+ * 項目数(fc)と集計タイプに応じて集計値領域を確保する。
  */
 static MssValue *getAggValMem(enum MssAggType aggType, int fc)
 {
@@ -1193,7 +1193,7 @@ static MssValue *getAggValMem(enum MssAggType aggType, int fc)
 
 /**
  * # FUNCTION #
- * ܿ(fc)Ƚץפ˱ƽΰ(val)򥯥ꥢ롣
+ * 項目数(fc)と集計タイプに応じて集計値領域(val)をクリアする。
  */
 void mssClearAggVal(MssValue *val, enum MssAggType aggType, int fc)
 {
@@ -1224,11 +1224,11 @@ void mssClearAggVal(MssValue *val, enum MssAggType aggType, int fc)
 
 /**
  * # FUNCTION #
- * ץפ˱ơ(val)򿷤(val2)ˤäƹ롣
+ * 集計タイプに応じて、集計値(val)を新しい値(val2)によって更新する。
  */
 void mssCalAggVal(MssValue *val, enum MssAggType aggType, MssValue *val2)
 {
-  /*val2:f= val:׻*/
+  /*val2:f=の値 val:計算結果*/
   switch(aggType){
   case aggSUM:
     aggSum( val ,val2);
@@ -1259,7 +1259,7 @@ void mssCalAggVal(MssValue *val, enum MssAggType aggType, MssValue *val2)
 
 /**
  * # FUNCTION #
- * ץפ˱ơǽ̤׻ԽϤ롣
+ * 集計タイプに応じて、最終結果を計算し、一行出力する。
  */
 void mssWriteAggFld( char **fld, MssValue *val, enum MssAggType aggType, struct mssFPW *fpw)
 {
@@ -1278,7 +1278,7 @@ void mssWriteAggFld( char **fld, MssValue *val, enum MssAggType aggType, struct
     break;
   case aggMAX:
     break;
-  case aggAVG: /*̵̣ѥ륨顼򤱤뤿*/
+  case aggAVG: /*意味無いがコンパイルエラーを避けるため*/
   case aggAVG2:
     for(i=0; i<OptFld->flds->cnt; i++){
       *(val+i)=mssVdiv(*(val+i), *(val+OptFld->flds->cnt+i) );
@@ -1324,9 +1324,9 @@ void mssWriteAggFld( char **fld, MssValue *val, enum MssAggType aggType, struct
 
 /**
  * # FUNCTION #
- * ץפ˱ơǽ̤׻ԽϤ롣
- *ʸȤƤιܤvalѴؿ
- *valrbtree뤿ΰŪʤ
+ * 集計タイプに応じて、最終結果を計算し、一行出力する。
+ *文字列としての項目をvalに変換する関数
+ *valはrbtreeに入れるための一時的なもの
  */
 void mssSetAggVal(MssValue *val, char **str)
 {
@@ -1343,48 +1343,48 @@ void mssSetAggVal(MssValue *val, char **str)
 
 /**
  * # FUNCTION #
- * RB塼Ѥڤʬɤ߹
- * ¤ѤäƤХå(ad->iStartad->iEnd)򽸷פʤ
- * ʻ礷Ƥ
- * եθĿϴPWayAʲˤʤäƤ뤳Ȥ
+ * RBキューを用いた項目切り分け型行読み込み
+ * 既に並べ変わっているバケット(ad->iStartからad->iEnd)を集計しながら
+ * 併合していく
+ * ファイルの個数は既にPWayA以下になっていることが前提
  */
 int mssReadWriteAgg(struct mssAggDat *ad, struct mssFPW *oFile)
 {
-  struct RBAGnode *node;     /*popˤƼΡɤǼ*/
-  int              bkt[PWayA];/*PwayʻRBtreepopǡΥХåNo*/
-  int              bktCnt;   /*ΥХåȿ*/
+  struct RBAGnode *node;     /*popにて取りだしたノードを格納*/
+  int              bkt[PWayA];/*Pway併合時にRBtreeからpopしたデータのバケットNo*/
+  int              bktCnt;   /*そのバケット数*/
   int i;
 
-  node=RBAGpop(ad->rb->left);           /*塼ԼФ*/
-  if(strcmp(node->key->str,readEnd)==0) /*readEnd(ʼ)Ф齪λ*/
+  node=RBAGpop(ad->rb->left);           /*キューから一行取り出し*/
+  if(strcmp(node->key->str,readEnd)==0) /*readEnd(番兵)を取り出したら終了*/
     return(EOF);
 
-  /*Խ񤭽Ф*/
+  /*一行書き出し*/
   mssWriteAggFld(node->key->fld,node->key->val,AGGType,oFile);
 
-  bktCnt=0;                      /*popǼФkeyͤΥХåȿ*/
+  bktCnt=0;                      /*popで取り出したkey値のバケット数*/
   for(i=0; i<PWayA; i++){
     if(*(node->key->bkt+i) == 1)
-      bkt[bktCnt++]=i;           /*Хåȥե饰򥻥å*/
+      bkt[bktCnt++]=i;           /*バケットフラグをセット*/
   } 
-  RBAGdeleteNode(node);          /*ФΡɤκ*/
+  RBAGdeleteNode(node);          /*取り出したノードの削除*/
 
-  /*popХåȤ鿷ɤߤRBtree*/
+  /*popしたバケットから新に読みこんでRBtreeに挿入する*/
   for(i=0; i<bktCnt; i++){
     readRBAGkey(ad->iFile[bkt[i]],ad->fr[bkt[i]]);
     fread(ad->val,sizeof(MssValue),ad->valCnt,ad->vFile[bkt[i]]);
     RBAGinsert(ad->rb->left,ad->fr[bkt[i]],bkt[i],ad->val);
   }
-  return(1); /*Ȥꤢ*/
+  return(1); /*とりあえず*/
 }
 
 /**
  * # FUNCTION #
- *ֹڤʤ齸סܽפʤPWayޡ
+ *赤黒木を作りながら集計＋集計しながらPWayマージソート
  */
 void mssPreAgg(struct mssAggDat *ad, struct mssFPR *iFile)
 {
-  /*ʥϥɥ*/
+  /*シグナルハンドラの設定*/
   mssGV.usedTempFileFlg=1;
   mssSetSignalHandler();
 
@@ -1396,7 +1396,7 @@ void mssPreAgg(struct mssAggDat *ad, struct mssFPR *iFile)
 
 /**
  * # FUNCTION #
- * mssAggDat¤ΤΥݥ󥿤֤
+ * mssAggDat構造体を初期化し、そのポインタを返す。
  */
 struct mssAggDat *mssInitAggDat(int fldCnt, MssOptKEY *optKey, MssOptFLD *optFld, char *aggType, char *tmpDir, int *inCnt)
 {
@@ -1413,7 +1413,7 @@ struct mssAggDat *mssInitAggDat(int fldCnt, MssOptKEY *optKey, MssOptFLD *optFld
   aggDat->valCnt  = getAggValCnt(aggDat->aggType, aggDat->optFld->flds->cnt);
   aggDat->aggVal  = getAggValMem(aggDat->aggType, aggDat->optFld->flds->cnt);
 
-  /*Хѿ*/
+  /*グローバル変数*/
   FldCnt  = aggDat->fldCnt;
   OptKey  = aggDat->optKey;
   OptFld  = aggDat->optFld;
@@ -1424,26 +1424,26 @@ struct mssAggDat *mssInitAggDat(int fldCnt, MssOptKEY *optKey, MssOptFLD *optFld
 
 /**
  * # FUNCTION #
- * mssAggDat¤Τγ
+ * mssAggDat構造体の開放。
  */
 void mssFreeAggDat(struct mssAggDat *ad)
 {
   int i;
 
   if(ad->procType==1){
-    /*ХåեΤˡϥեϤǽƥ*/
+    /*バッファ管理のために、入力ファイルはここで初めてクローズする*/
     for(i=0; i<=ad->iEnd-ad->iStart; i++){
       mssCloseFPR(ad->iFile[i]);
       mssFreeFldRec(ad->fr[i]);
     }
 
-    /*եκ*/
+    /*ファイルの削除*/
     for(i=ad->iStart; i<=ad->iEnd; i++){
       unlink(getFname(ad->prefixTxt,i));
       unlink(getFname(ad->prefixVal,i));
     }
 
-    /*ΰ賫*/
+    /*領域開放*/
     RBAGfree(ad->rb);
   }
   mssFree(ad->val);
