@@ -1,13 +1,13 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤŪʴؿ
- * 20040129 mktimeؿΥޥʡbug fix
- *          tmpѥͭĶѿѹǤ褦
- * 20040420 AllocInfϢؿľ(reallocбط)
- * 20040428 mssPRand()ݥʬɲ
- * 20040609 mssSort() ȴؿɲ
- * 20041004 mssGV.argvargv[]mssStrdup褦ѹ
+ * MUSASHIで用いられる基本的な関数
+ * 20040129 mktime関数のマイナーbug fix
+ *          tmpパスと有効桁数を環境変数で変更できるように
+ * 20040420 AllocInf関連関数見直し(reallocの対応関係改善)
+ * 20040428 mssPRand()ポアソン分布乱数追加
+ * 20040609 mssSort() ソート関数追加
+ * 20041004 mssGV.argvをargv[]からmssStrdupするように変更
  * ============================================================================
  */
 
@@ -29,7 +29,7 @@
 #include <limits.h>
 #include <math.h>
 
-/* ############ Хѿ ##############*/
+/* ############ グローバル変数 ##############*/
 struct mssGlobalVariables mssGV;
 
 extern double (*_func[_M])(void);
@@ -38,13 +38,13 @@ extern void (*initRND[_M])(long s);
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ʥå
+ * シグナル処理、メッセージ処理
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ۾ｪλΰե
+ * 異常終了時の一時ファイル削除
  */
 static void delTmpFile()
 {
@@ -63,7 +63,7 @@ static void delTmpFile()
     mssEnd(mssErrorNoDefault);
   }
   while ((dir = readdir(dp)) != NULL) {
-    if (dir->d_ino == 0) continue; /*removedեΥå*/
+    if (dir->d_ino == 0) continue; /*removedファイルのスキップ*/
     if(0==strncmp(dir->d_name,prefix,len)){
       /*fprintf(stderr,"%s\n", dir->d_name);*/
       strcpy(fname,mssGV.tmpPath);
@@ -77,7 +77,7 @@ static void delTmpFile()
  
 /**
  * # FUNCTION #
- * ʥˤ륨顼λ
+ * シグナルによるエラー終了
  */
 static void sigErrEnd(int sig)
 {
@@ -91,7 +91,7 @@ static void sigErrEnd(int sig)
 
 /**
  * # FUNCTION #
- * ʥˤｪλ
+ * シグナルによる正常終了
  */
 static void sigEnd(int sig)
 {
@@ -101,7 +101,7 @@ static void sigEnd(int sig)
 
 /**
  * # FUNCTION #
- *ʥ­Ͽ(եѤ)
+ *シグナル補足の登録(一時ファイルを利用する時)
  */
 void mssSetSignalHandler()
 {
@@ -113,12 +113,12 @@ void mssSetSignalHandler()
 
 /**
  * # FUNCTION #
- * åФɤȽ
- * ޥɥ饤 -Q ꤷQuiet⡼
- * Ķѿ mssQuiet ͤ1ʤQuiet⡼
- * ¾ξ NoQuiet⡼
- * externѿQuietsetOptionǥåȤ
- * : 1:Quiet⡼, 0:NoQuiet⡼
+ * メッセージを出すかどうかを判定
+ * コマンドラインで -Q を指定したらQuietモード
+ * 環境変数 mssQuiet の値が1ならQuietモード
+ * その他の場合は NoQuietモード
+ * extern変数QuietはsetOptionでセットされる
+ * 返値: 1:Quietモード, 0:NoQuietモード
  */
 static int isQuiet()
 {
@@ -133,8 +133,8 @@ static int isQuiet()
 
 /**
  * # FUNCTION #
- * Хѿ(mssGV¤)ΥåȤӥʥ­Ͽ
- * ̾ޥɤκǽ˸ƤӽФؿ
+ * グローバル変数(mssGV構造体)のセットおよびシグナル補足の登録
+ * 通常、コマンドの最初に呼び出される関数
  */
 void mssInit(int argc, char **argv, struct mssComHelp *comHelp)
 {
@@ -144,7 +144,7 @@ void mssInit(int argc, char **argv, struct mssComHelp *comHelp)
   int i;
   char buf[30];
 
-  /*Хѿν*/
+  /*グローバル変数の初期化および設定*/
   mssGV.comHelp=comHelp;
   mssGV.inCnt=0;
   mssGV.outCnt=0;
@@ -183,13 +183,13 @@ void mssInit(int argc, char **argv, struct mssComHelp *comHelp)
   sprintf(buf,"%%.%dg",sigDigits);
   mssGV.sigDigitsForm=mssStrdup(buf);
 
-  /*ʥϿ*/
+  /*シグナル処理の登録*/
   mssSetSignalHandler();
 }
 
 /**
  * # FUNCTION #
- * λ˸ƤӽФؿ
+ * 終了時に呼び出される関数
  */
 void mssEnd(int status)
 {
@@ -205,34 +205,34 @@ void mssEnd(int status)
     mssFree(*(mssGV.argv+i));
   }
   mssFree(mssGV.argv);
-  mssFree(mssGV.sigDigitsForm); /* ɲ 2004/10/31 */
+  mssFree(mssGV.sigDigitsForm); /* 追加 2004/10/31 */
   exit(status);
 }
 
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ΰݡϢ
+ * メモリ領域確保、開放関連
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # DOCUMENT #
- * ΰݡ˴ؤǥХåġλȤ 
- * 1:  "extern struct MssGlobalVariable mssGV;"롣
- * 2: ΰݤȳбطĴ٤֥å
- *    "mssGV.allocDeb=1;"Ȥ롣
- *    ʹߤmssMallocmssFreeθƤӽФƤmssGV.allocInf¤Τ
- *    Ͽ뤳Ȥˤʤ롣
- * 3: ֥åθmssGV.allocDeb=0ᤷϿ򤽤ޤǤȤ롣
- * 4:θmssShowAllocInf()ƤӽФСɤmssMallocɤmssFreeǳ
- * бطꥹȤϤ롣ϤɽΣܤ-1Ǥ
- * бطդʤä(魯)̣롣
+ * メモリ領域確保、開放に関するデバッグツールの使い方 
+ * 1: ソースで "extern struct MssGlobalVariable mssGV;"と宣言する。
+ * 2: メモリ領域確保と開放の対応関係を調べたいブロックの前で
+ *    "mssGV.allocDeb=1;"とする。
+ *    それ以降のmssMallocやmssFreeの呼び出し内容がmssGV.allocInf構造体に
+ *    記録されることになる。
+ * 3: ブロックの後でmssGV.allocDeb=0に戻し、記録をそこまでとする。
+ * 4:その後にmssShowAllocInf()を呼び出せば、どのmssMallocがどのmssFreeで開放され
+ * たかの対応関係リストが出力される。出力される結果表の２列目が-1であれば
+ * 対応関係が見付からなかったこと(開放しわすれ)を意味する。
  */
 
 /**
  * # FUNCTION #
- * ΰݡξ򥰥Хѿɲä
+ * メモリ領域確保、開放の情報をグローバル変数に追加する
  */
 static void addAllocInf(int func, void *add, int size,char *msg)
 {
@@ -265,7 +265,7 @@ static void addAllocInf(int func, void *add, int size,char *msg)
 
 /**
  * # FUNCTION #
- * mssReallocǥΰ褬ݤ줿Υɥ쥹򸫤ƹ
+ * mssReallocでメモリ領域が確保された時、新旧のアドレスを見て更新する
  */
 static void updAllocInf(int func, void *newAdd, void *oldAdd, int size, char *msg){
   int i;
@@ -304,7 +304,7 @@ static void updAllocInf(int func, void *newAdd, void *oldAdd, int size, char *ms
 
 /**
  * # FUNCTION #
- * ΰݡξ򥰥Хѿɲä
+ * メモリ領域確保、開放の情報をグローバル変数に追加する
  */
 void mssAddAllocLabel(char *msg)
 {
@@ -321,7 +321,7 @@ void mssAddAllocLabel(char *msg)
 
 /**
  * # FUNCTION #
- * ΰݡΰɽɽ
+ * メモリ領域確保、開放の一覧表を表示する
  */
 void mssShowAllocInf(void)
 {
@@ -344,22 +344,22 @@ void mssShowAllocInf(void)
 */
 
   fprintf(stderr,"========================================================\n");
-  fprintf(stderr,"ưŪΰγݡбɽ\n");
+  fprintf(stderr,"動的メモリ領域の確保＆解放対応表\n");
   fprintf(stderr,"--------------------------------------------------------\n");
-  fprintf(stderr,"1: No. (or줿)\n");
-  fprintf(stderr,"2: ؿ\n");
+  fprintf(stderr,"項目1: シーケンスNo. (確保or解放された順番)\n");
+  fprintf(stderr,"項目2: メモリ関数種別\n");
   fprintf(stderr,"      0:mssFree\n");
   fprintf(stderr,"      1:mssMalloc\n");
   fprintf(stderr,"      2:mssCalloc\n");
   fprintf(stderr,"      3:mssRealloc\n");
   fprintf(stderr,"      4:mssreallocLim\n");
   fprintf(stderr,"      5:mssStrdup\n");
-  fprintf(stderr,"3: ()줿Ƭɥ쥹\n");
-  fprintf(stderr,"4: ݤ줿\n");
-  fprintf(stderr,"5: -бNo.\n");
-  fprintf(stderr,"6: λǤΥݿ(ǽԤ0ΤϤ)\n");
-  fprintf(stderr,"       (ǽԤ0Ǥʤв˺줬)\n");
-  fprintf(stderr,"7: mssFree,mssStrdupʳˤĤơƤӽФå\n");
+  fprintf(stderr,"項目3: 確保(解放)された先頭アドレス\n");
+  fprintf(stderr,"項目4: 確保されたサイズ\n");
+  fprintf(stderr,"項目5: 確保-解放の対応シーケンスNo.\n");
+  fprintf(stderr,"項目6: その時点でのメモリ確保数(最終行がは0のはず)\n");
+  fprintf(stderr,"       (最終行が0でなければ解放忘れがある)\n");
+  fprintf(stderr,"項目7: mssFree,mssStrdup以外について、呼び出しメッセージ\n");
   fprintf(stderr,"========================================================\n");
   for(i=0; i<mssGV.allocCnt; i++){
     if( mssGV.allocInf[i].func==6){
@@ -379,8 +379,8 @@ void mssShowAllocInf(void)
 
 /**
  * # FUNCTION #
- * ΰ賫
- *   ɥ쥹 NULLʤ鲿⤷ʤ
+ * 領域開放
+ *   アドレスが NULLなら何もしない
  */
 void mssFree(void *add)
 {
@@ -396,7 +396,7 @@ void mssFree(void *add)
 
 /**
  * # FUNCTION #
- * callocˤΰ
+ * callocによる領域確保
  */
 void *mssCalloc(int size, char *errMsg)
 {
@@ -415,7 +415,7 @@ void *mssCalloc(int size, char *errMsg)
 
 /**
  * # FUNCTION #
- * mallocˤΰ
+ * mallocによる領域確保
  */
 void *mssMalloc(int size, char *errMsg)
 {
@@ -434,7 +434,7 @@ void *mssMalloc(int size, char *errMsg)
 
 /**
  * # FUNCTION #
- * reallocˤΰ
+ * reallocによる領域確保
  */
 void *mssRealloc(void *ptr, int size, char *errMsg)
 {
@@ -453,7 +453,7 @@ void *mssRealloc(void *ptr, int size, char *errMsg)
 
 /**
  * # FUNCTION #
- * ݤ륵꤬Ǥreallocˤΰ
+ * 確保するサイズ指定ができるreallocによる領域確保
  */
 void *mssReallocLim(void *ptr, int size,int lim, char *errMsg)
 {
@@ -477,7 +477,7 @@ void *mssReallocLim(void *ptr, int size,int lim, char *errMsg)
 
 /**
  * # FUNCTION #
- * strdupˤʸ󥳥ԡ
+ * strdupによる文字列コピー
  */
 char *mssStrdup(char *s)
 {
@@ -494,30 +494,30 @@ char *mssStrdup(char *s)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * mssStrings¤δϢδؿ
+ * mssStrings構造体関連の関数群
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # DOCUMENT #
- * δؿŪϡʸʻ(Concatenate)ʸΰ
- * 뤳Ȥưפ˼¸뤳Ȥˤ롣
+ * ここの関数群の目的は、文字列を併合(Concatenate)し新しい文字列領域を
+ * 作成することを容易に実現することにある。
  *
- * )
+ * 利用例)
  *   1: struct mssStrings *s;
- *   2: s=mssInitStrings();  mssStrings¤Τν
- *   3: catStrings(s,"abc"); "abc"Ȥʸ򥻥å
- *   4: catStrings(s,"xyz"); "xyz"Ȥʸɲ
- *   5: catStrings(s,"opq"); "opq"Ȥʸɲ
- *   6: freeStrings(s);      mssStrings¤ΰ
- *   嵭5:ܤޤǤνˤơs->str="abcxyzopq", s->cnt=9Ȥʤ롣
+ *   2: s=mssInitStrings();  mssStrings構造体の初期化
+ *   3: catStrings(s,"abc"); "abc"という文字列をセット
+ *   4: catStrings(s,"xyz"); "xyz"という文字列を追加
+ *   5: catStrings(s,"opq"); "opq"という文字列を追加
+ *   6: freeStrings(s);      mssStrings構造体領域を開放
+ *   上記の5:番目までの処理にて、s->str="abcxyzopq", s->cnt=9、となる。
  *
- * ʻ礵ʸФƥϡStrListϢδؿȤ
+ * 併合される各文字列に対してアクセスしたい場合は、StrList関連の関数群を使う。
  */
 
 /**
  * # FUNCTION #
- * mssStrings¤Τν
+ * mssStrings構造体の初期化
  */
 struct mssStrings *mssInitStrings()
 {
@@ -530,7 +530,7 @@ struct mssStrings *mssInitStrings()
 
 /**
  * # FUNCTION #
- * mssStrings¤ΰγ
+ * mssStrings構造体領域の開放
  */
 void mssFreeStrings(struct mssStrings *s)
 {
@@ -540,7 +540,7 @@ void mssFreeStrings(struct mssStrings *s)
 
 /**
  * # FUNCTION #
- * mssStrings¤Τʸɲä
+ * mssStrings構造体に文字列を追加する
  */
 void mssCatStrings(struct mssStrings *s, char *str)
 {
@@ -553,7 +553,7 @@ void mssCatStrings(struct mssStrings *s, char *str)
 
 /**
  * # FUNCTION #
- * mssStrings¤Τʸnʸɲä
+ * mssStrings構造体に文字列をn文字追加する
  */
 void mssCatnStrings(struct mssStrings *s, char *str, int n)
 {
@@ -568,37 +568,37 @@ void mssCatnStrings(struct mssStrings *s, char *str, int n)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * mssStrList¤δϢδؿ
+ * mssStrList構造体関連の関数群
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # DOCUMENT #
- * δؿŪϡĹʸΰ켡ΨŪ˺뤳Ȥˤ롣
- * ŪˤϡʸĤΥΰʻ(Concatenate)
- * ĤʸΰƳʸؤΥ
- * ʸ֥ݥ(ʸΰƬΥХȿ)ˤäƻȤ롣
- * Ǥ0Ϥޤ롣
+ * この関数群の目的は、可変長文字列の一次元配列を効率的に作成することにある。
+ * 内部的には、文字列を一つのメモリ領域に併合(Concatenate)し
+ * 新しい一つの文字列領域を作成し、そして各文字列へのアクセスを
+ * 文字位置ポインタ(文字列領域の先頭からのバイト数)によって参照する。
+ * 配列の要素は0から始まる。
  *
- * )
+ * 利用例)
  *   1: struct mssStrList *s;
- *   2: s=mssInitStrList();  mssStrList¤Τν
- *   3: mssPutStrList(s,"abc"); "abc"Ȥʸ0˥å
- *   4: mssPutStrList(s,"xyz"); "xyz"Ȥʸ1˥å
- *   5: mssPutStrList(s,"opq"); "opq"Ȥʸ2˥å
- *   6: mssFreeStrList(s);      mssStrList¤ΰ
- *   嵭5:ܤޤǤνˤƵϿ줿ʸϰʲΤ褦mssGetStrListؿ
- *   ˤƻȤǤ롣
+ *   2: s=mssInitStrList();  mssStrList構造体の初期化
+ *   3: mssPutStrList(s,"abc"); "abc"という文字列を要素0にセット
+ *   4: mssPutStrList(s,"xyz"); "xyz"という文字列を要素1にセット
+ *   5: mssPutStrList(s,"opq"); "opq"という文字列を要素2にセット
+ *   6: mssFreeStrList(s);      mssStrList構造体領域を開放
+ *   上記の5:番目までの処理にて記録された文字列は以下のようにmssGetStrList関数
+ *   にて参照できる。
  *     mssGetStrList(s,0)=="abc"
  *     mssGetStrList(s,1)=="xyz"
  *     mssGetStrList(s,2)=="opq"
- *   Ǥο s->cntˤƻȤǤ롣嵭Ǥ3
- *   åȤ줿ʸΤʸ s->chrCntǻȤǤ롣嵭Ǥ9
+ *   要素の数は s->cntにて参照できる。上記の例では3。
+ *   セットされた文字列全体の総文字数は s->chrCntで参照できる。上記の例では9。
  */
 
 /**
  * # FUNCTION #
- * mssStrList¤Τν
+ * mssStrList構造体の初期化
  */
 struct mssStrList *mssInitStrList()
 {
@@ -613,7 +613,7 @@ struct mssStrList *mssInitStrList()
 
 /**
  * # FUNCTION #
- * mssStrList¤ΰγ
+ * mssStrList構造体領域の開放
  */
 void mssFreeStrList(struct mssStrList *s)
 {
@@ -625,32 +625,32 @@ void mssFreeStrList(struct mssStrList *s)
 
 /**
  * # FUNCTION #
- * mssStrList¤Τʸɲä
+ * mssStrList構造体に文字列を追加する
  */
 void mssPutStrList(struct mssStrList *s, char *str)
 {
 
   int len;
 
-  /*ԤʸΥԡ*/
-  len = strlen(str)+1; /*+1'\0'Τ*/
+  /*行の文字列のコピー*/
+  len = strlen(str)+1; /*+1は'\0'のため*/
   s->chrCnt += len;
   s->str=mssRealloc(s->str,sizeof(char)* s->chrCnt,"putStrList");
 
-  strncpy(s->str+s->chrCnt-len,str,len-1); /*ʸΤߤ򥳥ԡ*/
-  *(s->str+s->chrCnt-1)='\0';              /*'\0'򥱥ĤˤĤ*/
+  strncpy(s->str+s->chrCnt-len,str,len-1); /*文字のみをコピー*/
+  *(s->str+s->chrCnt-1)='\0';              /*'\0'をケツにつける*/
 
-  /*Ԥʸι(ʸΰƬʸݥ󥿤Ȥ*/
+  /*行の文字数配列の更新(文字列領域の先頭からの文字数をポインタとして利用*/
   s->pointer=mssRealloc(s->pointer,sizeof(int)*(s->cnt+1),"putStrList");
   *(s->pointer+s->cnt)=s->chrCnt-len;
 
-  s->cnt++; /*쥳ɿ򥫥ȥå*/
+  s->cnt++; /*レコード数をカウントアップ*/
 }
 
 /**
  * # FUNCTION #
- * mssStrList¤ΤnܤǤؤΥݥ󥿤֤
- * ꤷֹ椬ǿ礭NULL֤
+ * mssStrList構造体のn番目の要素へのポインタを返す。
+ * 指定した要素番号が要素数より大きい場合はNULLを返す。
  */
 char *mssGetStrList(struct mssStrList *s,int n)
 {
@@ -661,13 +661,13 @@ char *mssGetStrList(struct mssStrList *s,int n)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ѿswap
+ * 二変数のswap
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * intѿswap
+ * int型変数のswap
  */
 void mssSwapInt(int *x, int *y)
 {
@@ -677,7 +677,7 @@ void mssSwapInt(int *x, int *y)
 
 /**
  * # FUNCTION #
- * longѿswap
+ * long型変数のswap
  */
 void mssSwapLng(long *x, long *y)
 {
@@ -687,7 +687,7 @@ void mssSwapLng(long *x, long *y)
 
 /**
  * # FUNCTION #
- * doubleѿswap
+ * double型変数のswap
  */
 void mssSwapDbl(double *x, double *y)
 {
@@ -699,13 +699,13 @@ void mssSwapDbl(double *x, double *y)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * Ѵδؿ
+ * 型変換の関数群
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ʸդtime_tͤѴ
+ * 文字列の日付からtime_t型日付値に変換
  */
 time_t mssStrToTime(char *str)
 {
@@ -713,15 +713,15 @@ time_t mssStrToTime(char *str)
   time_t caltime;
   struct tm worktm;
 
-  strncpy(buf, str, 4); /*ǽʸ4ʸԡ,źΤǼ*/
+  strncpy(buf, str, 4); /*最初の文字から4文字コピーする,添字のから格納*/
   buf[4] = '\0';
 
-  /*04ܤ˶ʸ*/
-  worktm.tm_year = atoi(buf) - 1900; /*֤ˤ뤿1900*/
+  /*0から数えて4つ目に空文字を代入*/
+  worktm.tm_year = atoi(buf) - 1900; /*暦時間にするために1900引く*/
 
   strncpy(buf, str+4, 2);
   buf[2] = '\0';
-  worktm.tm_mon = atoi(buf) - 1;    /*֤ˤ뤿1900*/
+  worktm.tm_mon = atoi(buf) - 1;    /*暦時間にするために1900引く*/
 
   strncpy(buf, str+6, 2);
   buf[2] = '\0';
@@ -731,7 +731,7 @@ time_t mssStrToTime(char *str)
   worktm.tm_sec = 0;
   worktm.tm_isdst = -1;
 
-  if((caltime = mktime(&worktm)) == -1){ /*mktimeˤ֤Ѵ*/
+  if((caltime = mktime(&worktm)) == -1){ /*mktimeにより暦時間に変換*/
     return(-1);
   }
   return(caltime);
@@ -739,7 +739,7 @@ time_t mssStrToTime(char *str)
 
 /**
  * # FUNCTION #
- * intͤʸѴ
+ * int型数値を文字列に変換
  */
 char *mssItoA(int num)
 {
@@ -750,8 +750,8 @@ char *mssItoA(int num)
 
 /**
  * # FUNCTION #
- * doubleͤʸѴ
- * ʲ̵̣ʣϼ롣(ex. 1.560000 -> 1.56, 1.0 -> 1)
+ * double型数値を文字列に変換
+ * 小数点以下の無意味な０は取り除かれる。(ex. 1.560000 -> 1.56, 1.0 -> 1)
  */
 char *mssFtoA(double num)
 {
@@ -775,20 +775,20 @@ char *mssFtoA(double num)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * Ϣδؿ
+ * 乱数関連の関数群
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ɤ
- * ɤꤷΥ()֤
- * seed-1ͿȤϡ߻򥷡ɤȤѤ롣
+ * 乱数シードの設定
+ * 乱数シードを設定し、そのシード(数値)を返す
+ * 引数seedに-1を与えたときは、現在時刻をシードとして用いる。
  */
 int mssInitRand(int seed)
 {
-  time_t  long_time;       /*μѤλֹ¤*/                         
-  struct tm     *nt;       /*Ʊ*/
+  time_t  long_time;       /*乱数の種用の時間構造体*/                         
+  struct tm     *nt;       /*同上*/
   int usedSeed;
 
   if(seed==-1){
@@ -806,7 +806,7 @@ int mssInitRand(int seed)
 
 /**
  * # FUNCTION #
- * 0ʾ1ʲμ¿ȯ롣
+ * 0以上1以下の実数乱数を発生させる。
  */
 double mssRand()
 {
@@ -815,8 +815,8 @@ double mssRand()
 
 /**
  * # FUNCTION #
- * Ϳ줿ϰϤ֤ͤ
- * ϰϤΥåϤƤʤΤǡץꥱ¦ǥå뤳ȡ
+ * 与えられた整数範囲の乱数を生成し、その値を返す。
+ * 整数範囲のチェックはしていないので、アプリケーション側でチェックすること。
  */
 int mssIRand(int from, int to)
 {
@@ -825,7 +825,7 @@ int mssIRand(int from, int to)
 
 /**
  * # FUNCTION #
- * ʬ(ʿm,ɸкs)
+ * 正規分布乱数(平均m,標準偏差s)。
  */
 double mssNRand(double m, double s)
 {
@@ -834,7 +834,7 @@ double mssNRand(double m, double s)
 
 /**
  * # FUNCTION #
- * ݥʬ(ʿm)
+ * ポアソン分布乱数(平均m)。
  */
 int mssPRand(double m)
 {
@@ -849,15 +849,15 @@ int mssPRand(double m)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ʸΤγƼؿ
+ * 文字列操作のための各種関数
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ĤʸϢ뤷ʸ֤
- * ȤĤʸˤϰѹäʤ
- * ΰݤ롣
+ * 二つの文字列を連結し新しい文字列を返す。
+ * もとの二つの文字列には一切変更を加えない。
+ * 新たな領域を確保する。
  */
 char *mssCatTwoStrings(char *str1, char *str2)
 {
@@ -886,16 +886,16 @@ char *mssCatTwoStrings(char *str1, char *str2)
  
 /**
  * # FUNCTION #
- * ̤ʤɤǰϤޤ줿ʸ֥å򥹥åפμΰ֤֤
- * ꤵ줿startChr,endCharʤäꡢ̤бطNULL
- * ֤
- * ̤μϳϳʸȽλʸǻꤹ롣
- * ϳʸȽλʸƱϡͥȤθǤʤΤǡ
- * γʸޤǤ򥹥åפ뤳Ȥˤʤ롣
- * 1)                      2)                    3)
+ * 括弧などで囲まれた文字列ブロックをスキップし、その次の位置を返す。
+ * 指定されたstartChr,endCharがなかったり、括弧の対応関係がおかしければNULLを
+ * 返す。
+ * 括弧の種類は開始括弧文字と終了括弧文字で指定する。
+ * 開始括弧文字と終了括弧文字が同じ場合は、ネストを考慮できないので、
+ * 次の括弧文字までをスキップすることになる。
+ * 例1)                      例2)                    例3)
  * abc(aaa*(aaa-ccc))xyz     abc"aaa*"aaa-ccc""xyz   ab(aaa)
  *    ^              ^          ^     ^              ^      ^
- *   str          ֤     str    ֤       str    ֤
+ *   str          返す位置     str    返す位置       str    返す位置
  */
 char *mssSkipStrBlock(char *str, char startChr, char endChr)
 {
@@ -921,25 +921,25 @@ char *mssSkipStrBlock(char *str, char startChr, char endChr)
 
 /**
  * # FUNCTION #
- * ʸΥȡʬԤʸݥ(char **)֤
- * dup1ȤϡꥸʥʸmssStrdupƤȡʬ
- * ԤΤǥꥸʥʸϰѹʤ
- * ǡdup0(1ʳ)ꤹȡꥸʥʸФƥȡ
- * ʬԤΤǡꥸʥʸѹ롣
- * ȡʬ䤵줿ʸοϰcntݥ󥿤Ǽ줿
- * ѿ˥åȤ롣
+ * 文字列のトークン分割を行い、文字列ポインタ(char **)を返す。
+ * 引数dupを1とした時は、オリジナルの文字列をmssStrdupしてからトークン分割を
+ * 行うのでオリジナルの文字列は一切変更されない。
+ * 一方で、引数dupに0(1以外)を指定すると、オリジナルの文字列に対してトークン
+ * 分割を行うので、オリジナルの文字は変更される。
+ * トークン分割された文字列の数は引数cntポインタで示された
+ * 整数変数にセットされる。
  *
- * ʤdup1ȤƤδؿѤƥȡʬ䤷硢
- * ˳ݤ줿ʸΰˤϡʸݥ󥿤κǽ
- * (ɥ쥹)Τ߳Ф褤
- *  -> ѹ2004/10/28ƤǤʤФʤʤ
- * )
+ * なお、引数dupを1としてこの関数を用いてトークン分割した場合、
+ * 新たに確保された文字列領域を開放するには、文字列ポインタの最初の
+ * 要素(アドレス)のみ開放すればよい。
+ *  -> 変更2004/10/28：全ての要素を解放しなければならない。
+ * 利用例)
  *   char **s;
  *   int cnt;
  *   s=mssTokByChr("abc,efg,hij", ',', &cnt, 1);
  *   Free(*s);
  *
- *    *(s+0)=="abc"
+ *   結果 *(s+0)=="abc"
  *        *(s+1)=="efg"
  *        *(s+2)=="hij"
  *           cnt==3;
@@ -970,7 +970,7 @@ char **mssTokByChr(char *string, char tok, int *cnt, int dup)
     str++;
   }
 
-  /* dupλ꤬listγǤstrdup ɲ 2004/10/28 */
+  /* dupの指定があればlistの各要素もstrdupする 追加 2004/10/28 */
   if(dup){
     for(i=0; i<*cnt; i++){
       *(list+i)=mssStrdup(*(list+i));
@@ -983,8 +983,8 @@ char **mssTokByChr(char *string, char tok, int *cnt, int dup)
 
 /**
  * # FUNCTION #
- * ʸ󤫤ɤå롣
- * ʸȤϡNULL⤷ĹʸΤȡ
+ * 妥当な文字列かどうかチェックする。
+ * 妥当な文字列とは、NULLもしくは長さ０の文字列のこと。
  */
 int mssIsValidStr(char *str)
 {
@@ -995,7 +995,7 @@ int mssIsValidStr(char *str)
 
 /**
  * # FUNCTION #
- * mssSortʸӥ롼
+ * mssSort用文字昇順比較ルーチン
  */
 static int cmpStrUp(const void **s1,const void **s2)
 {
@@ -1004,7 +1004,7 @@ static int cmpStrUp(const void **s1,const void **s2)
 
 /**
  * # FUNCTION #
- * mssSortʸ߽ӥ롼
+ * mssSort用文字降順比較ルーチン
  */
 static int cmpStrDown(const void **s1,const void **s2)
 {
@@ -1013,7 +1013,7 @@ static int cmpStrDown(const void **s1,const void **s2)
 
 /**
  * # FUNCTION #
- * mssSortѿ;ӥ롼
+ * mssSort用数値昇順比較ルーチン
  */
 static int cmpNumUp(const void **s1,const void **s2)
 {
@@ -1034,7 +1034,7 @@ static int cmpNumUp(const void **s1,const void **s2)
 
 /**
  * # FUNCTION #
- * mssSortѿ͹߽ӥ롼
+ * mssSort用数値降順比較ルーチン
  */
 static int cmpNumDown(const void **s1,const void **s2)
 {
@@ -1055,12 +1055,12 @@ static int cmpNumDown(const void **s1,const void **s2)
 
 /**
  * # FUNCTION #
- * ʸǡΥ(ͤȤƥȤ뤳Ȥǽ)
- * flagǻꤹͤ
- *     0:ʸ
- *     1:ʸ߽
- *     2:͹߽
- *     3:;
+ * メモリ内文字列データのソート(数値としてソートすることも可能)
+ * flagで指定する数値の内容
+ *     0:文字昇順
+ *     1:文字降順
+ *     2:数値降順
+ *     3:数値昇順
  */
 void mssSort(char **data, int cnt, int flag){
   switch(flag){
@@ -1083,14 +1083,14 @@ void mssSort(char **data, int cnt, int flag){
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * åνϴϢδؿ
+ * メッセージの出力関連の関数
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ޥɥ饤񤭽Ф
- * argv˲ԤޤޤƤХڡѴƽϤ
+ * コマンドラインを書き出す
+ * argvに改行が含まれていればスペースに変換して出力する
  */
 static void printCmdLine(struct mssFPW *fp)
 {
@@ -1123,16 +1123,16 @@ static void printCmdLine(struct mssFPW *fp)
 
 /**
  * # FUNCTION #
- * ϥå
- * ) #START# 2996 2003/04/11 21:56:37 "xtcut -f customer -i dat.xt"
- *   #START#³ơץֹ,,,ޥɥ饤
+ * 開始メッセージ
+ * 出力例) #START# 2996 2003/04/11 21:56:37 "xtcut -f customer -i dat.xt"
+ *   #START#に続いて、プロセス番号,日付,時刻,コマンドライン
  */
 void mssShowStartMsg()
 {
   struct mssFPW *fp;
 
   if(!isQuiet()){
-    fp=mssOpenFPW((char *)1,0,0); /*ɸ२顼ϥץ*/
+    fp=mssOpenFPW((char *)1,0,0); /*標準エラー出力オープン*/
     mssWriteStr("#START# ",fp);
     mssWriteInt(getpid(),fp);
     mssWriteStr(" ",fp);
@@ -1148,17 +1148,17 @@ void mssShowStartMsg()
 
 /**
  * # FUNCTION #
- * ｪλå
- * )
+ * 正常終了メッセージ
+ * 出力例)
  *   #END# 2999 2003/04/11 21:59:21 "xtcut -f customer -i xxcc.xt" in=25 out=25
- *   #END#³ơץֹ,,,ޥɥ饤,Ϸ,Ϸ
+ *   #END#に続いて、プロセス番号,日付,時刻,コマンドライン,入力件数,出力件数
  */
 void mssShowEndMsg()
 {
   struct mssFPW *fp;
 
   if(!isQuiet()){
-    fp=mssOpenFPW((char *)1,0,0); /*ɸ२顼ϥץ*/
+    fp=mssOpenFPW((char *)1,0,0); /*標準エラー出力オープン*/
     mssWriteStr("#END# ",fp);
     mssWriteInt(getpid(),fp);
     mssWriteStr(" ",fp);
@@ -1178,10 +1178,10 @@ void mssShowEndMsg()
 
 /**
  * # FUNCTION #
- * 顼λå
- * å˴ޤޤԤ"_"Ѵ롣
- * ) #ERROR# 2996 "xtcut" "option -f is mandatory"
- *   #ERROR#³,ץֹ,ޥɥ饤,顼å
+ * エラー終了メッセージ
+ * メッセージに含まれる改行は全て"_"に変換される。
+ * 出力例) #ERROR# 2996 "xtcut" "option -f is mandatory"
+ *   #ERROR#に続いて,プロセス番号,コマンドライン,エラーメッセージ
  */
 void mssShowErrMsg(char *msg, ...)
 {
@@ -1195,13 +1195,13 @@ void mssShowErrMsg(char *msg, ...)
   va_start(args,msg);
   vsprintf(tmp,msg,args);
 
-  /*Ԥ_Ѵ*/
+  /*改行を_に変換*/
   for(i=0;;i++){
     if(tmp[i]=='\0') break;
     if(tmp[i]=='\n') tmp[i]='_';
   }
 
-  fp=mssOpenFPW((char *)1,0,0); /*ɸ२顼ϥץ*/
+  fp=mssOpenFPW((char *)1,0,0); /*標準エラー出力オープン*/
   mssWriteStr("#ERROR# ",fp);
   mssWriteInt(getpid(),fp);
   mssWriteStr(" ",fp);
@@ -1216,8 +1216,8 @@ void mssShowErrMsg(char *msg, ...)
 
 /**
  * # FUNCTION #
- * ñʤå
- *   #MSG#³,ץֹ,å
+ * 単なるメッセージ出力
+ *   #MSG#に続いて,プロセス番号,メッセージ
  */
 void mssShowMsg(char *msg, ...)
 {
@@ -1231,13 +1231,13 @@ void mssShowMsg(char *msg, ...)
   va_start(args,msg);
   vsprintf(tmp,msg,args);
 
-  /*Ԥ_Ѵ*/
+  /*改行を_に変換*/
   for(i=0;;i++){
     if(tmp[i]=='\0') break;
     if(tmp[i]=='\n') tmp[i]='_';
   }
 
-  fp=mssOpenFPW((char *)1,0,0); /*ɸ२顼ϥץ*/
+  fp=mssOpenFPW((char *)1,0,0); /*標準エラー出力オープン*/
   mssWriteStr("#MSG# ",fp);
   mssWriteInt(getpid(),fp);
   mssWriteStr(" \"",fp);
