@@ -1,40 +1,42 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * XMLtableΥإå򰷤ؿ
- * 2004/01/15 mssFields(sf)ƱܤİʾȤƤХ顼λ
- * 2002/08/07 mssSetOptKey: numFlg,revFlg򥯥ꥢɲ
+ * XMLtableのヘッダーを扱う関数
+ * 2002/08/07 mssSetOptKey: numFlg,revFlgをクリア追加
+ * 2004/01/15 mssFields(sf)に同じ項目が２つ以上使われていればエラー終了する
+ * 2004/08/09 mssFreeHeader 引数がNULLでリターン
  * ============================================================================
  */
 
 #include <musashi/mssHeader.h>
 #include <musashi/mssXml.h>
 #include <musashi/mssXtTag.h>
+#include <musashi/qs5.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <fnmatch.h>
 
-/* ############ Хѿ ##############*/
-/*ƥȥե饰*/
+/* ############ グローバル変数 ##############*/
+/*テキストフラグ*/
 extern struct mssGlobalVariables mssGV;
 
 /**
  * # SECTION #
  *----------------------------------------------------------------------------- 
- * mssFldInfo¤Τιֹ̾桢ɥ쥹ʤɤѴ
+ * mssFldInfo構造体の項目名、項目番号、アドレス、などの相互変換
  *----------------------------------------------------------------------------- 
  */
 
 /**
  * # DOCUMENT #
- * ǤδؿreadHeaderؿˤHeader¤Τ򥻥åȤѲǽȤʤ롣
+ * ここでの関数はreadHeader関数にてHeader構造体をセットした後に利用可能となる。
  */
 
 /**
  * # FUNCTION #
- * mssFldInfo¤Τΰݡ
+ * mssFldInfo構造体の領域確保＆初期化
  */
 struct mssFldInfo *mssInitFldInfo()
 {
@@ -55,7 +57,7 @@ struct mssFldInfo *mssInitFldInfo()
 
 /**
  * # FUNCTION #
- * mssFldInfo¤Τΰ賫
+ * mssFldInfo構造体の領域開放
  */
 void mssFreeFldInfo( struct mssFldInfo *fi)
 {
@@ -69,7 +71,7 @@ void mssFreeFldInfo( struct mssFldInfo *fi)
 
 /**
  * # FUNCTION #
- * mssFldInfoν(ǥХå)
+ * mssFldInfoの出力(デバッグ用)
  */
 void mssShowFldInfo(struct mssFldInfo *fi)
 {
@@ -79,10 +81,10 @@ void mssShowFldInfo(struct mssFldInfo *fi)
 
 /**
  * # FUNCTION #
- * numǻꤵ줿ֹιܤmssFields¤ΤmssFldInfo¤(flds->fi)
- * õĤФΥݥ󥿤֤
- * ĤʤХ顼ɽƽλ롣
- * ǻꤵnumǤιֹǡϤޤ롣
+ * numで指定された番号の項目をmssFields構造体のmssFldInfo構造体(flds->fi)から
+ * 探し、見つかればそのポインタを返す。
+ * 見つからなければエラーを表示して終了する。
+ * ここで指定されるnumは内部での項目番号で、０から始まる。
  */
 struct mssFldInfo *mssFldNum2Add(struct mssFields *flds, int num)
 {
@@ -95,14 +97,14 @@ struct mssFldInfo *mssFldNum2Add(struct mssFields *flds, int num)
   }
   mssShowErrMsg("internal error field number not found : [%d]",num);
   mssEnd(mssErrorNoDefault);
-  return(NULL); /*ѥٹ򤱤뤿*/
+  return(NULL); /*コンパイル警告を避けるため*/
 }
 
 /**
  * # FUNCTION #
- * nameǻꤵ줿̾ιܤmssFields¤ΤmssFldInfo¤(flds->fi)
- * õĤФΥݥ󥿤֤
- * ĤʤХ顼ɽƽλ롣
+ * nameで指定された名前の項目をmssFields構造体のmssFldInfo構造体(flds->fi)から
+ * 探し、見つかればそのポインタを返す。
+ * 見つからなければエラーを表示して終了する。
  */
 struct mssFldInfo *mssFldNam2Add(struct mssFields *flds, char *name)
 {
@@ -115,14 +117,14 @@ struct mssFldInfo *mssFldNam2Add(struct mssFields *flds, char *name)
   }
   mssShowErrMsg("field name or number not found : [%s]",name);
   mssEnd(mssErrorNoDefault);
-  return(NULL); /*ѥٹ򤱤뤿*/
+  return(NULL); /*コンパイル警告を避けるため*/
 }
 
 /**
  * # FUNCTION #
- * nameǻꤵ줿磻ɥ(*,?ʤ)ޤ̾mssFields¤Τ
- * mssFldInfo¤(flds->fi)õޥåݥƤ֤
- * ĤޥåʤХ顼ɽƽλ롣
+ * nameで指定されたワイルドカード(*,?など)を含む項目名をmssFields構造体の
+ * mssFldInfo構造体(flds->fi)から探し、マッチしたポインタ全てを返す。
+ * 一つもマッチしなければエラーを表示して終了する。
  */
 struct mssFldInfo **mssFldGlbNam2Add(struct mssFields *flds, char *name)
 {
@@ -132,10 +134,10 @@ struct mssFldInfo **mssFldGlbNam2Add(struct mssFields *flds, char *name)
 
   for(i=0; i<flds->cnt; i++){
 
-    /*̾Υ磻ɥɥޥå*/
+    /*項目名のワイルドカードマッチング*/
     if( 0==fnmatch(name,(*(flds->fi+i))->name,0) ){
 
-      /*ΰ*/
+      /*領域確保*/
       fiList = mssRealloc(fiList,sizeof(struct mssFldInfo *)*(cnt+1),
         "FldGlbNam2Add");
       *(fiList+cnt) = *(flds->fi+i);
@@ -147,7 +149,7 @@ struct mssFldInfo **mssFldGlbNam2Add(struct mssFields *flds, char *name)
     mssEnd(mssErrorNoDefault);
   }
 
-  /*üNULLɲ*/
+  /*終端のNULLを追加*/
   fiList = mssRealloc(fiList,sizeof(struct mssFldInfo *)*(cnt+1),"fldRegN2A");
   *(fiList+cnt) = NULL;
 
@@ -156,10 +158,10 @@ struct mssFldInfo **mssFldGlbNam2Add(struct mssFields *flds, char *name)
 
 /**
  * # FUNCTION #
- * nameǻꤵ줿̾ιܤmssFields¤ΤmssFldInfo¤(flds->fi)
- * õĤФιֹ֤
- * ĤʤХ顼ɽƽλ롣
- * ) ֹȤϡXMLtable<field no="1">Ǥno°ͤ飱
+ * nameで指定された名前の項目をmssFields構造体のmssFldInfo構造体(flds->fi)から
+ * 探し、見つかればその項目番号を返す。
+ * 見つからなければエラーを表示して終了する。
+ * 注) 項目番号とは、XMLtableの<field no="1">要素のno属性の値から１を引いた数。
  */
 int mssFldNam2Num(struct mssFields *flds, char *name)
 {
@@ -174,17 +176,17 @@ int mssFldNam2Num(struct mssFields *flds, char *name)
   }
   mssShowErrMsg("field name or number not found : [%s]",name);
   mssEnd(mssErrorNoDefault);
-  return(0); /*Ȥꤢ*/
+  return(0); /*とりあえず*/
 }
 
 /**
  * # FUNCTION #
- * numǻꤵ줿ֹmssFields¤ΤmssFldInfo¤(flds->fi)
- * õֹ֤ͥͤ
- * ꤨʤֹ椬ꤵ줿Ȥϡ顼ɽƽλ롣
- * 1) ֹȤϡXMLtable<field no="1">Ǥno°ͤ飱
- * 2) ֹͥȤϡXMLtable<sort priority="1">Ǥpriority
- *      °ͤΤȡ
+ * numで指定された項目番号をmssFields構造体のmssFldInfo構造体(flds->fi)から
+ * 探し、ソート優先順位番号の値を返す。
+ * ありえない項目番号が指定されたときは、エラーを表示して終了する。
+ * 注1) 項目番号とは、XMLtableの<field no="1">要素のno属性の値から１を引いた数。
+ * 注2) ソート優先順位番号とは、XMLtableの<sort priority="1">要素のpriority
+ *      属性の値のこと。
  */
 int mssFldNum2SrtPri(struct mssFields *flds, int num)
 {
@@ -205,11 +207,11 @@ int mssFldNum2SrtPri(struct mssFields *flds, int num)
 
 /**
  * # FUNCTION #
- * numǻꤵ줿ֹmssFields¤ΤmssFldInfo¤(flds->fi)
- * õιܤս祽Ȥλ꤬УǤʤУ֤
- * ꤨʤֹ椬ꤵ줿Ȥϡ顼ɽƽλ롣
- * 1) ֹȤϡXMLtable<field no="1">Ǥno°ͤ飱
- * 2) ս祽ȻȤϡXMLtable<reverse/>ǤΤȡ
+ * numで指定された項目番号をmssFields構造体のmssFldInfo構造体(flds->fi)から
+ * 探し、その項目が逆順ソートの指定があれば１、そうでなければ０を返す。
+ * ありえない項目番号が指定されたときは、エラーを表示して終了する。
+ * 注1) 項目番号とは、XMLtableの<field no="1">要素のno属性の値から１を引いた数。
+ * 注2) 逆順ソート指定とは、XMLtableの<reverse/>要素のこと。
  */
 int mssFldNum2SrtRev(struct mssFields *flds, int num)
 {
@@ -230,11 +232,11 @@ int mssFldNum2SrtRev(struct mssFields *flds, int num)
 
 /**
  * # FUNCTION #
- * numǻꤵ줿ֹmssFields¤ΤmssFldInfo¤(flds->fi)
- * õιܤͥȤλ꤬УǤʤУ֤
- * ꤨʤֹ椬ꤵ줿Ȥϡ顼ɽƽλ롣
- * 1) ֹȤϡXMLtable<field no="1">Ǥno°ͤ飱
- * 2) ͥȻȤϡXMLtable<numeric/>ǤΤȡ
+ * numで指定された項目番号をmssFields構造体のmssFldInfo構造体(flds->fi)から
+ * 探し、その項目が数値ソートの指定があれば１、そうでなければ０を返す。
+ * ありえない項目番号が指定されたときは、エラーを表示して終了する。
+ * 注1) 項目番号とは、XMLtableの<field no="1">要素のno属性の値から１を引いた数。
+ * 注2) 数値ソート指定とは、XMLtableの<numeric/>要素のこと。
  */
 int mssFldNum2SrtNum(struct mssFields *flds, int num)
 {
@@ -256,16 +258,17 @@ int mssFldNum2SrtNum(struct mssFields *flds, int num)
 /**
  * # SECTION #
  *----------------------------------------------------------------------------- 
- * mssHeader¤Τ򰷤ؿ
+ * mssHeader構造体を扱う関数
  *----------------------------------------------------------------------------- 
  */
 
 /**
  * # FUNCTION #
- * إå¤Τΰ賫
+ * ヘッダ構造体の領域開放
  */
 void mssFreeHeader(struct mssHeader *hd)
 {
+  if(hd==NULL) return;
   mssFree(hd->title  );
   mssFree(hd->comment);
   mssFreeFields(hd->flds);
@@ -276,8 +279,8 @@ void mssFreeHeader(struct mssHeader *hd)
 
 /**
  * # FUNCTION #
- * ȥ(title)ȥ(comment)ˤHeader¤Τ
- * Ԥ
+ * タイトル(title)とコメント(comment)を引数にしてHeader構造体の生成および
+ * 初期化を行う。
  */
 struct mssHeader *mssInitHeader(char *title, char *comment)
 {
@@ -299,12 +302,12 @@ struct mssHeader *mssInitHeader(char *title, char *comment)
 
 /**
  * # FUNCTION #
- * mssHeader¤Τoldǻꤷ¸Υإå(ܾϽ)
- * ԡ롣
- * ԡϡtitle,comment,xmlver,xmlencǡ¾Ͻ롣
- * version MssXtDefVerǽ롣
- * ԡκݤmssStrdupѤΤǡ
- * ¸Υإå(ʸ)ݥ󥿤Ƕͭ뤳ȤϤʤ
+ * mssHeader構造体を生成し、oldで指定した既存のヘッダー情報(項目情報は除く)を
+ * コピーする。
+ * コピーする情報は、title,comment,xmlver,xmlencで、その他は初期化する。
+ * version はMssXtDefVerで初期化される。
+ * コピーの際はmssStrdupを利用するので、
+ * 既存のヘッダー情報(文字列)をポインタで共有することはない。
  */
 struct mssHeader *mssInitCpyHeader(struct mssHeader *old)
 {
@@ -333,10 +336,10 @@ struct mssHeader *mssInitCpyHeader(struct mssHeader *old)
 
 /**
  * # FUNCTION #
- * mssHeader¤Τǻꤷʸǥإåꤹ롣
- * ꤹϡtitle,comment,xmlver,xmlenc,versionǡ¾Ͻ롣
- * κݤmssStrdupѤΤǡ
- * ʸݥ󥿤Ƕͭ뤳ȤϤʤ
+ * mssHeader構造体を生成し、引数で指定した文字列でヘッダー情報を設定する。
+ * 設定する情報は、title,comment,xmlver,xmlenc,versionで、その他は初期化する。
+ * 設定の際はmssStrdupを利用するので、
+ * 引数の文字列をポインタで共有することはない。
  */
 struct mssHeader *mssInitSetHeader( char *title, char *comment, char *xmlver, char *xmlenc, int version)
 {
@@ -366,7 +369,7 @@ struct mssHeader *mssInitSetHeader( char *title, char *comment, char *xmlver, ch
 
 /**
  * # FUNCTION #
- * mssHeader¤ΤΥ쥳ɿ(recCnt)򥻥åȤ롣
+ * mssHeader構造体のレコード数(recCnt)をセットする。
  */
 void mssSetHeaderRecCnt(struct mssHeader *hd, int recCnt)
 {
@@ -376,13 +379,13 @@ void mssSetHeaderRecCnt(struct mssHeader *hd, int recCnt)
 /**
  * # SECTION #
  *----------------------------------------------------------------------------- 
- * mssFields,mssFldInfo¤Τ򰷤ؿ
+ * mssFields,mssFldInfo構造体を扱う関数
  *----------------------------------------------------------------------------- 
  */
 
 /**
  * # FUNCTION #
- * mssFields¤Τν
+ * mssFields構造体の初期化
  */
 struct mssFields *mssInitFields()
 {
@@ -395,7 +398,7 @@ struct mssFields *mssInitFields()
 
 /**
  * # FUNCTION #
- * mssFields¤Τΰ賫
+ * mssFields構造体の領域開放
  */
 void mssFreeFields(struct mssFields *flds)
 {
@@ -411,7 +414,7 @@ void mssFreeFields(struct mssFields *flds)
 
 /**
  * # FUNCTION #
- * إåܾν(ǥХå)
+ * ヘッダー項目情報の出力(デバッグ用)
  */
 void mssShowFields(struct mssFields *flds)
 {
@@ -425,7 +428,7 @@ void mssShowFields(struct mssFields *flds)
 
 /**
  * # FUNCTION #
- * mssUpdateSortPriorityؿѤ륽ȤӴؿ
+ * mssUpdateSortPriority関数で利用するソートの比較関数
  */
 static int cmpUpdHeader(const void **a, const void **b)
 {
@@ -435,16 +438,16 @@ static int cmpUpdHeader(const void **a, const void **b)
 
 /**
  * # FUNCTION #
- * mssFields¤ΤΥȾ򸡺ǤʤȾ롣
- * δؿȤ
- *   ϥǡΰΥإåܾ򿷤إåܾȤƺ
- *   Υpriorityʤʤǽ롣㤨Сϥǡ
- *   a,b,c,dΣĤιܤäȤơȤprioritya,b,cνǤä
- *   (a=1,b=2,c=3)ʤa,b,cǥȤƤȤ롣
- *   λa,c,dΣܤ򿷤ܤȤȴȤȤpriority
- *   ʤʤ롣aǤϥȤƤ뤬cǤϥȤƤʤ
- *   ǡδؿϡapriority1ΤޤޤǡcΥpriority
- *   õ롣
+ * mssFields構造体のソート情報を検査し、妥当でないソート情報を削除する。
+ * この関数が使われる状況
+ *   入力データの一部のヘッダー項目情報を新しいヘッダー項目情報として作成した時
+ *   元のソートpriorityが正しくなくなる可能性がある。例えば、入力データに
+ *   a,b,c,dの４つの項目があったとして、ソートのpriorityはa,b,cの順であったと
+ *   する(a=1,b=2,c=3)。すなわち、項目a,b,cでソートされているとする。
+ *   この時、a,c,dの３項目を新しい項目として抜きだしたとき、ソートのpriorityは
+ *   正しくなくなる。項目aではソートされているが、cではソートされていない。
+ *   そこで、この関数は、項目aのpriorityは1のままで、項目cのソートpriority
+ *   を消去する。
  */
 void mssUpdateFieldsSortPriority(struct mssFields *flds)
 {
@@ -455,7 +458,7 @@ void mssUpdateFieldsSortPriority(struct mssFields *flds)
 
   if(mssGV.txtFlg) return;
 
-  /*ȤƤܤpriorityֹlist˥å*/
+  /*ソートされている項目のpriority番号をlist配列にセット*/
   listCnt=0;
   for(i=0; i<flds->cnt; i++){
     if((*(flds->fi+i))->priority != 0){
@@ -463,13 +466,16 @@ void mssUpdateFieldsSortPriority(struct mssFields *flds)
     }
   }
 
-  /*list¤Ѥơpriorityֹ椬orʣƤսuntil*/
-  /*list[]=1,2,3,5 λ3ޤǤOKʹߤ䡣until=3 */
-  /*list[]=1,2,2,3 λǽ2ޤǤOKʹߤϽʣuntil=2 */
+  /*list配列を並べ変えて、priority番号が断絶or重複している箇所をuntilに入れる*/
+  /*list[]=1,2,3,5 の時、3まではOKだがそれ以降は断絶。そこでuntil=3 */
+  /*list[]=1,2,2,3 の時、最初の2まではOKだがそれ以降は重複。そこでuntil=2 */
   until=0;
   if(listCnt!=0){
+/*
     qsort(list,listCnt,sizeof(int),
                (int (*)(const void *,const void *))cmpUpdHeader);
+*/
+    qsort5(list,listCnt,sizeof(int), (int (*))cmpUpdHeader);
 
     for(i=0; i<listCnt; i++){
       if((i+1)!=list[i]) break;
@@ -477,7 +483,7 @@ void mssUpdateFieldsSortPriority(struct mssFields *flds)
     until=i;
   }
 
-  /*(until)priorityä*/
+  /*断絶(until)より上のpriorityを消す*/
   for(i=0; i<flds->cnt; i++){
     if((*(flds->fi+i))->priority > until){
       (*(flds->fi+i))->priority = 0;
@@ -489,7 +495,7 @@ void mssUpdateFieldsSortPriority(struct mssFields *flds)
 
 /**
  * # FUNCTION #
- * mssFldInfo¤ΤΥȾ(priority,revFlg,numFlg)򥻥åȤ롣
+ * mssFldInfo構造体のソート情報(priority,revFlg,numFlg)をセットする。
  */
 void mssSetFldInfoSort(struct mssFldInfo *fi, int prioriy, int revFlg,int numFlg)
 {
@@ -500,7 +506,7 @@ void mssSetFldInfoSort(struct mssFldInfo *fi, int prioriy, int revFlg,int numFlg
 
 /**
  * # FUNCTION #
- * fldsΥȾ򥯥ꥢ롣
+ * fldsのソート情報をクリアする。
  */
 void mssClearFieldsSort(struct mssFields *flds)
 {
@@ -515,14 +521,14 @@ void mssClearFieldsSort(struct mssFields *flds)
 
 /**
  * # FUNCTION #
- * fldsΥȾöꥢsfȾ򥳥ԡ롣
+ * fldsのソート情報を一旦クリアし、sfの全ソート情報をコピーする。
  */
 void mssSetFieldsSort(struct mssFields *flds, struct mssFields *sortFlds)
 {
   int i;
   int no;
 
-  /*öfldsƤΥȾ򥯥ꥢ*/
+  /*一旦、flds上の全てのソート情報をクリアする*/
   mssClearFieldsSort(flds);
 
   for(i=0; i<sortFlds->cnt; i++){
@@ -535,7 +541,7 @@ void mssSetFieldsSort(struct mssFields *flds, struct mssFields *sortFlds)
 
 /**
  * # FUNCTION #
- * flds˴ޤޤܤˤĤơϿ줿֤˥ֹͥդ롣
+ * fldsに含まれる全項目について、登録された順番にソート優先順位番号をふる。
  */
 void mssSetFieldsSortPriority(struct mssFields *flds)
 {
@@ -548,8 +554,8 @@ void mssSetFieldsSortPriority(struct mssFields *flds)
 
 /**
  * # FUNCTION #
- * mssFldInfo¤ΤιĹ(lenght)򥻥åȤ롣
- * ξϡĹܤˤ˥åȤ롣
+ * mssFldInfo構造体の項目長情報(lenght)をセットする。
+ * この情報は、固定長項目にする時にセットする。
  */
 void mssSetFldInfoLength(struct mssFldInfo *fi, int length)
 {
@@ -558,9 +564,9 @@ void mssSetFldInfoLength(struct mssFldInfo *fi, int length)
 
 /**
  * # FUNCTION #
- * mssFldInfo¤ΤιֹnumˤäƥåȤ롣
- * ǡǤ1ϤޤֹŪˤϣϤޤֹ档
- * ǤǤϡnumˤֹȤͿ뤳ȡ
+ * mssFldInfo構造体の項目番号を、numによってセットする。
+ * データ上では1から始まる番号だが、内部的には０から始まる番号。
+ * そこでここでは、numには内部の番号として与えること。
  */
 void mssSetFldInfoNum(struct mssFldInfo *fi, int num)
 {
@@ -569,7 +575,7 @@ void mssSetFldInfoNum(struct mssFldInfo *fi, int num)
 
 /**
  * # FUNCTION #
- * mssFldInfo¤Τι̾name ˤäƥåȤ롣
+ * mssFldInfo構造体の項目名を、name によってセットする。
  */
 void mssSetFldInfoName(struct mssFldInfo *fi, char *name)
 {
@@ -578,7 +584,7 @@ void mssSetFldInfoName(struct mssFldInfo *fi, char *name)
 
 /**
  * # FUNCTION #
- * mssFldInfo¤ΤΥȤcommentˤäƥåȤ롣
+ * mssFldInfo構造体のコメントを、commentによってセットする。
  */
 void mssSetFldInfoComment(struct mssFldInfo *fi, char *comment)
 {
@@ -587,8 +593,8 @@ void mssSetFldInfoComment(struct mssFldInfo *fi, char *comment)
 
 /**
  * # FUNCTION #
- * mssFields¤ΤFldInfo¤Τnum(ֹ)ˡ0ϤޤϢ֤˥å
- * 롣
+ * mssFields構造体の全FldInfo構造体のnum(項目番号)に、0から始まる連番にセット
+ * する。
  */
 void mssSetFieldsSequenceNum(struct mssFields *flds)
 {
@@ -601,8 +607,8 @@ void mssSetFieldsSequenceNum(struct mssFields *flds)
 
 /**
  * # FUNCTION #
- * mssFields¤ΤˡʸȤƻꤵ줿̾ɲä롣
- * Ⱦʤɤϥꥢ롣
+ * mssFields構造体に、文字列として指定された項目名を追加する。
+ * ソート情報などはクリアされる。
  */
 void mssAddFieldsByStr(struct mssFields *flds, char *str)
 {
@@ -621,8 +627,8 @@ void mssAddFieldsByStr(struct mssFields *flds, char *str)
 
 /**
  * # FUNCTION #
- * mssFields¤ΤˡʸꥹȤȤƻꤵ줿̾ɲä롣
- * Ⱦʤɤϥꥢ롣
+ * mssFields構造体に、文字列リストとして指定された項目名を追加する。
+ * ソート情報などはクリアされる。
  */
 void mssAddFieldsByStrList(struct mssFields *flds, char **str, int cnt)
 {
@@ -635,7 +641,7 @@ void mssAddFieldsByStrList(struct mssFields *flds, char **str, int cnt)
 
 /**
  * # FUNCTION #
- * mssFields¤Τˡꤵ줿mssFldInfoɲä롣
+ * mssFields構造体に、指定されたmssFldInfoを追加する。
  */
 void mssAddFieldsByFldInfo(struct mssFields *flds, struct mssFldInfo *fi)
 {
@@ -657,10 +663,10 @@ void mssAddFieldsByFldInfo(struct mssFields *flds, struct mssFldInfo *fi)
 
 /**
  * # FUNCTION #
- * mssFields¤fldsˡꤵ줿ʣmssFldInfo¤fiɲä롣
- * fiκǸǤNULLǤʤФʤʤ
- * 㤨mssFldGlbNam2AddǼʣmssFldInfoꥹȤϺǸǤNULL
- * ǽäƤΤǡΤޤѤǤ롣
+ * mssFields構造体fldsに、指定された複数のmssFldInfo構造体fiを追加する。
+ * fiの最後の要素はNULLでなければならない。
+ * 例えばmssFldGlbNam2Addで取得した複数のmssFldInfoリストは最後の要素はNULL
+ * で終っているので、そのまま利用できる。
  */
 void mssAddFieldsByFldInfoList(struct mssFields *flds, struct mssFldInfo **fi)
 {
@@ -674,8 +680,8 @@ void mssAddFieldsByFldInfoList(struct mssFields *flds, struct mssFldInfo **fi)
 
 /**
  * # FUNCTION #
- * mssFields¤Τˡꤵ줿mssFields¤ΤƤmssFldInfoɲä롣
- * ֹ桢̾ȾʤƤΤޤɲåԡ롣
+ * mssFields構造体に、指定されたmssFields構造体の全てのmssFldInfoを追加する。
+ * 項目番号、項目名、ソート情報など全てが、そのまま追加コピーされる。
  */
 void mssAddFieldsByFields(struct mssFields *flds, struct mssFields *addFlds)
 {
@@ -688,9 +694,9 @@ void mssAddFieldsByFields(struct mssFields *flds, struct mssFields *addFlds)
 
 /**
  * # FUNCTION #
- * mssFields¤Τˡץǻꤵ줿mssFields¤Τȥإå
- * mssFields¤ΤȤɲä롣λץǻꤵƤܤϡ
- * ̾ɲäǤʤܤϥإåιܤɲä롣
+ * mssFields構造体に、オプション上で指定されたmssFields構造体とヘッダー上の
+ * mssFields構造体とを追加する。この時、オプションで指定されている項目は、
+ * 新項目名を追加し、そうでない項目はヘッダーの項目を追加する。
  */
 void mssAddHeadOrOptFields(struct mssFields *flds, struct mssHeader *hd, MssOptFLD *optFld)
 {
@@ -700,10 +706,11 @@ void mssAddHeadOrOptFields(struct mssFields *flds, struct mssHeader *hd, MssOptF
   for(i=0; i<hd->flds->cnt; i++){
     mssAddFieldsByFldInfo(flds, *(hd->flds->fi+i));
 
-    /*ץǻꤵʤä*/
+    /*オプションで指定されなかった項目*/
     num=*(optFld->fldNo2optNo+i);
     if(*(optFld->fldNo2optNo+i)!=-1){
       mssSetFldInfoNum(*(flds->fi+flds->cnt-1), i);
+      mssFree((*(flds->fi+flds->cnt-1))->name); /* 追加 2004/10/31 */
       mssSetFldInfoName(*(flds->fi+flds->cnt-1), *(optFld->newNam+num));
       mssSetFldInfoSort(*(flds->fi+flds->cnt-1),0,0,0);
       mssSetFldInfoLength(*(flds->fi+flds->cnt-1),0);
@@ -715,24 +722,24 @@ void mssAddHeadOrOptFields(struct mssFields *flds, struct mssHeader *hd, MssOptF
 /**
  * # SECTION #
  *----------------------------------------------------------------------------- 
- * mssHeader¤Τϴؿ
+ * mssHeader構造体の入出力関数
  *----------------------------------------------------------------------------- 
  */
 
 /**
  * # FUNCTION #
- * ϥեι̾å
+ * 入力ファイルの項目名チェック
  */
 static void chkInfFldName(struct mssHeader *hd, struct mssFPR *fp )
 {
   char *fName;
   int i,j;
 
-  /*ե̾å*/
+  /*ファイル名セット*/
   if(fp->fName==NULL) fName="stdin";
   else                fName=fp->fName;
 
-  /*̾NULLå*/
+  /*項目名NULLチェック*/
   for(i=0; i<hd->flds->cnt; i++){
     if(NULL==(*(hd->flds->fi+i))->name){
       mssShowErrMsg("name of %dth field is null in %s",i+1,fName);
@@ -740,7 +747,7 @@ static void chkInfFldName(struct mssHeader *hd, struct mssFPR *fp )
     }
   }
 
-  /*̾ʣå*/
+  /*項目名重複チェック*/
   for(i=0; i<hd->flds->cnt-1; i++){
     for(j=i+1; j<hd->flds->cnt; j++){
       if(0==strcmp((*(hd->flds->fi+i))->name,(*(hd->flds->fi+j))->name)){
@@ -753,19 +760,19 @@ static void chkInfFldName(struct mssHeader *hd, struct mssFPR *fp )
 
 /**
  * # FUNCTION #
- * ϥեι̾å
+ * 出力ファイルの項目名チェック
  */
 static void chkOtfFldName(struct mssHeader *hd, struct mssFPW *fp )
 {
   char *fName;
   int i,j;
 
-  /*ե̾å*/
+  /*ファイル名セット*/
   if(fp->fName==NULL)           fName="stdout";
   else if(fp->fName==(char *)1) fName="stderr";
   else                          fName=fp->fName;
 
-  /*̾NULLå*/
+  /*項目名NULLチェック*/
   for(i=0; i<hd->flds->cnt; i++){
     if(NULL==(*(hd->flds->fi+i))->name){
       mssShowErrMsg("name of %dth field is null in %s",i+1,fName);
@@ -773,7 +780,7 @@ static void chkOtfFldName(struct mssHeader *hd, struct mssFPW *fp )
     }
   }
 
-  /*̾ʣå*/
+  /*項目名重複チェック*/
   for(i=0; i<hd->flds->cnt-1; i++){
     for(j=i+1; j<hd->flds->cnt; j++){
       if(0==strcmp((*(hd->flds->fi+i))->name,(*(hd->flds->fi+j))->name)){
@@ -787,7 +794,7 @@ static void chkOtfFldName(struct mssHeader *hd, struct mssFPW *fp )
 
 /**
  * # FUNCTION #
- * mssFldInfo¤ξإåȤƽ񤭽Ф
+ * mssFldInfo構造体情報をヘッダー情報として書き出す。
  */
 void mssWriteFldInfo( struct mssFldInfo *fi, int version, struct mssFPW *fp)
 {
@@ -845,7 +852,7 @@ void mssWriteFldInfo( struct mssFldInfo *fi, int version, struct mssFPW *fp)
     break;
 
     /*XMLtable version 1.1*/
-    /*<field num="1" name="̾" sort="1" numeric="1" reverse="1" length="10">ܥ<field> */
+    /*<field num="1" name="項目名" sort="1" numeric="1" reverse="1" length="10">項目コメント<field> */
   case 11:
     fieldTag=mssInitXmlTag("field",NULL);
     mssAddXmlTagAttributeInt(fieldTag,"no"  ,fi->num+1,NULL);
@@ -868,6 +875,7 @@ void mssWriteFldInfo( struct mssFldInfo *fi, int version, struct mssFPW *fp)
     }
     mssWriteXmlEndTag(fieldTag, NULL, fp);
     mssWriteRet(fp);
+    mssFreeXmlTag(fieldTag);
     break;
 
   default:
@@ -878,7 +886,7 @@ void mssWriteFldInfo( struct mssFldInfo *fi, int version, struct mssFPW *fp)
 
 /**
  * # FUNCTION #
- * إåν񤭽Ф
+ * ヘッダーの書き出し。
  */
 void mssWriteHeader( struct mssHeader *hd, struct mssFPW *fp)
 {
@@ -902,11 +910,11 @@ void mssWriteHeader( struct mssHeader *hd, struct mssFPW *fp)
     mssEnd(mssErrorNoDefault);
   }
 
-  chkOtfFldName(hd,fp); /*Ϲ̾Υå*/
+  chkOtfFldName(hd,fp); /*出力項目名のチェック*/
 
   mssWriteXmlDeclaration( hd->xmlver, hd->xmlenc ,fp);
 
-  /*xmlTableإåν񤭽Ф<xmltbl version="1.1">*/
+  /*xmlTableヘッダーの書き出し<xmltbl version="1.1">*/
   xtTag=mssInitXmlTag("xmltbl",NULL);
   mssAddXmlTagAttributeStr(xtTag,"version",version,NULL);
   mssWriteXmlStartTag(xtTag,NULL,fp);
@@ -925,7 +933,7 @@ void mssWriteHeader( struct mssHeader *hd, struct mssFPW *fp)
   mssWriteXmlTagStr(0,"comment",hd->comment,1,NULL,fp);
 
   /*<field>*/
-  for(i=0; i<hd->flds->cnt; i++){    /*إåιܥ*/
+  for(i=0; i<hd->flds->cnt; i++){    /*ヘッダーの項目タグを出力*/
     mssWriteFldInfo(*(hd->flds->fi+i), hd->version, fp);
   }
 
@@ -946,7 +954,7 @@ void mssWriteHeader( struct mssHeader *hd, struct mssFPW *fp)
 
 /**
  * # FUNCTION #
- * եåν񤭽Ф
+ * フッターの書き出し。
  */
 void mssWriteFooter(struct mssFPW *fp)
 {
@@ -961,11 +969,11 @@ void mssWriteFooter(struct mssFPW *fp)
 
 /**
  * # FUNCTION #
- * ǡxmlTable롣
- * Ϳ줿fldCntĤι̾fldName顢xmlTableإåιܤ롣
- * δؿϡxtmkdata,xtcalenderޥɤΤ褦ˡǡݤ
- * Ѥ롣ɬפʹ̾ȼäǡСϥǡȼä
- * եΤޤѲǽȤʤ롣
+ * 空データのxmlTableを作成する。
+ * 与えられたfldCnt個の項目名fldNameから、xmlTableヘッダーの項目を作成する。
+ * この関数は、xtmkdata,xtcalenderコマンドのように、新しくデータを作成する際に
+ * 利用される。既に必要な項目名を伴った空データがあれば、入力データを伴った
+ * 処理フローがそのまま利用可能となる。
  */
 void mssCreateBlankXtFile(char **fldName, int fldCnt, char *fname)
 {
@@ -983,7 +991,7 @@ void mssCreateBlankXtFile(char **fldName, int fldCnt, char *fname)
 
   mssAddFieldsByStrList(hd->flds,fldName,fldCnt);
 
-  /*ɸϥץ+إåեåν*/
+  /*標準出力オープン+ヘッダー、フッターの出力*/
   fpw=mssOpenFPW(fname, 0, 0);
   mssWriteHeader(hd, fpw);
   mssWriteFooter(fpw);
@@ -993,11 +1001,11 @@ void mssCreateBlankXtFile(char **fldName, int fldCnt, char *fname)
 
 
 
-static char numChr[MssFieldMaxCnt][4]; /*ֹȤƤι̾*/
+static char numChr[MssFieldMaxCnt][4]; /*項目番号としての項目名用*/
 
 /**
  * # FUNCTION #
- * إåɤ߹ߡ
+ * ヘッダー情報の読み込み。
  */
 struct mssHeader *mssReadHeader( struct mssFPR *fp)
 {
@@ -1014,7 +1022,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
   char *pos;
   char *str;
   int i;
-  int datFldCnt;  /*ǡιܿ*/
+  int datFldCnt;  /*データ上の項目数*/
   int fldNum;
   int priority;
   int revFlg;
@@ -1023,42 +1031,43 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
   hd=mssMalloc( sizeof(struct mssHeader),"readHeader" );
   hd->flds=mssInitFields();
 
-  /*---------------------------- plainTextξ*/
+  /*---------------------------- plainTextの場合*/
   if(mssGV.txtFlg){
-    datFldCnt = mssGetFldCntOnData(fp); /*ǡιܿ򥫥*/
-    hd->title   = NULL;        /*ȥ*/
-    hd->comment = NULL;        /**/
-    hd->recCnt  = -1;          /*쥳ɿ*/
+    datFldCnt = mssGetFldCntOnData(fp); /*データ上の項目数をカウント*/
+    hd->title   = NULL;        /*タイトル*/
+    hd->comment = NULL;        /*コメント*/
+    hd->recCnt  = -1;          /*レコード数*/
     hd->xmlver  = NULL;        /*xml version*/
     hd->xmlenc  = NULL;        /*xml encoding*/
-    /*ܤΥγ*/
-    hd->flds->cnt = 0;   /*ܿ*/
+    /*項目のメモリの確保*/
+    hd->flds->cnt = 0;   /*項目数*/
     for(i=0; i<datFldCnt; i++){
       sprintf(numChr[i+1],"%d",i+1);
-      mssAddFieldsByStr(hd->flds, mssStrdup(numChr[i+1]));
+      /*mssAddFieldsByStr(hd->flds, mssStrdup(numChr[i+1]));*/
+      mssAddFieldsByStr(hd->flds, numChr[i+1]); /* 変更 2004/10/31 */
     }
-  /*---------------------------- xmlTblξ*/
+  /*---------------------------- xmlTblの場合*/
   }else{
 
-    mssReadSetTop(hd, fp); /*xmlΥСenc⥻åȤ*/
+    mssReadSetTop(hd, fp); /*xmlのバージョンとencもセットする*/
 
-    /*إå(<header>....</header>)ե뤫˥å*/
+    /*全ヘッダー(<header>....</header>)をファイルからメモリにセット*/
     head=mssReadTag("header", fp);
     if(head==NULL){
       mssShowErrMsg("cannot find header tag");
       mssEnd(mssErrorNoDefault);
     }
 
-    /*ȥμ*/
+    /*タイトルの取得*/
     title=mssGetTag("title", head->str, &pos);
     if(title!=NULL){
-      hd->title=mssGetTagCont(title->str,"title",1); /*titleƤ*/
+      hd->title=mssGetTagCont(title->str,"title",1); /*titleタグ内の内容を取得*/
       mssFreeStrings(title);
     }else{
       hd->title=NULL;
     }
 
-    /*Ȥμ*/
+    /*コメントの取得*/
     comment=mssGetTag("comment", head->str, &pos);
     if(comment!=NULL){
       hd->comment=mssGetTagCont(comment->str,"comment",0);
@@ -1067,7 +1076,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
       hd->comment=NULL;
     }
 
-    /*쥳ɿμ*/
+    /*レコード数の取得*/
     hd->recCnt=-1;
     recCnt=mssGetTag("recCnt", head->str, &pos);
     if(recCnt!=NULL){
@@ -1079,21 +1088,21 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
       hd->recCnt=-1;
     }
 
-    /*ܾμ*/
+    /*項目情報の取得*/
     tmpStr=head->str;
     while(1) {
-      /*fieldΥå*/
+      /*fieldタグのセット*/
       field=mssGetTag("field", tmpStr, &pos);
       if( NULL == field ){
          break;
       }
 
-      /*оݤʸ餹Ȥǡfieldθ*/
+      /*検索対象を一文字ずらすことで、次のfieldの検索に備える*/
       tmpStr=pos+1;
 
       switch(hd->version){
       case 10:
-        /*̾*/
+        /*項目名*/
         str = mssGetTagCont(field->str, "name",1);
         if(str!=NULL){
           mssAddFieldsByStr(hd->flds, str);
@@ -1103,7 +1112,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
           mssEnd(mssErrorNoDefault);
         }
 
-        /*ֹ*/
+        /*項目番号*/
         str = mssGetTagAtt(field->str, "field", "no");
         if(str!=NULL){
           fldNum=atoi(str);
@@ -1119,7 +1128,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
           mssEnd(mssErrorNoDefault);
         }
 
-        /*sortΥå (Υʤ0åȤ)*/
+        /*sortタグのセット (このタグがなければ0がセットされる)*/
         priority = 0;
         revFlg   = 0;
         numFlg   = 0;
@@ -1135,7 +1144,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
         mssSetFldInfoSort(*(hd->flds->fi+hd->flds->cnt-1),
                                                       priority,revFlg,numFlg);
 
-        /*lenghtΥå*/
+        /*lenghtタグのセット*/
         str = mssGetTagCont(field->str, "length",1);
         if(str!=NULL) length = atoi(str);
         else          length = 0;
@@ -1144,7 +1153,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
         break;
 
       case 11:
-        /*̾*/
+        /*項目名*/
         str = mssGetTagAtt(field->str, "field", "name");
         if(str!=NULL){
           mssAddFieldsByStr(hd->flds, str);
@@ -1154,7 +1163,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
           mssEnd(mssErrorNoDefault);
         }
 
-        /*ֹ*/
+        /*項目番号*/
         str = mssGetTagAtt(field->str, "field", "no");
         if(str!=NULL){
           fldNum=atoi(str);
@@ -1170,7 +1179,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
           mssEnd(mssErrorNoDefault);
         }
 
-        /*Ⱦ*/
+        /*ソート情報*/
         priority = 0;
         revFlg   = 0;
         numFlg   = 0;
@@ -1201,7 +1210,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
                                                       priority,revFlg,numFlg);
         }
 
-        /*lenghtΥå*/
+        /*lenghtタグのセット*/
         str = mssGetTagAtt(field->str, "field","length");
         if(str!=NULL) length = atoi(str);
         else          length = 0;
@@ -1209,7 +1218,7 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
         mssSetFldInfoLength(*(hd->flds->fi+hd->flds->cnt-1),length);
         break;
 
-        /**/
+        /*コメント*/
         str=mssGetTagCont(field->str,"field",0);
         mssSetFldInfoComment(*(hd->flds->fi+hd->flds->cnt-1), str);
         mssFree(str);
@@ -1226,13 +1235,13 @@ struct mssHeader *mssReadHeader( struct mssFPR *fp)
     mssSkipToBody(fp);
   }
 
-  chkInfFldName(hd,fp); /*Ϲ̾Υå*/
+  chkInfFldName(hd,fp); /*入力項目名のチェック*/
   return(hd);
 }
 
 /**
  * # FUNCTION #
- * إåν(ǥХå)
+ * ヘッダー情報の出力(デバッグ用)
  */
 void mssShowHeader(struct mssHeader *hd)
 {
@@ -1248,24 +1257,24 @@ void mssShowHeader(struct mssHeader *hd)
 
 /**
  * # FUNCTION #
- * mssFields¤Τ˳ǼƤ륽ȾheaderΥȾӤ
- * mssFieldsΥȾ󤫤鸫ưפƤХȺѤȤߤʤ
- * numeric,reverseʤǡȤ̤ͥפƤ1֤
- * numeric,reverseǡȤ̤ͥפƤ2֤
- * mssFields(sf)ƱܤİʾȤƤХ顼λ
+ * mssFields構造体に格納されているソート情報とheaderのソート情報を比較し
+ * mssFieldsのソート情報から見て全て一致していればソート済とみなす。
+ * numeric,reverseなしで、ソートの優先順位が一致していれば1を返す。
+ * numeric,reverseありで、ソートの優先順位が一致していれば2を返す。
+ * mssFields(sf)に同じ項目が２つ以上使われていればエラー終了する
  */
 int mssChkSorted( struct mssFields *sf, struct mssHeader *hd)
 {
 
   int i;
 
-  /*ꤵƤʤ(same,diff)ϥȤƤȤߤʤ*/
+  /*キーが指定されていない場合(same,diff)はソートされているとみなす*/
   if(sf->cnt<1) return(1);
 
-  /*ƥȤξϥȤƤȤߤʤ*/
+  /*テキストの場合はソートされているとみなす*/
   if(mssGV.txtFlg) return(1);
 
-  /*sfƱܤʤɤå*/
+  /*sfに同じ項目がないかどうかチェックする*/
   for(i=0; i<sf->cnt-1; i++){
     if( (*(sf->fi+i))->num == (*(sf->fi+i+1))->num ){
       mssShowErrMsg("same field name is used two or more times on -k(-s)");
@@ -1273,7 +1282,7 @@ int mssChkSorted( struct mssFields *sf, struct mssHeader *hd)
     }
   }
 
-  /*sfγƹܤhdγƹܤӤ*/
+  /*sfの各項目とhdの各項目を比較する*/
   for(i=0; i<sf->cnt; i++){
     if(mssFldNum2SrtRev(hd->flds,(*(sf->fi+i))->num) != (*(sf->fi+i))->revFlg){
       return(0);
@@ -1286,7 +1295,7 @@ int mssChkSorted( struct mssFields *sf, struct mssHeader *hd)
     }
   }
 
-  /*numeric,reverseꤵƤ뤫򸡺*/
+  /*次にnumeric,reverseが指定されているかを検査*/
   for(i=0; i<sf->cnt; i++){
     if( (*(sf->fi+i))->revFlg) return(2);
     if( (*(sf->fi+i))->numFlg) return(2);
@@ -1297,18 +1306,18 @@ int mssChkSorted( struct mssFields *sf, struct mssHeader *hd)
 /**
  * # SECTION #
  *----------------------------------------------------------------------------- 
- * MssOptFLD,OptKey Ϣؿ
+ * MssOptFLD,OptKey 関連関数
  *----------------------------------------------------------------------------- 
  */
 
 /**
  * # FUNCTION #
- * ϥǡβܤιܤץȤƻꤵ줿ܤιܤˤĤ
- * ξ֤
+ * 入力データの何番目の項目が、オプションとして指定された何番目の項目かについて
+ * の情報を返す。
  *   ex.) 
- *     ϥǡ̾:a  b  c  d  e
- *     -f c,e,a λ
- *     {2,-1,0,-1,1}֤
+ *     入力データ項目名:a  b  c  d  e
+ *     -f c,e,a の時
+ *     配列{2,-1,0,-1,1}を返す。
  */
 static int *setFldNo2optNo(struct mssFields *flds, int headFldCnt)
 {
@@ -1328,22 +1337,22 @@ static int *setFldNo2optNo(struct mssFields *flds, int headFldCnt)
 
 /**
  * # FUNCTION #
- * ̾ʸ֤
- * ̾̾ "-f nam:newNam"ηǻꤵ롣
- * ΤȤnamnewNameˤƿ̾ʸ֤
- * δؿǤϼλ˴Ťơ̾롣
- * 1. newNam'&'ʸޤޤƤСʸnamִ롣
- * 2. 1ִ̿̾ĹMssFieldMaxLenĶȥ顼&
- * 3. newNamNULLʤСnam֤
- * 4. ̾Τ˿ʸΰݤΤǡnam,newNameȤδ
- *    Ϥʤ
+ * 新項目名を作成し、その文字列を返す。
+ * 通常、新項目名は "-f nam:newNam"の形式で指定される。
+ * このとき、namとnewNameを引数にして新しい項目名を生成し、その文字列を返す
+ * この関数では次の事項に基づいて、新項目名を生成する。
+ * 1. newNamに'&'文字が含まれていれば、その文字をnamに置換する。
+ * 2. 1で置換した結果新項目名の長さがMssFieldMaxLenを超えるとエラー&停止
+ * 3. newNamがNULLならば、namを返す。
+ * 4. 新項目名のために新たな文字列領域を確保するので、nam,newNameとの干渉
+ *    はない。
  *   ex.) 
  *     newNam = NULL        , nam="Jan" -> return("Jan")
  *     newNam = "amount(&)" , nam="Jan" -> return("amount(Jan)")
  */
 static char *setNewFldNam(char *newNam,char *nam)
 {
-  char retStr[MssFieldMaxLen]; /*Ÿ뿷̾ΰХåե*/
+  char retStr[MssFieldMaxLen]; /*展開される新しい項目名の一時バッファ*/
   char *namPnt;
   int  i;
 
@@ -1385,12 +1394,12 @@ static char *setNewFldNam(char *newNam,char *nam)
 
 /**
  * # FUNCTION #
- * MssOptFLD¤ΤˤĤoptFld->nam˻ꤵ줿磻ɥɤɾ
- * optFld->nam,newNam,fldOpt򹹿롣ΤȤ磻ɥɤɾоݤ
- * fldsܤȤ롣
- * ץ򥻥åȤؿmssSetOptionǤϡ磻ɥɤŸϤʤ
- * Ǥδؿˤƥ磻ɥɾоݹܤꤷƽŸǽ
- * ʤ롣
+ * MssOptFLD構造体についてoptFld->namに指定されたワイルドカードを評価し、
+ * optFld->nam,newNam,fldOptを更新する。そのときワイルドカードの評価対象は
+ * flds項目とする。
+ * オプションをセットする関数mssSetOptionでは、ワイルドカードの展開はしない。
+ * そこでこの関数にてワイルドカード評価対象項目を指定して初めて展開が可能と
+ * なる。
  *   ex.)
  *    flds->nam={"customer","date","amount1","amount2"}
  *    optFld->flds->nam={"amount*"}
@@ -1407,15 +1416,15 @@ static void evalOptFldNameGlob(MssOptFLD *optFLD, struct mssFields *flds)
   int cnt=0;
   int i;
 
-  for(i=0 ; i<optFLD->cnt ; i++) { /*ץǻꤵ줿ƹ*/
-    /*WC˥ޥåܥꥹȤfiList(ǸNULLǽ)*/
+  for(i=0 ; i<optFLD->cnt ; i++) { /*オプションで指定された各項目毎に*/
+    /*WCにマッチする項目リストがfiListに代入される(最後はNULLで終る)*/
     fiCnt=0;
 
-    /*globOKʤŸ*/
+    /*glob指定OKなら展開する*/
     if(optFLD->globFlg) {
       fiList = mssFldGlbNam2Add(flds,*(optFLD->nam+i));
 
-    /*globNGʤñ˹̾Address*/
+    /*glob指定NGなら単に項目名のAddressを取得する*/
     }else{
       fiList = mssCalloc(sizeof(struct mssFldInfo *) * 2,"evalGlob");
       *fiList = mssFldNam2Add(flds,*(optFLD->nam+i));
@@ -1423,22 +1432,22 @@ static void evalOptFldNameGlob(MssOptFLD *optFLD, struct mssFields *flds)
 
     while( *(fiList+fiCnt) != NULL ){
 
-      /*磻ɥŸ塢optFld->maxCntۤ饨顼Υå*/
+      /*ワイルドカード展開後、optFld->maxCntを越えたらエラーのチェック*/
       if(cnt>=optFLD->maxCnt){
         mssShowErrMsg("the max number of fields in the option is %d: -%s %s",
           optFLD->maxCnt,optFLD->keyWord,optFLD->str);
         mssEnd(mssErrorNoDefault);
       }
 
-      /*̾*/
+      /*項目名*/
       name=mssRealloc(name,sizeof(char *)*(cnt+1), "evalOptFldNameGlob");
       *(name+cnt) = mssStrdup((*(fiList+fiCnt))->name);
 
-      /*̾*/
+      /*新項目名*/
       newName=mssRealloc(newName,sizeof(char *)*(cnt+1), "evalOptFldNameGlob");
       *(newName+cnt)=setNewFldNam(*(optFLD->newNam+i),*(name+cnt));
 
-      /*ܥץ*/
+      /*項目オプション*/
       fldOpt=mssRealloc(fldOpt,sizeof(char *)*(cnt+1), "evalOptFldNameGlob");
       *(fldOpt+cnt)=mssStrdup(*(optFLD->fldOpt+i));
 
@@ -1448,6 +1457,9 @@ static void evalOptFldNameGlob(MssOptFLD *optFLD, struct mssFields *flds)
     mssFree(fiList);
   }
 
+  for(i=0; i<optFLD->cnt; i++){
+    mssFree(*(optFLD->nam+i)); /* 追加 2004/10/28 */
+  }
   mssFree(optFLD->nam   );
   mssFree(optFLD->newNam);
   mssFree(optFLD->fldOpt);
@@ -1460,16 +1472,16 @@ static void evalOptFldNameGlob(MssOptFLD *optFLD, struct mssFields *flds)
 
 /**
  * # FUNCTION #
- * optFLD¤Τιܤإåιܤͤ碌ưʲΣĤ򤪤ʤ
- * 1.MssOptFLDǻꤵ줿̾(nam)˴ޤޤ磻ɥɤɾ
- *   optFld->nam,newNam,fldOpt򹹿롣
- * 2.optFLD->fldsˡإåбܾ򥳥ԡ롣
- * 3.إåιֹ->ץλ֤ꡣ
+ * optFLD構造体の項目をヘッダーの項目と突き合わせて以下の３つの設定をおこなう
+ * 1.MssOptFLDで指定された項目名(nam)に含まれるワイルドカードを評価し、
+ *   optFld->nam,newNam,fldOptを更新する。
+ * 2.optFLD->fldsに、ヘッダーの対応する項目情報をコピーする。
+ * 3.ヘッダーの項目番号->オプションの指定位置の配列を設定。
  *   ex.) -f customer%r,date:DATE%rn,amt*:new(&)
  *             optFLD->nam   ={"customer","date","amt*"}
  *             optFLD->newNam={NULL,"DATE","new(&)"}
  *             optFLD->fldOpt={"r","rn",NULL}
- *        ϥǡΥإå={"customer","class","date","time","amt1","amt2"}
+ *        入力データのヘッダー={"customer","class","date","time","amt1","amt2"}
  *           -->>
  *        optFLD->nam   ={"customer,"date","amt1","amt2"}
  *        optFLD->newNam={"customer,"DATE","new(amt1)","new(amt2)"}
@@ -1486,40 +1498,41 @@ void mssSetOptFld(MssOptFLD *optFLD, struct mssHeader *hd)
 
   optFLD->flds=mssInitFields();
 
-  /*磻ɥɤɾ*/
+  /*ワイルドカードの評価*/
   evalOptFldNameGlob(optFLD, hd->flds);
 
-  /*optFLDǻꤵ줿̾ΥإåܤؤΥݥ󥿤Ͽ*/
+  /*optFLDで指定された項目名のヘッダー項目へのポインタを登録*/
   for(i=0 ; i<optFLD->cnt ; i++) {
     mssAddFieldsByFldInfo(optFLD->flds, mssFldNam2Add(hd->flds,*(optFLD->nam+i)));
 
-    /*̾Ͽ*/
+    /*新項目名があれば登録*/
     if(optFLD->newFlg){
       if(0 != strcmp(*(optFLD->nam+i), *(optFLD->newNam+i)) ){
+        mssFree((*(optFLD->flds->fi+optFLD->flds->cnt-1))->name); /* 追加2004/10/31 */
         mssSetFldInfoName(*(optFLD->flds->fi+optFLD->flds->cnt-1),
                           *(optFLD->newNam+i));
       }
     }
 
-    /* 硿߽硢ʸ硿ͽΥե饰 */
+    /* 昇順／降順、文字順／数値順のフラグを設定 */
     rev=mssIsFldOptOn(optFLD,i,'r');
     num=mssIsFldOptOn(optFLD,i,'n');
     mssSetFldInfoSort(*(optFLD->flds->fi+i),0,rev,num);
   }
 
-  /*ֹflag*/
+  /*項目番号flagの設定*/
   optFLD->fldNo2optNo=setFldNo2optNo(optFLD->flds,hd->flds->cnt);
 }
 
 /**
  * # FUNCTION #
- * MssOptKEY¤Τιܤإåιܤͤ碌ưʲ3ĤΤȤ򤪤ʤ
- * 1.optFLD->fldsˡإåбܾ򥳥ԡ롣
- * 2.إåιֹ->ץλ֤ꡣ
- * 3.ƱܤʣꤷƤХ顼ǽλ
+ * MssOptKEY構造体の項目をヘッダーの項目と突き合わせて以下の3つのことをおこなう
+ * 1.optFLD->fldsに、ヘッダーの対応する項目情報をコピーする。
+ * 2.ヘッダーの項目番号->オプションの指定位置の配列を設定。
+ * 3.同一項目を複数指定していればエラーで終了する
  *   ex.) -f customer,date
  *             optFLD->nam   ={"customer","date"}
- *        ϥǡΥإå={"customer","class","date","time","amt1","amt2"}
+ *        入力データのヘッダー={"customer","class","date","time","amt1","amt2"}
  *           -->>
  *        optFLD->fldNo2optNo={0,-1,1,-1,-1,-1}
  *        optFLD->flds->fi
@@ -1532,13 +1545,13 @@ void mssSetOptKey(MssOptKEY *optKEY, struct mssHeader *hd)
 
   optKEY->flds=mssInitFields();
 
-  /*optKEYǻꤵ줿̾ΥإåܤؤΥݥ󥿤Ͽ*/
+  /*optKEYで指定された項目名のヘッダー項目へのポインタを登録*/
   for(i=0 ; i<optKEY->cnt ; i++) {
     mssAddFieldsByFldInfo(optKEY->flds, mssFldNam2Add(hd->flds,*(optKEY->nam+i)));
     mssSetFldInfoSort(*(optKEY->flds->fi+i),0,0,0);
   }
 
-  /*optKEYƱܤꤵ줿饨顼*/
+  /*optKEYで同じ項目が指定されたらエラー*/
   for(i=0 ; i<optKEY->cnt-1 ; i++) {
     for(j=i+1 ; j<optKEY->cnt ; j++) {
       if( MssFlds2num(optKEY->flds,i)==MssFlds2num(optKEY->flds,j) ){
@@ -1548,6 +1561,6 @@ void mssSetOptKey(MssOptKEY *optKEY, struct mssHeader *hd)
     }
   }
 
-  /*ֹflag*/
+  /*項目番号flagの設定*/
   optKEY->fldNo2optNo=setFldNo2optNo(optKEY->flds,hd->flds->cnt);
 }
