@@ -1,22 +1,22 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤ륪ץϢδؿ
+ * MUSASHIで用いられるオプション関連の関数
  * Change Log
- * 20040214 manڡϤˤƣܤζ
- * 20040608 -x  -XMLˡ-X-MANѹ
- * 20040730 optINFwild cardåˡѹ
- * 20040804 mssCpyOptFldؿɲ
- * 20040809 mssSetOption switchbreakgotoѹ
- * 20040818 optionɤʣʸб (ex --field1)
- * 20041004 mssCpyOptFldؿ,nam,newNam,fldOptνХեå
- * 20041004 get_optȼǼ
- * 20041006 mssSetOptionOINF(ϥե)Υ磻ɥɤˤ
- *          GLOB_NOMAGICƤʤĶǤϡεǽѤʤ
- *          褦ѹ
- * 20041006 mssSetargStrν(warning򤱤뤿)
- * 20041028 ꡼ν
- * 20041031 ꡼ν
+ * 20040214 manページ出力において２行目の空白を除去
+ * 20040608 -x を -XMLに、-Xを-MANに変更
+ * 20040730 optINFのwild cardチェックの方法を変更
+ * 20040804 mssCpyOptFld関数追加
+ * 20040809 mssSetOption switchのbreakをgotoに変更
+ * 20040818 optionキーワードの複数文字対応 (ex --field1)
+ * 20041004 mssCpyOptFld関数,nam,newNam,fldOptの初期化バグフィックス
+ * 20041004 get_optを独自で実装
+ * 20041006 mssSetOptionのOINF(入力ファイル)のワイルドカードにおいて
+ *          GLOB_NOMAGICが定義されていない環境では、その機能を利用しない
+ *          ように変更
+ * 20041006 mssSetのargStrの初期化(warningを避けるため)
+ * 20041028 メモリリークの修正
+ * 20041031 メモリリークの修正
  * ============================================================================
  */
 
@@ -38,13 +38,13 @@ extern struct mssGlobalVariables mssGV;
 
 /**
  * # FUNCTION #
- * ʸꥹstrListcntĤγʸˤĤơܤ˽иȡ(tok)
- * ʬ䤷θʸꥹȤ֤
+ * 文字列リストstrListのcnt個の各文字列について、一つ目に出現するトークン(tok)
+ * で分割し、その後の文字列リストを返す。
  *
  * ex.)
  * strList={"aaa:bbb","ccc:ddd","eee:fff"}
  *   ->
- * strList={"aaa","ccc","eee"}  ={"bbb","ddd","fff"}
+ * strList={"aaa","ccc","eee"}  返値={"bbb","ddd","fff"}
  */
 static char **getNextStr(char **strList, int cnt, char tok)
 {
@@ -73,9 +73,9 @@ static char **getNextStr(char **strList, int cnt, char tok)
 
 /**
  * # FUNCTION #
- * Ƽ索ץι¤Τΰ롣
- * ۤ륪ץι¤Τvoidݥ󥿤ͿǤΥפȽǤ
- * ƥץ˱¸Ƥ롣
+ * 各種オプションの構造体の領域を開放する。
+ * 異るオプションの構造体をvoidポインタで与え、第一要素のタイプで判断して
+ * 各オプションに応じた開放を実現している。
  */
 void mssFreeOption(void *opt[])
 {
@@ -113,7 +113,7 @@ void mssFreeOption(void *opt[])
         optSLS=(MssOptSLS *)opt[i];
         mssFree(optSLS->str    );
         if(optSLS->strList!=NULL){
-	  /* ǲѹ 2004/10/28 */
+	  /* 全要素解放に変更 2004/10/28 */
 	  for(j=0; j<optSLS->cnt; j++){
             mssFree(*(optSLS->strList+j));
 	  }
@@ -128,7 +128,7 @@ void mssFreeOption(void *opt[])
         if(optSRL->from!=NULL){
           for(j=0; j<optSRL->cnt; j++){
             if(*(optSRL->from+j)!=NULL){
-	      /* ǲѹ 2004/10/28 */
+	      /* 全要素解放に変更 2004/10/28 */
               for(k=0; k<*(optSRL->valCnt+j); k++){
                 mssFree(*(*(optSRL->from+j)+k));
 	      }
@@ -141,7 +141,7 @@ void mssFreeOption(void *opt[])
             mssFree(*(optSRL->to+j));
           }
         }
-        mssFree(optSRL->valCnt); /* ɲ 2004/10/31 */
+        mssFree(optSRL->valCnt); /* 追加 2004/10/31 */
         mssFree(optSRL->from);
         mssFree(optSRL->to);
         break;
@@ -210,11 +210,11 @@ void mssFreeOption(void *opt[])
         optFLD=(MssOptFLD *)opt[i];
         mssFree(optFLD->str);
         if(optFLD->nam!=NULL){
-	  /* Ǥΰѹ 2004/10/28 */
+	  /* 全要素の領域解放に変更 2004/10/28 */
 	  for(j=0; j<optFLD->cnt; j++){
             mssFree(*(optFLD->nam+j));
             mssFree(*(optFLD->newNam+j));
-            mssFree(*(optFLD->fldOpt+j)); /* ɲ 2004/10/31 */
+            mssFree(*(optFLD->fldOpt+j)); /* 追加 2004/10/31 */
 	  }
         }
         mssFree(optFLD->nam   );
@@ -228,7 +228,7 @@ void mssFreeOption(void *opt[])
         optKEY=(MssOptKEY *)opt[i];
         mssFree(optKEY->str);
         if(optKEY->nam!=NULL){
-	  /* Ǥΰѹ 2004/10/28 */
+	  /* 全要素の領域解放に変更 2004/10/28 */
 	  for(j=0; j<optKEY->cnt; j++){
             mssFree(*(optKEY->nam+j));
 	  }
@@ -263,12 +263,12 @@ void mssFreeOption(void *opt[])
 
 /**
  * # FUNCTION #
- * ץ¤Τsetե饰mustե饰顢ɬܻѥ᡼
- * ꤵƤ뤫ɤå롣
- * ꤵƤʤС顼åϤƽλ롣
- * xmlTableξϡmust==1 && set!=1ǥ顼(ɬܻѥ᡼ʤ)Ȥʤ롣
- * plain textξϡxmlTableξξ˲äơ
- * must==2 && set==1Ǥ⥨顼(Υѥ᡼ɬפʤ)Ȥʤ롣
+ * オプション構造体のsetフラグとmustフラグから、必須指定パラメータが
+ * 指定されているかどうかチェックする。
+ * 指定されていなければ、エラーメッセージを出力して終了する。
+ * xmlTableの場合は、must==1 && set!=1でエラー(必須指定パラメータなし)となる。
+ * plain textの場合は、xmlTableの場合の条件に加えて、
+ * must==2 && set==1でもエラー(そのパラメータは必要ない)となる。
  */
 static void chkMust(char *keyWord, int set, int must)
 {
@@ -293,9 +293,9 @@ static void chkMust(char *keyWord, int set, int must)
 
 /**
  * # FUNCTION #
- * keyWordopt鸡opt[]->set1˥åȤ롣
- * opt[]ֹ֤
- * keyWordդʤ-1֤
+ * keyWordをoptから検索し、opt[]->setを1にセットする。
+ * opt[]の要素番号を返す。
+ * keyWordが見付からなければ-1を返す。
  */
 int setOptionSet(int *isFlag, char *keyWord, void *opt[], int optCnt){
   int i;
@@ -304,7 +304,7 @@ int setOptionSet(int *isFlag, char *keyWord, void *opt[], int optCnt){
 
   if(*keyWord=='\0') return(-1);
 
-  /*ޥɥ饤ե饰(set)ȥѥ᡼ʸΥå(str)*/
+  /*コマンドライン指定フラグ(set)とパラメータ文字のセット(str)*/
   for(i=0; i<optCnt; i++){
     if(0==strcmp(keyWord,((MssOptKEY *)opt[i])->keyWord)) break;
   }
@@ -334,14 +334,14 @@ int setOptionSet(int *isFlag, char *keyWord, void *opt[], int optCnt){
 
 /**
  * # FUNCTION #
- * ޥ¦ʣΥץ¤(opt[])̤Сѿ
- * 򥳥ޥɥ饤Ѥꤹ롣
- * ޥɥ饤ΤʲΥѥ᡼ꥷܥüʰ̣
- * ȤƲᤵ롣
- * -Q : λåɽʤ
- * -t : xmlTableǤʤplainTextϥǡȤѤ롣
- * ޤ̾mssHelpDocؿƤӽФȤˤ-h,-x,-Xüʰ̣ȤƲ
- * 롣
+ * コマンド側で定義した複数のオプション構造体(opt[])の未定義メンバー変数
+ * をコマンドライン引数を用いて設定する。
+ * ただし、コマンドライン引数のうち、以下のパラメータ指定シンボルは特殊な意味
+ * として解釈される。
+ * -Q : 終了メッセージを表示しない。
+ * -t : xmlTableでなく、plainTextを入出力データとして用いる。
+ * また、通常mssHelpDoc関数を呼び出すことにより-h,-x,-Xも特殊な意味として解釈
+ * される。
  */
 void mssSetOption(void *opt[], int argc, char *argv[])
 {
@@ -379,11 +379,11 @@ void mssSetOption(void *opt[], int argc, char *argv[])
   MssOptOTF *optOTF;
   MssOptFLG *optFLG;
 
-  /* getoptؿ˥顼åϤʤ */
+  /* getopt関数にエラーメッセージを出力させない */
   opterr=0;
 
-  /*ޥɥ饤ե饰ν*/
-  /* ץο򥫥Ȥ */
+  /*コマンドライン指定フラグの初期化*/
+  /* オプションの数をカウントする */
   optCnt=-1;
   while( opt[++optCnt]!=NULL ){
 
@@ -406,10 +406,10 @@ void mssSetOption(void *opt[], int argc, char *argv[])
     }
   }
 
-  /* getoptǥץ򥻥åȤ */
+  /* getoptでオプションをセットする */
   argPos=1;
 
-  /* ǽ鸽ƤargStr˥å */
+  /* 最初現在走査している引数をargStrにセット */
   if(argPos<argc){
     argStr=argv[argPos];
   }
@@ -418,20 +418,20 @@ void mssSetOption(void *opt[], int argc, char *argv[])
 
     isLongKeyWord=0;
 
-    /* (-x)ǤʤФʤʤ */
+    /* キーワード(-x)でなければならない */
     if(*argStr!='-'){
       mssShowErrMsg("non-option argument: %s",argv[argPos]);
       exit(mssErrorNoDefault);
     }
     argStr++;
 
-    /* longNameɤɤå */
+    /* longNameキーワードかどうかチェック */
     if(*argStr=='-'){
       isLongKeyWord=1;
       argStr++;
       keyWord=mssStrdup(argStr);
     }else{
-      if(*argStr=='Q'){ /* åɽ̵⡼*/
+      if(*argStr=='Q'){ /* メッセージ表示無しモード*/
         mssGV.quiet=1;
         *argStr='-';
 	if(*(argStr+1)=='\0'){
@@ -441,7 +441,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         }
         continue;
       }
-      if(*argStr=='t'){ /* plain text⡼*/
+      if(*argStr=='t'){ /* plain textモード*/
         mssGV.txtFlg=1;
         *argStr='-';
 	if(*(argStr+1)=='\0'){
@@ -467,23 +467,23 @@ void mssSetOption(void *opt[], int argc, char *argv[])
       if(isLongKeyWord){
         argPos++;
         if(argPos>=argc){
-          mssFree(keyWord); /* ɲ 2004/10/31 */
+          mssFree(keyWord); /* 追加 2004/10/31 */
 	  break;
 	}
 	argStr=argv[argPos];
-        mssFree(keyWord); /* ɲ 2004/10/31 */
+        mssFree(keyWord); /* 追加 2004/10/31 */
 	continue;
       }else{
         *argStr='-';
 	if(*(argStr+1)=='\0'){
           argPos++;
           if(argPos>=argc){
-            mssFree(keyWord); /* ɲ 2004/10/31 */
+            mssFree(keyWord); /* 追加 2004/10/31 */
 	    break;
 	  }
 	  argStr=argv[argPos];
         }
-        mssFree(keyWord); /* ɲ 2004/10/31 */
+        mssFree(keyWord); /* 追加 2004/10/31 */
 	continue;
       }
     }else{
@@ -509,7 +509,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
     mssFree(keyWord);
 //printf("argStr=%s\n",argStr);
 
-    /*ޥɥ饤ե饰(set)ȥѥ᡼ʸΥå(str)*/
+    /*コマンドライン指定フラグ(set)とパラメータ文字のセット(str)*/
     switch( ((MssOptKEY *)opt[optNo])->type ){
       case OSTR: ((MssOptSTR *)opt[optNo])->str=mssStrdup(argStr); break;
       case OSEL: ((MssOptSEL *)opt[optNo])->str=mssStrdup(argStr); break;
@@ -535,12 +535,12 @@ void mssSetOption(void *opt[], int argc, char *argv[])
   }
 //exit(1);
 
-  /* 1: mustˤå                                        */
-  /* 2: ΤʤäץˤĤƥǥեͤstr˥å */
-  /*      MssOptINF,MssOptOTF,MssOptFLDϥǥեȤʤʤΤNULL򥻥å  */
-  /*      MssOptKEYdef1or2Ȥ뤬strˤNULL򥻥åȡ        */
-  /*      MssOptFLGdefsetȤƥåȤ롣                      */
-  /* 3: Ʒ˱ơstrƤϤƼѿ˥åȤ     */
+  /* 1: mustによるチェック                                        */
+  /* 2: 指定のなかったオプションについてデフォルト値をstrにセット */
+  /*      MssOptINF,MssOptOTF,MssOptFLDはデフォルトなしなのでNULLをセット  */
+  /*      MssOptKEYはdefが1or2をとるが、strにはNULLをセット。        */
+  /*      MssOptFLGはdefをsetとしてセットする。                      */
+  /* 3: 各型に応じて、strの内容を解析し、各種変数にセットする     */
   err=0;
   for(i=0; i<optCnt; i++){
     switch( ((MssOptKEY *)opt[i])->type ){
@@ -549,7 +549,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optSTR->keyWord,optSTR->set,optSTR->must);
         if(!optSTR->set && optSTR->def!=NULL) optSTR->str=mssStrdup(optSTR->def);
 
-        /*å*/
+        /*チェック*/
         if(optSTR->set){
           len=strlen(optSTR->str);
           if(len<optSTR->minLen || len >optSTR->maxLen){
@@ -564,7 +564,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optSEL->keyWord,optSEL->set,optSEL->must);
         if(!optSEL->set && optSEL->def!=NULL) optSEL->str=mssStrdup(optSEL->def);
 
-        /*å*/
+        /*チェック*/
         if(optSEL->set){
           cnt=0;
           list1=mssTokByChr(optSEL->selList,',',&cnt,1);
@@ -575,7 +575,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
             mssShowErrMsg("argument must be one of \"%s\" on option -%s",optSEL->selList,optSEL->keyWord);
             exit(mssErrorNoDefault);
           }
-	  /* ǲѹ 2004/10/28 */
+	  /* 全要素解放に変更 2004/10/28 */
 	  for(j=0; j<cnt; j++){
             mssFree(*(list1+j));
 	  }
@@ -588,21 +588,21 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optSLS->keyWord,optSLS->set,optSLS->must);
         if(!optSLS->set && optSLS->def!=NULL) optSLS->str=mssStrdup(optSLS->def);
 
-        /**/
+        /*初期化*/
         optSLS->strList=NULL;
         optSLS->colList=NULL;
         optSLS->cnt=0;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if( optSLS->str==NULL ) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         optSLS->strList=mssTokByChr(optSLS->str,',',&optSLS->cnt,1);
 
-        /*ˤȡʬ*/
+        /*コロンによるトークン分割*/
         optSLS->colList=getNextStr(optSLS->strList,optSLS->cnt,':');
 
-        /*å*/
+        /*チェック*/
         if(optSLS->set){
           if(optSLS->cnt>optSLS->maxCnt){
             mssShowErrMsg("the max number of elements in the option is %d: -%s %s", optSLS->maxCnt,optSLS->keyWord,optSLS->str);
@@ -636,28 +636,28 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         if(!optSRL->set && optSRL->def!=NULL)
           optSRL->str=mssStrdup(optSRL->def);
 
-        /**/
+        /*初期化*/
         optSRL->from  =NULL;
         optSRL->to    =NULL;
         optSRL->valCnt=NULL;
         optSRL->cnt   =0;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if( optSRL->str==NULL ) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         list1=mssTokByChr(optSRL->str,',',&optSRL->cnt,1);
         optSRL->valCnt=mssMalloc(sizeof(int)*optSRL->cnt    ,"setOpt");
         optSRL->from  =mssMalloc(sizeof(char **)*optSRL->cnt,"setOpt");
         optSRL->to    =mssMalloc(sizeof(char **)*optSRL->cnt,"setOpt");
 
         for(j=0; j<optSRL->cnt; j++){
-          /*ˤȡʬ*/
+          /*コロンによるトークン分割*/
           *(optSRL->from+j)=mssTokByChr( *(list1+j),':',optSRL->valCnt+j,1);
           *(optSRL->to  +j)=getNextStr(*(optSRL->from+j),*(optSRL->valCnt+j),'~');
         }
 
-        /*å*/
+        /*チェック*/
         if(optSRL->set){
           if(optSRL->cnt>optSRL->maxCnt){
             mssShowErrMsg("the max number of elements in the option is %d: -%s %s", optSRL->maxCnt,optSRL->keyWord,optSRL->str);
@@ -690,7 +690,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
             }
           }
         }
-	/* ǲѹ 2004/10/28 */
+	/* 全要素解放に変更 2004/10/28 */
 	for(j=0; j<optSRL->cnt; j++){
           mssFree(*(list1+j));
 	}
@@ -707,7 +707,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           optINT->val=atoi(optINT->str);
         }
 
-        /*å*/
+        /*チェック*/
         if(optINT->min>optINT->val || optINT->max<optINT->val){
           mssShowErrMsg("the value of option -%s is out of range : %d(%d,%d)",
             optINT->keyWord,optINT->val,optINT->min,optINT->max);
@@ -720,17 +720,17 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optILS->keyWord,optILS->set,optILS->must);
         if(!optILS->set && optILS->def!=NULL) optILS->str=mssStrdup(optILS->def);
 
-        /**/
+        /*初期化*/
         optILS->val=NULL;
         optILS->cnt=0;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if( optILS->str==NULL ) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         list1=mssTokByChr(optILS->str,',',&optILS->cnt,1);
 
-        /*list1ʸͥꥹȤѴ*/
+        /*list1の文字列を数値リストに変換*/
         optILS->val=mssMalloc(sizeof(int)*optILS->cnt,"option");
         for(j=0; j<optILS->cnt; j++){
                 if(0==strcmp(*(list1+j),"MIN")){
@@ -742,7 +742,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-        /*å*/
+        /*チェック*/
         if(optILS->set){
           if(optILS->cnt>optILS->maxCnt){
             mssShowErrMsg("the max number of elements in the option is %d: -%s %s", optILS->maxCnt,optILS->keyWord,optILS->str);
@@ -762,7 +762,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
             }
           }
         }
-	/* ǲѹ 2004/10/28 */
+	/* 全要素解放に変更 2004/10/28 */
 	for(j=0; j<optILS->cnt; j++){
           mssFree(*(list1+j));
 	}
@@ -774,21 +774,21 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optRNG->keyWord,optRNG->set,optRNG->must);
         if(!optRNG->set && optRNG->def!=NULL) optRNG->str=mssStrdup(optRNG->def);
 
-        /**/
+        /*初期化*/
         optRNG->from=NULL;
         optRNG->to  =NULL;
         optRNG->cnt =0;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if( optRNG->str==NULL ) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         list1=mssTokByChr(optRNG->str,',',&optRNG->cnt,1);
 
-        /*Сˤȡʬ*/
+        /*アンダーバーによるトークン分割*/
         list2=getNextStr(list1,optRNG->cnt,'_');
 
-        /*list1,list2ʸϰϤѴ*/
+        /*list1,list2の文字列を数値範囲に変換*/
         optRNG->from=mssMalloc(sizeof(int)*optRNG->cnt,"option");
         optRNG->to  =mssMalloc(sizeof(int)*optRNG->cnt,"option");
         for(j=0; j<optRNG->cnt; j++){
@@ -810,7 +810,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-        /*å*/
+        /*チェック*/
         if(optRNG->set){
           if(optRNG->cnt>optRNG->maxCnt){
             mssShowErrMsg("the max number of elements in the option is %d: -%s %s", optRNG->maxCnt,optRNG->keyWord,optRNG->str);
@@ -832,7 +832,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-	/* ǲѹ 2004/10/28 */
+	/* 全要素解放に変更 2004/10/28 */
 	for(j=0; j<optRNG->cnt; j++){
           mssFree(*(list1+j));
 	}
@@ -852,7 +852,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         if(!optRAG->set && optRAG->def!=NULL)
           optRAG->str=mssStrdup(optRAG->def);
 
-        /**/
+        /*初期化*/
         optRAG->st    = NULL;
         optRAG->ed    = NULL;
         optRAG->stEq  = NULL;
@@ -861,10 +861,10 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         optRAG->opt   = NULL;
         optRAG->cnt   = 0;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if( optRAG->str==NULL ) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         list1=mssTokByChr(optRAG->str,',',&optRAG->cnt,1);
         optRAG->st   = mssCalloc(sizeof(char *)*optRAG->cnt,"setOpt");
         optRAG->ed   = mssCalloc(sizeof(char *)*optRAG->cnt,"setOpt");
@@ -873,31 +873,31 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         optRAG->val  = mssCalloc(sizeof(char *)*optRAG->cnt,"setOpt");
         optRAG->opt  = mssCalloc(sizeof(char *)*optRAG->cnt,"setOpt");
 
-        /*ޤˤȡʬ (st)*/
-        /* list1=mssTokByChr(optRAG->str,',',&optRAG->cnt,1);  2004/10/28 */
+        /*カンマによるトークン分割 (st)*/
+        /* list1=mssTokByChr(optRAG->str,',',&optRAG->cnt,1); 削除 2004/10/28 */
 
-        /*%ˤȡʬ (opt)*/
+        /*%によるトークン分割 (opt)*/
         list2=getNextStr(list1,optRAG->cnt,'%');
 
-        /*:ˤȡʬ (val)*/
+        /*:によるトークン分割 (val)*/
         list3=getNextStr(list1,optRAG->cnt,':');
 
-        /*_ˤȡʬ(ed)*/
+        /*_によるトークン分割(ed)*/
         list4=getNextStr(list1,optRAG->cnt,'_');
 
         for(j=0; j<optRAG->cnt; j++){
           /* st */
           if(*(list1+j)!=NULL){
-            if(**(list1+j)=='['){       /*ʾ*/
+            if(**(list1+j)=='['){       /*以上*/
               *(optRAG->stEq+j)=1;
               *(optRAG->st+j)=mssStrdup(*(list1+j)+1);
-            }else if(**(list1+j)=='('){ /*礭*/
+            }else if(**(list1+j)=='('){ /*より大きい*/
               *(optRAG->stEq+j)=0;
               *(optRAG->st+j)=mssStrdup(*(list1+j)+1);
             }else if(**(list1+j)=='\0'){ /*_12*/
               *(optRAG->stEq+j)=1;
               *(optRAG->st+j)=mssStrdup("*");
-            }else{                      /*ǥե(ʾ)*/
+            }else{                      /*デフォルト(以上)*/
               *(optRAG->stEq+j)=1;
               *(optRAG->st+j)=mssStrdup(*(list1+j));
             }
@@ -909,18 +909,18 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           /* ed */
           if(*(list4+j)!=NULL){
             len=strlen(*(list4+j));
-            if(*(*(list4+j)+len-1)==']'){  /*ʲ*/
+            if(*(*(list4+j)+len-1)==']'){  /*以下*/
               *(*(list4+j)+len-1)='\0';
               *(optRAG->edEq+j)=1;
               *(optRAG->ed+j)=mssStrdup(*(list4+j));
-            }else if(*(*(list4+j)+len-1)==')'){ /*꾮*/
+            }else if(*(*(list4+j)+len-1)==')'){ /*より小さい*/
               *(*(list4+j)+len-1)='\0';
               *(optRAG->edEq+j)=0;
               *(optRAG->ed+j)=mssStrdup(*(list4+j));
             }else if(*(*(list4+j)+len-1)=='\0'){ /* 12_ */
               *(optRAG->edEq+j)=1;
               *(optRAG->ed+j)=mssStrdup("*");
-            }else{                      /*ǥե(ʲ)*/
+            }else{                      /*デフォルト(以下)*/
               *(optRAG->edEq+j)=1;
               *(optRAG->ed+j)=mssStrdup(*(list4+j));
             }
@@ -940,7 +940,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-        /*å*/
+        /*チェック*/
         if(optRAG->set){
           if(optRAG->cnt>optRAG->maxCnt){
             mssShowErrMsg("the max number of elements in the option is %d: -%s %s", optRAG->maxCnt,optRAG->keyWord,optRAG->str);
@@ -963,7 +963,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
             }
           }
         }
-	/* ǲѹ 2004/10/28 */
+	/* 全要素解放に変更 2004/10/28 */
 	for(j=0; j<optRAG->cnt; j++){
           mssFree(*(list1+j));
 	}
@@ -986,7 +986,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           optDBL->val=atof(optDBL->str);
         }
 
-        /*å*/
+        /*チェック*/
         if(optDBL->min>optDBL->val || optDBL->max<optDBL->val){
           mssShowErrMsg("the value of option -%s is out of range : %g(%g,%g)",
             optDBL->keyWord,optDBL->val,optDBL->min,optDBL->max);
@@ -999,17 +999,17 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optDLS->keyWord,optDLS->set,optDLS->must);
         if(!optDLS->set && optDLS->def!=NULL) optDLS->str=mssStrdup(optDLS->def);
 
-        /**/
+        /*初期化*/
         optDLS->val=NULL;
         optDLS->cnt=0;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if( optDLS->str==NULL ) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         list1=mssTokByChr(optDLS->str,',',&optDLS->cnt,1);
 
-        /*list1ʸͥꥹȤѴ*/
+        /*list1の文字列を数値リストに変換*/
         optDLS->val=mssMalloc(sizeof(double)*optDLS->cnt,"option");
         for(j=0; j<optDLS->cnt; j++){
                 if(0==strcmp(*(list1+j),"MIN")){
@@ -1021,7 +1021,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-        /*å*/
+        /*チェック*/
         if(optDLS->set){
           if(optDLS->cnt>optDLS->maxCnt){
             mssShowErrMsg("the max number of elements in the option is %d: -%s %s", optDLS->maxCnt,optDLS->keyWord,optDLS->str);
@@ -1041,7 +1041,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
             }
           }
         }
-	/* ǲѹ 2004/10/28 */
+	/* 全要素解放に変更 2004/10/28 */
 	for(j=0; j<optDLS->cnt; j++){
           mssFree(*(list1+j));
 	}
@@ -1053,7 +1053,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optFLD->keyWord,optFLD->set,optFLD->must);
         if(!optFLD->set) optFLD->str=NULL;
 
-        /**/
+        /*初期化*/
         optFLD=(MssOptFLD *)opt[i];
         optFLD->nam=NULL;
         optFLD->newNam=NULL;
@@ -1062,26 +1062,26 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         optFLD->flds=NULL;
         optFLD->fldNo2optNo=NULL;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if( optFLD->str==NULL ) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         optFLD->nam=mssTokByChr(optFLD->str,',',&optFLD->cnt,1);
-        /*:ˤȡʬ*/
+        /*:によるトークン分割*/
         optFLD->newNam=getNextStr(optFLD->nam,optFLD->cnt,':');
 
-        /*%ˤȡʬ*/
+        /*%によるトークン分割*/
         optFLD->fldOpt=getNextStr(optFLD->nam,optFLD->cnt,'%');
 
-        /*å*/
-        /*maxCntĶƤХ顼*/
+        /*チェック*/
+        /*maxCntを超えていればエラー*/
         if(optFLD->set){
           if(optFLD->cnt>optFLD->maxCnt){
             mssShowErrMsg("the max number of fields in the option is %d: -%s %s", optFLD->maxCnt,optFLD->keyWord,optFLD->str);
             exit(mssErrorNoDefault);
           }
         }
-        /*̾ǤʤΤ˻ꤷƤХ顼*/
+        /*新項目名が指定できないのに指定していればエラー*/
         if(!optFLD->newFlg){
           for(j=0; j<optFLD->cnt; j++){
             if(*(optFLD->newNam+j)!=NULL){
@@ -1097,7 +1097,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optKEY->keyWord,optKEY->set,optKEY->must);
         if(!optKEY->set) optKEY->str=NULL;
 
-        /**/
+        /*初期化*/
         optKEY=(MssOptKEY *)opt[i];
         optKEY->nam=NULL;
         optKEY->diffSame=0;
@@ -1105,13 +1105,13 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         optKEY->flds=NULL;
         optKEY->fldNo2optNo=NULL;
 
-        /*strNULLʤdiffSamedef饻åȤƥ꥿*/
+        /*strがNULLならdiffSameをdefからセットしてリターン*/
         if( optKEY->str==NULL ){
           optKEY->diffSame=optKEY->def;
           break;
 
-        /*str#diff#,#same#ʤ餽줾1,2򥻥å */
-        /* set=0,str=NULL ʤ-kǻꤷʤäȤȤ */
+        /*strが#diff#,#same#ならそれぞれ1,2をセット */
+        /* set=0,str=NULL すなわち-kで指定しなかったこととする */
         }else{
           if( 0==strcmp(optKEY->str,"#diff#") ){
             optKEY->diffSame=1;
@@ -1129,10 +1129,10 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         optKEY->nam=mssTokByChr(optKEY->str,',',&optKEY->cnt,1);
 
-        /*å*/
+        /*チェック*/
         if(optKEY->set){
           if(optKEY->cnt>optKEY->maxCnt){
             mssShowErrMsg("the max number of fields in the option is %d: -%s %s", optKEY->maxCnt,optKEY->keyWord,optKEY->str);
@@ -1146,17 +1146,17 @@ void mssSetOption(void *opt[], int argc, char *argv[])
         chkMust(optINF->keyWord,optINF->set,optINF->must);
         if(!optINF->set) optINF->str=NULL;
 
-        /**/
+        /*初期化*/
         optINF->strList=NULL;
         optINF->cnt=0;
 
-        /*strNULLʤ꥿*/
+        /*strがNULLならリターン*/
         if(optINF->str==NULL) break;
 
-        /*ޤˤȡʬ*/
+        /*カンマによるトークン分割*/
         optINF->strList=mssTokByChr(optINF->str,',',&optINF->cnt,1);
 
-        /*å*/
+        /*チェック*/
         if(optINF->set){
           if(optINF->cnt>optINF->maxCnt){
             mssShowErrMsg("the max number of elements in the option is %d: -%s %s", optINF->maxCnt,optINF->keyWord,optINF->str);
@@ -1164,7 +1164,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-        /*磻ɥɤŸ*/
+        /*ワイルドカードの展開*/
         fname.gl_pathc=0;
         for(j=0; j<optINF->cnt; j++){
           if(fname.gl_pathc==0){
@@ -1182,7 +1182,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
           }
         }
 
-	/* ΰѹ 2004/10/28 */
+	/* 全領域解放に変更 2004/10/28 */
 	for(j=0; j<optINF->cnt; j++){
           mssFree(*(optINF->strList+j));
 	}
@@ -1219,7 +1219,7 @@ void mssSetOption(void *opt[], int argc, char *argv[])
 
 /**
  * # FUNCTION #
- * ץ¤ΤƤɽ(debug)
+ * オプション構造体の内容を表示する(debug用)。
  */
 void mssShowOption(void *opt[])
 {
@@ -1528,7 +1528,7 @@ void mssShowOption(void *opt[])
 
 /**
  * # FUNCTION #
- * mssComHelp¤ΤƤ饳ޥɥإפɽ롣
+ * mssComHelp構造体の内容からコマンドヘルプを表示する。
  */
 static void prnComHlp(void *opt[], struct mssComHelp *comHelp)
 {
@@ -1558,7 +1558,7 @@ static void prnComHlp(void *opt[], struct mssComHelp *comHelp)
 
   fpw=mssOpenFPW((char *)1,0,0);
 
-  /* ץο򥫥Ȥ */
+  /* オプションの数をカウントする */
   while( opt[++optCnt]!=NULL );
 
   /* ####### name */
@@ -1728,7 +1728,7 @@ static void prnComHlp(void *opt[], struct mssComHelp *comHelp)
           }
           mssWriteStr(*(list1+j),fpw);
           mssWriteStr("}]",fpw);
-	  /* ΰѹ 2004/10/28 */
+	  /* 全領域解放に変更 2004/10/28 */
 	  for(j=0; j<list1Cnt; j++){
             mssFree(*(list1+j));
 	  }
@@ -1837,7 +1837,7 @@ static void prnComHlp(void *opt[], struct mssComHelp *comHelp)
 
 /**
  * # FUNCTION #
- * mssComHelp¤ΤƤmanɥ(groff)Ϥ롣
+ * mssComHelp構造体の内容からmanドキュメント(groff)を出力する。
  */
 static void prnMan(void *opt[], struct mssComHelp *comHelp)
 {
@@ -1872,7 +1872,7 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
 
   fpw=mssOpenFPW((char *)1,0,0);
 
-  /* ץο򥫥Ȥ */
+  /* オプションの数をカウントする */
   while( opt[++optCnt]!=NULL );
 
   /* ####### comment */
@@ -1891,8 +1891,8 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
   mssWriteStr("MUSASHI",fpw);
   mssWriteRet(fpw); mssWriteRet(fpw);
 
-  /* ####### .SH ̾ */
-  /*mssWriteStr(".SH ̾\n",fpw);*/
+  /* ####### .SH 名前 */
+  /*mssWriteStr(".SH 名前\n",fpw);*/
   mssWriteStr(".SH NAME\n",fpw);
   mssWriteStr(comHelp->name,fpw);
   mssWriteStr(" \\- ",fpw);
@@ -1904,8 +1904,8 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
   }
   mssWriteRet(fpw);
 
-  /* ####### .SH : */
-  /*mssWriteStr(".SH \n",fpw);*/
+  /* ####### .SH 書式: */
+  /*mssWriteStr(".SH 書式\n",fpw);*/
   mssWriteStr(".SH SYNOPSIS\n",fpw);
   mssWriteStr(comHelp->name,fpw);
   mssWriteStr(" ", fpw);
@@ -2055,7 +2055,7 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
           }
           mssWriteStr(*(list1+j),fpw);
           mssWriteStr("}]",fpw);
-	  /* ΰѹ 2004/10/28 */
+	  /* 全領域解放に変更 2004/10/28 */
 	  for(j=0; j<list1Cnt; j++){
             mssFree(*(list1+j));
 	  }
@@ -2111,9 +2111,9 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
   mssWriteRet(fpw);
   mssWriteRet(fpw);
 
-  /* ####### .SH  */
+  /* ####### .SH 説明 */
   if(mssIsValidStr(comHelp->summary)){
-    /*mssWriteStr(".SH \n",fpw);*/
+    /*mssWriteStr(".SH 説明\n",fpw);*/
     mssWriteStr(".SH DESCRIPTION\n",fpw);
     mssWriteStr(comHelp->summary,fpw);
     mssWriteRet(fpw);
@@ -2121,8 +2121,8 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
   }
 
 
-  /* ####### .SH ѥ᡼ */
-  /*mssWriteStr(".SH ѥ᡼\n",fpw);*/
+  /* ####### .SH パラメータ */
+  /*mssWriteStr(".SH パラメータ\n",fpw);*/
   mssWriteStr(".SH PARAMETERS\n",fpw);
   for(i=0; i<optCnt; i++){
     if( strlen( ((MssOptKEY *)opt[i])->keyWord) > 1){
@@ -2251,8 +2251,8 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
   }
   mssWriteRet(fpw);
 
-  /* ####### .SH ץ */
-  /*mssWriteStr(".SH ץ\n",fpw);*/
+  /* ####### .SH オプション */
+  /*mssWriteStr(".SH オプション\n",fpw);*/
   mssWriteStr(".SH OPTIONS\n",fpw);
   for(i=0; i<optCnt; i++){
     if( ((MssOptKEY *)opt[i])->type == OFLG ){
@@ -2274,9 +2274,9 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
   }
   mssWriteRet(fpw);
 
-  /* ####### .SH  */
+  /* ####### .SH 利用例 */
   if(mssIsValidStr(comHelp->example)){
-    /*mssWriteStr(".SH \n",fpw);*/
+    /*mssWriteStr(".SH 利用例\n",fpw);*/
     mssWriteStr(".SH EXAMPLE\n",fpw);
     list1Cnt=0;
     list1=mssTokByChr(comHelp->example,'\n',&list1Cnt,1);
@@ -2288,7 +2288,7 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
         mssWriteRet(fpw);
       }
     }
-    /* ΰѹ 2004/10/28 */
+    /* 全領域解放に変更 2004/10/28 */
     for(j=0; j<list1Cnt; j++){
       mssFree(*(list1+j));
     }
@@ -2296,9 +2296,9 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
     mssWriteRet(fpw);
   }
 
-  /* ####### .SH  */
+  /* ####### .SH 参照 */
   if(mssIsValidStr(comHelp->example)){
-    /*mssWriteStr(".SH \n",fpw);*/
+    /*mssWriteStr(".SH 参照\n",fpw);*/
     mssWriteStr(".SH SEE ALSO\n",fpw);
     list1Cnt=0;
     list1=mssTokByChr(comHelp->reference,',',&list1Cnt,1);
@@ -2313,7 +2313,7 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
         }
       }
     }
-    /* ΰѹ 2004/10/28 */
+    /* 全領域解放に変更 2004/10/28 */
     for(j=0; j<list1Cnt; j++){
       mssFree(*(list1));
     }
@@ -2322,25 +2322,25 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
   }
 
 
-  /* ####### .SH webڡ */
+  /* ####### .SH webページ */
   if(mssIsValidStr(comHelp->homepage)){
-    /*mssWriteStr(".SH webڡ\n",fpw);*/
+    /*mssWriteStr(".SH webページ\n",fpw);*/
     mssWriteStr(".SH WEB PAGE\n",fpw);
     mssWriteStr(comHelp->homepage,fpw);
     mssWriteRet(fpw); mssWriteRet(fpw);
   }
 
-  /* ####### .SH Х */
+  /* ####### .SH バグ報告 */
   if(mssIsValidStr(comHelp->bugReport)){
-    /*mssWriteStr(".SH Х\n",fpw);*/
+    /*mssWriteStr(".SH バグ報告\n",fpw);*/
     mssWriteStr(".SH BUG REPORT\n",fpw);
     mssWriteStr(comHelp->bugReport,fpw);
     mssWriteRet(fpw); mssWriteRet(fpw);
   }
 
-  /* ####### .SH  */
+  /* ####### .SH 作者 */
   if(mssIsValidStr(comHelp->example)){
-    /*mssWriteStr(".SH \n",fpw);*/
+    /*mssWriteStr(".SH 作者\n",fpw);*/
     mssWriteStr(".SH AUTHORS\n",fpw);
     mssWriteStr(comHelp->author,fpw);
     mssWriteRet(fpw);
@@ -2349,7 +2349,7 @@ static void prnMan(void *opt[], struct mssComHelp *comHelp)
 
 /**
  * # FUNCTION #
- * mssComHelp¤ΤƤXMLɥȤϤ롣
+ * mssComHelp構造体の内容からXMLドキュメントを出力する。
  */
 static void prnComXml(void *opt[], struct mssComHelp *comHelp)
 {
@@ -2387,7 +2387,7 @@ static void prnComXml(void *opt[], struct mssComHelp *comHelp)
   fpw=mssOpenFPW((char *)1,0,0);
   manTag=mssInitXmlTag("mandatory",NULL);
 
-  /* ץο򥫥Ȥ */
+  /* オプションの数をカウントする */
   while( opt[++optCnt]!=NULL );
 
   /* <?xml version="1.0" encoding="EUC-JP"?> */
@@ -2424,7 +2424,7 @@ static void prnComXml(void *opt[], struct mssComHelp *comHelp)
       mssWriteRet(fpw);
       mssFreeXmlTag(referTag);
     }
-    /* ΰѹ 2004/10/28 */
+    /* 全領域解放に変更 2004/10/28 */
     for(j=0; j<list1Cnt; j++){
       mssFree(*(list1+j));
     }
@@ -2445,7 +2445,7 @@ static void prnComXml(void *opt[], struct mssComHelp *comHelp)
       mssWriteRet(fpw);
       mssFreeXmlTag(authorTag);
     }
-    /* ΰѹ 2004/10/28 */
+    /* 全領域解放に変更 2004/10/28 */
     for(j=0; j<list1Cnt; j++){
       mssFree(*(list1+j));
     }
@@ -2466,7 +2466,7 @@ static void prnComXml(void *opt[], struct mssComHelp *comHelp)
       mssWriteRet(fpw);
       mssFreeXmlTag(exampleTag);
     }
-    /* ΰѹ 2004/10/28 */
+    /* 全領域解放に変更 2004/10/28 */
     for(j=0; j<list1Cnt; j++){
       mssFree(*(list1+j));
     }
@@ -2528,12 +2528,12 @@ static void prnComXml(void *opt[], struct mssComHelp *comHelp)
             mssWriteRet(fpw);
             mssFreeXmlTag(xmlTag);
           }
-          /* ΰѹ 2004/10/28 */
+          /* 全領域解放に変更 2004/10/28 */
           for(j=0; j<list1Cnt; j++){
             mssFree(*(list1+j));
 	  }
           mssFree(list1);
-          /* ΰѹ 2004/10/28 */
+          /* 全領域解放に変更 2004/10/28 */
           for(j=0; j<list2Cnt; j++){
             mssFree(*(list2+j));
 	  }
@@ -2665,12 +2665,12 @@ static void prnComXml(void *opt[], struct mssComHelp *comHelp)
             mssWriteRet(fpw);
             mssFreeXmlTag(xmlTag);
           }
-          /* ΰѹ 2004/10/28 */
+          /* 全領域解放に変更 2004/10/28 */
           for(j=0; j<list1Cnt; j++){
             mssFree(*(list1+j));
 	  }
           mssFree(list1);
-          /* ΰѹ 2004/10/28 */
+          /* 全領域解放に変更 2004/10/28 */
           for(j=0; j<list2Cnt; j++){
             mssFree(*(list2+j));
 	  }
@@ -2729,11 +2729,11 @@ static void prnComXml(void *opt[], struct mssComHelp *comHelp)
 
 /**
  * # FUNCTION #
- * ޥɥإץɥȤϤ롣
- * ѥ᡼εˤʲ˼ΥɥȤϤ롣
- *   -h : ʰץإפɽ
- *   -x : XMLɥȤˤɽ
- *   -X : manɥ(troff)ˤɽ
+ * コマンドヘルプドキュメントを出力する。
+ * 第一パラメータの記号により以下に示す３種類のドキュメントを出力する。
+ *   -h : 簡易ヘルプの表示
+ *   -x : XMLドキュメントによる表示
+ *   -X : manドキュメント(troff)による表示
  */
 void mssHelpDoc(void *opt[],struct mssComHelp *comHelp, int argc, char **argv)
 {
@@ -2756,9 +2756,9 @@ void mssHelpDoc(void *opt[],struct mssComHelp *comHelp, int argc, char **argv)
 
 /**
  * # FUNCTION #
- * optFldiܤιܤ˹ܥץcꤵƤ뤫ɤ֤
+ * optFldのi番目の項目に項目オプションcが指定されているかどうかを返す。
  * ex)
- *  "-k %nr"λc=='r'⤷c=='n'λ֤ʳλ֤
+ *  "-k 日付%nr"の時、c=='r'もしくはc=='n'の時１を返し、それ以外の時０を返す。
  */
 int mssIsFldOptOn(MssOptFLD *optFld,int i, char c )
 {
@@ -2773,14 +2773,14 @@ int mssIsFldOptOn(MssOptFLD *optFld,int i, char c )
 
 /**
  * # FUNCTION #
- * ܥץ¤(MssOptKEY)strʲξΤȤƥԡ롣
+ * キー項目オプション構造体(MssOptKEY)のstr以下の情報を実体としてコピーする。
  */
 void mssCpyOptKey(MssOptKEY *to,MssOptKEY *from)
 {
   int i;
 
   to->str=mssStrdup(from->str);
-  /**/
+  /*初期化*/
   to->diffSame=from->diffSame;
   to->cnt     =from->cnt;
 
@@ -2797,7 +2797,7 @@ void mssCpyOptKey(MssOptKEY *to,MssOptKEY *from)
 
 /**
  * # FUNCTION #
- * ܥץ¤(MssOptFLD)strʲξΤȤƥԡ롣
+ * 項目オプション構造体(MssOptFLD)のstr以下の情報を実体としてコピーする。
  */
 void mssCpyOptFld(MssOptFLD *to,MssOptFLD *from)
 {
@@ -2825,8 +2825,8 @@ void mssCpyOptFld(MssOptFLD *to,MssOptFLD *from)
 
 /**
  * # FUNCTION #
- * Ϳ줿(val)ϰϹ¤ΤϰϤˤУ֤
- * ǤʤУ֤
+ * 与えられた数値(val)が数値範囲構造体の範囲にあれば１を返し、
+ * そうでなければ０を返す。
  */
 int mssIsInRange(MssOptRNG *optRNG,int val)
 {
