@@ -1,7 +1,9 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤǡνϴϢδؿ
+ * MUSASHIで用いられるデータの出力関連の関数
+ * 20040824 -z オプションを無向化 (標準出力は圧縮無し)に仕様変更
+ *             (mssOpenFPW関数を大幅に変更)
  * ============================================================================
  */
 
@@ -19,7 +21,7 @@
 
 /**
  * # FUNCTION #
- * ̥եν񤭹ߥץ󥨥顼ɽλ
+ * 圧縮ファイルの書き込みオープンエラーの表示＆終了。
  */
 static void zwOpenErr(char *fName)
 {
@@ -29,7 +31,7 @@ static void zwOpenErr(char *fName)
 
 /**
  * # FUNCTION #
- * ̾եν񤭹ߥץ󥨥顼ɽλ
+ * 通常ファイルの書き込みオープンエラーの表示＆終了。
  */
 static void fwOpenErr(char *fName)
 {
@@ -39,11 +41,11 @@ static void fwOpenErr(char *fName)
 
 /**
  * # FUNCTION #
- * ե̾ɬפʥǥ쥯ȥ롣
+ * ファイル名から必要なディレクトリを作成する。
  * ex.)
  * fileName="abc/def/ghi/dat.xt"
- *  -> ȥǥ쥯ȥˤơabc/dec/ghiΥǥ쥯ȥ
- *     Ǹ/ʲ̾եȤߤʤ
+ *  -> カレントディレクトリにおいて、abc/dec/ghiのディレクトリを作成。
+ *     最後の/以下は通常ファイルとみなす。
  */
 static void mkDir(char *fileName)
 {
@@ -52,7 +54,7 @@ static void mkDir(char *fileName)
   char *dirTbl[100];
   int cnt=0;
   int i;
-  int rt=0; /*롼ȤꤵƤ뤫ե饰'/tmp'*/
+  int rt=0; /*ルートが指定されているかフラグ'/tmp'*/
   int err;
   char dirStr[MssFileNameMaxLen];
 
@@ -94,107 +96,104 @@ static void mkDir(char *fileName)
 
 /**
  * # FUNCTION #
- * 񤭹ߥե򥪡ץ󤹤롣
- * ե̾(fileName)NULLξɸϡξɸ२顼ϤȤ
- * ץ󤹤롣
- * ξϡ̥եȤƥץ󤷡񤭹߷̤
- * gzip̤롣
- * 軰ξϡե̾˴ޤޤǥ쥯ȥŪ˺롣
+ * 書き込みファイルをオープンする。
+ * ファイル名(fileName)がNULLの場合は標準出力、１の場合は標準エラー出力として
+ * オープンする。
+ * 第二引数が１の場合は、圧縮ファイルとしてオープンし、書き込み結果は全て
+ * gzip圧縮される。
+ * 第三引数が１の場合は、ファイル名に含まれるディレクトリを強制的に作成する。
+ *
+ * ファイル名を判断して圧縮するかどうかを決める。
+ * 第二引数の効力はなくす。(1.1.0では廃止の方向で)
  */
 struct mssFPW *mssOpenFPW( char *fileName, int z, int d)
 {
   struct mssFPW *fp;
   int len;
+  char *pos;
 
   if(d) mkDir(fileName);
 
   fp=mssMalloc(sizeof(struct mssFPW),"openFPW");
-  if(fileName==NULL || fileName==(char *)1){
-    fp->fName=fileName;
-  }else{
-    fp->fName=mssMalloc(sizeof(char)*(strlen(fileName)+1),"openFPW");
-    strcpy(fp->fName,fileName);
-  }
 
-  if(z){
-    if(fileName == NULL){
-      fp->zfd=gzdopen(1,"wb"); /*stdout*/
-    }else if(fileName==(char *)1){
-      fp->zfd=gzdopen(2,"wb"); /*stderr*/
-    }else{
-      fp->zfd=gzopen(fileName,"wb");
-    }
-    if(fp->zfd == NULL) zwOpenErr(fileName);
-    fp->zflg=1;
+  if(fileName == NULL){          /*stdout*/
+    fp->fp=stdout;
+    //fp->fp=fopen("/dev/stdout","wb");//stdout;
+    fp->fName=mssStrdup("stdout");
+    fp->zflg=0;
+  }else if(fileName==(char *)1){ /*stderr*/
+    fp->fp=stderr;
+    //fp->fp=fopen("/dev/stderr","wb");//stderr;
+    fp->fName=mssStrdup("stderr");
+    fp->zflg=0;
   }else{
-    if(fileName == NULL){
-      fp->fp=stdout; /*stdout*/
-      fp->zflg=0;
-    }else if(fileName==(char *)1){
-      fp->fp=stderr; /*stderr*/
-      fp->zflg=0;
-    }else{
-      len=strlen(fileName);
-      if(0==strcmp(fileName+len-3,".gz") ){
-        fp->zfd=gzopen(fileName,"wb");
-        if(fp->zfd == NULL) zwOpenErr(fileName);
+    len=strlen(fileName);
+    fp->zflg=0;
+    if(len>=3){
+      pos=fileName+len-3;
+      if(*pos=='.' && *(pos+1)=='g' && *(pos+2)=='z'){
         fp->zflg=1;
-      }else{
-        fp->fp=fopen(fileName,"w");
-        if(fp->fp == NULL) fwOpenErr(fileName);
-        fp->zflg=0;
       }
     }
+    if(fp->zflg){
+      fp->zfd=gzopen(fileName,"wb");
+      if(fp->zfd == NULL) zwOpenErr(fileName);
+    }else{
+      fp->fp=fopen(fileName,"wb");
+      if(fp->fp == NULL) fwOpenErr(fileName);
+    }
+    fp->fName=mssStrdup(fileName);
   }
   return(fp);
 }
 
 /**
  * # FUNCTION #
- * 񤭹ߥե򥯥롣
+ * 書き込みファイルをクローズする。
  */
 void mssCloseFPW(struct mssFPW *fp){
 
   if(fp==NULL) return;
 
-  if(fp->fName!=NULL && fp->fName!=(char *)1){
-    if(fp->zflg){
-      gzclose(fp->zfd);
-    }else{
+  if(fp->zflg){
+    gzclose(fp->zfd);
+  }else{
+    if(fp->fp != stdout && fp->fp != stderr){
       fclose(fp->fp);
     }
   }
-  if(fp->fName!=NULL && fp->fName!=(char *)1 ) mssFree(fp->fName);
+
+  mssFree(fp->fName);
   mssFree(fp);
 }
 
 /**
  * # FUNCTION #
- * xmlTableιܥǥߥʸ(MssFieldDelim)νϡ
+ * xmlTableの項目デリミター文字(MssFieldDelim)の出力。
  */
 void mssWriteDlm(struct mssFPW *fp){
   if(fp->zflg){
     gzputc(fp->zfd,MssFieldDelim);
   }else{
-    putc(MssFieldDelim,fp->fp);
+    fputc(MssFieldDelim,fp->fp);
   }
 }
 
 /**
  * # FUNCTION #
- * ʸνϡ
+ * 改行文字の出力。
  */
 void mssWriteRet(struct mssFPW *fp){
   if(fp->zflg){
     gzputc(fp->zfd,'\n');
   }else{
-    putc('\n',fp->fp);
+    fputc('\n',fp->fp);
   }
 }
 
 /**
  * # FUNCTION #
- * ʸνϡ
+ * 文字列の出力。
  */
 void mssWriteStr(char *str,struct mssFPW *fp){
   if(fp->zflg){
@@ -206,19 +205,19 @@ void mssWriteStr(char *str,struct mssFPW *fp){
 
 /**
  * # FUNCTION #
- * ʸνϡ
+ * 文字の出力。
  */
 void mssWriteChr(char chr,struct mssFPW *fp){
   if(fp->zflg){
     gzputc(fp->zfd, chr);
   }else{
-    putc(chr, fp->fp);
+    fputc(chr, fp->fp);
   }
 }
 
 /**
  * # FUNCTION #
- * (int)νϡ
+ * 整数(int)の出力。
  */
 void mssWriteInt(int num,struct mssFPW *fp){
   if(fp->zflg){
@@ -230,7 +229,7 @@ void mssWriteInt(int num,struct mssFPW *fp){
 
 /**
  * # FUNCTION #
- * Long(long)νϡ
+ * Long整数(long)の出力。
  */
 void mssWriteLong(long num,struct mssFPW *fp){
   if(fp->zflg){
@@ -242,7 +241,7 @@ void mssWriteLong(long num,struct mssFPW *fp){
 
 /**
  * # FUNCTION #
- * Double¿(double)ƣưɽ(".")ν񼰤ǽϡ
+ * Double型実数(double)を全て１０進浮動小数点表記("整数部.小数部")の書式で出力。
  */
 void mssWriteDbl(double num, struct mssFPW *fp){
   char *buf;
@@ -254,8 +253,8 @@ void mssWriteDbl(double num, struct mssFPW *fp){
 
 /**
  * # FUNCTION #
- * Double¿(double)礭˱ƣưɽ⤷
- * ʻؿɽ(ex.3.14152e+10)ν񼰤ǽϡ
+ * Double型実数(double)を数の大きさに応じて１０進浮動小数点表記もしくは
+ * １０進指数表記(ex.3.14152e+10)の書式で出力。
  */
 void mssWriteDbe(double num, struct mssFPW *fp){
   char buf[100];
@@ -266,7 +265,7 @@ void mssWriteDbe(double num, struct mssFPW *fp){
 
 /**
  * # FUNCTION #
- * NULL(MssNullChr)νϡ
+ * NULL値(MssNullChr)の出力。
  */
 void mssWriteNull(struct mssFPW *fp){
   mssWriteChr(MssNullChr,fp);
@@ -274,9 +273,9 @@ void mssWriteNull(struct mssFPW *fp){
 
 /**
  * # FUNCTION #
- * ߻νϡ
- * sepFlg򣱤˻ꤹȡ"HH:MM:SS"ν񼰤ǽϡ
- * ʳ"HHMMSS"ν񼰤ǽϡ
+ * 現在時刻の出力。
+ * sepFlgを１に指定すると、"HH:MM:SS"の書式で出力。
+ * それ以外は"HHMMSS"の書式で出力。
  */
 void mssWriteTime(struct mssFPW *fp,int sepFlg){
   time_t  long_time;
@@ -302,9 +301,9 @@ void mssWriteTime(struct mssFPW *fp,int sepFlg){
 
 /**
  * # FUNCTION #
- * դνϡ
- * sepFlg򣱤˻ꤹȡ"YYYY/MM/DD"ν񼰤ǽϡ
- * ʳ"YYYYMMDD"ν񼰤ǽϡ
+ * 現在日付の出力。
+ * sepFlgを１に指定すると、"YYYY/MM/DD"の書式で出力。
+ * それ以外は"YYYYMMDD"の書式で出力。
  */
 void mssWriteDate(struct mssFPW *fp,int sepFlg){
   time_t  long_time;
@@ -314,7 +313,7 @@ void mssWriteDate(struct mssFPW *fp,int sepFlg){
   time(&long_time);
   nt = localtime(&long_time);
 
-  /**/
+  /*日付*/
   if(sepFlg){
     sprintf(msg, "%04d/%02d/%02d",
           nt->tm_year + 1900,
@@ -331,9 +330,9 @@ void mssWriteDate(struct mssFPW *fp,int sepFlg){
 
 /**
  * # FUNCTION #
- * ʸcntĤʸϤʸȤendStrϤ롣
- * Ϥʸʸδ֤ˤMssFieldDelimϤ롣
- * δؿϡ̾ǡԤϤ뤿Ѥ롣
+ * 文字列配列のcnt個の文字列を出力し、末尾文字列としてendStrを出力する。
+ * 出力される文字列と文字列の間にはMssFieldDelimが出力される。
+ * この関数は、通常、データ一行を出力するために利用する。
  * 
  */
 void mssWriteFld(char **str, int cnt, char *endStr, struct mssFPW *fp){
