@@ -1,7 +1,7 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤ뽸״Ϣδؿ
+ * MUSASHIで用いられる集計関連の関数
  * ============================================================================
  */
 
@@ -16,23 +16,23 @@
 #include <signal.h>
 
 /**
- * Хѿ
+ * グローバル変数
  */
 extern struct mssGlobalVariables mssGV;
 
-static MssOptKEY  *OptKey;               /*-kѥ᡼*/
-static int  FldCnt;                   /*פܿ*/
-static char readEnd[2]={0xff,0};      /*ʼ*/
-static char fname[MssFileNameMaxLen]; /*ե̾*/
+static MssOptKEY  *OptKey;               /*-kパラメータ*/
+static int  FldCnt;                   /*集計する項目数*/
+static char readEnd[2]={0xff,0};      /*番兵*/
+static char fname[MssFileNameMaxLen]; /*一時ファイル名*/
 
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ֹ(Red Black Tree)
+ * 赤黒木(Red Black Tree)
  * ----------------------------------------------------------------------------
- * ʸ: إǡ¤ȥ르ꥺٶΩ,2000,64.
- * p.224 9ܤϸ!!
- * ) if (v == NULL ) return(1) -> ) if (v == NULL ) return(0)
+ * 参考文献: 渡部敏正『データ構造とアルゴリズム』共立出版,2000,6章4節.
+ * p.224 下から9行目は誤り!!
+ * 誤) if (v == NULL ) return(1) -> 正) if (v == NULL ) return(0)
  */
 
 /**
@@ -183,7 +183,7 @@ static int keyCmp(struct mssFldRec *fr, struct RBUQnode *v)
       return(cmp);
     }
   }
-  return(0); /*Ʊ!!*/
+  return(0); /*同じキー!!*/
 }
 
 /**
@@ -399,7 +399,7 @@ static void RBUQptree(struct RBUQnode *p,int h)
 
 /**
  * # FUNCTION #
- * RBUQcpKeyδؿǳݤ줿̤η׻
+ * RBUQcpKeyの関数で確保されたメモリ量の計算
  */
 static int RBUQcpKeyMemCnt( struct mssFldRec *fr)
 {
@@ -407,24 +407,24 @@ static int RBUQcpKeyMemCnt( struct mssFldRec *fr)
   int memCnt=0;
 
   if(fr->eof==1){ /*EOF*/
-    /*ʸȤʼƤ*/
+    /*文字列として番兵を入れておく*/
     memCnt+=2*sizeof(char);
 
-    /*ܤΥɥ쥹ʼꤹ*/
+    /*キー項目のアドレスを全て番兵に設定する*/
     memCnt+=FldCnt*sizeof(char *);
 
-    /*sortUQǤϰʲbktѿѤƤʤmergeRBUQѡ*/
+    /*sortUQでは以下のbkt変数は利用していない。mergeRBUQで利用。*/
     memCnt+=(sizeof(int)*PWayU);
 
   }else{
 
-    /*frܤޤ뤴ȥԡ*/
+    /*frの全項目をまるごとコピー*/
     memCnt+=fr->chrCnt*sizeof(char);
 
-    /*ܤΥɥ쥹׻ˤꥻå*/
+    /*キー項目のアドレスを計算によりセット*/
     memCnt+=FldCnt*sizeof(char *);
 
-    /*sortUQǤϰʲbktѿѤƤʤmergeRBUQѡ*/
+    /*sortUQでは以下のbkt変数は利用していない。mergeRBUQで利用。*/
     memCnt+=(sizeof(int)*PWayU);
   }
   return(memCnt);
@@ -438,17 +438,17 @@ static void RBUQcpKey( struct RBUQnode  *v, struct mssFldRec *fr, int bkt)
   int i;
 
   if(fr->eof==1){ /*EOF*/
-    /*ʸȤʼƤ*/
+    /*文字列として番兵を入れておく*/
     v->key->str = mssMalloc(2*sizeof(char),"RBUQUQtree1");
     memcpy(v->key->str, readEnd, 2);
 
-    /*ܤΥɥ쥹ʼꤹ*/
+    /*キー項目のアドレスを全て番兵に設定する*/
     v->key->fld = mssMalloc(FldCnt*sizeof(char *),"RBUQUQtree2");
     for(i=0; i<FldCnt; i++){
       *(v->key->fld+i) = v->key->str;
     }
 
-    /*sortUQǤϰʲbktѿѤƤʤmergeRBUQѡ*/
+    /*sortUQでは以下のbkt変数は利用していない。mergeRBUQで利用。*/
     v->key->bkt    = mssCalloc(sizeof(int)*PWayU, "RBUQtree");
     *(v->key->bkt+bkt) = 1;
     /**v->key->bkt    = bkt;*/
@@ -456,17 +456,17 @@ static void RBUQcpKey( struct RBUQnode  *v, struct mssFldRec *fr, int bkt)
 
   }else{
 
-    /*frܤޤ뤴ȥԡ*/
+    /*frの全項目をまるごとコピー*/
     v->key->str = mssMalloc(fr->chrCnt*sizeof(char),"RBUQUQtree4");
     memcpy(v->key->str, *fr->pnt, fr->chrCnt); 
 
-    /*ܤΥɥ쥹׻ˤꥻå*/
+    /*キー項目のアドレスを計算によりセット*/
     v->key->fld = mssMalloc(FldCnt*sizeof(char *),"RBUQUQtree5");
     for(i=0; i<FldCnt; i++){
       *(v->key->fld+i) = v->key->str + (*(fr->pnt+i) - *fr->pnt);
     }
 
-    /*sortUQǤϰʲbktѿѤƤʤmergeRBUQѡ*/
+    /*sortUQでは以下のbkt変数は利用していない。mergeRBUQで利用。*/
     v->key->bkt    = mssCalloc(sizeof(int)*PWayU, "RBUQtree");
     *(v->key->bkt+bkt) = 1;
   }
@@ -474,18 +474,18 @@ static void RBUQcpKey( struct RBUQnode  *v, struct mssFldRec *fr, int bkt)
 
 /**
  * # FUNCTION #
- *ΥΡɤFldRec¤ΤΥǡǹ
+ *指定のノードをFldRec構造体のデータで更新
  */
 static void RBUQupdate( struct RBUQnode *v, int bkt)
 {
-  /*ХåֹХåȥե饰˹*/
+  /*更新したバケット番号をバケットフラグに更新する*/
   *(v->key->bkt+bkt) = 1;
 }
 
 /**
  * # FUNCTION #
- * RBtreeFldRec¤ΤΥǡɲ
- * ˥¸ߤRBUQupdateͤ򹹿
+ * RBtreeにFldRec構造体のデータを追加
+ * 既にキーが存在すればRBUQupdateで値を更新
  */
 static int RBUQinsert( struct RBUQnode *v, struct mssFldRec *fr, int bkt)
 {
@@ -493,7 +493,7 @@ static int RBUQinsert( struct RBUQnode *v, struct mssFldRec *fr, int bkt)
 
   v = RBUQmember(fr, v);
 
-  /*¸ߤʤɲ*/
+  /*キーが存在しなければ追加*/
   if(RBUQisExternalNode(v)){
     RBUQcpKey(v, fr, bkt);
     memCnt=RBUQcpKeyMemCnt(fr);
@@ -503,7 +503,7 @@ static int RBUQinsert( struct RBUQnode *v, struct mssFldRec *fr, int bkt)
     memCnt+=sizeof(struct RBUQnode)*2;
     memCnt+=sizeof(struct RBUQkey )*2;
 
-  /*¸ߤСɤ߹ߥե饰ON*/
+  /*キーが存在すれば、読み込みフラグをON*/
   }else{
     RBUQupdate(v, bkt);
   }
@@ -513,7 +513,7 @@ static int RBUQinsert( struct RBUQnode *v, struct mssFldRec *fr, int bkt)
 
 /**
  * # FUNCTION #
- *ΥΡɤ
+ *指定のノードを削除
  */
 static void RBUQdeleteNode(struct RBUQnode *v)
 {
@@ -572,9 +572,9 @@ static void RBUQdeleteNode(struct RBUQnode *v)
 
 /**
  * # FUNCTION #
- *ΥΡɤ
- *RBtreeͥԤΥΡɥɥ쥹֤
- *νǥΡɤϤʤƤӽФ¦RBUQdeleteNode(node)¹
+ *指定のノードを削除
+ *RBtreeから優先行のノードアドレスを返す
+ *この処理でノードを削除はしない。呼び出す本体側でRBUQdeleteNode(node)を実行
  */
 static struct RBUQnode *RBUQpop(struct RBUQnode *v)
 {
@@ -585,7 +585,7 @@ static struct RBUQnode *RBUQpop(struct RBUQnode *v)
   }else{
     vv=v;
     while(!RBUQisExternalNode(vv)){
-      vv=vv->left; /*rightéк硢leftϺǾ*/
+      vv=vv->left; /*rightを辿れば最大、leftは最小*/
     }
     return(vv->parent);
   }
@@ -593,7 +593,7 @@ static struct RBUQnode *RBUQpop(struct RBUQnode *v)
 
 /**
  * # FUNCTION #
- * RBtreeĥ꡼Ȥƽ񤭽Ф(ǥХå)
+ * RBtreeをツリーとして書き出す(デバッグ用)
  */
 void RBUQprintTree(char *s,struct RBUQnode *pp)
 {
@@ -603,13 +603,13 @@ void RBUQprintTree(char *s,struct RBUQnode *pp)
 
 /**
  * # FUNCTION #
- * ΥΡɤԤȤƽ񤭽Ф
+ * 指定のノードを行として書き出す
  */
 static void RBUQwriteNode( struct RBUQnode *p, struct mssFPW *fpw)
 {
   int i;
 
-  /*ǡƥȤν*/
+  /*データテキストの出力*/
   for(i=0; i<FldCnt-1; i++){
     mssWriteStr(*(p->key->fld+i),fpw); mssWriteDlm(fpw);
   }
@@ -618,7 +618,7 @@ static void RBUQwriteNode( struct RBUQnode *p, struct mssFPW *fpw)
 
 /**
  * # FUNCTION #
- * RBtreeƹԤȤƽ񤭽Ф(ǥХå)
+ * RBtreeを全て行として書き出す(デバッグ用)
  */
 static void RBUQwriteAllNode(struct RBUQnode *p, struct mssFPW *fpw)
 {
@@ -631,7 +631,7 @@ static void RBUQwriteAllNode(struct RBUQnode *p, struct mssFPW *fpw)
 
 /**
  * # FUNCTION #
- * RBtreeΥΰ
+ * RBtreeのメモリ領域解放
  */
 static void RBUQfree(struct RBUQnode *v)
 {
@@ -642,11 +642,11 @@ static void RBUQfree(struct RBUQnode *v)
 
 /**
  * # FUNCTION #
- * RBnodeν(Ρɺ)
+ * RBnodeの初期化(ノード作成)
  */
 static struct RBUQnode *RBUQinit(struct RBUQnode *rb)
 {
-  /*ֹڤν*/
+  /*赤黒木の初期化*/
   rb               = RBUQmakeNode();
   rb->parent       = rb;
   rb->right        = NULL;
@@ -659,24 +659,24 @@ static struct RBUQnode *RBUQinit(struct RBUQnode *rb)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ״Ϣؿ
+ * 集計関連関数
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ե̾μ
+ * 一時ファイル名の取得
  */
 static char *getFname(char *prefix, int number)
 {
-  /*fnameϥХѿ*/
+  /*fnameはグローバル変数*/
   sprintf(fname,"%s%d",prefix,number);
   return(fname);
 }
 
 /**
  * # FUNCTION #
- * mssFldRec¤Τ˰ɤ߹(ʼ)
+ * mssFldRec構造体に一行読み込む(番兵処理)
  */
 static void readRBUQkey( struct mssFPR *fp, struct mssFldRec *fr)
 {
@@ -684,25 +684,25 @@ static void readRBUQkey( struct mssFPR *fp, struct mssFldRec *fr)
 
   if(EOF==mssReadFldRec(fp,fr)){
     for(i=0; i<fr->fldCnt; i++)
-      *(fr->pnt+i)=readEnd; /*EOFλʼ*/
+      *(fr->pnt+i)=readEnd; /*EOFの時は番兵を入れる*/
   }
 }
 
 /**
  * # FUNCTION #
- *ƥХåȤκǽιԤRB塼ɤ߹
- *mergeRB,preSortƤӽФ
- *iFromiToޤǤΥեƬԤRB塼
- * ud   : iFile,rb򥻥åȤ
- * iFrom: ϥեֹ
- * iTo  : λեֹ
+ *各バケットの最初の行をRBキューに読み込み
+ *mergeRB,preSortから呼び出される
+ *iFromからiToまでのファイルの先頭行をRBキューに入れる
+ * ud   : iFile,rbをセットする
+ * iFrom: 開始ファイル番号
+ * iTo  : 終了ファイル番号
  */
 static void setFirstLineRBUQ( struct mssUnqDat *ud, int iFrom, int iTo)
 {
-  int bkt;                /*߽ΥХåֹ(0Ϥޤ)*/
+  int bkt;                /*現在処理中のバケット番号(0から始まる)*/
   int i;
 
-  /*ץ饤ƥ塼ν*/
+  /*プライオリティキューの初期化*/
   ud->rb=RBUQinit(ud->rb);
   bkt=0;
   for(i=iFrom; i<=iTo; i++){
@@ -710,10 +710,10 @@ static void setFirstLineRBUQ( struct mssUnqDat *ud, int iFrom, int iTo)
 
     ud->iFile[bkt]=mssOpenFPR(getFname(ud->prefixTxt,i),4);
 
-    /*(Ƭ)ɤ߹*/
+    /*一行(先頭行)読み込み*/
     readRBUQkey(ud->iFile[bkt],ud->fr[bkt]);
 
-    /*ֹڤ(ʪŪ˥ԡ)*/
+    /*赤黒木に挿入(物理的にコピー)*/
     RBUQinsert(ud->rb->left,ud->fr[bkt],bkt);
     bkt++;
   }
@@ -721,117 +721,117 @@ static void setFirstLineRBUQ( struct mssUnqDat *ud, int iFrom, int iTo)
 
 /**
  * # FUNCTION #
- * RB塼ѤPWayޡ
- * ¤ѤäƤХå(iCnt)ʻ礷Ƥ
- * ǸΰĤˤʤޤʻϤʤ
- * PWayUĤ꾯ʤʤäȤʻߤ
+ * RBキューを用いたPWayマージ
+ * 既に並べ変わっているバケット(iCnt個)を併合していく
+ * 最後の一つになるまで併合はしない
+ * PWayU個より少なくなったときに併合を止める
  */
 static void mergeRBUQ(struct mssUnqDat *ud)
 {
-  int    bkt[PWayU];       /*PwayʻRBtreepopǡΥХåNo*/
-  int    bktCnt;           /*ΥХåȿ*/
-  struct RBUQnode *node;   /*popˤƼΡɤǼ*/
+  int    bkt[PWayU];       /*Pway併合時にRBtreeからpopしたデータのバケットNo*/
+  int    bktCnt;           /*そのバケット数*/
+  struct RBUQnode *node;   /*popにて取りだしたノードを格納*/
 
-  struct mssFPW *oFile;       /*ϥեݥ*/
+  struct mssFPW *oFile;       /*出力ワークファイルポインタ*/
 
-  int    iStart;           /*ϥեγֹ(ե̾ΰ)*/
-  int    iEnd;             /*ϥեνλֹ(ե̾ΰ)*/
-  int    oStart;           /*ϥեγֹ(ե̾ΰ)*/
-  int    oEnd;             /*ϥեνλֹ(ե̾ΰ)*/
-  int    iFrom,iTo;        /*ʻ礹Υեֹ*/
+  int    iStart;           /*入力ワークファイルの開始番号(ファイル名の一部)*/
+  int    iEnd;             /*入力ワークファイルの終了番号(ファイル名の一部)*/
+  int    oStart;           /*出力ワークファイルの開始番号(ファイル名の一部)*/
+  int    oEnd;             /*出力ワークファイルの終了番号(ファイル名の一部)*/
+  int    iFrom,iTo;        /*併合する時のファイル番号*/
   int    k;
   int    i;
 
-  /*Υ롼פin,outswapΤǡǤϵդ*/
+  /*次のループでin,outをswapするので、ここでは逆に定義*/
   iStart=ud->iEnd+1;
   iEnd  =ud->iEnd+1;
   oStart=ud->iStart;
   oEnd  =ud->iEnd;
 
-  /*եʻ礹롼 iCntPWayUĤ礭ޤ³*/
+  /*ファイルを併合するループ iCntがPWayU個より大きい場合まわり続ける*/
   while(1){
     mssSwapInt(&iStart,&oStart);
     mssSwapInt(&iEnd  ,&oEnd  );
     oEnd=oStart;
 
-    /*ϥեPWayUʲʤнλ*/
+    /*入力ファイル数がPWayU以下ならば終了*/
     if(iEnd-iStart+1 <= PWayU){
       ud->iStart = iStart;
       ud->iEnd   = iEnd;
       break;
     }
 
-    /*PwayĤiFileĤoFile˽񤭽Ф"򷫤֤롼*/
+    /*Pway個のiFileを一つのoFileに書き出す"を繰り返すループ*/
     k=0;
     while(1){
-      /*ƥХåȤκǽԤ򥭥塼*/
-      iFrom= k   *PWayU+iStart;     /* PWayU=3ǰե뤬
-                                          0,1,2,3,4,5,6λ*/
+      /*各バケットの最初行をキューに入れる*/
+      iFrom= k   *PWayU+iStart;     /* PWayU=3で一時ファイルが
+                                          0,1,2,3,4,5,6の時*/
       iTo  =(k+1)*PWayU+iStart-1; /* iFrom: 0 3 6*/
       if(iTo>iEnd) iTo=iEnd;        /* iTo  : 2 5 6*/
 
       setFirstLineRBUQ(ud, iFrom,iTo);
 
-      /*ϥե륪ץ*/
+      /*出力ファイルオープン*/
       oFile=mssOpenFPW(getFname(ud->prefixTxt,oEnd),0,0);
 
-      /*ƥХåȤԤŤɤ߹߽񤭽Ф롼*/
+      /*各バケットから一行づつ読み込み書き出すループ*/
       while(1) {
-        node=RBUQpop(ud->rb->left);          /*塼ԼФ*/
-        if(strcmp(node->key->str,readEnd)==0)/*readEnd(ʼ)Ф齪λ*/
+        node=RBUQpop(ud->rb->left);          /*キューから一行取り出し*/
+        if(strcmp(node->key->str,readEnd)==0)/*readEnd(番兵)を取り出したら終了*/
           break;
-        RBUQwriteNode(node,oFile);  /*Խ񤭽Ф*/
-        bktCnt=0;                   /*popǼФkeyͤΥХåȿ*/
+        RBUQwriteNode(node,oFile);  /*一行書き出し*/
+        bktCnt=0;                   /*popで取り出したkey値のバケット数*/
         for(i=0; i<PWayU; i++){
           if(*(node->key->bkt+i) == 1)
-          bkt[bktCnt++]=i;          /*Хåֹ򥻥å*/
+          bkt[bktCnt++]=i;          /*バケット番号をセット*/
         } 
-        RBUQdeleteNode(node);              /*ФΡɤκ*/
+        RBUQdeleteNode(node);              /*取り出したノードの削除*/
 
-        /*popХåȤ鿷ɤߤRBtree*/
+        /*popしたバケットから新に読みこんでRBtreeに挿入する*/
         for(i=0; i<bktCnt; i++){
           readRBUQkey(ud->iFile[bkt[i]],ud->fr[bkt[i]]);
           RBUQinsert(ud->rb->left,ud->fr[bkt[i]],bkt[i]);
         }
       }
 
-      RBUQfree(ud->rb);                    /*塼γ*/
-      for(i=0; i<=iTo-iFrom; i++){          /*ϥեΥ*/
+      RBUQfree(ud->rb);                    /*キューの開放*/
+      for(i=0; i<=iTo-iFrom; i++){          /*入力ファイルのクローズ*/
         mssCloseFPR(ud->iFile[i]);
         mssFreeFldRec(ud->fr[i]);
       }
-      mssCloseFPW(oFile);                     /*ϥեΥ*/
-      if(iTo==iEnd)break;                  /*ǸΥХåȤޤǤнλ*/
-      oEnd++;                              /*ϥեֹ楫ȥå*/
-      k++;                                 /*ʻȥå*/
+      mssCloseFPW(oFile);                     /*出力ファイルのクローズ*/
+      if(iTo==iEnd)break;                  /*最後のバケットまでいけば終了*/
+      oEnd++;                              /*出力ファイル番号カウントアップ*/
+      k++;                                 /*併合回数カウントアップ*/
     }
     for(i=iStart; i<=iEnd; i++){
-      unlink(getFname(ud->prefixTxt,i));      /*ϥեκ*/
+      unlink(getFname(ud->prefixTxt,i));      /*入力ワークファイルの削除*/
     }
   }
 }
 
 /**
  * # FUNCTION #
- * פʤsortؿ
- * פʤֹڤ
- * MAXۤե˽񤭽Ф
+ * 集計しながらsortする関数
+ * 集計しながら赤黒木を作成
+ * メモリ消費がMAXを越えたら一時ファイルに書き出し
  */
 static void sortUQ( struct mssUnqDat *ud, struct mssFPR *fpr)
 {
 
-  struct mssFldRec *fr;    /*ϥե򥭡¤ٴ뤿ΥХåե*/
-  int    pid;              /*ץID(ե̾ΰ)*/
-  int    oNum;             /*եֹΥȥåѿ*/
-  int    memCnt;           /**/
+  struct mssFldRec *fr;    /*入力ファイルをキー順に並べ換えるためのバッファ*/
+  int    pid;              /*プロセスID(ファイル名の一部)*/
+  int    oNum;             /*ワークファイル番号のカウントアップ変数*/
+  int    memCnt;           /*メモリ消費量*/
 
-  struct RBUQnode *rb=NULL; /*ֹ*/
-  struct mssFPW *fpw;      /*ϰե*/
+  struct RBUQnode *rb=NULL; /*赤黒木*/
+  struct mssFPW *fpw;      /*出力一時ファイル*/
 
-  fr=mssInitFldRec(FldCnt);/*FldRecν*/
-  rb=RBUQinit(rb);          /*RBUQtreeν*/
+  fr=mssInitFldRec(FldCnt);/*FldRecの初期化*/
+  rb=RBUQinit(rb);          /*RBUQtreeの初期化*/
 
-  /*ե̾Υץեå*/
+  /*ファイル名のプレフィックスの設定*/
   pid=getpid();
   if(strlen(ud->tmpDir) > MssFileNameMaxLen - 50 ) {
     mssShowErrMsg("length of path name must be less than %d",MssFileNameMaxLen-50);
@@ -839,33 +839,33 @@ static void sortUQ( struct mssUnqDat *ud, struct mssFPR *fpr)
   }
   sprintf(ud->prefixTxt,"%s/xt##%d-PreUnqTxt-",ud->tmpDir,pid);
 
-  memCnt=0; /*ꥫ󥿤Υꥢ*/
-  oNum=0;   /*ϥեֹ*/
+  memCnt=0; /*消費メモリカウンタのクリア*/
+  oNum=0;   /*出力ファイル番号*/
   while(1){
-    /*ǡɤ߹*/
+    /*データの読み込み*/
     mssReadFldRec(fpr,fr);
     (*ud->inCnt)++;
 
-    /*ֹڤΥMaxۤ ⤷ ǽԤ򸡽Ф*/
-    /*եؽ񤭽Ф*/
+    /*赤黒木のサイズがMaxを越えたら もしくは 最終行を検出したら*/
+    /*ワークファイルへ書き出す*/
     if( memCnt >= MaxMemU || fr->eof==1){
-      fpw=mssOpenFPW(getFname(ud->prefixTxt,oNum),0,0);/*ϥե륪ץ*/
-      RBUQwriteAllNode(rb->left, fpw);        /*RBtreeƽ*/
-      mssCloseFPW(fpw);                          /*ϥեΥ*/
-      oNum++;                                     /*ϥեcountUp*/
-      RBUQfree(rb);   /*RBUQtreeΰ*/
-      if(fr->eof==1){ /*ǽԤǽλ*/
+      fpw=mssOpenFPW(getFname(ud->prefixTxt,oNum),0,0);/*出力ファイルオープン*/
+      RBUQwriteAllNode(rb->left, fpw);        /*RBtree全て出力*/
+      mssCloseFPW(fpw);                          /*出力ファイルのクローズ*/
+      oNum++;                                     /*出力ファイル数countUp*/
+      RBUQfree(rb);   /*RBUQtreeの領域解放*/
+      if(fr->eof==1){ /*最終行で終了*/
         (*ud->inCnt)--;
         break;
       }
-      rb=RBUQinit(rb);    /*RBUQtreeν*/
-      memCnt=0;           /*ꥫ󥿤Υꥢ*/
+      rb=RBUQinit(rb);    /*RBUQtreeの初期化*/
+      memCnt=0;           /*消費メモリカウンタのクリア*/
     }
 
-    /*ֹڤ(ʪŪ˥ԡ)򥫥ȥå*/
+    /*赤黒木に挿入して(物理的にコピー)、メモリ消費をカウントアップ*/
     memCnt += RBUQinsert(rb->left,fr,1);
   }
-  mssFreeFldRec(fr);/*FldRecν*/
+  mssFreeFldRec(fr);/*FldRecの初期化*/
 
   ud->iStart = 0;
   ud->iEnd   = oNum-1;
@@ -873,8 +873,8 @@ static void sortUQ( struct mssUnqDat *ud, struct mssFPR *fpr)
 
 /**
  * # FUNCTION #
- *ɬѤȤʤܴطΥХѿ
- *preUnqrbTreeUQȤΤĤʤΤѿƤ
+ *必用となる項目関係のグローバル変数の設定
+ *preUnqとrbTreeUQとのつなぎのための変数は全てここで
  */
 struct mssUnqDat *mssInitUnqDat(int fldCnt, MssOptKEY *optKey, char *tmpDir, int *inCnt)
 {
@@ -886,7 +886,7 @@ struct mssUnqDat *mssInitUnqDat(int fldCnt, MssOptKEY *optKey, char *tmpDir, int
   unqDat->tmpDir  = tmpDir;
   unqDat->inCnt   = inCnt;
     
-  /*Хѿ*/
+  /*グローバル変数*/
   FldCnt  = unqDat->fldCnt;
   OptKey  = unqDat->optKey;
   
@@ -895,61 +895,61 @@ struct mssUnqDat *mssInitUnqDat(int fldCnt, MssOptKEY *optKey, char *tmpDir, int
 
 /**
  * # FUNCTION #
- * RB塼Ѥڤʬɤ߹
- * ¤ѤäƤХå(ud->iStartud->iEnd)
- * פʤʻ礷Ƥ
- * եθĿϴPWayUʲˤʤäƤ뤳Ȥ
+ * RBキューを用いた項目切り分け型行読み込み
+ * 既に並べ変わっているバケット(ud->iStartからud->iEnd)を
+ * 集計しながら併合していく
+ * ファイルの個数は既にPWayU以下になっていることが前提
  */
 int mssReadWriteUnq(struct mssUnqDat *ud, struct mssFPW *oFile)
 {
-  struct RBUQnode *node;      /*popˤƼΡɤǼ*/
-  int              bkt[PWayU];/*PwayʻRBtreepopǡΥХåNo*/
-  int              bktCnt;    /*ΥХåȿ*/
+  struct RBUQnode *node;      /*popにて取りだしたノードを格納*/
+  int              bkt[PWayU];/*Pway併合時にRBtreeからpopしたデータのバケットNo*/
+  int              bktCnt;    /*そのバケット数*/
   int i;
 
-  node=RBUQpop(ud->rb->left);           /*塼ԼФ*/
-  if(strcmp(node->key->str,readEnd)==0) /*readEnd(ʼ)Ф齪λ*/
+  node=RBUQpop(ud->rb->left);           /*キューから一行取り出し*/
+  if(strcmp(node->key->str,readEnd)==0) /*readEnd(番兵)を取り出したら終了*/
     return(EOF);
 
-  /*Խ񤭽Ф*/
+  /*一行書き出し*/
   mssWriteFld(node->key->fld,FldCnt,"\n",oFile);
 
-  bktCnt=0;                      /*popǼФkeyͤΥХåȿ*/
+  bktCnt=0;                      /*popで取り出したkey値のバケット数*/
   for(i=0; i<PWayU; i++){
     if(*(node->key->bkt+i) == 1)
-      bkt[bktCnt++]=i;           /*Хåȥե饰򥻥å*/
+      bkt[bktCnt++]=i;           /*バケットフラグをセット*/
   } 
-  RBUQdeleteNode(node);          /*ФΡɤκ*/
+  RBUQdeleteNode(node);          /*取り出したノードの削除*/
 
-  /*popХåȤ鿷ɤߤRBtree*/
+  /*popしたバケットから新に読みこんでRBtreeに挿入する*/
   for(i=0; i<bktCnt; i++){
     readRBUQkey(ud->iFile[bkt[i]],ud->fr[bkt[i]]);
     RBUQinsert(ud->rb->left,ud->fr[bkt[i]],bkt[i]);
   }
-  return(1); /*Ȥꤢ*/
+  return(1); /*とりあえず*/
 }
 
 /**
  * # FUNCTION #
- * mssUnqDat¤Τγ
+ * mssUnqDat構造体の開放。
  */
 void mssFreeUnqDat(struct mssUnqDat *ud)
 {
   int i;
 
   if(ud->procType==1){
-    /*ХåեΤˡϥեϤǽƥ*/
+    /*バッファ管理のために、入力ファイルはここで初めてクローズする*/
     for(i=0; i<=ud->iEnd-ud->iStart; i++){
       mssCloseFPR(ud->iFile[i]);
       mssFreeFldRec(ud->fr[i]);
     }
 
-    /*եκ*/
+    /*ファイルの削除*/
     for(i=ud->iStart; i<=ud->iEnd; i++){
       unlink(getFname(ud->prefixTxt,i));
     }
 
-    /*ΰ賫*/
+    /*領域開放*/
     RBUQfree(ud->rb);
   }
   mssFree(ud);
@@ -957,11 +957,11 @@ void mssFreeUnqDat(struct mssUnqDat *ud)
 
 /**
  * # FUNCTION #
- * ֹڤʤ齸סܽפʤPWayޡ
+ * 赤黒木を作りながら集計＋集計しながらPWayマージソート
  */
 void mssPreUnq( struct mssUnqDat *ud, struct mssFPR *iFile)
 {
-  /*ʥϥɥ*/
+  /*シグナルハンドラの設定*/
   mssGV.usedTempFileFlg=1;
   mssSetSignalHandler();
 
