@@ -1,12 +1,13 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤMssValue˴ؤؿ
+ * MUSASHIで用いられるMssValue型に関する関数
  *
  * Change log
- * 2004/02/14 : ͱ黻ϰϥ顼Υåɲ(finite)
+ * 2004/02/14 : 数値演算範囲エラーのチェック追加(finite)
+ * 2004/08/02 : mssVcmpをmssVcmpOpeに変更+mssVcmp関数追加
  * ============================================================================
- * NULLФ黻NULL
+ * NULLに対する演算は全てNULL
  */
 
 
@@ -28,8 +29,8 @@
 
 /**
  * # FUNCTION #
- * MssValueν
- * MssValue򣰥ꥢΥǡפ򥻥åȤ롣
+ * MssValueの初期化
+ * MssValueを０クリアし、指定のデータタイプをセットする。
  */
 void mssVinit(MssValue *v, enum vType vType)
 {
@@ -39,20 +40,20 @@ void mssVinit(MssValue *v, enum vType vType)
 
 /**
  * # FUNCTION #
- * MssValueΣꥢ
+ * MssValueの０クリア
  */
 void mssVclear(MssValue *v)
 {
   v->nul=0;
-  v->v.d=0; /*Ǥ⥵礭(double)ǽ*/
+  v->v.d=0; /*最もサイズの大きい型(double)で初期化*/
 } 
 
 /**
  * # FUNCTION #
- * MssValueη˱ǾͤǤΥꥢ
- * INT:INT_MIN
- * DBL:-DBL_MAX
- * ¾η:NULL򥻥å
+ * MssValueの型に応じた最小値でのクリア
+ * INT型:INT_MINに設定
+ * DBL型:-DBL_MAXに設定
+ * その他の型:NULLをセット
  */
 void mssVclearMin(MssValue *v)
 {
@@ -66,10 +67,10 @@ void mssVclearMin(MssValue *v)
   
 /**
  * # FUNCTION #
- * MssValueη˱ͤǤΥꥢ
- * INT:INT_MAX
- * DBL:DBL_MAX
- * ¾η:NULL򥻥å
+ * MssValueの型に応じた最大値でのクリア
+ * INT型:INT_MAXに設定
+ * DBL型:DBL_MAXに設定
+ * その他の型:NULLをセット
  */
 void mssVclearMax(MssValue *v)
 {
@@ -83,7 +84,7 @@ void mssVclearMax(MssValue *v)
  
 /**
  * # FUNCTION #
- * intMssValueINTѴ
+ * int型をMssValueのINT型に変換
  */
 MssValue mssVint2i(int i)
 {
@@ -96,7 +97,7 @@ MssValue mssVint2i(int i)
 
 /**
  * # FUNCTION #
- *intMssValueDBLѴ
+ *int型をMssValueのDBL型に変換
  */
 MssValue mssVint2d(int i)
 {
@@ -109,8 +110,8 @@ MssValue mssVint2d(int i)
 
 /**
  * # FUNCTION #
- * intMssValueSTRѴ
- * MssValueSTR˿ʸΰݤ롣
+ * int型をMssValueのSTR型に変換
+ * MssValueのSTR型に新たに文字列領域を確保する。
  */
 MssValue mssVint2s(int i)
 {
@@ -123,7 +124,7 @@ MssValue mssVint2s(int i)
 
 /**
  * # FUNCTION #
- * doubleMssValueINTѴ
+ * double型をMssValueのINT型に変換
  */
 MssValue mssVdbl2i(double d)
 {
@@ -136,7 +137,7 @@ MssValue mssVdbl2i(double d)
 
 /**
  * # FUNCTION #
- * doubleMssValueDBLѴ
+ * double型をMssValueのDBL型に変換
  */
 MssValue mssVdbl2d(double d)
 {
@@ -149,8 +150,8 @@ MssValue mssVdbl2d(double d)
 
 /**
  * # FUNCTION #
- * doubleMssValueSTRѴ
- * MssValueSTR˿ʸΰݤ롣
+ * double型をMssValueのSTR型に変換
+ * MssValueのSTR型に新たに文字列領域を確保する。
  */
 MssValue mssVdbl2s(double d)
 {
@@ -163,9 +164,9 @@ MssValue mssVdbl2s(double d)
 
 /**
  * # FUNCTION #
- * ʸ(char *)MssValueINTѴ
- * ʸƬ"*"(NULL)λϡMssValueNULL˥åȤ롣
- * ѴˤatoiؿѤƤ롣
+ * 文字列型(char *)をMssValueのINT型に変換
+ * 文字列の先頭が"*"(NULL値)の時は、MssValueもNULLにセットする。
+ * 変換にはatoi関数を利用している。
  */
 MssValue mssVstr2i(char *str)
 {
@@ -183,9 +184,9 @@ MssValue mssVstr2i(char *str)
 
 /**
  * # FUNCTION #
- * ʸ(char *)MssValueDBLѴ
- * ʸƬ"*"(NULL)λϡMssValueNULL˥åȤ롣
- * ѴˤatofؿѤƤ롣
+ * 文字列型(char *)をMssValueのDBL型に変換
+ * 文字列の先頭が"*"(NULL値)の時は、MssValueもNULLにセットする。
+ * 変換にはatof関数を利用している。
  */
 MssValue mssVstr2d(char *str)
 {
@@ -203,10 +204,10 @@ MssValue mssVstr2d(char *str)
 
 /**
  * # FUNCTION #
- * ʸ(char *)MssValueSTRѴ
- * ʸƬ"*"(NULL)λϡMssValueNULL˥åȤ롣
- * ʸΰ򥳥ԡ뤳ȤϤʤ
- * ʤñ˰strΥɥ쥹򥻥åȤ
+ * 文字列型(char *)をMssValueのSTR型に変換
+ * 文字列の先頭が"*"(NULL値)の時は、MssValueもNULLにセットする。
+ * 新たに文字領域をコピーすることはしない。
+ * すなわち、単に引数strのアドレスをセットするだけ。
  */
 MssValue mssVstr2s(char *str)
 {
@@ -224,7 +225,7 @@ MssValue mssVstr2s(char *str)
 
 /**
  * # FUNCTION #
- * ηʤΡ顼åλ
+ * 引数の型が合わない場合の、エラーメッセージ＆終了
  */
 static void errorInvalidType(char *msg)
 {
@@ -234,7 +235,7 @@ static void errorInvalidType(char *msg)
 
 /**
  * # FUNCTION #
- * MssValueINTMssValueDBLѴ
+ * MssValueのINT型をMssValueのDBL型に変換
  */
 MssValue mssVi2d(MssValue v)
 {
@@ -251,7 +252,7 @@ MssValue mssVi2d(MssValue v)
 
 /**
  * # FUNCTION #
- * MssValueINTMssValueSTRѴ
+ * MssValueのINT型をMssValueのSTR型に変換
  */
 MssValue mssVi2s(MssValue v)
 {
@@ -268,7 +269,7 @@ MssValue mssVi2s(MssValue v)
 
 /**
  * # FUNCTION #
- * MssValueDBLMssValueINTѴ
+ * MssValueのDBL型をMssValueのINT型に変換
  */
 MssValue mssVd2i(MssValue v)
 {
@@ -285,8 +286,8 @@ MssValue mssVd2i(MssValue v)
 
 /**
  * # FUNCTION #
- * MssValueDBLMssValueSTRѴ
- * MssValueSTR˿ʸΰݤ롣
+ * MssValueのDBL型をMssValueのSTR型に変換
+ * MssValueのSTR型に新たに文字列領域を確保する。
  */
 MssValue mssVd2s(MssValue v)
 {
@@ -303,9 +304,9 @@ MssValue mssVd2s(MssValue v)
 
 /**
  * # FUNCTION #
- * MssValueSTRMssValueINTѴ
- * Ϳ줿MssValueSTRʸΰϳʤ
- * ѴˤatoiؿѤƤ롣
+ * MssValueのSTR型をMssValueのINT型に変換
+ * 引数で与えられたMssValueのSTR型の文字列領域は開放しない。
+ * 変換にはatoi関数を利用している。
  */
 MssValue mssVs2i(MssValue v)
 {
@@ -322,9 +323,9 @@ MssValue mssVs2i(MssValue v)
 
 /**
  * # FUNCTION #
- * MssValueSTRMssValueDBLѴ
- * Ϳ줿MssValueSTRʸΰϳʤ
- * ѴˤatofؿѤƤ롣
+ * MssValueのSTR型をMssValueのDBL型に変換
+ * 引数で与えられたMssValueのSTR型の文字列領域は開放しない。
+ * 変換にはatof関数を利用している。
  */
 MssValue mssVs2d(MssValue v)
 {
@@ -341,7 +342,7 @@ MssValue mssVs2d(MssValue v)
 
 /**
  * # FUNCTION #
- * ĤΰηۤΡ顼åλ
+ * ２つの引数の型が異る場合の、エラーメッセージ＆終了
  */
 static void errorDiffType(char *msg)
 {
@@ -351,11 +352,11 @@ static void errorDiffType(char *msg)
 
 /**
  * # FUNCTION #
- * MssValue­
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ĤMssValue(v1,v2)ηפʤХ顼Ϥ롣
- * ֤ͤηϡηƱ
+ * MssValueの足し算
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * ２つのMssValue引数(v1,v2)の型が一致しなければエラーを出力する。
+ * 返す値の型は、引数の型に同じ。
  */
 MssValue mssVadd(MssValue v1, MssValue v2)
 {
@@ -379,11 +380,11 @@ MssValue mssVadd(MssValue v1, MssValue v2)
 
 /**
  * # FUNCTION #
- * MssValueΰ
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ĤMssValue(v1,v2)ηפʤХ顼Ϥ롣
- * ֤ͤηϡηƱ
+ * MssValueの引き算
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * ２つのMssValue引数(v1,v2)の型が一致しなければエラーを出力する。
+ * 返す値の型は、引数の型に同じ。
  */
 MssValue mssVsub(MssValue v1, MssValue v2)
 {
@@ -405,11 +406,11 @@ MssValue mssVsub(MssValue v1, MssValue v2)
 
 /**
  * # FUNCTION #
- * MssValueΤ
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ĤMssValue(v1,v2)ηפʤХ顼Ϥ롣
- * ֤ͤηϡηƱ
+ * MssValueのかけ算
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * ２つのMssValue引数(v1,v2)の型が一致しなければエラーを出力する。
+ * 返す値の型は、引数の型に同じ。
  */
 MssValue mssVmul(MssValue v1, MssValue v2)
 {
@@ -433,12 +434,12 @@ MssValue mssVmul(MssValue v1, MssValue v2)
 
 /**
  * # FUNCTION #
- * MssValueγ껻
- * MssValueDBLФƤΤѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ĤMssValue(v1,v2)ηפʤХ顼Ϥ롣
- * ֤ͤηϡηƱ(DBL)
- * v2ξNULL֤ͤ
+ * MssValueの割り算
+ * MssValueのDBL型に対してのみ利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * ２つのMssValue引数(v1,v2)の型が一致しなければエラーを出力する。
+ * 返す値の型は、引数の型に同じ(DBL)。
+ * v2が０の場合はNULL値を返す。
  */
 MssValue mssVdiv(MssValue v1, MssValue v2)
 {
@@ -462,13 +463,13 @@ MssValue mssVdiv(MssValue v1, MssValue v2)
 
 /**
  * # FUNCTION #
- * MssValueξ;
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ĤMssValue(v1,v2)ηפʤХ顼Ϥ롣
- * ֤ͤηϡηƱ
- * v2ξNULL֤ͤ
- * INTξ"%"黻ҤȤDBLξfmodؿѤƤ롣
+ * MssValueの剰余算
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * ２つのMssValue引数(v1,v2)の型が一致しなければエラーを出力する。
+ * 返す値の型は、引数の型に同じ。
+ * v2が０の場合はNULL値を返す。
+ * INTの場合は"%"演算子を使い、DBLの場合はfmod関数を利用している。
  * ex. 5 % 2 = 1, 5.2 % 1.2 = 0.3
  */
 MssValue mssVmod(MssValue v1, MssValue v2)
@@ -497,11 +498,11 @@ MssValue mssVmod(MssValue v1, MssValue v2)
 
 /**
  * # FUNCTION #
- * MssValueʿ
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ֤ͤηϡη˴ؤ餺DBL
- * v2οξNULL֤ͤ
+ * MssValueの平方根
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * 返す値の型は、引数の型に関わらずDBL型。
+ * v2が負の数の場合はNULL値を返す。
  */
 MssValue mssVsqrt(MssValue v)
 {
@@ -525,10 +526,10 @@ MssValue mssVsqrt(MssValue v)
 
 /**
  * # FUNCTION #
- * MssValueΥȥå
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ֤ͤηϡηƱ
+ * MssValueのカウントアップ
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * 返す値の型は、引数の型に同じ。
  */
 MssValue mssVcntUp(MssValue v)
 {
@@ -545,10 +546,10 @@ MssValue mssVcntUp(MssValue v)
 
 /**
  * # FUNCTION #
- * MssValueΥȥ
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ֤ͤηϡηƱ
+ * MssValueのカウントダウン
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * 返す値の型は、引数の型に同じ。
  */
 MssValue mssVcntDown(MssValue v)
 {
@@ -565,11 +566,11 @@ MssValue mssVcntDown(MssValue v)
 
 /**
  * # FUNCTION #
- * ĤMssValuev1,v2Ǿ֤ͤ
- * ĤMssValueƱv1֤
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ֤ͤηϡηƱ
+ * ２つのMssValue引数v1,v2で小さい値を返す
+ * ２つのMssValue引数が同じ場合はv1を返す
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * 返す値の型は、引数の型に同じ。
  */
 MssValue mssVmin(MssValue v1, MssValue v2)
 {
@@ -594,11 +595,11 @@ MssValue mssVmin(MssValue v1, MssValue v2)
 
 /**
  * # FUNCTION #
- * ĤMssValuev1,v2礭֤ͤ
- * ĤMssValueƱv1֤
- * MssValueINTDBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ֤ͤηϡηƱ
+ * ２つのMssValue引数v1,v2で大きい値を返す
+ * ２つのMssValue引数が同じ場合はv1を返す
+ * MssValueのINT型およびDBL型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * 返す値の型は、引数の型に同じ。
  */
 MssValue mssVmax(MssValue v1, MssValue v2)
 {
@@ -623,14 +624,14 @@ MssValue mssVmax(MssValue v1, MssValue v2)
 
 /**
  * # FUNCTION #
- * ĤMssValuea,bӱ黻
- * "a ope b"ɾʤ1ʤ飰֤
- * a,b줫NULLʤ-1֤
- * MssValueINT,DBL,DBLФѲǽǡ¾ηꤵХ顼
- * åɽλ롣
- * ֤ͤηϡint
+ * ２つのMssValue引数a,bの比較演算
+ * "a ope b"を評価し、真ならば1、偽なら０を返す。
+ * a,bいずれかがNULLなら-1を返す。
+ * MssValueのINT型,DBL型,STR型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * 返す値の型は、常にint型。
  */
-int mssVcmp(MssValue a, enum OpeType ope, MssValue b)
+int mssVcmpOpe(MssValue a, enum OpeType ope, MssValue b)
 {
   double d=0;
   int  flag=0;
@@ -638,7 +639,7 @@ int mssVcmp(MssValue a, enum OpeType ope, MssValue b)
   if(a.nul || b.nul) return(-1);
 
   switch(a.vType){
-    /*Double ------- -DBL0 0 +DBL0 ++++++++ */
+    /*Double型 ------- -DBL0 0 +DBL0 ++++++++ */
     case DBL:
     d=a.v.d-b.v.d;
     switch(ope){
@@ -651,7 +652,7 @@ int mssVcmp(MssValue a, enum OpeType ope, MssValue b)
     }
     break;
 
-    /*INT*/
+    /*INT型*/
     case INT:
     switch(ope){
       case OPE_LT: if(a.v.i <b.v.i) flag=1; break;
@@ -663,7 +664,7 @@ int mssVcmp(MssValue a, enum OpeType ope, MssValue b)
     }
     break;
 
-    /*STR*/
+    /*STR型*/
     case STR:
     switch(ope){
       case OPE_LT: if(0> strcmp(a.v.s,b.v.s)) flag=1; break;
@@ -675,6 +676,60 @@ int mssVcmp(MssValue a, enum OpeType ope, MssValue b)
     }
     break;
 
+    default : errorInvalidType("mssVcmpOpe");
+    break;
+  }
+  return(flag);
+} 
+
+
+/**
+ * # FUNCTION #
+ * ２つのMssValue引数a,bの比較演算
+ * "a > b"なら+1、a<bなら-1、a=bなら0を返す。
+ * a,bいずれかがNULLなら9を返す。
+ * MssValueのINT型,DBL型,STR型に対して利用可能で、その他の型が指定されればエラー
+ * メッセージを表示し、終了する。
+ * 返す値の型は、常にint型。
+ */
+int mssVcmp(MssValue a, MssValue b)
+{
+  double d=0;
+  int  flag=0;
+
+  if(a.nul || b.nul) return(9);
+
+  switch(a.vType){
+    /*Double型 ------- -DBL0 0 +DBL0 ++++++++ */
+    case DBL:
+    d=a.v.d-b.v.d;
+         if(d<-DBL0) flag=-1;
+    else if(d> DBL0) flag=1;
+    else             flag=0;
+    break;
+
+    /*INT型*/
+    case INT:
+         if(a.v.i<b.v.i) flag=-1;
+    else if(a.v.i>b.v.i) flag=1;
+    else                 flag=0;
+    break;
+
+    /*STR型*/
+    case STR:
+    flag=strcmp(a.v.s,b.v.s);
+         if(flag<0) flag=-1;
+    else if(flag>0) flag=1;
+    else            flag=0;
+    break;
+
+    /*ADD型*/
+    case ADD:
+         if(a.v.a<b.v.a) flag=-1;
+    else if(a.v.a>b.v.a) flag=1;
+    else                 flag=0;
+    break;
+
     default : errorInvalidType("mssVcmp");
     break;
   }
@@ -683,8 +738,8 @@ int mssVcmp(MssValue a, enum OpeType ope, MssValue b)
 
 /**
  * # FUNCTION #
- * MssValueν
- * MssValueηưŪȽǤŬڤ˽Ϥ롣
+ * MssValueの出力
+ * MssValueの型を時動的に判断し、適切に出力する。
  */
 void mssVwrite(MssValue v, struct mssFPW *fp)
 {
@@ -703,7 +758,7 @@ void mssVwrite(MssValue v, struct mssFPW *fp)
 
 /**
  * # FUNCTION #
- * MssValueINTν
+ * MssValueのINT型の出力
  */
 void mssVwriteInt(MssValue v, struct mssFPW *fp)
 {
@@ -717,7 +772,7 @@ void mssVwriteInt(MssValue v, struct mssFPW *fp)
 
 /**
  * # FUNCTION #
- * MssValueDBLν
+ * MssValueのDBL型の出力
  */
 void mssVwriteDbl(MssValue v, struct mssFPW *fp)
 {
@@ -731,7 +786,7 @@ void mssVwriteDbl(MssValue v, struct mssFPW *fp)
 
 /**
  * # FUNCTION #
- * MssValueSTRν
+ * MssValueのSTR型の出力
  */
 void mssVwriteStr(MssValue v, struct mssFPW *fp)
 {
