@@ -1,11 +1,11 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤXMLǡϴϢδؿ
- * iconvؿ(const char **)˥ץȥѴ 2003/12/24
- * mssAddXmlTagAttribute* Ϣδؿ°̾NULLλʤˤ⤻˽λ
- *   褦ѹ 2004/08/15
- * ꡼ 2004/10/31
+ * MUSASHIで用いられるXMLデータの入力関連の関数
+ * iconv関数の第二引数を(const char **)にプロトタイプ変換 2003/12/24
+ * mssAddXmlTagAttribute* 関連の関数で属性名がNULLの時なにもせずに終了する
+ *   ように変更 2004/08/15
+ * メモリリーク修正 2004/10/31
  * ============================================================================
  */
 
@@ -26,7 +26,7 @@
 #endif
 
 /*############################################################################*/
-/* Хѿ                                                             */
+/* グローバル変数                                                             */
 /*############################################################################*/
 xmlParserCtxtPtr ctxt;
 char mssXmlDomErrMsg[1024];
@@ -34,31 +34,31 @@ char mssXmlDomErrMsg[1024];
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * ʸΥ󥳡ǥѴ
+ * 文字列のエンコーディング変換
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * ʸstrencoding롣encodingˡϥХѿicidǷޤ롣
- *  : Ѵʸݥ󥿤֤
- *        strNULLʤNULL֤
- *        encodingˡꤵƤʤstr֤
- * icidˡ
+ * 文字列strをencodingする。encoding方法はグローバル変数icidで決まる。
+ * 返値 : 変換後の文字列ポインタを返す。
+ *        strがNULLならNULLを返す。
+ *        encodingの方法が指定されていなければstrを返す。
+ * icidの設定方法
  * include <iconv.h>
- * icid=iconv_open("UTF-8","EUC-JP"); EUC-JPUTF-8ؤѴ
+ * icid=iconv_open("UTF-8","EUC-JP"); EUC-JPからUTF-8への変換
  */
 char *mssEncoding(char *str, iconv_t *icid)
 {
-  size_t  encilen; /*iconv ʸĹ*/
-  size_t  encolen; /*iconv ʸĹ*/
+  size_t  encilen; /*iconv用 入力文字列長*/
+  size_t  encolen; /*iconv用 出力文字列長*/
 #ifdef MssNeedLibiconv
-  const char *encip;     /*iconv ʸ򼨤ݥ */
+  const char *encip;     /*iconv用 入力文字列を示すポインタ */
 #else
-  char *encip;     /*iconv ʸ򼨤ݥ */
+  char *encip;     /*iconv用 入力文字列を示すポインタ */
 #endif
-  char *encop;     /*iconv ʸ򼨤ݥ */
-  char *outStr;    /*ʸѥݥ*/
+  char *encop;     /*iconv用 出力文字列を示すポインタ */
+  char *outStr;    /*出力文字列の辺値用ポインタ*/
   int  encMax;
 
   if(str==NULL)return(NULL);
@@ -67,7 +67,7 @@ char *mssEncoding(char *str, iconv_t *icid)
 
   encMax=strlen(str)*4;
 
-  /*ʸΣܤΰ*/
+  /*一応、入力文字列の４倍の領域確保*/
   outStr=mssCalloc(sizeof(char)*encMax,"encoding");
   encip=str;
   encop=outStr;
@@ -82,19 +82,19 @@ char *mssEncoding(char *str, iconv_t *icid)
 
 /**
  * # FUNCTION #
- * mssEncodingؿʸС
+ * mssEncoding関数の文字数指定バージョン
  */
 char *mssNencoding(char *str, int len, iconv_t *icid)
 {
-  size_t  encilen; /*iconv ʸĹ*/
-  size_t  encolen; /*iconv ʸĹ*/
+  size_t  encilen; /*iconv用 入力文字列長*/
+  size_t  encolen; /*iconv用 出力文字列長*/
 #ifdef MssNeedLibiconv
-  const char *encip;     /*iconv ʸ򼨤ݥ */
+  const char *encip;     /*iconv用 入力文字列を示すポインタ */
 #else
-  char *encip;     /*iconv ʸ򼨤ݥ */
+  char *encip;     /*iconv用 入力文字列を示すポインタ */
 #endif
-  char *encop;     /*iconv ʸ򼨤ݥ */
-  char *outStr;    /*ʸѥݥ*/
+  char *encop;     /*iconv用 出力文字列を示すポインタ */
+  char *outStr;    /*出力文字列の辺値用ポインタ*/
   int  encMax;
 
   if(str==NULL)return(NULL);
@@ -102,7 +102,7 @@ char *mssNencoding(char *str, int len, iconv_t *icid)
 
   encMax=strlen(str)*4;
 
-  /*ʸΣܤΰ*/
+  /*一応、入力文字列の４倍の領域確保*/
   outStr=mssCalloc(sizeof(char)*encMax,"encoding");
   encip=str;
   encop=outStr;
@@ -118,18 +118,18 @@ char *mssNencoding(char *str, int len, iconv_t *icid)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * XML˴ؤʸ󢫢mssXmlTag¤ΡѴ
+ * XMLタグに関する「文字列←→mssXmlTag構造体」相互変換
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τν
- * ̾(element)Ͽ(ݤ)
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * °򥻥åȤmssAddXmlTagAttribute{Str,Int,Dbl}Ѥ롣
- * elementNULLλNULL֤
- * element'\0'ξϥ顼λ
+ * mssXmlTag構造体の初期化。
+ * 要素名(element)を登録する(メモリを確保して)。
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * 属性をセットする時はmssAddXmlTagAttribute{Str,Int,Dbl}を利用する。
+ * elementがNULLの時はNULLを返す。
+ * elementが'\0'の場合はエラー終了。
  */
 struct mssXmlTag *mssInitXmlTag(char *element, iconv_t *icid)
 {
@@ -153,10 +153,10 @@ struct mssXmlTag *mssInitXmlTag(char *element, iconv_t *icid)
 
 /**
  * # FUNCTION #
- * ѥ᡼Ϳ줿ǡ°ꥹȤ򥻥åȡmssXmlTag¤Τ֤
+ * パラメータで与えられた要素＆属性リストをセット、mssXmlTag構造体を返す。
  * str="element:attNam1=attVal1,attNam2=attVal2"
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * ̾'\0'ξϥ顼λ
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * 要素名が'\0'の場合はエラー終了。
  */
 struct mssXmlTag *mssInitXmlTagByOpt(char *str, iconv_t *icid)
 {
@@ -169,18 +169,18 @@ struct mssXmlTag *mssInitXmlTagByOpt(char *str, iconv_t *icid)
 
   if(!mssIsValidStr(str)) return(NULL);
   
-  /*ʸ¸*/
+  /*元の文字列を保存*/
   tmp=mssStrdup(str);
 
-  /* -°ѥ졼ȯ*/
+  /* 要素-属性セパレータの発見*/
   if( NULL!=(pos=strchr(tmp,':')) ){
     *pos='\0';
   }
 
-  /*ǤϿ*/
+  /*要素の登録*/
   xmlTag=mssInitXmlTag(tmp,icid);
 
-  /*°Ͽ*/
+  /*属性の登録*/
   if( pos!=NULL ){
     pos++;
 
@@ -202,7 +202,7 @@ struct mssXmlTag *mssInitXmlTagByOpt(char *str, iconv_t *icid)
 
 /**
  * # FUNCTION #
- * mssXmlTag¤ΰγ
+ * mssXmlTag構造体領域の開放。
  */
 void mssFreeXmlTag(struct mssXmlTag *xmlTag)
 {
@@ -220,11 +220,11 @@ void mssFreeXmlTag(struct mssXmlTag *xmlTag)
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τ˻°̾(name)뤫ɤĴ١С
- * °̾Ф(ʸ:value)򹹿롣ʤС°̾ͤɲä
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * xmlTag->attributesζǤ°̾򡢴Ǥͤݻ롣
- * xmlTagNULLξϲ⤻˥꥿󤹤롣
+ * mssXmlTag構造体に指定の属性名(name)があるかどうかを調べ、あれば、
+ * その属性名に対する値(文字列:value)を更新する。なければ、属性名と値を追加する
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * xmlTag->attributesの偶数番要素に属性名を、奇数番要素に値が保持される。
+ * xmlTagがNULLの場合は何もせずにリターンする。
  */
 void mssAddXmlTagAttributeFmt(struct mssXmlTag *xmlTag, char *name, iconv_t *icid, char *fmt, ... )
 {
@@ -245,14 +245,14 @@ void mssAddXmlTagAttributeFmt(struct mssXmlTag *xmlTag, char *name, iconv_t *ici
     exit(mssErrorNoDefault);
   }
 
-  /*°̾*/
+  /*属性名*/
   if(icid==NULL){
     nam=mssStrdup(name);
   }else{
     nam=mssEncoding(name,icid);
   }
 
-  /*°*/
+  /*属性値*/
   va_start(args,fmt);
   vsprintf(tmp,fmt,args);
   va_end(args);
@@ -268,9 +268,9 @@ void mssAddXmlTagAttributeFmt(struct mssXmlTag *xmlTag, char *name, iconv_t *ici
   }
   mssFree(buf);
  
-  /*ϿƤ뤫Ĵ٤*/
+  /*既に登録されているか調べる*/
   for(i=0; i<xmlTag->attCnt; i=i+2){
-    /*פ°ä!!*/
+    /*一致する属性があった!!*/
     if(strcmp(*(xmlTag->attributes+i),nam)==0){
       mssFree(*(xmlTag->attributes+i+1));
       *(xmlTag->attributes+i+1)=val;
@@ -278,7 +278,7 @@ void mssAddXmlTagAttributeFmt(struct mssXmlTag *xmlTag, char *name, iconv_t *ici
     }
   }
   
-  /*value˰פ°̾ʤäΤɲ*/
+  /*valueに一致する属性名がなかったので追加*/
   xmlTag->attCnt+=2;
   xmlTag->attributes=mssRealloc(xmlTag->attributes,
                                 sizeof(char *)*xmlTag->attCnt,"addXmlAtt");
@@ -288,11 +288,11 @@ void mssAddXmlTagAttributeFmt(struct mssXmlTag *xmlTag, char *name, iconv_t *ici
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τ˻°̾(name)뤫ɤĴ١С
- * °̾Ф(ʸ:value)򹹿롣ʤС°̾ͤɲä
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * xmlTag->attributesζǤ°̾򡢴Ǥͤݻ롣
- * xmlTagNULLξϲ⤻˥꥿󤹤롣
+ * mssXmlTag構造体に指定の属性名(name)があるかどうかを調べ、あれば、
+ * その属性名に対する値(文字列:value)を更新する。なければ、属性名と値を追加する
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * xmlTag->attributesの偶数番要素に属性名を、奇数番要素に値が保持される。
+ * xmlTagがNULLの場合は何もせずにリターンする。
  */
 void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value, iconv_t *icid)
 {
@@ -309,13 +309,13 @@ void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value,
     return;
   }
 
-  /*°̾*/
+  /*属性名*/
   if(icid==NULL){
     nam=mssStrdup(name);
   }else{
     nam=mssEncoding(name,icid);
   }
-  /*°*/
+  /*属性値*/
   buf=mssMalloc(sizeof(char)*(strlen(value)+3),"updXmlTag");
   strcpy(buf,"\"");
   strcat(buf,value);
@@ -327,9 +327,9 @@ void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value,
   }
   mssFree(buf);
  
-  /*ϿƤ뤫Ĵ٤*/
+  /*既に登録されているか調べる*/
   for(i=0; i<xmlTag->attCnt; i=i+2){
-    /*פ°ä!!*/
+    /*一致する属性があった!!*/
     if(strcmp(*(xmlTag->attributes+i),nam)==0){
       mssFree(*(xmlTag->attributes+i+1));
       *(xmlTag->attributes+i+1)=val;
@@ -337,7 +337,7 @@ void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value,
     }
   }
   
-  /*value˰פ°̾ʤäΤɲ*/
+  /*valueに一致する属性名がなかったので追加*/
   xmlTag->attCnt+=2;
   xmlTag->attributes=mssRealloc(xmlTag->attributes,
                                 sizeof(char *)*xmlTag->attCnt,"addXmlAtt");
@@ -347,11 +347,11 @@ void mssAddXmlTagAttributeStr(struct mssXmlTag *xmlTag, char *name, char *value,
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τ˻°̾(name)뤫ɤĴ١С
- * °̾Τ(:value)򹹿롣ʤС°̾ͤɲä
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * xmlTag->attributesζǤ°̾򡢴Ǥͤݻ롣
- * xmlTagNULLξϲ⤻˥꥿󤹤롣
+ * mssXmlTag構造体に指定の属性名(name)があるかどうかを調べ、あれば、
+ * その属性名に体する値(整数:value)を更新する。なければ、属性名と値を追加する
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * xmlTag->attributesの偶数番要素に属性名を、奇数番要素に値が保持される。
+ * xmlTagがNULLの場合は何もせずにリターンする。
  */
 void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, iconv_t *icid)
 {
@@ -365,14 +365,14 @@ void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, i
     return;
   }
 
-  /*°̾*/
+  /*属性名*/
   if(icid==NULL){
     nam=mssStrdup(name);
   }else{
     nam=mssEncoding(name,icid);
   }
 
-  /*°*/
+  /*属性値*/
   strcpy(buf,"\"");
   tmp=mssItoA(value);
   strcat(buf,tmp); mssFree(tmp);
@@ -383,9 +383,9 @@ void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, i
     val=mssEncoding(buf,icid);
   }
  
-  /*ϿƤ뤫Ĵ٤*/
+  /*既に登録されているか調べる*/
   for(i=0; i<xmlTag->attCnt; i=i+2){
-    /*פ°ä!!*/
+    /*一致する属性があった!!*/
     if(strcmp(*(xmlTag->attributes+i),nam)==0){
       mssFree(*(xmlTag->attributes+i+1));
       *(xmlTag->attributes+i+1)=val;
@@ -393,7 +393,7 @@ void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, i
     }
   }
 
-  /*value˰פ°̾ʤäΤɲ*/
+  /*valueに一致する属性名がなかったので追加*/
   xmlTag->attCnt+=2;
   xmlTag->attributes=mssRealloc(xmlTag->attributes,
                                 sizeof(char *)*xmlTag->attCnt,"addXmlAtt");
@@ -403,11 +403,11 @@ void mssAddXmlTagAttributeInt(struct mssXmlTag *xmlTag, char *name, int value, i
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τ˻°̾(name)뤫ɤĴ١С
- * °̾Τ(¿:value)򹹿롣ʤС°̾ͤɲä
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * xmlTag->attributesζǤ°̾򡢴Ǥͤݻ롣
- * xmlTagNULLξϲ⤻˥꥿󤹤롣
+ * mssXmlTag構造体に指定の属性名(name)があるかどうかを調べ、あれば、
+ * その属性名に体する値(実数:value)を更新する。なければ、属性名と値を追加する
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * xmlTag->attributesの偶数番要素に属性名を、奇数番要素に値が保持される。
+ * xmlTagがNULLの場合は何もせずにリターンする。
  */
 void mssAddXmlTagAttributeDbl(struct mssXmlTag *xmlTag, char *name, double value, iconv_t *icid)
 {
@@ -421,14 +421,14 @@ void mssAddXmlTagAttributeDbl(struct mssXmlTag *xmlTag, char *name, double value
     return;
   }
 
-  /*°̾*/
+  /*属性名*/
   if(icid==NULL){
     nam=mssStrdup(name);
   }else{
     nam=mssEncoding(name,icid);
   }
 
-  /*°*/
+  /*属性値*/
   strcpy(buf,"\"");
   tmp=mssFtoA(value);
   strcat(buf,tmp); mssFree(tmp);
@@ -439,9 +439,9 @@ void mssAddXmlTagAttributeDbl(struct mssXmlTag *xmlTag, char *name, double value
     val=mssEncoding(buf,icid);
   }
  
-  /*ϿƤ뤫Ĵ٤*/
+  /*既に登録されているか調べる*/
   for(i=0; i<xmlTag->attCnt; i=i+2){
-    /*פ°ä!!*/
+    /*一致する属性があった!!*/
     if(strcmp(*(xmlTag->attributes+i),nam)==0){
       mssFree(*(xmlTag->attributes+i+1));
       *(xmlTag->attributes+i+1)=val;
@@ -449,7 +449,7 @@ void mssAddXmlTagAttributeDbl(struct mssXmlTag *xmlTag, char *name, double value
     }
   }
 
-  /*value˰פ°̾ʤäΤɲ*/
+  /*valueに一致する属性名がなかったので追加*/
   xmlTag->attCnt+=2;
   xmlTag->attributes=mssRealloc(xmlTag->attributes,
                                 sizeof(char *)*xmlTag->attCnt,"addXmlAtt");
@@ -459,11 +459,11 @@ void mssAddXmlTagAttributeDbl(struct mssXmlTag *xmlTag, char *name, double value
 
 /**
  * # FUNCTION #
- * ץǻꤵ-°λ񼰤mssXmlTag¤Τ˥åȤ
- * Υݥ󥿤֤
- * Ϳ줿ʸ(str)NULLξNULL֤
- * Ϳ줿ʸ(str)ˤϰѹä̾°̾°
- * Ͽΰ˥åȤ롣
+ * オプションで指定される要素-属性の指定書式をmssXmlTag構造体にセットし、
+ * そのポインタを返す。
+ * 与えられた文字列(str)がNULLの場合はNULLを返す。
+ * 与えられた文字列(str)には一切変更を加えず、要素名、属性名、属性値
+ * は新しい領域にセットされる。
  *
  * ex)
  * str="title:date=2002/01/01,time=10:34:58"
@@ -486,13 +486,13 @@ struct mssXmlTag *mssOpt2XmlTag(char *str, iconv_t *icid)
   tmpStr=mssStrdup(str);
   pos=strchr(tmpStr,':');
 
-  /*̾ξ*/
+  /*要素名だけの場合*/
   if(pos==NULL){
     xmlTag=mssInitXmlTag(tmpStr,icid);
     return(xmlTag);
   }
 
-  /*°̾°ͤΥå*/
+  /*属性名、属性値のセット*/
   *pos++='\0';
   xmlTag=mssInitXmlTag(tmpStr,icid);
   atts=mssTokByChr(pos,',',&attCnt,0);
@@ -513,9 +513,9 @@ struct mssXmlTag *mssOpt2XmlTag(char *str, iconv_t *icid)
 
 /**
  * # FUNCTION #
- * mssXmlTag¤ΤʸȤƤζΥݥ󥿤֤
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * °ο(xmlTag->attCnt)Ĥξϡ°κǸǤ̵뤵롣
+ * mssXmlTag構造体から文字列としての空タグを作成し、そのポインタを返す。
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * 属性の数(xmlTag->attCnt)が奇数個の場合は、属性の最後の配列要素は無視される。
  *
  * ex.)
  * xmlTag->element="title"
@@ -577,9 +577,9 @@ char *mssXmlTag2emptyTag(struct mssXmlTag *xmlTag, iconv_t *icid)
 
 /**
  * # FUNCTION #
- * mssXmlTag¤ΤʸȤƤγϥΥݥ󥿤֤
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
- * °ο(xmlTag->attCnt)Ĥξϡ°κǸǤ̵뤵롣
+ * mssXmlTag構造体から文字列としての開始タグを作成し、そのポインタを返す。
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
+ * 属性の数(xmlTag->attCnt)が奇数個の場合は、属性の最後の配列要素は無視される。
  *
  * ex.)
  * xmlTag->element="title"
@@ -640,8 +640,8 @@ char *mssXmlTag2startTag(struct mssXmlTag *xmlTag, iconv_t *icid)
 
 /**
  * # FUNCTION #
- * mssXmlTag¤ΤʸȤƤνλΥݥ󥿤֤
- * icidåȤƤ(NULLǤʤ)󥳡ǥ󥰤Ѵ򤪤ʤ
+ * mssXmlTag構造体から文字列としての終了タグを作成し、そのポインタを返す。
+ * icidがセットされていれば(NULLでなければ)エンコーディングの変換をおこなう。
  *
  * ex.)
  * xmlTag->element="title"
@@ -682,16 +682,16 @@ char *mssXmlTag2endTag(struct mssXmlTag *xmlTag, iconv_t *icid)
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * XMLνϴϢ
+ * XMLの出力関連
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # FUNCTION #
- * XMLνϡ
- * Сȥ󥳡ǥ󥰤ϡ줾ver,encǻꤹ롣
+ * XML宣言の出力。
+ * バージョンとエンコーディングは、それぞれver,encで指定する。
  *
- * )
+ * 例)
  * <?XML version="1.0" encoding="EUC-JP"?>
  */
 void mssWriteXmlDeclaration( char *ver, char *enc, struct mssFPW *fp )
@@ -713,8 +713,8 @@ void mssWriteXmlDeclaration( char *ver, char *enc, struct mssFPW *fp )
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τξ򸵤ˡϥϤ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * mssXmlTag構造体の情報を元に、開始タグを出力する。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  */
 void mssWriteXmlStartTag(struct mssXmlTag *xmlTag, iconv_t *icid, struct mssFPW *fpw)
 {
@@ -726,8 +726,8 @@ void mssWriteXmlStartTag(struct mssXmlTag *xmlTag, iconv_t *icid, struct mssFPW
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τξ򸵤ˡλϤ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * mssXmlTag構造体の情報を元に、終了タグを出力する。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  */
 void mssWriteXmlEndTag(struct mssXmlTag *xmlTag, iconv_t *icid, struct mssFPW *fpw)
 {
@@ -739,8 +739,8 @@ void mssWriteXmlEndTag(struct mssXmlTag *xmlTag, iconv_t *icid, struct mssFPW *f
 
 /**
  * # FUNCTION #
- * mssXmlTag¤Τξ򸵤ˡϤ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * mssXmlTag構造体の情報を元に、空タグを出力する。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  */
 void mssWriteXmlEmptyTag(struct mssXmlTag *xmlTag, iconv_t *icid, struct mssFPW *fpw)
 {
@@ -752,8 +752,8 @@ void mssWriteXmlEmptyTag(struct mssXmlTag *xmlTag, iconv_t *icid, struct mssFPW
 
 /**
  * # FUNCTION #
- * ʸ(str)Ϥ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * 文字列(str)を出力する。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  */
 void mssWriteXmlContent( char *str, iconv_t *icid, struct mssFPW *fp )
 {
@@ -772,8 +772,8 @@ void mssWriteXmlContent( char *str, iconv_t *icid, struct mssFPW *fp )
 
 /**
  * # FUNCTION #
- * XMLΥǥȤϤ롣
- * ǥȤñ̤ȾѶʸǡcntĤζϤ롣
+ * XMLのインデントを出力する。
+ * インデントの単位は半角空白２文字で、cnt個の空白を出力する。
  */
 void mssWriteXmlIndent(int cnt, struct mssFPW *fpw)
 {
@@ -790,10 +790,10 @@ void mssWriteXmlIndent(int cnt, struct mssFPW *fpw)
 
 /**
  * # FUNCTION #
- * ϥʸ󡢽λ򥻥åȤǽϤ롣
- * °ޤ೫ϥϰʤ
- * ޤǥȡԤ̵ͭǤ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * 開始タグ、文字列、終了タグをセットで出力する。
+ * 属性を含む開始タグは扱えない。
+ * またインデント、改行の有無も指定できる。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  * ex)
  * indCnt=2, element="title", content="this is title" ,retFlg=1
  * ->
@@ -820,10 +820,10 @@ void mssWriteXmlTagStr(int indCnt, char *element, char *content, int retFlg, ico
 
 /**
  * # FUNCTION #
- * ϥλ򥻥åȤǽϤ롣
- * °ޤ೫ϥϰʤ
- * ޤǥȡԤ̵ͭǤ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * 開始タグ、整数、終了タグをセットで出力する。
+ * 属性を含む開始タグは扱えない。
+ * またインデント、改行の有無も指定できる。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  * ex)
  * indCnt=2, element="title", content=10 ,retFlg=1
  * ->
@@ -846,15 +846,15 @@ void mssWriteXmlTagInt(int indCnt, char *element, int content, int retFlg, iconv
   if(retFlg){
     mssWriteRet(fp);
   }
-  mssFree(buf); /* ɲ 2004/10/31 */
+  mssFree(buf); /* 追加 2004/10/31 */
 }
 
 /**
  * # FUNCTION #
- * ϥ¿λ򥻥åȤǽϤ롣
- * °ޤ೫ϥϰʤ
- * ޤǥȡԤ̵ͭǤ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * 開始タグ、実数、終了タグをセットで出力する。
+ * 属性を含む開始タグは扱えない。
+ * またインデント、改行の有無も指定できる。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  * ex)
  * indCnt=2, element="title", content=5.24 ,retFlg=1
  * ->
@@ -877,15 +877,15 @@ void mssWriteXmlTagDbl(int indCnt, char *element, double content, int retFlg, ic
   if(retFlg){
     mssWriteRet(fp);
   }
-  mssFree(buf); /* ɲ 2004/10/31 */
+  mssFree(buf); /* 追加 2004/10/31 */
 }
 
 /**
  * # FUNCTION #
- * flgʤжϤ롣
- * °ޤϰʤ
- * ޤǥȡԤ̵ͭǤ롣
- * icidNULLǤʤХ󥳡ǥѴԤäƽϤ롣
+ * flgが１ならば空タグを出力する。
+ * 属性を含む空タグは扱えない。
+ * またインデント、改行の有無も指定できる。
+ * icidがNULLでなければエンコーディング変換を行って出力する。
  * ex)
  * indCnt=2, element="title", flg=1 ,retFlg=1
  * ->
@@ -912,31 +912,31 @@ void mssWriteXmlTagFlg(int indCnt, char *element, int flg, int retFlg, iconv_t *
 /**
  * # SECTION #
  * ----------------------------------------------------------------------------
- * 顼ϥɥ
+ * エラーハンドラ
  * ----------------------------------------------------------------------------
  */
 
 /**
  * # GLOBAL #
- * DOMΥ顼ϥɥ顼
- * 顼åmssXmlDomErrMsg[]Ѥ롣
- * mainؿǡmssXmlDomErrMsg[0]='\0'ȤƽƤȡ
+ * DOMのエラーハンドラー。
+ * エラーメッセージがmssXmlDomErrMsg[]に蓄積される。
+ * main関数で、mssXmlDomErrMsg[0]='\0'として初期化しておくこと。
  */
 void mssXmlDomErrHandler(void *ctxt, const char *msg, ...){
 
   char bufMsg[1024];
 
-  /*顼åbufMsg˳Ǽencoding*/
+  /*エラーメッセージをbufMsgに格納しencoding*/
   va_list args;
   va_start(args,msg);
   vsprintf(bufMsg,msg,args);
 
-  /*Ĺå*/
+  /*長さチェック*/
   if(strlen(bufMsg)+strlen(mssXmlDomErrMsg) >= 1023){
     return;
   }
 
-  /*嵭åϢ*/
+  /*上記メッセージを連結*/
   strcat(mssXmlDomErrMsg,bufMsg);
 }
 
