@@ -1,21 +1,21 @@
 /**
  * # CHAPTER #
  * ============================================================================
- * MUSASHIѤXMLtableΥϢδؿ
+ * MUSASHIで用いられるXMLtableのタグを操作する関連の関数
  * ============================================================================
- * ̾ή
- * 1. mssReadTagǥե뤫ɤ߹ΥStrings˥åȤ
- * 2. mssGetTagɬפʥStrings˥åȤ
- * 3. mssGetTagCont,mssGetTagAtt,mssGetNulTagʤɤƤФ
- * 4. 2ǳݤStrings
- * 5. 2,3,4ν򷫤֤
- * 6. 1ǳݤStrings
+ * 通常の流れ
+ * 1. mssReadTagでファイルから読み込み特定のタグをStringsにセットする
+ * 2. mssGetTagで必要なタグをStringsにセットする
+ * 3. mssGetTagCont,mssGetTagAtt,mssGetNulTagなどで内容を取り出す
+ * 4. 2で確保したStringsを開放する
+ * 5. 2,3,4の処理を繰り返す
+ * 6. 1で確保したStringsを開放する
  *
- * mssGetTagCont,mssGetTagAtt,mssGetNulTagStringsʸñˤ򸡺ǽ 
- * ߤĤƤ֤ΤǡStrings˥ʣmssGetTag
- * 餫ɬפʥStrings˥åȤƤ
+ * mssGetTagCont,mssGetTagAtt,mssGetNulTagはStringsの文字列単にを検索し、最初に 
+ * みつけた内容を返すので、Stringsの中にタグが複数ある場合はmssGetTagで
+ * あらかじめ必要なタグをStringsにセットしておく
  *
- * 20040204 MssBeginBodyTagθstrncmpstrstrѹ
+ * 20040204 MssBeginBodyTagの検査をstrncmpからstrstrに変更
  */
 
 #include <musashi/mssInput.h>
@@ -23,15 +23,15 @@
 #include <stdlib.h>
 #include <string.h>
 
-/* ############ Хѿ ##############*/
+/* ############ グローバル変数 ##############*/
 extern struct mssGlobalVariables mssGV;
 
 
 /** 
  * # FUNCTION # 
- * 3İʸ󤫤鿷ĤʸΥݥ󥿤֤
- * κݡʸΰ褬ݤ롣
- * Tagκʤɤ
+ * 3つ以内の文字列から新しい一つの文字列を作成し、そのポインタを返す。
+ * その際、新たな文字列領域が確保される。
+ * Tagの作成などに利用
  * ex.) bgn="<", str="field", end=">"
  *      ->
  *      "<field>"
@@ -48,12 +48,12 @@ static char *mkStr(char *bgn, char *str, char *end){
 
 /** 
  * # FUNCTION # 
- * ե(fp)꥿(tag)򸡺Strings˥åȤΥݥ󥿤֤
- * ϥ̵NULL֤
- * ϥꡢλ̵Х顼ɽλ
+ * ファイル(fp)から指定タグ(tag)を検索しStringsにセットし、そのポインタを返す。
+ * 開始タグが無ければNULLを返す。
+ * 開始タグがあり、終了タグが無ければエラー表示＆終了。
  * ex.)
- * ե뤬"<xmltable><header>....</header></xmltable>"Ȥȡ
- * strings->str="<header><title>this is title</title></header>"
+ * ファイルが"<xmltable><header>....</header></xmltable>"とすると、
+ * 返値strings->str="<header><title>this is title</title></header>"
  */
 struct mssStrings *mssReadTag(char *tag, struct mssFPR *fp){
     
@@ -66,11 +66,11 @@ struct mssStrings *mssReadTag(char *tag, struct mssFPR *fp){
 
   rec=mssInitRec();
 
-  /*beginend򤽤줾쥻åȤ*/
+  /*beginタグとendタグをそれぞれセットする*/
   bgnTag=mkStr("<" ,tag,"" );
   endTag=mkStr("</",tag,">");
 
-  /*beginθ*/
+  /*beginタグの検索*/
   while( EOF != (len=mssReadRec(fp, rec)) ){
     if( NULL != (tagTmp=strstr(rec->pnt, bgnTag)) ){
       strings=mssInitStrings();
@@ -80,13 +80,13 @@ struct mssStrings *mssReadTag(char *tag, struct mssFPR *fp){
     }
   }
 
-  /*beginʤä*/
+  /*beginタグがなかった*/
   if(len==EOF){
     mssFree(bgnTag); mssFree(endTag);
     return(NULL);
   }
 
-  /*endθ*/
+  /*endタグの検索*/
   while( EOF != (len=mssReadRec(fp, rec)) ){
     if( NULL != (tagTmp=strstr(rec->pnt, endTag)) ){
       mssCatnStrings(strings, rec->pnt, rec->pnt-tagTmp+strlen(endTag));
@@ -98,7 +98,7 @@ struct mssStrings *mssReadTag(char *tag, struct mssFPR *fp){
     }
   }
 
-  /*endʤä*/
+  /*endタグがなかった*/
   if(len==EOF){
     mssShowErrMsg("there is not the end tag : %s",tag);
     mssEnd(mssErrorNoDefault);
@@ -112,17 +112,17 @@ struct mssStrings *mssReadTag(char *tag, struct mssFPR *fp){
 
 /** 
  * # FUNCTION #
- * ʸ(str)꥿(tag)ǰϤޤ줿ʸStrings˥åȤ
- * Υݥ󥿤֤
- * ϥ̵NULL֤
- * ϥꡢλ̵Х顼ɽλ
- * *posˡ줿ϥƬΥݥ󥿤򥻥åȤ롣
- * γؤϹθƤʤΤǡƱ̾ҹ¤ˤʤäƤ
- * ޤưʤ
+ * 文字列(str)から指定タグ(tag)で囲まれた文字列をStringsにセットし、
+ * そのポインタを返す。
+ * 開始タグが無ければNULLを返す。
+ * 開始タグがあり、終了タグが無ければエラー表示＆終了。
+ * さらに*posに、検索された開始タグの先頭のポインタをセットする。
+ * タグの階層は考慮していないので、同名タグが入れ子構造になっている場合は
+ * うまく動作しない。
  * ex.)
- * *str="<header><title>this is title</title><header>"Ȥȡ
- * strings->str="<title>this is title</title>"
- * *posϡꥸʥ*str"<title>...."Ƭ֤åȤ롣
+ * *str="<header><title>this is title</title><header>"とすると、
+ * 返値strings->str="<title>this is title</title>"
+ * *posは、オリジナルの*strの"<title>...."の先頭位置がセットされる。
  */
 struct mssStrings *mssGetTag(char *tag, char *str, char **pos){
 
@@ -132,18 +132,18 @@ struct mssStrings *mssGetTag(char *tag, char *str, char **pos){
   char *endTagTmp;
   struct mssStrings *strings;
 
-  /*beginend򤽤줾쥻åȤ*/
+  /*beginタグとendタグをそれぞれセットする*/
   bgnTag=mkStr("<" ,tag,"" );
   endTag=mkStr("</",tag,">");
 
-  /*beginθ*/
+  /*beginタグの検索*/
   bgnTagTmp=strstr(str, bgnTag);
   if( bgnTagTmp == NULL ){
     mssFree(bgnTag); mssFree(endTag);
     return(NULL);
   }
 
-  /*endθ*/
+  /*endタグの検索*/
   endTagTmp=strstr(bgnTagTmp, endTag);
   if( endTagTmp == NULL ){
     mssShowErrMsg("there is not the end tag : %s",tag);
@@ -161,18 +161,18 @@ struct mssStrings *mssGetTag(char *tag, char *str, char **pos){
 
 /** 
  * # FUNCTION #
- * ʸ(str)ǥ򸡺1ʤ0֤
- * ǥ: <numeric/>
+ * 文字列(str)から空要素タグを検索し、あれば1、なければ0を返す。
+ * 空要素タグの例: <numeric/>
  */
 int mssGetNullTag(char *str, char *tag){
 
   char *t;
   int   ret=0;
 
-  /**/
+  /*タグを作る*/
   t=mkStr("<",tag,"/>");
 
-  /*θ*/
+  /*タグの検索*/
   if(NULL != strstr(str, t)) ret=1;
 
   mssFree(t);
@@ -181,17 +181,17 @@ int mssGetNullTag(char *str, char *tag){
 
 /** 
  * # FUNCTION #
- * ʸ(str)꥿(tag)Ƥ֤
- * ꥿ʤNULL֤ͤ
- * ϥꡢλ̵Х顼ɽλ
- * strƤѤˡ˥ݤơΥɥ쥹֤
- * retIgnoreʤвԤ̵뤹롣
- * γؤϹθƤʤΤǡƱ̾ҹ¤ˤʤäƤ
- * ޤưʤ
+ * 文字列(str)から指定タグ(tag)の内容を返す。
+ * 指定タグがなければNULL値を返す。
+ * 開始タグがあり、終了タグが無ければエラー表示＆終了。
+ * strの内容は変えずに、新たにメモリを確保して、そのアドレスを返す。
+ * retIgnoreが１ならば改行を無視する。
+ * タグの階層は考慮していないので、同名タグが入れ子構造になっている場合は
+ * うまく動作しない。
  * ex.)
  * str="<title>this is title</title>"
  * tag="title"
- * ="this is title"
+ * 返値="this is title"
  */
 char *mssGetTagCont(char *str, char *tag, int retIgnore){
 
@@ -206,11 +206,11 @@ char *mssGetTagCont(char *str, char *tag, int retIgnore){
 
   if( str == NULL ) return(NULL);
 
-  /*beginend򤽤줾쥻åȤ*/
+  /*beginタグとendタグをそれぞれセットする*/
   bgnTag=mkStr("<" ,tag,"" );
   endTag=mkStr("</",tag,">");
 
-  /*begin,endθ*/
+  /*begin,endタグの検索*/
   bgnTagTmp=strstr(str, bgnTag);
   if( bgnTagTmp == NULL ){
     mssFree(bgnTag); mssFree(endTag);
@@ -251,13 +251,13 @@ char *mssGetTagCont(char *str, char *tag, int retIgnore){
 
 /** 
  * # FUNCTION #
- * ʸ(str)꥿(tag)λ°(att)֤ͤ
- * ϥꡢλ̵Х顼ɽλ
- * strƤѤˡ˥ݤơΥɥ쥹֤
- * °ͤ'"'ǰϤޤƤ뤳Ȥ
+ * 文字列(str)から指定タグ(tag)の指定の属性(att)の値を返す。
+ * 開始タグがあり、終了タグが無ければエラー表示＆終了。
+ * strの内容は変えずに、新たにメモリを確保して、そのアドレスを返す。
+ * 属性値は'"'で囲まれていることを前提。
  * ex.)
  * str="<field no="1">...</field>"
- * ="1"
+ * 返値="1"
  */
 char *mssGetTagAtt(char *str, char *tag, char *att){
 
@@ -269,18 +269,18 @@ char *mssGetTagAtt(char *str, char *tag, char *att){
   char buf[256];
   int i;
 
-  /*begin°̾򥻥åȤ*/
+  /*beginタグ、属性名をセットする*/
   bgnTag=mkStr("<",tag," " );
   attStr=mkStr("" ,att,"=");
 
-  /*beginθ*/
+  /*beginタグの検索*/
   bgnTagTmp=strstr(str, bgnTag);
   if( bgnTagTmp == NULL ){
     mssFree(bgnTag); mssFree(attStr);
     return(NULL);
   }
 
-  /*Ū">"'\0'ˤ롣*/
+  /*一時的に">"を'\0'にする。*/
   pos=bgnTagTmp;
   while(*pos!='>' && *pos!='\0') pos++;
   if(*pos!='>'){
@@ -289,13 +289,13 @@ char *mssGetTagAtt(char *str, char *tag, char *att){
   }
   *pos='\0';
 
-  /*°θ*/
+  /*属性の検索*/
   bgnTagTmp=strstr(bgnTagTmp, attStr);
   if( bgnTagTmp == NULL ){
     retStr=NULL;
   }else{
 
-    /*°ͤΥå*/
+    /*属性値のセット*/
     while(*bgnTagTmp!='"' && *bgnTagTmp!='\0') bgnTagTmp++;
     if(*bgnTagTmp=='\0'){
       mssShowErrMsg("invalid attribute value : %s",att);
@@ -321,11 +321,11 @@ char *mssGetTagAtt(char *str, char *tag, char *att){
 
 /** 
  * # FUNCTION #
- * ȥå׹(xml<xmltbl>)ɤ߹
- * ܤXMLȤߤʤ
- * xmltblиޤǥǡ򥹥åפ롣
- * XMLС󡢥󥳡ǥ󥰤򥻥åȡ
- * xmlTableΥС򥻥åȡ
+ * トップ行(xml宣言、<xmltbl>タグ)の読み込み
+ * １行目はXML宣言とみなす。
+ * xmltblタグが出現するまでデータをスキップする。
+ * XMLバージョン、エンコーディングをセット。
+ * xmlTableのバージョンをセット。
  */
 void mssReadSetTop(struct mssHeader *header, struct mssFPR *fp){
   struct mssRec *rec;
@@ -338,7 +338,7 @@ void mssReadSetTop(struct mssHeader *header, struct mssFPR *fp){
   buf=mssInitStrings();
 
   len=mssReadRec(fp, rec);
-  /*mssReadRecEOFȤȤϥǡʤȤ*/
+  /*mssReadRecでEOFということはデータなしということ*/
   if(len==EOF) {
     mssShowErrMsg("no input data");
     exit(mssErrorNoDefault);
@@ -351,14 +351,14 @@ void mssReadSetTop(struct mssHeader *header, struct mssFPR *fp){
     header->xmlver=mssGetTagAtt(rec->pnt, "?xml", "version");
     header->xmlenc=mssGetTagAtt(rec->pnt, "?xml", "encoding");
     len=mssReadRec(fp, rec);
-    /*mssReadRecEOFȤȤϥǡʤȤ*/
+    /*mssReadRecでEOFということはデータなしということ*/
     if(len==EOF) {
       mssShowErrMsg("no input data");
       exit(mssErrorNoDefault);
     }
   }
 
-  /*xmltblĤޤɤ³*/
+  /*xmltblタグが見つかるまで読み続ける*/
   while(1) {
     pnt=strstr(rec->pnt,"<xmltbl");
     if(pnt!=NULL)break;
@@ -378,16 +378,16 @@ void mssReadSetTop(struct mssHeader *header, struct mssFPR *fp){
     mssShowErrMsg("version of XMLtable is not specified");
     exit(mssErrorNoDefault);
   }
-  mssFree(version); /*ɲ 2004/10/28 */
+  mssFree(version); /*追加 2004/10/28 */
   mssFreeRec(rec);
-  mssFreeStrings(buf);  /*20021126ɲ*/
+  mssFreeStrings(buf);  /*20021126追加*/
 }
 
 /** 
  * # FUNCTION #
- * ǡޤǥåפ롣
- * Ūˤ"<body><![CDATA["μιԤ˥եݥ󥿤ܤ
- * <body>ϰԤ˽񤫤Ƥ뤳Ȥ
+ * データ部までスキップする。
+ * 具体的には"<body><![CDATA["の次の行にファイルポインタを移す
+ * <body>タグは一行に書かれていることが前提
  */
 void mssSkipToBody(struct mssFPR *fp){
   struct mssRec *rec=NULL;
