@@ -1,43 +1,43 @@
 /*
-Tomy(tomy@tk.airnet.ne.jp)꾵(2004/01/25)ʲHPΥѤѤƤޤ꤬Ȥޤ
+Tomy氏(tomy@tk.airnet.ne.jp)より承諾を得て(2004/01/25)以下のHPのソースを一部改変して利用させていただきました。ありがとうございます。
 http://www5.airnet.ne.jp/tomy/cpro/random.htm
 */
 
-/*	random.c	(Pseudo-Random numbers)	*/
+/*	random.c	擬似乱数(Pseudo-Random numbers)	*/
 #include <stdio.h>
 #include <stdlib.h>
 #include <musashi/random.h>
 
 /*#define		DEBUG		 debug routine */
 
-ulong _idum_u0, _idum_u1, _idum_u2;		/* urnd0()urnd6() */
-ulong _idum_u3, _idum_u4, _idum_u5;		/*              */
-ulong _idum_u6;							/*              */
-ulong *_prx, *_prx_end;					/* mrnd()ˤۤѿ */
-ulong _rx[522];							/*              */
-unsigned int r_s1, r_s2, r_s3;			/* rrnd()ˤۤѿ */
-long _idum_o0, _idum_o1, _idum_o2;		/* ornd0()ornd2() */
-long _idum_b, b_nd, b_iy;				/* brnd()ˤۤѿ */
-long b_iv[NTAB];						/*              */
-long _idum_e1, _idum_e2, e_nd, e_iy;	/* ernd()ˤۤѿ */
-long e_iv[NTAB];						/*              */
-long *k_ma_end, *pk1, *pk2;				/* krnd()ˤۤѿ */
-long k_ma[57];							/*              */
-ulong _idum_d;							/* drnd() */
-ulong _idum_q;							/* qrnd() */
-ulong _idum_p0, _idum_p1, _idum_p2;		/* prnd0()prnd33() */
-ulong _idum_p3, _idum_p4, _idum_p5;		/*              */
-ulong _idum_p6, _idum_p7, _idum_p8;		/*              */
-ulong _idum_p9, _idum_p10, _idum_p11;	/*              */
-ulong _idum_p12, _idum_p13, _idum_p14;	/*              */
-ulong _idum_p15, _idum_p16, _idum_p17;	/*              */
-ulong _idum_p18, _idum_p19, _idum_p20;	/*              */
-ulong _idum_p21, _idum_p22, _idum_p23;	/*              */
-ulong _idum_p24, _idum_p25, _idum_p26;	/*              */
-ulong _idum_p27, _idum_p28, _idum_p29;	/*              */
-ulong _idum_p30, _idum_p31, _idum_p32;	/*              */
-ulong _idum_p33;						/*              */
-double (*_rand)(void);					/* ʳǸƤӽФʬ */ 
+ulong _idum_u0, _idum_u1, _idum_u2;		/* urnd0()〜urnd6()の乱数核 */
+ulong _idum_u3, _idum_u4, _idum_u5;		/*      〃        */
+ulong _idum_u6;							/*      〃        */
+ulong *_prx, *_prx_end;					/* mrnd()の乱数核ほか変数 */
+ulong _rx[522];							/*      〃        */
+unsigned int r_s1, r_s2, r_s3;			/* rrnd()の乱数核ほか変数 */
+long _idum_o0, _idum_o1, _idum_o2;		/* ornd0()〜ornd2()の乱数核 */
+long _idum_b, b_nd, b_iy;				/* brnd()の乱数核ほか変数 */
+long b_iv[NTAB];						/*      〃        */
+long _idum_e1, _idum_e2, e_nd, e_iy;	/* ernd()の乱数核ほか変数 */
+long e_iv[NTAB];						/*      〃        */
+long *k_ma_end, *pk1, *pk2;				/* krnd()の乱数核ほか変数 */
+long k_ma[57];							/*      〃        */
+ulong _idum_d;							/* drnd()の乱数核 */
+ulong _idum_q;							/* qrnd()の乱数核 */
+ulong _idum_p0, _idum_p1, _idum_p2;		/* prnd0()〜prnd33()の乱数核 */
+ulong _idum_p3, _idum_p4, _idum_p5;		/*      〃        */
+ulong _idum_p6, _idum_p7, _idum_p8;		/*      〃        */
+ulong _idum_p9, _idum_p10, _idum_p11;	/*      〃        */
+ulong _idum_p12, _idum_p13, _idum_p14;	/*      〃        */
+ulong _idum_p15, _idum_p16, _idum_p17;	/*      〃        */
+ulong _idum_p18, _idum_p19, _idum_p20;	/*      〃        */
+ulong _idum_p21, _idum_p22, _idum_p23;	/*      〃        */
+ulong _idum_p24, _idum_p25, _idum_p26;	/*      〃        */
+ulong _idum_p27, _idum_p28, _idum_p29;	/*      〃        */
+ulong _idum_p30, _idum_p31, _idum_p32;	/*      〃        */
+ulong _idum_p33;						/*      〃        */
+double (*_rand)(void);					/* 一様乱数以外の乱数で呼び出す一様分布乱数 */ 
 double _tri;
 
 
@@ -502,7 +502,7 @@ double rrnd(void)
 	return r - 2.;
 }
 
-double ornd0(void)					/* Park and Miller Ρֺ */
+double ornd0(void)					/* Park and Miller の「最低基準」乱数 */
 {
 	long w;
 	double d = 1. / 2147483647.;
@@ -513,7 +513,7 @@ double ornd0(void)					/* Park and Miller Ρֺ */
 	return (double)_idum_o0 * d;
 }
 
-double ornd1(void)					/* Park and Miller Ρֺ */
+double ornd1(void)					/* Park and Miller の「最低基準」乱数 */
 {
 	long w;
 	double d = 1. / 2147483647.;
@@ -524,7 +524,7 @@ double ornd1(void)					/* Park and Miller Ρֺ */
 	return (double)_idum_o1 * d;
 }
 
-double ornd2(void)					/* Park and Miller Ρֺ */
+double ornd2(void)					/* Park and Miller の「最低基準」乱数 */
 {
 	long w;
 	double d = 1. / 2147483647.;
@@ -955,3 +955,51 @@ void rnd_vector3(double *x, double *y, double *z)
 	*z = 2. * *z - 1.;
 	return;
 }
+
+void shuffle_i(int *a, int n, long seed)
+{
+        int i, m, *p, *q, w;
+
+        init_ornd2(seed);
+        for(i = 0, m = n * 5; i < m; i++)
+        {
+                p = a + (int)(ornd2() * n);
+                q = a + (int)(ornd2() * n);
+                w = *p;
+                *p = *q;
+                *q = w;
+        }
+}
+
+void shuffle_d(double *a, int n, long seed)
+{
+        int i, m;
+        double *p, *q, w;
+
+        init_ornd2(seed);
+        for(i = 0, m = n * 5; i < m; i++)
+        {
+                p = a + (int)(ornd2() * n);
+                q = a + (int)(ornd2() * n);
+                w = *p;
+                *p = *q;
+                *q = w;
+        }
+}
+
+void shuffle_c(unsigned char **a, int n, long seed)
+{
+        int i, m;
+        unsigned char **p, **q, *w;
+
+        init_ornd2(seed);
+        for(i = 0, m = n * 5; i < m; i++)
+        {
+                p = a + (int)(ornd2() * n);
+                q = a + (int)(ornd2() * n);
+                w = *p;
+                *p = *q;
+                *q = w;
+        }
+}
+
